@@ -97,7 +97,7 @@ static ULONG WINAPI holder_AddRef(IHolder *iface)
 {
     holder *This = impl_from_IHolder(iface);
     ULONG ref = InterlockedIncrement(&This->ref);
-    TRACE("(%p)->(%d)\n", This, ref);
+    TRACE("(%p)->(%ld)\n", This, ref);
     return ref;
 }
 
@@ -105,7 +105,7 @@ static ULONG WINAPI holder_Release(IHolder *iface)
 {
     holder *This = impl_from_IHolder(iface);
     ULONG ref = InterlockedDecrement(&This->ref);
-    TRACE("(%p)->(%d)\n", This, ref);
+    TRACE("(%p)->(%ld)\n", This, ref);
 
     if (!ref)
     {
@@ -121,11 +121,11 @@ static HRESULT WINAPI holder_AllocResource(IHolder *iface, const RESTYPID typeid
     HRESULT hr;
     TIMEINSECS secs;
 
-    TRACE("(%p)->(%08lx, %p) stub\n", This, typeid, resid);
+    TRACE("(%p)->(%08Ix, %p) stub\n", This, typeid, resid);
 
     hr = IDispenserDriver_CreateResource(This->driver, typeid, resid, &secs);
 
-    TRACE("<- 0x%08x\n", hr);
+    TRACE("<- 0x%08lx\n", hr);
     return hr;
 }
 
@@ -134,11 +134,11 @@ static HRESULT WINAPI holder_FreeResource(IHolder *iface, const RESID resid)
     holder *This = impl_from_IHolder(iface);
     HRESULT hr;
 
-    TRACE("(%p)->(%08lx) stub\n", This, resid);
+    TRACE("(%p)->(%08Ix) stub\n", This, resid);
 
     hr = IDispenserDriver_DestroyResource(This->driver, resid);
 
-    TRACE("<- 0x%08x\n", hr);
+    TRACE("<- 0x%08lx\n", hr);
 
     return hr;
 }
@@ -147,7 +147,7 @@ static HRESULT WINAPI holder_TrackResource(IHolder *iface, const RESID resid)
 {
     holder *This = impl_from_IHolder(iface);
 
-    FIXME("(%p)->(%08lx) stub\n", This, resid);
+    FIXME("(%p)->(%08Ix) stub\n", This, resid);
 
     return E_NOTIMPL;
 }
@@ -165,7 +165,7 @@ static HRESULT WINAPI holder_UntrackResource(IHolder *iface, const RESID resid,
 {
     holder *This = impl_from_IHolder(iface);
 
-    FIXME("(%p)->(%08lx, %d) stub\n", This, resid, value);
+    FIXME("(%p)->(%08Ix, %d) stub\n", This, resid, value);
 
     return E_NOTIMPL;
 }
@@ -194,7 +194,7 @@ static HRESULT WINAPI holder_RequestDestroyResource(IHolder *iface, const RESID
 {
     holder *This = impl_from_IHolder(iface);
 
-    FIXME("(%p)->(%08lx) stub\n", This, resid);
+    FIXME("(%p)->(%08Ix) stub\n", This, resid);
 
     return E_NOTIMPL;
 }
@@ -263,7 +263,7 @@ static ULONG WINAPI dismanager_AddRef(IDispenserManager *iface)
 {
     dispensermanager *This = impl_from_IDispenserManager(iface);
     ULONG ref = InterlockedIncrement(&This->ref);
-    TRACE("(%p)->(%d)\n", This, ref);
+    TRACE("(%p)->(%ld)\n", This, ref);
     return ref;
 }
 
@@ -271,7 +271,7 @@ static ULONG WINAPI dismanager_Release(IDispenserManager *iface)
 {
     dispensermanager *This = impl_from_IDispenserManager(iface);
     ULONG ref = InterlockedDecrement(&This->ref);
-    TRACE("(%p)->(%d)\n", This, ref);
+    TRACE("(%p)->(%ld)\n", This, ref);
 
     if (!ref)
     {
@@ -299,7 +299,7 @@ static HRESULT WINAPI dismanager_RegisterDispenser(IDispenserManager *iface, IDi
     if (!This->mta_cookie)
         CoIncrementMTAUsage(&This->mta_cookie);
 
-    TRACE("<-- 0x%08x, %p\n", hr, *dispenser);
+    TRACE("<-- 0x%08lx, %p\n", hr, *dispenser);
 
     return hr;
 }
@@ -429,7 +429,7 @@ static ULONG WINAPI new_moniker_AddRef(IMoniker* iface)
     struct new_moniker *moniker = impl_from_IMoniker(iface);
     ULONG refcount = InterlockedIncrement(&moniker->refcount);
 
-    TRACE("%p, refcount %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     return refcount;
 }
@@ -439,7 +439,7 @@ static ULONG WINAPI new_moniker_Release(IMoniker* iface)
     struct new_moniker *moniker = impl_from_IMoniker(iface);
     ULONG refcount = InterlockedDecrement(&moniker->refcount);
 
-    TRACE("%p, refcount %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     if (!refcount)
     {
@@ -600,7 +600,7 @@ static HRESULT WINAPI new_moniker_BindToStorage(IMoniker *iface, IBindCtx *pbc,
 static HRESULT WINAPI new_moniker_Reduce(IMoniker *iface, IBindCtx *pbc, DWORD flags, IMoniker **ppmkToLeft,
         IMoniker **ret)
 {
-    TRACE("%p, %p, %d, %p, %p.\n", iface, pbc, flags, ppmkToLeft, ret);
+    TRACE("%p, %p, %ld, %p, %p.\n", iface, pbc, flags, ppmkToLeft, ret);
 
     if (!ret)
         return E_POINTER;
@@ -758,7 +758,7 @@ static ULONG WINAPI new_moniker_rotdata_Release(IROTData *iface)
 
 static HRESULT WINAPI new_moniker_rotdata_GetComparisonData(IROTData *iface, byte *data, ULONG data_len, ULONG *length)
 {
-    FIXME("%p, %p, %u, %p.\n", iface, data, data_len, length);
+    FIXME("%p, %p, %lu, %p.\n", iface, data, data_len, length);
 
     return E_NOTIMPL;
 }
