@@ -52,7 +52,7 @@ static ULONG STDMETHODCALLTYPE d2d_bitmap_AddRef(ID2D1Bitmap1 *iface)
     struct d2d_bitmap *bitmap = impl_from_ID2D1Bitmap1(iface);
     ULONG refcount = InterlockedIncrement(&bitmap->refcount);
 
-    TRACE("%p increasing refcount to %u.\n", iface, refcount);
+    TRACE("%p increasing refcount to %lu.\n", iface, refcount);
 
     return refcount;
 }
@@ -62,7 +62,7 @@ static ULONG STDMETHODCALLTYPE d2d_bitmap_Release(ID2D1Bitmap1 *iface)
     struct d2d_bitmap *bitmap = impl_from_ID2D1Bitmap1(iface);
     ULONG refcount = InterlockedDecrement(&bitmap->refcount);
 
-    TRACE("%p decreasing refcount to %u.\n", iface, refcount);
+    TRACE("%p decreasing refcount to %lu.\n", iface, refcount);
 
     if (!refcount)
     {
@@ -133,9 +133,33 @@ static void STDMETHODCALLTYPE d2d_bitmap_GetDpi(ID2D1Bitmap1 *iface, float *dpi_
 static HRESULT STDMETHODCALLTYPE d2d_bitmap_CopyFromBitmap(ID2D1Bitmap1 *iface,
         const D2D1_POINT_2U *dst_point, ID2D1Bitmap *bitmap, const D2D1_RECT_U *src_rect)
 {
-    FIXME("iface %p, dst_point %p, bitmap %p, src_rect %p stub!\n", iface, dst_point, bitmap, src_rect);
+    struct d2d_bitmap *src_bitmap = unsafe_impl_from_ID2D1Bitmap(bitmap);
+    struct d2d_bitmap *dst_bitmap = impl_from_ID2D1Bitmap1(iface);
+    ID3D11DeviceContext *context;
+    ID3D11Device *device;
+    D3D11_BOX box;
 
-    return E_NOTIMPL;
+    TRACE("iface %p, dst_point %p, bitmap %p, src_rect %p.\n", iface, dst_point, bitmap, src_rect);
+
+    if (src_rect)
+    {
+        box.left = src_rect->left;
+        box.top = src_rect->top;
+        box.front = 0;
+        box.right = src_rect->right;
+        box.bottom = src_rect->bottom;
+        box.back = 1;
+    }
+
+    ID3D11Resource_GetDevice(dst_bitmap->resource, &device);
+    ID3D11Device_GetImmediateContext(device, &context);
+    ID3D11DeviceContext_CopySubresourceRegion(context, dst_bitmap->resource, 0,
+            dst_point ? dst_point->x : 0, dst_point ? dst_point->y : 0, 0,
+            src_bitmap->resource, 0, src_rect ? &box : NULL);
+    ID3D11DeviceContext_Release(context);
+    ID3D11Device_Release(device);
+
+    return S_OK;
 }
 
 static HRESULT STDMETHODCALLTYPE d2d_bitmap_CopyFromRenderTarget(ID2D1Bitmap1 *iface,
@@ -295,13 +319,13 @@ static void d2d_bitmap_init(struct d2d_bitmap *bitmap, struct d2d_device_context
     if (bitmap->options & D2D1_BITMAP_OPTIONS_TARGET)
     {
         if (FAILED(hr = ID3D11Device_CreateRenderTargetView(d3d_device, resource, NULL, &bitmap->rtv)))
-            WARN("Failed to create RTV, hr %#x.\n", hr);
+            WARN("Failed to create RTV, hr %#lx.\n", hr);
     }
 
     if (!(bitmap->options & D2D1_BITMAP_OPTIONS_CANNOT_DRAW))
     {
         if (FAILED(hr = ID3D11Device_CreateShaderResourceView(d3d_device, resource, NULL, &bitmap->srv)))
-            WARN("Failed to create SRV, hr %#x.\n", hr);
+            WARN("Failed to create SRV, hr %#lx.\n", hr);
     }
     ID3D11Device_Release(d3d_device);
 
@@ -366,7 +390,7 @@ HRESULT d2d_bitmap_create(struct d2d_device_context *context, D2D1_SIZE_U size,
     if (FAILED(hr = ID3D11Device1_CreateTexture2D(context->d3d_device, &texture_desc,
             src_data ? &resource_data : NULL, &texture)))
     {
-        ERR("Failed to create texture, hr %#x.\n", hr);
+        ERR("Failed to create texture, hr %#lx.\n", hr);
         return hr;
     }
 
@@ -468,7 +492,7 @@ HRESULT d2d_bitmap_create_shared(struct d2d_device_context *context, REFIID iid,
 
         if (FAILED(hr = IDXGISurface_GetDesc(surface, &surface_desc)))
         {
-            WARN("Failed to get surface desc, hr %#x.\n", hr);
+            WARN("Failed to get surface desc, hr %#lx.\n", hr);
             ID3D11Resource_Release(resource);
             return hr;
         }
@@ -536,7 +560,7 @@ HRESULT d2d_bitmap_create_from_wic_bitmap(struct d2d_device_context *context, IW
 
     if (FAILED(hr = IWICBitmapSource_GetSize(bitmap_source, &size.width, &size.height)))
     {
-        WARN("Failed to get bitmap size, hr %#x.\n", hr);
+        WARN("Failed to get bitmap size, hr %#lx.\n", hr);
         return hr;
     }
 
@@ -556,7 +580,7 @@ HRESULT d2d_bitmap_create_from_wic_bitmap(struct d2d_device_context *context, IW
 
     if (FAILED(hr = IWICBitmapSource_GetPixelFormat(bitmap_source, &wic_format)))
     {
-        WARN("Failed to get bitmap format, hr %#x.\n", hr);
+        WARN("Failed to get bitmap format, hr %#lx.\n", hr);
         return hr;
     }
 
@@ -605,7 +629,7 @@ HRESULT d2d_bitmap_create_from_wic_bitmap(struct d2d_device_context *context, IW
     rect.Height = size.height;
     if (FAILED(hr = IWICBitmapSource_CopyPixels(bitmap_source, &rect, pitch, data_size, data)))
     {
-        WARN("Failed to copy bitmap pixels, hr %#x.\n", hr);
+        WARN("Failed to copy bitmap pixels, hr %#lx.\n", hr);
         heap_free(data);
         return hr;
     }
