@@ -102,7 +102,7 @@ static ULONG STDMETHODCALLTYPE d2d_factory_AddRef(ID2D1Factory2 *iface)
     struct d2d_factory *factory = impl_from_ID2D1Factory2(iface);
     ULONG refcount = InterlockedIncrement(&factory->refcount);
 
-    TRACE("%p increasing refcount to %u.\n", iface, refcount);
+    TRACE("%p increasing refcount to %lu.\n", iface, refcount);
 
     return refcount;
 }
@@ -112,7 +112,7 @@ static ULONG STDMETHODCALLTYPE d2d_factory_Release(ID2D1Factory2 *iface)
     struct d2d_factory *factory = impl_from_ID2D1Factory2(iface);
     ULONG refcount = InterlockedDecrement(&factory->refcount);
 
-    TRACE("%p decreasing refcount to %u.\n", iface, refcount);
+    TRACE("%p decreasing refcount to %lu.\n", iface, refcount);
 
     if (!refcount)
     {
@@ -157,7 +157,7 @@ static HRESULT STDMETHODCALLTYPE d2d_factory_CreateRectangleGeometry(ID2D1Factor
 
     if (FAILED(hr = d2d_rectangle_geometry_init(object, (ID2D1Factory *)iface, rect)))
     {
-        WARN("Failed to initialize rectangle geometry, hr %#x.\n", hr);
+        WARN("Failed to initialise rectangle geometry, hr %#lx.\n", hr);
         heap_free(object);
         return hr;
     }
@@ -181,7 +181,7 @@ static HRESULT STDMETHODCALLTYPE d2d_factory_CreateRoundedRectangleGeometry(ID2D
 
     if (FAILED(hr = d2d_rounded_rectangle_geometry_init(object, (ID2D1Factory *)iface, rounded_rect)))
     {
-        WARN("Failed to initialize rounded rectangle geometry, hr %#x.\n", hr);
+        WARN("Failed to initialise rounded rectangle geometry, hr %#lx.\n", hr);
         heap_free(object);
         return hr;
     }
@@ -205,7 +205,7 @@ static HRESULT STDMETHODCALLTYPE d2d_factory_CreateEllipseGeometry(ID2D1Factory2
 
     if (FAILED(hr = d2d_ellipse_geometry_init(object, (ID2D1Factory *)iface, ellipse)))
     {
-        WARN("Failed to initialize ellipse geometry, hr %#x.\n", hr);
+        WARN("Failed to initialise ellipse geometry, hr %#lx.\n", hr);
         heap_free(object);
         return hr;
     }
@@ -230,7 +230,7 @@ static HRESULT STDMETHODCALLTYPE d2d_factory_CreateGeometryGroup(ID2D1Factory2 *
 
     if (FAILED(hr = d2d_geometry_group_init(object, (ID2D1Factory *)iface, fill_mode, geometries, geometry_count)))
     {
-        WARN("Failed to initialize geometry group, hr %#x.\n", hr);
+        WARN("Failed to initialise geometry group, hr %#lx.\n", hr);
         heap_free(object);
         return hr;
     }
@@ -283,6 +283,7 @@ static HRESULT STDMETHODCALLTYPE d2d_factory_CreateStrokeStyle(ID2D1Factory2 *if
         ID2D1StrokeStyle **stroke_style)
 {
     struct d2d_stroke_style *object;
+    D2D1_STROKE_STYLE_PROPERTIES1 desc1;
     HRESULT hr;
 
     TRACE("iface %p, desc %p, dashes %p, dash_count %u, stroke_style %p.\n",
@@ -291,15 +292,24 @@ static HRESULT STDMETHODCALLTYPE d2d_factory_CreateStrokeStyle(ID2D1Factory2 *if
     if (!(object = heap_alloc_zero(sizeof(*object))))
         return E_OUTOFMEMORY;
 
-    if (FAILED(hr = d2d_stroke_style_init(object, (ID2D1Factory *)iface, desc, dashes, dash_count)))
+    desc1.startCap = desc->startCap;
+    desc1.endCap = desc->endCap;
+    desc1.dashCap = desc->dashCap;
+    desc1.lineJoin = desc->lineJoin;
+    desc1.miterLimit = desc->miterLimit;
+    desc1.dashStyle = desc->dashStyle;
+    desc1.dashOffset = desc->dashOffset;
+    desc1.transformType = D2D1_STROKE_TRANSFORM_TYPE_NORMAL;
+
+    if (FAILED(hr = d2d_stroke_style_init(object, (ID2D1Factory *)iface, &desc1, dashes, dash_count)))
     {
-        WARN("Failed to initialize stroke style, hr %#x.\n", hr);
+        WARN("Failed to initialise stroke style, hr %#lx.\n", hr);
         heap_free(object);
         return hr;
     }
 
     TRACE("Created stroke style %p.\n", object);
-    *stroke_style = &object->ID2D1StrokeStyle_iface;
+    *stroke_style = (ID2D1StrokeStyle *)&object->ID2D1StrokeStyle1_iface;
 
     return S_OK;
 }
@@ -338,7 +348,7 @@ static HRESULT d2d_factory_get_device(struct d2d_factory *factory, ID3D10Device1
 
     if (!factory->device && FAILED(hr = D3D10CreateDevice1(NULL, D3D10_DRIVER_TYPE_HARDWARE, NULL, D3D10_CREATE_DEVICE_BGRA_SUPPORT,
             D3D10_FEATURE_LEVEL_10_0, D3D10_1_SDK_VERSION, &factory->device)))
-        WARN("Failed to create device, hr %#x.\n", hr);
+        WARN("Failed to create device, hr %#lx.\n", hr);
 
     *device = factory->device;
     return hr;
@@ -365,7 +375,7 @@ static HRESULT STDMETHODCALLTYPE d2d_factory_CreateWicBitmapRenderTarget(ID2D1Fa
 
     if (FAILED(hr = d2d_wic_render_target_init(object, (ID2D1Factory1 *)iface, device, target, desc)))
     {
-        WARN("Failed to initialize render target, hr %#x.\n", hr);
+        WARN("Failed to initialise render target, hr %#lx.\n", hr);
         heap_free(object);
         return hr;
     }
@@ -395,7 +405,7 @@ static HRESULT STDMETHODCALLTYPE d2d_factory_CreateHwndRenderTarget(ID2D1Factory
 
     if (FAILED(hr = d2d_hwnd_render_target_init(object, (ID2D1Factory1 *)iface, device, desc, hwnd_rt_desc)))
     {
-        WARN("Failed to initialize render target, hr %#x.\n", hr);
+        WARN("Failed to initialise render target, hr %#lx.\n", hr);
         heap_free(object);
         return hr;
     }
@@ -417,7 +427,7 @@ static HRESULT STDMETHODCALLTYPE d2d_factory_CreateDxgiSurfaceRenderTarget(ID2D1
 
     if (FAILED(hr = IDXGISurface_GetDevice(surface, &IID_IDXGIDevice, (void **)&dxgi_device)))
     {
-        WARN("Failed to get DXGI device, hr %#x.\n", hr);
+        WARN("Failed to get DXGI device, hr %#lx.\n", hr);
         return hr;
     }
 
@@ -425,7 +435,7 @@ static HRESULT STDMETHODCALLTYPE d2d_factory_CreateDxgiSurfaceRenderTarget(ID2D1
     IDXGIDevice_Release(dxgi_device);
     if (FAILED(hr))
     {
-        WARN("Failed to create D2D device, hr %#x.\n", hr);
+        WARN("Failed to create D2D device, hr %#lx.\n", hr);
         return hr;
     }
 
@@ -452,7 +462,7 @@ static HRESULT STDMETHODCALLTYPE d2d_factory_CreateDCRenderTarget(ID2D1Factory2
 
     if (FAILED(hr = d2d_dc_render_target_init(object, (ID2D1Factory1 *)iface, device, desc)))
     {
-        WARN("Failed to initialize render target, hr %#x.\n", hr);
+        WARN("Failed to initialise render target, hr %#lx.\n", hr);
         heap_free(object);
         return hr;
     }
@@ -485,10 +495,27 @@ static HRESULT STDMETHODCALLTYPE d2d_factory_CreateStrokeStyle1(ID2D1Factory2 *i
         const D2D1_STROKE_STYLE_PROPERTIES1 *desc, const float *dashes, UINT32 dash_count,
         ID2D1StrokeStyle1 **stroke_style)
 {
-    FIXME("iface %p, desc %p, dashes %p, dash_count %u, stroke_style %p stub!\n",
+    struct d2d_stroke_style *object;
+    HRESULT hr;
+
+    TRACE("iface %p, desc %p, dashes %p, dash_count %u, stroke_style %p.\n",
             iface, desc, dashes, dash_count, stroke_style);
 
-    return E_NOTIMPL;
+    if (!(object = heap_alloc_zero(sizeof(*object))))
+        return E_OUTOFMEMORY;
+
+    if (FAILED(hr = d2d_stroke_style_init(object, (ID2D1Factory *)iface,
+            desc, dashes, dash_count)))
+    {
+        WARN("Failed to initialise stroke style, hr %#lx.\n", hr);
+        heap_free(object);
+        return hr;
+    }
+
+    TRACE("Created stroke style %p.\n", object);
+    *stroke_style = &object->ID2D1StrokeStyle1_iface;
+
+    return S_OK;
 }
 
 static HRESULT STDMETHODCALLTYPE d2d_factory_CreatePathGeometry1(ID2D1Factory2 *iface, ID2D1PathGeometry1 **geometry)
@@ -639,7 +666,7 @@ static void STDMETHODCALLTYPE d2d_factory_mt_Enter(ID2D1Multithread *iface)
 
     TRACE("%p.\n", iface);
 
-    return EnterCriticalSection(&factory->cs);
+    EnterCriticalSection(&factory->cs);
 }
 
 static void STDMETHODCALLTYPE d2d_factory_mt_Leave(ID2D1Multithread *iface)
@@ -648,7 +675,7 @@ static void STDMETHODCALLTYPE d2d_factory_mt_Leave(ID2D1Multithread *iface)
 
     TRACE("%p.\n", iface);
 
-    return LeaveCriticalSection(&factory->cs);
+    LeaveCriticalSection(&factory->cs);
 }
 
 static BOOL STDMETHODCALLTYPE d2d_factory_st_GetMultithreadProtected(ID2D1Multithread *iface)
@@ -910,9 +937,10 @@ D2D1_COLOR_F WINAPI D2D1ConvertColorSpace(D2D1_COLOR_SPACE src_colour_space,
     return ret;
 }
 
-static BOOL get_config_key_dword(HKEY default_key, HKEY application_key, const char *name, DWORD *value)
+static bool get_config_key_u32(HKEY default_key, HKEY application_key, const char *name, uint32_t *value)
 {
-    DWORD type, data, size;
+    DWORD type, size;
+    uint32_t data;
 
     size = sizeof(data);
     if (application_key && !RegQueryValueExA(application_key,
@@ -924,11 +952,11 @@ static BOOL get_config_key_dword(HKEY default_key, HKEY application_key, const c
             name, 0, &type, (BYTE *)&data, &size) && type == REG_DWORD)
         goto success;
 
-    return FALSE;
+    return false;
 
 success:
     *value = data;
-    return TRUE;
+    return true;
 }
 
 static void d2d_settings_init(void)
@@ -962,7 +990,7 @@ static void d2d_settings_init(void)
     if (!default_key && !application_key)
         return;
 
-    if (get_config_key_dword(default_key, application_key, "max_version_factory", &d2d_settings.max_version_factory))
+    if (get_config_key_u32(default_key, application_key, "max_version_factory", &d2d_settings.max_version_factory))
         ERR_(winediag)("Limiting maximum Direct2D factory version to %#x.\n", d2d_settings.max_version_factory);
 
     if (application_key)
