@@ -72,12 +72,8 @@ static PFN_vkGetInstanceProcAddr load_vulkan(void)
 static PFN_vkGetInstanceProcAddr load_vulkan(void)
 {
     const struct vulkan_funcs *vk_funcs;
-    HDC hdc;
-
-    hdc = GetDC(0);
-    vk_funcs = __wine_get_vulkan_driver(hdc, WINE_VULKAN_DRIVER_VERSION);
-    ReleaseDC(0, hdc);
 
+    vk_funcs = __wine_get_vulkan_driver(WINE_VULKAN_DRIVER_VERSION);
     if (vk_funcs)
         return (PFN_vkGetInstanceProcAddr)vk_funcs->p_vkGetInstanceProcAddr;
 
