@@ -36,7 +36,7 @@ enum D3DCOMPILER_SIGNATURE_ELEMENT_SIZE
 struct d3dcompiler_shader_signature
 {
     D3D11_SIGNATURE_PARAMETER_DESC *elements;
-    UINT element_count;
+    unsigned int element_count;
     char *string_data;
 };
 
@@ -45,7 +45,7 @@ struct d3dcompiler_shader_reflection_type
     ID3D11ShaderReflectionType ID3D11ShaderReflectionType_iface;
     ID3D10ShaderReflectionType ID3D10ShaderReflectionType_iface;
 
-    DWORD id;
+    uint32_t id;
     struct wine_rb_entry entry;
 
     struct d3dcompiler_shader_reflection *reflection;
@@ -58,7 +58,7 @@ struct d3dcompiler_shader_reflection_type
 struct d3dcompiler_shader_reflection_type_member
 {
     char *name;
-    DWORD offset;
+    uint32_t offset;
     struct d3dcompiler_shader_reflection_type *type;
 };
 
@@ -109,7 +109,7 @@ struct d3dcompiler_shader_reflection
 
     enum D3DCOMPILER_REFLECTION_VERSION interface_version;
 
-    DWORD target;
+    uint32_t target;
     char *creator;
     UINT flags;
     UINT version;
@@ -124,6 +124,7 @@ struct d3dcompiler_shader_reflection
     UINT gs_max_output_vertex_count;
     D3D_PRIMITIVE input_primitive;
     UINT cut_instruction_count;
+    UINT def_count;
     UINT dcl_count;
     UINT static_flow_control_count;
     UINT float_instruction_count;
@@ -138,9 +139,10 @@ struct d3dcompiler_shader_reflection
     UINT texture_bias_instructions;
     UINT texture_gradient_instructions;
     UINT dynamic_flow_control_count;
+    UINT macro_instruction_count;
     UINT c_control_points;
     D3D_TESSELLATOR_OUTPUT_PRIMITIVE hs_output_primitive;
-    D3D_TESSELLATOR_PARTITIONING hs_prtitioning;
+    D3D_TESSELLATOR_PARTITIONING hs_partitioning;
     D3D_TESSELLATOR_DOMAIN tessellator_domain;
 
     struct d3dcompiler_shader_signature *isgn;
@@ -152,7 +154,7 @@ struct d3dcompiler_shader_reflection
     struct wine_rb_tree types;
 };
 
-static struct d3dcompiler_shader_reflection_type *get_reflection_type(struct d3dcompiler_shader_reflection *reflection, const char *data, DWORD offset);
+static struct d3dcompiler_shader_reflection_type *get_reflection_type(struct d3dcompiler_shader_reflection *reflection, const char *data, uint32_t offset);
 
 static const struct ID3D11ShaderReflectionConstantBufferVtbl d3dcompiler_shader_reflection_constant_buffer_vtbl;
 static const struct ID3D11ShaderReflectionVariableVtbl d3dcompiler_shader_reflection_variable_vtbl;
@@ -205,7 +207,7 @@ static BOOL copy_name(const char *ptr, char **name)
     return TRUE;
 }
 
-static BOOL copy_value(const char *ptr, void **value, DWORD size)
+static BOOL copy_value(const char *ptr, void **value, uint32_t size)
 {
     if (!ptr || !size) return TRUE;
 
@@ -224,7 +226,7 @@ static BOOL copy_value(const char *ptr, void **value, DWORD size)
 static int d3dcompiler_shader_reflection_type_compare(const void *key, const struct wine_rb_entry *entry)
 {
     const struct d3dcompiler_shader_reflection_type *t = WINE_RB_ENTRY_VALUE(entry, const struct d3dcompiler_shader_reflection_type, entry);
-    const DWORD *id = key;
+    const uint32_t *id = key;
 
     return *id - t->id;
 }
@@ -360,7 +362,7 @@ static ULONG STDMETHODCALLTYPE d3dcompiler_shader_reflection_AddRef(ID3D11Shader
     struct d3dcompiler_shader_reflection *This = impl_from_ID3D11ShaderReflection(iface);
     ULONG refcount = InterlockedIncrement(&This->refcount);
 
-    TRACE("%p increasing refcount to %u\n", This, refcount);
+    TRACE("%p increasing refcount to %lu.\n", This, refcount);
 
     return refcount;
 }
@@ -370,7 +372,7 @@ static ULONG STDMETHODCALLTYPE d3dcompiler_shader_reflection_Release(ID3D11Shade
     struct d3dcompiler_shader_reflection *This = impl_from_ID3D11ShaderReflection(iface);
     ULONG refcount = InterlockedDecrement(&This->refcount);
 
-    TRACE("%p decreasing refcount to %u\n", This, refcount);
+    TRACE("%p decreasing refcount to %lu.\n", This, refcount);
 
     if (!refcount)
     {
@@ -385,7 +387,7 @@ static ULONG STDMETHODCALLTYPE d3dcompiler_shader_reflection_Release(ID3D11Shade
 
 static HRESULT STDMETHODCALLTYPE d3dcompiler_shader_reflection_GetDesc(ID3D11ShaderReflection *iface, D3D11_SHADER_DESC *desc)
 {
-    struct d3dcompiler_shader_reflection *This = impl_from_ID3D11ShaderReflection(iface);
+    struct d3dcompiler_shader_reflection *reflection = impl_from_ID3D11ShaderReflection(iface);
 
     FIXME("iface %p, desc %p partial stub!\n", iface, desc);
 
@@ -395,41 +397,41 @@ static HRESULT STDMETHODCALLTYPE d3dcompiler_shader_reflection_GetDesc(ID3D11Sha
         return E_FAIL;
     }
 
-    desc->Version = This->version;
-    desc->Creator = This->creator;
-    desc->Flags = This->flags;
-    desc->ConstantBuffers = This->constant_buffer_count;
-    desc->BoundResources = This->bound_resource_count;
-    desc->InputParameters = This->isgn ? This->isgn->element_count : 0;
-    desc->OutputParameters = This->osgn ? This->osgn->element_count : 0;
-    desc->InstructionCount = This->instruction_count;
-    desc->TempRegisterCount = This->temp_register_count;
-    desc->TempArrayCount = This->temp_array_count;
-    desc->DefCount = 0;
-    desc->DclCount = This->dcl_count;
-    desc->TextureNormalInstructions = This->texture_normal_instructions;
-    desc->TextureLoadInstructions = This->texture_load_instructions;
-    desc->TextureCompInstructions = This->texture_comp_instructions;
-    desc->TextureBiasInstructions = This->texture_bias_instructions;
-    desc->TextureGradientInstructions = This->texture_gradient_instructions;
-    desc->FloatInstructionCount = This->float_instruction_count;
-    desc->IntInstructionCount = This->int_instruction_count;
-    desc->UintInstructionCount = This->uint_instruction_count;
-    desc->StaticFlowControlCount = This->static_flow_control_count;
-    desc->DynamicFlowControlCount = This->dynamic_flow_control_count;
-    desc->MacroInstructionCount = 0;
-    desc->ArrayInstructionCount = This->array_instruction_count;
-    desc->CutInstructionCount = This->cut_instruction_count;
-    desc->EmitInstructionCount = This->emit_instruction_count;
-    desc->GSOutputTopology = This->gs_output_topology;
-    desc->GSMaxOutputVertexCount = This->gs_max_output_vertex_count;
-    desc->InputPrimitive = This->input_primitive;
-    desc->PatchConstantParameters = This->pcsg ? This->pcsg->element_count : 0;
+    desc->Version = reflection->version;
+    desc->Creator = reflection->creator;
+    desc->Flags = reflection->flags;
+    desc->ConstantBuffers = reflection->constant_buffer_count;
+    desc->BoundResources = reflection->bound_resource_count;
+    desc->InputParameters = reflection->isgn ? reflection->isgn->element_count : 0;
+    desc->OutputParameters = reflection->osgn ? reflection->osgn->element_count : 0;
+    desc->InstructionCount = reflection->instruction_count;
+    desc->TempRegisterCount = reflection->temp_register_count;
+    desc->TempArrayCount = reflection->temp_array_count;
+    desc->DefCount = reflection->def_count;
+    desc->DclCount = reflection->dcl_count;
+    desc->TextureNormalInstructions = reflection->texture_normal_instructions;
+    desc->TextureLoadInstructions = reflection->texture_load_instructions;
+    desc->TextureCompInstructions = reflection->texture_comp_instructions;
+    desc->TextureBiasInstructions = reflection->texture_bias_instructions;
+    desc->TextureGradientInstructions = reflection->texture_gradient_instructions;
+    desc->FloatInstructionCount = reflection->float_instruction_count;
+    desc->IntInstructionCount = reflection->int_instruction_count;
+    desc->UintInstructionCount = reflection->uint_instruction_count;
+    desc->StaticFlowControlCount = reflection->static_flow_control_count;
+    desc->DynamicFlowControlCount = reflection->dynamic_flow_control_count;
+    desc->MacroInstructionCount = reflection->macro_instruction_count;
+    desc->ArrayInstructionCount = reflection->array_instruction_count;
+    desc->CutInstructionCount = reflection->cut_instruction_count;
+    desc->EmitInstructionCount = reflection->emit_instruction_count;
+    desc->GSOutputTopology = reflection->gs_output_topology;
+    desc->GSMaxOutputVertexCount = reflection->gs_max_output_vertex_count;
+    desc->InputPrimitive = reflection->input_primitive;
+    desc->PatchConstantParameters = reflection->pcsg ? reflection->pcsg->element_count : 0;
     desc->cGSInstanceCount = 0;
-    desc->cControlPoints = This->c_control_points;
-    desc->HSOutputPrimitive = This->hs_output_primitive;
-    desc->HSPartitioning = This->hs_prtitioning;
-    desc->TessellatorDomain = This->tessellator_domain;
+    desc->cControlPoints = reflection->c_control_points;
+    desc->HSOutputPrimitive = reflection->hs_output_primitive;
+    desc->HSPartitioning = reflection->hs_partitioning;
+    desc->TessellatorDomain = reflection->tessellator_domain;
     desc->cBarrierInstructions = 0;
     desc->cInterlockedInstructions = 0;
     desc->cTextureStoreInstructions = 0;
@@ -1085,117 +1087,119 @@ static const struct ID3D11ShaderReflectionTypeVtbl d3dcompiler_shader_reflection
     d3dcompiler_shader_reflection_type_ImplementsInterface,
 };
 
-static HRESULT d3dcompiler_parse_stat(struct d3dcompiler_shader_reflection *r, const char *data, DWORD data_size)
+static HRESULT d3dcompiler_parse_stat(struct d3dcompiler_shader_reflection *r, const char *data, size_t data_size)
 {
     const char *ptr = data;
-    DWORD size = data_size >> 2;
+    size_t size = data_size >> 2;
 
-    TRACE("Size %u\n", size);
+    TRACE("Size %Iu.\n", size);
 
-    read_dword(&ptr, &r->instruction_count);
-    TRACE("InstructionCount: %u\n", r->instruction_count);
+    r->instruction_count = read_u32(&ptr);
+    TRACE("InstructionCount: %u.\n", r->instruction_count);
 
-    read_dword(&ptr, &r->temp_register_count);
-    TRACE("TempRegisterCount: %u\n", r->temp_register_count);
+    r->temp_register_count = read_u32(&ptr);
+    TRACE("TempRegisterCount: %u.\n", r->temp_register_count);
 
-    skip_dword_unknown(&ptr, 1);
+    r->def_count = read_u32(&ptr);
+    TRACE("DefCount: %u.\n", r->def_count);
 
-    read_dword(&ptr, &r->dcl_count);
-    TRACE("DclCount: %u\n", r->dcl_count);
+    r->dcl_count = read_u32(&ptr);
+    TRACE("DclCount: %u.\n", r->dcl_count);
 
-    read_dword(&ptr, &r->float_instruction_count);
-    TRACE("FloatInstructionCount: %u\n", r->float_instruction_count);
+    r->float_instruction_count = read_u32(&ptr);
+    TRACE("FloatInstructionCount: %u.\n", r->float_instruction_count);
 
-    read_dword(&ptr, &r->int_instruction_count);
-    TRACE("IntInstructionCount: %u\n", r->int_instruction_count);
+    r->int_instruction_count = read_u32(&ptr);
+    TRACE("IntInstructionCount: %u.\n", r->int_instruction_count);
 
-    read_dword(&ptr, &r->uint_instruction_count);
-    TRACE("UintInstructionCount: %u\n", r->uint_instruction_count);
+    r->uint_instruction_count = read_u32(&ptr);
+    TRACE("UintInstructionCount: %u.\n", r->uint_instruction_count);
 
-    read_dword(&ptr, &r->static_flow_control_count);
-    TRACE("StaticFlowControlCount: %u\n", r->static_flow_control_count);
+    r->static_flow_control_count = read_u32(&ptr);
+    TRACE("StaticFlowControlCount: %u.\n", r->static_flow_control_count);
 
-    read_dword(&ptr, &r->dynamic_flow_control_count);
-    TRACE("DynamicFlowControlCount: %u\n", r->dynamic_flow_control_count);
+    r->dynamic_flow_control_count = read_u32(&ptr);
+    TRACE("DynamicFlowControlCount: %u.\n", r->dynamic_flow_control_count);
 
-    skip_dword_unknown(&ptr, 1);
+    r->macro_instruction_count = read_u32(&ptr);
+    TRACE("MacroInstructionCount: %u.\n", r->macro_instruction_count);
 
-    read_dword(&ptr, &r->temp_array_count);
-    TRACE("TempArrayCount: %u\n", r->temp_array_count);
+    r->temp_array_count = read_u32(&ptr);
+    TRACE("TempArrayCount: %u.\n", r->temp_array_count);
 
-    read_dword(&ptr, &r->array_instruction_count);
-    TRACE("ArrayInstructionCount: %u\n", r->array_instruction_count);
+    r->array_instruction_count = read_u32(&ptr);
+    TRACE("ArrayInstructionCount: %u.\n", r->array_instruction_count);
 
-    read_dword(&ptr, &r->cut_instruction_count);
-    TRACE("CutInstructionCount: %u\n", r->cut_instruction_count);
+    r->cut_instruction_count = read_u32(&ptr);
+    TRACE("CutInstructionCount: %u.\n", r->cut_instruction_count);
 
-    read_dword(&ptr, &r->emit_instruction_count);
-    TRACE("EmitInstructionCount: %u\n", r->emit_instruction_count);
+    r->emit_instruction_count = read_u32(&ptr);
+    TRACE("EmitInstructionCount: %u.\n", r->emit_instruction_count);
 
-    read_dword(&ptr, &r->texture_normal_instructions);
-    TRACE("TextureNormalInstructions: %u\n", r->texture_normal_instructions);
+    r->texture_normal_instructions = read_u32(&ptr);
+    TRACE("TextureNormalInstructions: %u.\n", r->texture_normal_instructions);
 
-    read_dword(&ptr, &r->texture_load_instructions);
-    TRACE("TextureLoadInstructions: %u\n", r->texture_load_instructions);
+    r->texture_load_instructions = read_u32(&ptr);
+    TRACE("TextureLoadInstructions: %u.\n", r->texture_load_instructions);
 
-    read_dword(&ptr, &r->texture_comp_instructions);
-    TRACE("TextureCompInstructions: %u\n", r->texture_comp_instructions);
+    r->texture_comp_instructions = read_u32(&ptr);
+    TRACE("TextureCompInstructions: %u.\n", r->texture_comp_instructions);
 
-    read_dword(&ptr, &r->texture_bias_instructions);
-    TRACE("TextureBiasInstructions: %u\n", r->texture_bias_instructions);
+    r->texture_bias_instructions = read_u32(&ptr);
+    TRACE("TextureBiasInstructions: %u.\n", r->texture_bias_instructions);
 
-    read_dword(&ptr, &r->texture_gradient_instructions);
-    TRACE("TextureGradientInstructions: %u\n", r->texture_gradient_instructions);
+    r->texture_gradient_instructions = read_u32(&ptr);
+    TRACE("TextureGradientInstructions: %u.\n", r->texture_gradient_instructions);
 
-    read_dword(&ptr, &r->mov_instruction_count);
-    TRACE("MovInstructionCount: %u\n", r->mov_instruction_count);
+    r->mov_instruction_count = read_u32(&ptr);
+    TRACE("MovInstructionCount: %u.\n", r->mov_instruction_count);
 
-    skip_dword_unknown(&ptr, 1);
+    skip_u32_unknown(&ptr, 1);
 
-    read_dword(&ptr, &r->conversion_instruction_count);
-    TRACE("ConversionInstructionCount: %u\n", r->conversion_instruction_count);
+    r->conversion_instruction_count = read_u32(&ptr);
+    TRACE("ConversionInstructionCount: %u.\n", r->conversion_instruction_count);
 
-    skip_dword_unknown(&ptr, 1);
+    skip_u32_unknown(&ptr, 1);
 
-    read_dword(&ptr, &r->input_primitive);
-    TRACE("InputPrimitive: %x\n", r->input_primitive);
+    r->input_primitive = read_u32(&ptr);
+    TRACE("InputPrimitive: %x.\n", r->input_primitive);
 
-    read_dword(&ptr, &r->gs_output_topology);
-    TRACE("GSOutputTopology: %x\n", r->gs_output_topology);
+    r->gs_output_topology = read_u32(&ptr);
+    TRACE("GSOutputTopology: %x.\n", r->gs_output_topology);
 
-    read_dword(&ptr, &r->gs_max_output_vertex_count);
-    TRACE("GSMaxOutputVertexCount: %u\n", r->gs_max_output_vertex_count);
+    r->gs_max_output_vertex_count = read_u32(&ptr);
+    TRACE("GSMaxOutputVertexCount: %u.\n", r->gs_max_output_vertex_count);
 
-    skip_dword_unknown(&ptr, 2);
+    skip_u32_unknown(&ptr, 2);
 
     /* old dx10 stat size */
     if (size == 28) return S_OK;
 
-    skip_dword_unknown(&ptr, 1);
+    skip_u32_unknown(&ptr, 1);
 
     /* dx10 stat size */
     if (size == 29) return S_OK;
 
-    skip_dword_unknown(&ptr, 1);
+    skip_u32_unknown(&ptr, 1);
 
-    read_dword(&ptr, &r->c_control_points);
-    TRACE("cControlPoints: %u\n", r->c_control_points);
+    r->c_control_points = read_u32(&ptr);
+    TRACE("cControlPoints: %u.\n", r->c_control_points);
 
-    read_dword(&ptr, &r->hs_output_primitive);
-    TRACE("HSOutputPrimitive: %x\n", r->hs_output_primitive);
+    r->hs_output_primitive = read_u32(&ptr);
+    TRACE("HSOutputPrimitive: %x.\n", r->hs_output_primitive);
 
-    read_dword(&ptr, &r->hs_prtitioning);
-    TRACE("HSPartitioning: %x\n", r->hs_prtitioning);
+    r->hs_partitioning = read_u32(&ptr);
+    TRACE("HSPartitioning: %x.\n", r->hs_partitioning);
 
-    read_dword(&ptr, &r->tessellator_domain);
-    TRACE("TessellatorDomain: %x\n", r->tessellator_domain);
+    r->tessellator_domain = read_u32(&ptr);
+    TRACE("TessellatorDomain: %x.\n", r->tessellator_domain);
 
-    skip_dword_unknown(&ptr, 3);
+    skip_u32_unknown(&ptr, 3);
 
     /* dx11 stat size */
     if (size == 37) return S_OK;
 
-    FIXME("Unhandled size %u\n", size);
+    FIXME("Unhandled size %Iu.\n", size);
 
     return E_FAIL;
 }
@@ -1203,9 +1207,9 @@ static HRESULT d3dcompiler_parse_stat(struct d3dcompiler_shader_reflection *r, c
 static HRESULT d3dcompiler_parse_type_members(struct d3dcompiler_shader_reflection *ref,
         struct d3dcompiler_shader_reflection_type_member *member, const char *data, const char **ptr)
 {
-    DWORD offset;
+    uint32_t offset;
 
-    read_dword(ptr, &offset);
+    offset = read_u32(ptr);
     if (!copy_name(data + offset, &member->name))
     {
         ERR("Failed to copy name.\n");
@@ -1213,8 +1217,8 @@ static HRESULT d3dcompiler_parse_type_members(struct d3dcompiler_shader_reflecti
     }
     TRACE("Member name: %s.\n", debugstr_a(member->name));
 
-    read_dword(ptr, &offset);
-    TRACE("Member type offset: %x\n", offset);
+    offset = read_u32(ptr);
+    TRACE("Member type offset: %x.\n", offset);
 
     member->type = get_reflection_type(ref, data, offset);
     if (!member->type)
@@ -1224,45 +1228,45 @@ static HRESULT d3dcompiler_parse_type_members(struct d3dcompiler_shader_reflecti
         return E_FAIL;
     }
 
-    read_dword(ptr, &member->offset);
-    TRACE("Member offset %x\n", member->offset);
+    member->offset = read_u32(ptr);
+    TRACE("Member offset %x.\n", member->offset);
 
     return S_OK;
 }
 
-static HRESULT d3dcompiler_parse_type(struct d3dcompiler_shader_reflection_type *type, const char *data, DWORD offset)
+static HRESULT d3dcompiler_parse_type(struct d3dcompiler_shader_reflection_type *type, const char *data, uint32_t offset)
 {
     const char *ptr = data + offset;
-    DWORD temp;
+    uint32_t temp;
     D3D11_SHADER_TYPE_DESC *desc;
     unsigned int i;
     struct d3dcompiler_shader_reflection_type_member *members = NULL;
     HRESULT hr;
-    DWORD member_offset;
+    uint32_t member_offset;
 
     desc = &type->desc;
 
-    read_dword(&ptr, &temp);
+    temp = read_u32(&ptr);
     desc->Class = temp & 0xffff;
     desc->Type = temp >> 16;
     TRACE("Class %s, Type %s\n", debug_d3dcompiler_shader_variable_class(desc->Class),
             debug_d3dcompiler_shader_variable_type(desc->Type));
 
-    read_dword(&ptr, &temp);
+    temp = read_u32(&ptr);
     desc->Rows = temp & 0xffff;
     desc->Columns = temp >> 16;
     TRACE("Rows %u, Columns %u\n", desc->Rows, desc->Columns);
 
-    read_dword(&ptr, &temp);
+    temp = read_u32(&ptr);
     desc->Elements = temp & 0xffff;
     desc->Members = temp >> 16;
     TRACE("Elements %u, Members %u\n", desc->Elements, desc->Members);
 
-    read_dword(&ptr, &member_offset);
-    TRACE("Member Offset %u\n", member_offset);
+    member_offset = read_u32(&ptr);
+    TRACE("Member Offset %u.\n", member_offset);
 
     if ((type->reflection->target & D3DCOMPILER_SHADER_TARGET_VERSION_MASK) >= 0x500)
-        skip_dword_unknown(&ptr, 4);
+        skip_u32_unknown(&ptr, 4);
 
     if (desc->Members)
     {
@@ -1288,7 +1292,7 @@ static HRESULT d3dcompiler_parse_type(struct d3dcompiler_shader_reflection_type
 
     if ((type->reflection->target & D3DCOMPILER_SHADER_TARGET_VERSION_MASK) >= 0x500)
     {
-        read_dword(&ptr, &offset);
+        offset = read_u32(&ptr);
         if (!copy_name(data + offset, &type->name))
         {
             ERR("Failed to copy name.\n");
@@ -1312,7 +1316,7 @@ err_out:
     return hr;
 }
 
-static struct d3dcompiler_shader_reflection_type *get_reflection_type(struct d3dcompiler_shader_reflection *reflection, const char *data, DWORD offset)
+static struct d3dcompiler_shader_reflection_type *get_reflection_type(struct d3dcompiler_shader_reflection *reflection, const char *data, uint32_t offset)
 {
     struct d3dcompiler_shader_reflection_type *type;
     struct wine_rb_entry *entry;
@@ -1337,7 +1341,7 @@ static struct d3dcompiler_shader_reflection_type *get_reflection_type(struct d3d
     hr = d3dcompiler_parse_type(type, data, offset);
     if (FAILED(hr))
     {
-        ERR("Failed to parse type info, hr %#x.\n", hr);
+        ERR("Failed to parse type info, hr %#lx.\n", hr);
         HeapFree(GetProcessHeap(), 0, type);
         return NULL;
     }
@@ -1353,7 +1357,7 @@ static struct d3dcompiler_shader_reflection_type *get_reflection_type(struct d3d
 }
 
 static HRESULT d3dcompiler_parse_variables(struct d3dcompiler_shader_reflection_constant_buffer *cb,
-        const char *data, DWORD data_size, const char *ptr)
+        const char *data, size_t data_size, const char *ptr)
 {
     struct d3dcompiler_shader_reflection_variable *variables;
     unsigned int i;
@@ -1369,13 +1373,13 @@ static HRESULT d3dcompiler_parse_variables(struct d3dcompiler_shader_reflection_
     for (i = 0; i < cb->variable_count; i++)
     {
         struct d3dcompiler_shader_reflection_variable *v = &variables[i];
-        DWORD offset;
+        uint32_t offset;
 
         v->ID3D11ShaderReflectionVariable_iface.lpVtbl = &d3dcompiler_shader_reflection_variable_vtbl;
         v->ID3D10ShaderReflectionVariable_iface.lpVtbl = &d3d10_shader_reflection_variable_vtbl;
         v->constant_buffer = cb;
 
-        read_dword(&ptr, &offset);
+        offset = read_u32(&ptr);
         if (!copy_name(data + offset, &v->name))
         {
             ERR("Failed to copy name.\n");
@@ -1384,17 +1388,17 @@ static HRESULT d3dcompiler_parse_variables(struct d3dcompiler_shader_reflection_
         }
         TRACE("Variable name: %s.\n", debugstr_a(v->name));
 
-        read_dword(&ptr, &v->start_offset);
+        v->start_offset = read_u32(&ptr);
         TRACE("Variable offset: %u\n", v->start_offset);
 
-        read_dword(&ptr, &v->size);
+        v->size = read_u32(&ptr);
         TRACE("Variable size: %u\n", v->size);
 
-        read_dword(&ptr, &v->flags);
+        v->flags = read_u32(&ptr);
         TRACE("Variable flags: %u\n", v->flags);
 
-        read_dword(&ptr, &offset);
-        TRACE("Variable type offset: %x\n", offset);
+        offset = read_u32(&ptr);
+        TRACE("Variable type offset: %x.\n", offset);
         v->type = get_reflection_type(cb->reflection, data, offset);
         if (!v->type)
         {
@@ -1403,8 +1407,8 @@ static HRESULT d3dcompiler_parse_variables(struct d3dcompiler_shader_reflection_
             goto err_out;
         }
 
-        read_dword(&ptr, &offset);
-        TRACE("Variable default value offset: %x\n", offset);
+        offset = read_u32(&ptr);
+        TRACE("Variable default value offset: %x.\n", offset);
         if (!copy_value(data + offset, &v->default_value, offset ? v->size : 0))
         {
             ERR("Failed to copy name.\n");
@@ -1413,7 +1417,7 @@ static HRESULT d3dcompiler_parse_variables(struct d3dcompiler_shader_reflection_
         }
 
         if ((cb->reflection->target & D3DCOMPILER_SHADER_TARGET_VERSION_MASK) >= 0x500)
-            skip_dword_unknown(&ptr, 4);
+            skip_u32_unknown(&ptr, 4);
     }
 
     cb->variables = variables;
@@ -1429,34 +1433,34 @@ err_out:
     return hr;
 }
 
-static HRESULT d3dcompiler_parse_rdef(struct d3dcompiler_shader_reflection *r, const char *data, DWORD data_size)
+static HRESULT d3dcompiler_parse_rdef(struct d3dcompiler_shader_reflection *r, const char *data, size_t data_size)
 {
     struct d3dcompiler_shader_reflection_constant_buffer *constant_buffers = NULL;
-    DWORD offset, cbuffer_offset, resource_offset, creator_offset;
+    uint32_t offset, cbuffer_offset, resource_offset, creator_offset;
     unsigned int i, string_data_offset, string_data_size;
     D3D12_SHADER_INPUT_BIND_DESC *bound_resources = NULL;
     char *string_data = NULL, *creator = NULL;
-    DWORD size = data_size >> 2;
+    size_t size = data_size >> 2;
+    uint32_t target_version;
     const char *ptr = data;
-    DWORD target_version;
     HRESULT hr;
 
-    TRACE("Size %u\n", size);
+    TRACE("Size %Iu.\n", size);
 
-    read_dword(&ptr, &r->constant_buffer_count);
-    TRACE("Constant buffer count: %u\n", r->constant_buffer_count);
+    r->constant_buffer_count = read_u32(&ptr);
+    TRACE("Constant buffer count: %u.\n", r->constant_buffer_count);
 
-    read_dword(&ptr, &cbuffer_offset);
-    TRACE("Constant buffer offset: %#x\n", cbuffer_offset);
+    cbuffer_offset = read_u32(&ptr);
+    TRACE("Constant buffer offset: %#x.\n", cbuffer_offset);
 
-    read_dword(&ptr, &r->bound_resource_count);
-    TRACE("Bound resource count: %u\n", r->bound_resource_count);
+    r->bound_resource_count = read_u32(&ptr);
+    TRACE("Bound resource count: %u.\n", r->bound_resource_count);
 
-    read_dword(&ptr, &resource_offset);
-    TRACE("Bound resource offset: %#x\n", resource_offset);
+    resource_offset = read_u32(&ptr);
+    TRACE("Bound resource offset: %#x.\n", resource_offset);
 
-    read_dword(&ptr, &r->target);
-    TRACE("Target: %#x\n", r->target);
+    r->target = read_u32(&ptr);
+    TRACE("Target: %#x.\n", r->target);
 
     target_version = r->target & D3DCOMPILER_SHADER_TARGET_VERSION_MASK;
 
@@ -1468,10 +1472,10 @@ static HRESULT d3dcompiler_parse_rdef(struct d3dcompiler_shader_reflection *r, c
     }
 #endif
 
-    read_dword(&ptr, &r->flags);
-    TRACE("Flags: %u\n", r->flags);
+    r->flags = read_u32(&ptr);
+    TRACE("Flags: %u.\n", r->flags);
 
-    read_dword(&ptr, &creator_offset);
+    creator_offset = read_u32(&ptr);
     TRACE("Creator at offset %#x.\n", creator_offset);
 
     if (!copy_name(data + creator_offset, &creator))
@@ -1484,13 +1488,13 @@ static HRESULT d3dcompiler_parse_rdef(struct d3dcompiler_shader_reflection *r, c
     /* todo: Parse RD11 */
     if (target_version >= 0x500)
     {
-        skip_dword_unknown(&ptr, 8);
+        skip_u32_unknown(&ptr, 8);
     }
 
     if (r->bound_resource_count)
     {
         /* 8 for each bind desc */
-        string_data_offset = resource_offset + r->bound_resource_count * 8 * sizeof(DWORD);
+        string_data_offset = resource_offset + r->bound_resource_count * 8 * sizeof(uint32_t);
         string_data_size = (cbuffer_offset ? cbuffer_offset : creator_offset) - string_data_offset;
 
         string_data = HeapAlloc(GetProcessHeap(), 0, string_data_size);
@@ -1515,36 +1519,36 @@ static HRESULT d3dcompiler_parse_rdef(struct d3dcompiler_shader_reflection *r, c
         {
             D3D12_SHADER_INPUT_BIND_DESC *desc = &bound_resources[i];
 
-            read_dword(&ptr, &offset);
+            offset = read_u32(&ptr);
             desc->Name = string_data + (offset - string_data_offset);
-            TRACE("Input bind Name: %s\n", debugstr_a(desc->Name));
+            TRACE("Input bind Name: %s.\n", debugstr_a(desc->Name));
 
-            read_dword(&ptr, &desc->Type);
-            TRACE("Input bind Type: %#x\n", desc->Type);
+            desc->Type = read_u32(&ptr);
+            TRACE("Input bind Type: %#x.\n", desc->Type);
 
-            read_dword(&ptr, &desc->ReturnType);
-            TRACE("Input bind ReturnType: %#x\n", desc->ReturnType);
+            desc->ReturnType = read_u32(&ptr);
+            TRACE("Input bind ReturnType: %#x.\n", desc->ReturnType);
 
-            read_dword(&ptr, &desc->Dimension);
-            TRACE("Input bind Dimension: %#x\n", desc->Dimension);
+            desc->Dimension = read_u32(&ptr);
+            TRACE("Input bind Dimension: %#x.\n", desc->Dimension);
 
-            read_dword(&ptr, &desc->NumSamples);
-            TRACE("Input bind NumSamples: %u\n", desc->NumSamples);
+            desc->NumSamples = read_u32(&ptr);
+            TRACE("Input bind NumSamples: %u.\n", desc->NumSamples);
 
-            read_dword(&ptr, &desc->BindPoint);
-            TRACE("Input bind BindPoint: %u\n", desc->BindPoint);
+            desc->BindPoint = read_u32(&ptr);
+            TRACE("Input bind BindPoint: %u.\n", desc->BindPoint);
 
-            read_dword(&ptr, &desc->BindCount);
-            TRACE("Input bind BindCount: %u\n", desc->BindCount);
+            desc->BindCount = read_u32(&ptr);
+            TRACE("Input bind BindCount: %u.\n", desc->BindCount);
 
-            read_dword(&ptr, &desc->uFlags);
-            TRACE("Input bind uFlags: %u\n", desc->uFlags);
+            desc->uFlags = read_u32(&ptr);
+            TRACE("Input bind uFlags: %u.\n", desc->uFlags);
 
             if (target_version >= 0x501)
             {
-                read_dword(&ptr, &desc->Space);
+                desc->Space = read_u32(&ptr);
                 TRACE("Input bind Space %u.\n", desc->Space);
-                read_dword(&ptr, &desc->uID);
+                desc->uID = read_u32(&ptr);
                 TRACE("Input bind uID %u.\n", desc->uID);
             }
             else
@@ -1574,7 +1578,7 @@ static HRESULT d3dcompiler_parse_rdef(struct d3dcompiler_shader_reflection *r, c
             cb->ID3D10ShaderReflectionConstantBuffer_iface.lpVtbl = &d3d10_shader_reflection_constant_buffer_vtbl;
             cb->reflection = r;
 
-            read_dword(&ptr, &offset);
+            offset = read_u32(&ptr);
             if (!copy_name(data + offset, &cb->name))
             {
                 ERR("Failed to copy name.\n");
@@ -1583,11 +1587,11 @@ static HRESULT d3dcompiler_parse_rdef(struct d3dcompiler_shader_reflection *r, c
             }
             TRACE("Name: %s.\n", debugstr_a(cb->name));
 
-            read_dword(&ptr, &cb->variable_count);
-            TRACE("Variable count: %u\n", cb->variable_count);
+            cb->variable_count = read_u32(&ptr);
+            TRACE("Variable count: %u.\n", cb->variable_count);
 
-            read_dword(&ptr, &offset);
-            TRACE("Variable offset: %x\n", offset);
+            offset = read_u32(&ptr);
+            TRACE("Variable offset: %x.\n", offset);
 
             hr = d3dcompiler_parse_variables(cb, data, data_size, data + offset);
             if (hr != S_OK)
@@ -1596,14 +1600,14 @@ static HRESULT d3dcompiler_parse_rdef(struct d3dcompiler_shader_reflection *r, c
                 goto err_out;
             }
 
-            read_dword(&ptr, &cb->size);
-            TRACE("Cbuffer size: %u\n", cb->size);
+            cb->size = read_u32(&ptr);
+            TRACE("Cbuffer size: %u.\n", cb->size);
 
-            read_dword(&ptr, &cb->flags);
-            TRACE("Cbuffer flags: %u\n", cb->flags);
+            cb->flags = read_u32(&ptr);
+            TRACE("Cbuffer flags: %u.\n", cb->flags);
 
-            read_dword(&ptr, &cb->type);
-            TRACE("Cbuffer type: %#x\n", cb->type);
+            cb->type = read_u32(&ptr);
+            TRACE("Cbuffer type: %#x.\n", cb->type);
         }
     }
 
@@ -1629,14 +1633,13 @@ err_out:
 
 static HRESULT d3dcompiler_parse_signature(struct d3dcompiler_shader_signature *s, struct dxbc_section *section)
 {
+    enum D3DCOMPILER_SIGNATURE_ELEMENT_SIZE element_size;
     D3D11_SIGNATURE_PARAMETER_DESC *d;
     unsigned int string_data_offset;
-    unsigned int string_data_size;
     const char *ptr = section->data;
+    unsigned int string_data_size;
+    unsigned int i, count;
     char *string_data;
-    unsigned int i;
-    DWORD count;
-    enum D3DCOMPILER_SIGNATURE_ELEMENT_SIZE element_size;
 
     switch (section->tag)
     {
@@ -1656,10 +1659,10 @@ static HRESULT d3dcompiler_parse_signature(struct d3dcompiler_shader_signature *
             break;
     }
 
-    read_dword(&ptr, &count);
+    count = read_u32(&ptr);
     TRACE("%u elements\n", count);
 
-    skip_dword_unknown(&ptr, 1);
+    skip_u32_unknown(&ptr, 1);
 
     d = HeapAlloc(GetProcessHeap(), 0, count * sizeof(*d));
     if (!d)
@@ -1668,8 +1671,8 @@ static HRESULT d3dcompiler_parse_signature(struct d3dcompiler_shader_signature *
         return E_OUTOFMEMORY;
     }
 
-    /* 2 DWORDs for the header, element_size for each element. */
-    string_data_offset = 2 * sizeof(DWORD) + count * element_size * sizeof(DWORD);
+    /* 2 u32s for the header, element_size for each element. */
+    string_data_offset = 2 * sizeof(uint32_t) + count * element_size * sizeof(uint32_t);
     string_data_size = section->data_size - string_data_offset;
 
     string_data = HeapAlloc(GetProcessHeap(), 0, string_data_size);
@@ -1683,8 +1686,7 @@ static HRESULT d3dcompiler_parse_signature(struct d3dcompiler_shader_signature *
 
     for (i = 0; i < count; ++i)
     {
-        UINT name_offset;
-        DWORD mask;
+        uint32_t name_offset, mask;
 
 #if D3D_COMPILER_VERSION >= 46
         /* FIXME */
@@ -1692,20 +1694,20 @@ static HRESULT d3dcompiler_parse_signature(struct d3dcompiler_shader_signature *
 #endif
         if (element_size == D3DCOMPILER_SIGNATURE_ELEMENT_SIZE7)
         {
-            read_dword(&ptr, &d[i].Stream);
+            d[i].Stream = read_u32(&ptr);
         }
         else
         {
             d[i].Stream = 0;
         }
 
-        read_dword(&ptr, &name_offset);
+        name_offset = read_u32(&ptr);
         d[i].SemanticName = string_data + (name_offset - string_data_offset);
-        read_dword(&ptr, &d[i].SemanticIndex);
-        read_dword(&ptr, &d[i].SystemValueType);
-        read_dword(&ptr, &d[i].ComponentType);
-        read_dword(&ptr, &d[i].Register);
-        read_dword(&ptr, &mask);
+        d[i].SemanticIndex = read_u32(&ptr);
+        d[i].SystemValueType = read_u32(&ptr);
+        d[i].ComponentType = read_u32(&ptr);
+        d[i].Register = read_u32(&ptr);
+        mask = read_u32(&ptr);
         d[i].ReadWriteMask = (mask >> 8) & 0xff;
         d[i].Mask = mask & 0xff;
 
@@ -1733,11 +1735,11 @@ static HRESULT d3dcompiler_parse_signature(struct d3dcompiler_shader_signature *
     return S_OK;
 }
 
-static HRESULT d3dcompiler_parse_shdr(struct d3dcompiler_shader_reflection *r, const char *data, DWORD data_size)
+static HRESULT d3dcompiler_parse_shdr(struct d3dcompiler_shader_reflection *r, const char *data, size_t data_size)
 {
     const char *ptr = data;
 
-    read_dword(&ptr, &r->version);
+    r->version = read_u32(&ptr);
     TRACE("Shader version: %u\n", r->version);
 
     /* todo: Check if anything else is needed from the shdr or shex blob. */
@@ -1894,7 +1896,7 @@ static ULONG STDMETHODCALLTYPE d3d10_shader_reflection_AddRef(ID3D10ShaderReflec
     struct d3dcompiler_shader_reflection *reflection = impl_from_ID3D10ShaderReflection(iface);
     ULONG refcount = InterlockedIncrement(&reflection->refcount);
 
-    TRACE("%p increasing refcount to %u.\n", reflection, refcount);
+    TRACE("%p increasing refcount to %lu.\n", reflection, refcount);
 
     return refcount;
 }
@@ -1904,7 +1906,7 @@ static ULONG STDMETHODCALLTYPE d3d10_shader_reflection_Release(ID3D10ShaderRefle
     struct d3dcompiler_shader_reflection *reflection = impl_from_ID3D10ShaderReflection(iface);
     ULONG refcount = InterlockedDecrement(&reflection->refcount);
 
-    TRACE("%p decreasing refcount to %u.\n", reflection, refcount);
+    TRACE("%p decreasing refcount to %lu.\n", reflection, refcount);
 
     if (!refcount)
         heap_free(reflection);
@@ -1917,7 +1919,7 @@ static HRESULT STDMETHODCALLTYPE d3d10_shader_reflection_GetDesc(ID3D10ShaderRef
 {
     struct d3dcompiler_shader_reflection *reflection = impl_from_ID3D10ShaderReflection(iface);
 
-    FIXME("iface %p, desc %p partial stub!\n", iface, desc);
+    TRACE("iface %p, desc %p.\n", iface, desc);
 
     if (!desc)
     {
@@ -1935,7 +1937,7 @@ static HRESULT STDMETHODCALLTYPE d3d10_shader_reflection_GetDesc(ID3D10ShaderRef
     desc->InstructionCount = reflection->instruction_count;
     desc->TempRegisterCount = reflection->temp_register_count;
     desc->TempArrayCount = reflection->temp_array_count;
-    desc->DefCount = 0;
+    desc->DefCount = reflection->def_count;
     desc->DclCount = reflection->dcl_count;
     desc->TextureNormalInstructions = reflection->texture_normal_instructions;
     desc->TextureLoadInstructions = reflection->texture_load_instructions;
@@ -1947,7 +1949,7 @@ static HRESULT STDMETHODCALLTYPE d3d10_shader_reflection_GetDesc(ID3D10ShaderRef
     desc->UintInstructionCount = reflection->uint_instruction_count;
     desc->StaticFlowControlCount = reflection->static_flow_control_count;
     desc->DynamicFlowControlCount = reflection->dynamic_flow_control_count;
-    desc->MacroInstructionCount = 0;
+    desc->MacroInstructionCount = reflection->macro_instruction_count;
     desc->ArrayInstructionCount = reflection->array_instruction_count;
     desc->CutInstructionCount = reflection->cut_instruction_count;
     desc->EmitInstructionCount = reflection->emit_instruction_count;
@@ -2318,7 +2320,7 @@ HRESULT WINAPI D3D10ReflectShader(const void *data, SIZE_T data_size, ID3D10Shad
     struct d3dcompiler_shader_reflection *object;
     HRESULT hr;
 
-    TRACE("data %p, data_size %lu, reflector %p.\n", data, data_size, reflector);
+    TRACE("data %p, data_size %Iu, reflector %p.\n", data, data_size, reflector);
 
     if (!(object = heap_alloc_zero(sizeof(*object))))
     {
@@ -2349,10 +2351,10 @@ HRESULT WINAPI D3D10ReflectShader(const void *data, SIZE_T data_size, ID3D10Shad
 HRESULT WINAPI D3DReflect(const void *data, SIZE_T data_size, REFIID riid, void **reflector)
 {
     struct d3dcompiler_shader_reflection *object;
+    const uint32_t *temp = data;
     HRESULT hr;
-    const DWORD *temp = data;
 
-    TRACE("data %p, data_size %lu, riid %s, blob %p\n", data, data_size, debugstr_guid(riid), reflector);
+    TRACE("data %p, data_size %Iu, riid %s, blob %p.\n", data, data_size, debugstr_guid(riid), reflector);
 
     if (!data || data_size < 32)
     {
