@@ -66,10 +66,11 @@ int __cdecl symt_cmp_addr(const void* p1, const void* p2)
 
 /* dbghelp exposes the internal symbols/types with DWORD indexes.
  * - custom symbols are always stored with index starting at BASE_CUSTOM_SYMT
- * - for all the others (non custom) symbols:
- *   + on 32bit machine, index is set to the actual adress of symt
- *   + on 64bit machine, we have a dedicated array to store symt exposed to caller
- *     index is the index in this array of the symbol
+ * - for all the other (non custom) symbols:
+ *   + on 32-bit machines, index is set to the actual address of symt
+ *   + on 64-bit machines, the symt address is stored in a dedicated array
+ *     which is exposed to the caller and index is the index of the symbol in
+ *     this array
  */
 DWORD             symt_ptr2index(struct module* module, const struct symt* sym)
 {
@@ -258,7 +259,7 @@ struct symt_public* symt_new_public(struct module* module,
     struct symt_public* sym;
     struct symt**       p;
 
-    TRACE_(dbghelp_symt)("Adding public symbol %s:%s @%lx\n",
+    TRACE_(dbghelp_symt)("Adding public symbol %s:%s @%Ix\n",
                          debugstr_w(module->modulename), name, address);
     if ((dbghelp_options & SYMOPT_AUTO_PUBLICS) &&
         symt_find_nearest(module, address) != NULL)
@@ -291,7 +292,7 @@ struct symt_data* symt_new_global_variable(struct module* module,
     struct symt**       p;
     DWORD64             tsz;
 
-    TRACE_(dbghelp_symt)("Adding global symbol %s:%s %d@%lx %p\n",
+    TRACE_(dbghelp_symt)("Adding global symbol %s:%s %d@%Ix %p\n",
                          debugstr_w(module->modulename), name, loc.kind, loc.offset, type);
     if ((sym = pool_alloc(&module->pool, sizeof(*sym))))
     {
@@ -304,7 +305,7 @@ struct symt_data* symt_new_global_variable(struct module* module,
         if (type && size && symt_get_info(module, type, TI_GET_LENGTH, &tsz))
         {
             if (tsz != size)
-                FIXME("Size mismatch for %s.%s between type (%s) and src (%lu)\n",
+                FIXME("Size mismatch for %s.%s between type (%s) and src (%Iu)\n",
                       debugstr_w(module->modulename), name,
                       wine_dbgstr_longlong(tsz), size);
         }
@@ -345,7 +346,7 @@ struct symt_function* symt_new_function(struct module* module,
 {
     struct symt_function* sym;
 
-    TRACE_(dbghelp_symt)("Adding global function %s:%s @%lx-%lx\n",
+    TRACE_(dbghelp_symt)("Adding global function %s:%s @%Ix-%Ix\n",
                          debugstr_w(module->modulename), name, addr, addr + size - 1);
     if ((sym = pool_alloc(&module->pool, sizeof(*sym))))
     {
@@ -371,7 +372,7 @@ struct symt_inlinesite* symt_new_inlinesite(struct module* module,
 {
     struct symt_inlinesite* sym;
 
-    TRACE_(dbghelp_symt)("Adding inline site %s @%lx\n", name, addr);
+    TRACE_(dbghelp_symt)("Adding inline site %s @%Ix\n", name, addr);
     if ((sym = pool_alloc(&module->pool, sizeof(*sym))))
     {
         struct symt** p;
@@ -612,7 +613,7 @@ BOOL symt_add_inlinesite_range(struct module* module,
             {
                 struct addr_range* ar = (struct addr_range*)vector_at(&inlined->vranges, i);
                 if (!addr_range_disjoint(ar, p) && !addr_range_inside(ar, p))
-                    FIXME("Added addr_range not compatible with parent\n");
+                    WARN("Added addr_range not compatible with parent\n");
             }
         }
     }
@@ -627,7 +628,7 @@ struct symt_thunk* symt_new_thunk(struct module* module,
 {
     struct symt_thunk*  sym;
 
-    TRACE_(dbghelp_symt)("Adding global thunk %s:%s @%lx-%lx\n",
+    TRACE_(dbghelp_symt)("Adding global thunk %s:%s @%Ix-%Ix\n",
                          debugstr_w(module->modulename), name, addr, addr + size - 1);
 
     if ((sym = pool_alloc(&module->pool, sizeof(*sym))))
@@ -889,7 +890,7 @@ static void symt_fill_sym_info(struct module_pair* pair,
     else
         symbol_setname(sym_info, name);
 
-    TRACE_(dbghelp_symt)("%p => %s %u %s\n",
+    TRACE_(dbghelp_symt)("%p => %s %lu %s\n",
                          sym, sym_info->Name, sym_info->Size,
                          wine_dbgstr_longlong(sym_info->Address));
 }
@@ -2186,7 +2187,7 @@ BOOL WINAPI SymUnDName64(PIMAGEHLP_SYMBOL64 sym, PSTR UnDecName, DWORD UnDecName
 DWORD WINAPI UnDecorateSymbolName(const char *decorated_name, char *undecorated_name,
                                   DWORD undecorated_length, DWORD flags)
 {
-    TRACE("(%s, %p, %d, 0x%08x)\n",
+    TRACE("(%s, %p, %ld, 0x%08lx)\n",
           debugstr_a(decorated_name), undecorated_name, undecorated_length, flags);
 
     if (!undecorated_name || !undecorated_length)
@@ -2205,7 +2206,7 @@ DWORD WINAPI UnDecorateSymbolNameW(const WCHAR *decorated_name, WCHAR *undecorat
     char *buf, *ptr;
     int len, ret = 0;
 
-    TRACE("(%s, %p, %d, 0x%08x)\n",
+    TRACE("(%s, %p, %ld, 0x%08lx)\n",
           debugstr_w(decorated_name), undecorated_name, undecorated_length, flags);
 
     if (!undecorated_name || !undecorated_length)
@@ -2410,7 +2411,7 @@ static inline BOOL doSymSearch(HANDLE hProcess, ULONG64 BaseOfDll, DWORD Index,
 
     if (Options != SYMSEARCH_GLOBALSONLY)
     {
-        FIXME("Unsupported searching with options (%x)\n", Options);
+        FIXME("Unsupported searching with options (%lx)\n", Options);
         SetLastError(ERROR_INVALID_PARAMETER);
         return FALSE;
     }
@@ -2436,7 +2437,7 @@ BOOL WINAPI SymSearch(HANDLE hProcess, ULONG64 BaseOfDll, DWORD Index,
     LPWSTR      maskW = NULL;
     BOOLEAN     ret;
 
-    TRACE("(%p %s %u %u %s %s %p %p %x)\n",
+    TRACE("(%p %s %lu %lu %s %s %p %p %lx)\n",
           hProcess, wine_dbgstr_longlong(BaseOfDll), Index, SymTag, Mask,
           wine_dbgstr_longlong(Address), EnumSymbolsCallback,
           UserContext, Options);
@@ -2465,7 +2466,7 @@ BOOL WINAPI SymSearchW(HANDLE hProcess, ULONG64 BaseOfDll, DWORD Index,
 {
     struct sym_enumW    sew;
 
-    TRACE("(%p %s %u %u %s %s %p %p %x)\n",
+    TRACE("(%p %s %lu %lu %s %s %p %p %lx)\n",
           hProcess, wine_dbgstr_longlong(BaseOfDll), Index, SymTag, debugstr_w(Mask),
           wine_dbgstr_longlong(Address), EnumSymbolsCallback,
           UserContext, Options);
@@ -2487,7 +2488,7 @@ BOOL WINAPI SymAddSymbol(HANDLE hProcess, ULONG64 BaseOfDll, PCSTR name,
 {
     struct module_pair  pair;
 
-    TRACE("(%p %s %s %u)\n", hProcess, wine_dbgstr_a(name), wine_dbgstr_longlong(addr), size);
+    TRACE("(%p %s %s %lu)\n", hProcess, wine_dbgstr_a(name), wine_dbgstr_longlong(addr), size);
 
     if (!module_init_pair(&pair, hProcess, BaseOfDll)) return FALSE;
 
@@ -2503,7 +2504,7 @@ BOOL WINAPI SymAddSymbolW(HANDLE hProcess, ULONG64 BaseOfDll, PCWSTR nameW,
 {
     char       name[MAX_SYM_NAME];
 
-    TRACE("(%p %s %s %u)\n", hProcess, wine_dbgstr_w(nameW), wine_dbgstr_longlong(addr), size);
+    TRACE("(%p %s %s %lu)\n", hProcess, wine_dbgstr_w(nameW), wine_dbgstr_longlong(addr), size);
 
     WideCharToMultiByte(CP_ACP, 0, nameW, -1, name, ARRAY_SIZE(name), NULL, NULL);
 
@@ -2583,7 +2584,7 @@ BOOL WINAPI SymEnumLines(HANDLE hProcess, ULONG64 base, PCSTR compiland,
 BOOL WINAPI SymGetLineFromName(HANDLE hProcess, PCSTR ModuleName, PCSTR FileName,
                 DWORD dwLineNumber, PLONG plDisplacement, PIMAGEHLP_LINE Line)
 {
-    FIXME("(%p) (%s, %s, %d %p %p): stub\n", hProcess, ModuleName, FileName,
+    FIXME("(%p) (%s, %s, %ld %p %p): stub\n", hProcess, ModuleName, FileName,
                 dwLineNumber, plDisplacement, Line);
     return FALSE;
 }
@@ -2591,7 +2592,7 @@ BOOL WINAPI SymGetLineFromName(HANDLE hProcess, PCSTR ModuleName, PCSTR FileName
 BOOL WINAPI SymGetLineFromName64(HANDLE hProcess, PCSTR ModuleName, PCSTR FileName,
                 DWORD dwLineNumber, PLONG lpDisplacement, PIMAGEHLP_LINE64 Line)
 {
-    FIXME("(%p) (%s, %s, %d %p %p): stub\n", hProcess, ModuleName, FileName,
+    FIXME("(%p) (%s, %s, %ld %p %p): stub\n", hProcess, ModuleName, FileName,
                 dwLineNumber, lpDisplacement, Line);
     return FALSE;
 }
@@ -2599,7 +2600,7 @@ BOOL WINAPI SymGetLineFromName64(HANDLE hProcess, PCSTR ModuleName, PCSTR FileNa
 BOOL WINAPI SymGetLineFromNameW64(HANDLE hProcess, PCWSTR ModuleName, PCWSTR FileName,
                 DWORD dwLineNumber, PLONG plDisplacement, PIMAGEHLP_LINEW64 Line)
 {
-    FIXME("(%p) (%s, %s, %d %p %p): stub\n", hProcess, debugstr_w(ModuleName), debugstr_w(FileName),
+    FIXME("(%p) (%s, %s, %ld %p %p): stub\n", hProcess, debugstr_w(ModuleName), debugstr_w(FileName),
                 dwLineNumber, plDisplacement, Line);
     return FALSE;
 }
@@ -2610,7 +2611,7 @@ BOOL WINAPI SymGetLineFromNameW64(HANDLE hProcess, PCWSTR ModuleName, PCWSTR Fil
  */
 BOOL WINAPI SymFromIndex(HANDLE hProcess, ULONG64 BaseOfDll, DWORD index, PSYMBOL_INFO symbol)
 {
-    FIXME("hProcess = %p, BaseOfDll = %s, index = %d, symbol = %p\n",
+    FIXME("hProcess = %p, BaseOfDll = %s, index = %ld, symbol = %p\n",
           hProcess, wine_dbgstr_longlong(BaseOfDll), index, symbol);
 
     return FALSE;
@@ -2622,7 +2623,7 @@ BOOL WINAPI SymFromIndex(HANDLE hProcess, ULONG64 BaseOfDll, DWORD index, PSYMBO
  */
 BOOL WINAPI SymFromIndexW(HANDLE hProcess, ULONG64 BaseOfDll, DWORD index, PSYMBOL_INFOW symbol)
 {
-    FIXME("hProcess = %p, BaseOfDll = %s, index = %d, symbol = %p\n",
+    FIXME("hProcess = %p, BaseOfDll = %s, index = %ld, symbol = %p\n",
           hProcess, wine_dbgstr_longlong(BaseOfDll), index, symbol);
 
     return FALSE;
@@ -2659,7 +2660,7 @@ BOOL WINAPI SymFromInlineContext(HANDLE hProcess, DWORD64 addr, ULONG inline_ctx
     struct module_pair pair;
     struct symt_inlinesite* inlined;
 
-    TRACE("(%p, %#I64x, 0x%x, %p, %p)\n", hProcess, addr, inline_ctx, disp, si);
+    TRACE("(%p, %#I64x, 0x%lx, %p, %p)\n", hProcess, addr, inline_ctx, disp, si);
 
     switch (IFC_MODE(inline_ctx))
     {
@@ -2692,7 +2693,7 @@ BOOL WINAPI SymFromInlineContextW(HANDLE hProcess, DWORD64 addr, ULONG inline_ct
     unsigned            len;
     BOOL                ret;
 
-    TRACE("(%p, %#I64x, 0x%x, %p, %p)\n", hProcess, addr, inline_ctx, disp, siW);
+    TRACE("(%p, %#I64x, 0x%lx, %p, %p)\n", hProcess, addr, inline_ctx, disp, siW);
 
     len = sizeof(*si) + siW->MaxNameLen * sizeof(WCHAR);
     si = HeapAlloc(GetProcessHeap(), 0, len);
@@ -2739,7 +2740,7 @@ BOOL WINAPI SymGetLineFromInlineContext(HANDLE hProcess, DWORD64 addr, ULONG inl
 {
     struct internal_line_t intl;
 
-    TRACE("(%p, %#I64x, 0x%x, %#I64x, %p, %p)\n",
+    TRACE("(%p, %#I64x, 0x%lx, %#I64x, %p, %p)\n",
           hProcess, addr, inline_ctx, mod_addr, disp, line);
 
     if (line->SizeOfStruct < sizeof(*line)) return FALSE;
@@ -2757,7 +2758,7 @@ BOOL WINAPI SymGetLineFromInlineContextW(HANDLE hProcess, DWORD64 addr, ULONG in
 {
     struct internal_line_t intl;
 
-    TRACE("(%p, %#I64x, 0x%x, %#I64x, %p, %p)\n",
+    TRACE("(%p, %#I64x, 0x%lx, %#I64x, %p, %p)\n",
           hProcess, addr, inline_ctx, mod_addr, disp, line);
 
     if (line->SizeOfStruct < sizeof(*line)) return FALSE;
