@@ -36,15 +36,15 @@ WINE_DEFAULT_DEBUG_CHANNEL(dinput);
 
 static const struct dinput_device_vtbl keyboard_vtbl;
 
-typedef struct SysKeyboardImpl SysKeyboardImpl;
-struct SysKeyboardImpl
+struct keyboard
 {
-    struct IDirectInputDeviceImpl base;
+    struct dinput_device base;
 };
 
-static inline SysKeyboardImpl *impl_from_IDirectInputDevice8W(IDirectInputDevice8W *iface)
+static inline struct keyboard *impl_from_IDirectInputDevice8W( IDirectInputDevice8W *iface )
 {
-    return CONTAINING_RECORD(CONTAINING_RECORD(iface, IDirectInputDeviceImpl, IDirectInputDevice8W_iface), SysKeyboardImpl, base);
+    return CONTAINING_RECORD( CONTAINING_RECORD( iface, struct dinput_device, IDirectInputDevice8W_iface ),
+                              struct keyboard, base );
 }
 
 static BYTE map_dik_code(DWORD scanCode, DWORD vkCode, DWORD subType, DWORD version)
@@ -85,9 +85,9 @@ static BYTE map_dik_code(DWORD scanCode, DWORD vkCode, DWORD subType, DWORD vers
 
 int dinput_keyboard_hook( IDirectInputDevice8W *iface, WPARAM wparam, LPARAM lparam )
 {
-    SysKeyboardImpl *This = impl_from_IDirectInputDevice8W( iface );
-    BYTE new_diks, subtype = GET_DIDEVICE_SUBTYPE( This->base.instance.dwDevType );
-    int dik_code, ret = This->base.dwCoopLevel & DISCL_EXCLUSIVE;
+    struct keyboard *impl = impl_from_IDirectInputDevice8W( iface );
+    BYTE new_diks, subtype = GET_DIDEVICE_SUBTYPE( impl->base.instance.dwDevType );
+    int dik_code, ret = impl->base.dwCoopLevel & DISCL_EXCLUSIVE;
     KBDLLHOOKSTRUCT *hook = (KBDLLHOOKSTRUCT *)lparam;
     DWORD scan_code;
 
@@ -95,8 +95,8 @@ int dinput_keyboard_hook( IDirectInputDevice8W *iface, WPARAM wparam, LPARAM lpa
         wparam != WM_SYSKEYDOWN && wparam != WM_SYSKEYUP)
         return 0;
 
-    TRACE("(%p) wp %08lx, lp %08lx, vk %02x, scan %02x\n",
-          iface, wparam, lparam, hook->vkCode, hook->scanCode);
+    TRACE( "iface %p, wparam %#Ix, lparam %#Ix, vkCode %#lx, scanCode %#lx.\n", iface, wparam,
+           lparam, hook->vkCode, hook->scanCode );
 
     switch (hook->vkCode)
     {
@@ -108,28 +108,28 @@ int dinput_keyboard_hook( IDirectInputDevice8W *iface, WPARAM wparam, LPARAM lpa
         default:
             scan_code = hook->scanCode & 0xff;
             if (hook->flags & LLKHF_EXTENDED) scan_code |= 0x100;
-            dik_code = map_dik_code( scan_code, hook->vkCode, subtype, This->base.dinput->dwVersion );
+            dik_code = map_dik_code( scan_code, hook->vkCode, subtype, impl->base.dinput->dwVersion );
     }
     new_diks = hook->flags & LLKHF_UP ? 0 : 0x80;
 
     /* returns now if key event already known */
-    if (new_diks == This->base.device_state[dik_code]) return ret;
+    if (new_diks == impl->base.device_state[dik_code]) return ret;
 
-    This->base.device_state[dik_code] = new_diks;
-    TRACE( " setting key %02x to %02x\n", dik_code, This->base.device_state[dik_code] );
+    impl->base.device_state[dik_code] = new_diks;
+    TRACE( " setting key %02x to %02x\n", dik_code, impl->base.device_state[dik_code] );
 
-    EnterCriticalSection(&This->base.crit);
-    queue_event(iface, DIDFT_MAKEINSTANCE(dik_code) | DIDFT_PSHBUTTON,
-                new_diks, GetCurrentTime(), This->base.dinput->evsequence++);
-    if (This->base.hEvent) SetEvent( This->base.hEvent );
-    LeaveCriticalSection(&This->base.crit);
+    EnterCriticalSection( &impl->base.crit );
+    queue_event( iface, DIDFT_MAKEINSTANCE( dik_code ) | DIDFT_PSHBUTTON, new_diks,
+                 GetCurrentTime(), impl->base.dinput->evsequence++ );
+    if (impl->base.hEvent) SetEvent( impl->base.hEvent );
+    LeaveCriticalSection( &impl->base.crit );
 
     return ret;
 }
 
 static DWORD get_keyboard_subtype(void)
 {
-    DWORD kbd_type, kbd_subtype, dev_subtype;
+    INT kbd_type, kbd_subtype, dev_subtype;
     kbd_type = GetKeyboardType(0);
     kbd_subtype = GetKeyboardType(1);
 
@@ -138,28 +138,18 @@ static DWORD get_keyboard_subtype(void)
     else if (kbd_type == 7 && kbd_subtype == 2)
         dev_subtype = DIDEVTYPEKEYBOARD_JAPAN106;
     else {
-        FIXME("Unknown keyboard type=%u, subtype=%u\n", kbd_type, kbd_subtype);
+        FIXME( "Unknown keyboard type %d, subtype %d\n", kbd_type, kbd_subtype );
         dev_subtype = DIDEVTYPEKEYBOARD_PCENH;
     }
     return dev_subtype;
 }
 
-static HRESULT keyboard_enum_device( DWORD type, DWORD flags, DIDEVICEINSTANCEW *instance, DWORD version, int index )
+HRESULT keyboard_enum_device( DWORD type, DWORD flags, DIDEVICEINSTANCEW *instance, DWORD version )
 {
     BYTE subtype = get_keyboard_subtype();
     DWORD size;
 
-    TRACE( "type %#x, flags %#x, instance %p, version %#04x, index %d\n", type, flags, instance, version, index );
-
-    if (index != 0) return DIERR_GENERIC;
-    if (flags & DIEDFL_FORCEFEEDBACK) return DI_NOEFFECT;
-    if (version < 0x0800 && type != 0 && type != DIDEVTYPE_KEYBOARD) return DI_NOEFFECT;
-    if (version >= 0x0800 && type != DI8DEVCLASS_ALL && type != DI8DEVCLASS_KEYBOARD && type != DI8DEVTYPE_KEYBOARD)
-        return DI_NOEFFECT;
-
-    if (instance->dwSize != sizeof(DIDEVICEINSTANCEW) &&
-        instance->dwSize != sizeof(DIDEVICEINSTANCE_DX3W))
-        return DIERR_INVALIDPARAM;
+    TRACE( "type %#lx, flags %#lx, instance %p, version %#lx.\n", type, flags, instance, version );
 
     size = instance->dwSize;
     memset( instance, 0, size );
@@ -174,27 +164,26 @@ static HRESULT keyboard_enum_device( DWORD type, DWORD flags, DIDEVICEINSTANCEW
     return DI_OK;
 }
 
-static HRESULT keyboard_create_device( IDirectInputImpl *dinput, const GUID *guid, IDirectInputDevice8W **out )
+HRESULT keyboard_create_device( struct dinput *dinput, const GUID *guid, IDirectInputDevice8W **out )
 {
-    SysKeyboardImpl *impl;
+    struct keyboard *impl;
     HRESULT hr;
 
-    TRACE( "dinput %p, guid %s, out %p\n", dinput, debugstr_guid( guid ), out );
+    TRACE( "dinput %p, guid %s, out %p.\n", dinput, debugstr_guid( guid ), out );
 
     *out = NULL;
     if (!IsEqualGUID( &GUID_SysKeyboard, guid )) return DIERR_DEVICENOTREG;
 
-    if (FAILED(hr = direct_input_device_alloc( sizeof(SysKeyboardImpl), &keyboard_vtbl,
-                                               guid, dinput, (void **)&impl )))
+    if (FAILED(hr = dinput_device_alloc( sizeof(struct keyboard), &keyboard_vtbl, guid, dinput, (void **)&impl )))
         return hr;
-    impl->base.crit.DebugInfo->Spare[0] = (DWORD_PTR)(__FILE__ ": SysKeyboardImpl*->base.crit");
+    impl->base.crit.DebugInfo->Spare[0] = (DWORD_PTR)(__FILE__ ": struct keyboard*->base.crit");
 
-    keyboard_enum_device( 0, 0, &impl->base.instance, dinput->dwVersion, 0 );
+    keyboard_enum_device( 0, 0, &impl->base.instance, dinput->dwVersion );
     impl->base.caps.dwDevType = impl->base.instance.dwDevType;
     impl->base.caps.dwFirmwareRevision = 100;
     impl->base.caps.dwHardwareRevision = 100;
 
-    if (FAILED(hr = direct_input_device_init( &impl->base.IDirectInputDevice8W_iface )))
+    if (FAILED(hr = dinput_device_init( &impl->base.IDirectInputDevice8W_iface )))
     {
         IDirectInputDevice_Release( &impl->base.IDirectInputDevice8W_iface );
         return hr;
@@ -204,12 +193,6 @@ static HRESULT keyboard_create_device( IDirectInputImpl *dinput, const GUID *gui
     return DI_OK;
 }
 
-const struct dinput_device keyboard_device = {
-  "Wine keyboard driver",
-  keyboard_enum_device,
-  keyboard_create_device
-};
-
 static HRESULT keyboard_poll( IDirectInputDevice8W *iface )
 {
     check_dinput_events();
@@ -223,8 +206,8 @@ static HRESULT keyboard_acquire( IDirectInputDevice8W *iface )
 
 static HRESULT keyboard_unacquire( IDirectInputDevice8W *iface )
 {
-    SysKeyboardImpl *This = impl_from_IDirectInputDevice8W( iface );
-    memset( This->base.device_state, 0, sizeof(This->base.device_state) );
+    struct keyboard *impl = impl_from_IDirectInputDevice8W( iface );
+    memset( impl->base.device_state, 0, sizeof(impl->base.device_state) );
     return DI_OK;
 }
 
@@ -251,7 +234,7 @@ static BOOL try_enum_object( const DIPROPHEADER *filter, DWORD flags, LPDIENUMDE
 static HRESULT keyboard_enum_objects( IDirectInputDevice8W *iface, const DIPROPHEADER *filter,
                                       DWORD flags, LPDIENUMDEVICEOBJECTSCALLBACKW callback, void *context )
 {
-    SysKeyboardImpl *impl = impl_from_IDirectInputDevice8W( iface );
+    struct keyboard *impl = impl_from_IDirectInputDevice8W( iface );
     BYTE subtype = GET_DIDEVICE_SUBTYPE( impl->base.instance.dwDevType );
     DIDEVICEOBJECTINSTANCEW instance =
     {
@@ -277,7 +260,7 @@ static HRESULT keyboard_enum_objects( IDirectInputDevice8W *iface, const DIPROPH
 }
 
 static HRESULT keyboard_get_property( IDirectInputDevice8W *iface, DWORD property,
-                                      DIPROPHEADER *header, DIDEVICEOBJECTINSTANCEW *instance )
+                                      DIPROPHEADER *header, const DIDEVICEOBJECTINSTANCEW *instance )
 {
     switch (property)
     {
@@ -291,12 +274,6 @@ static HRESULT keyboard_get_property( IDirectInputDevice8W *iface, DWORD propert
     return DIERR_UNSUPPORTED;
 }
 
-static HRESULT keyboard_set_property( IDirectInputDevice8W *iface, DWORD property,
-                                      const DIPROPHEADER *header, const DIDEVICEOBJECTINSTANCEW *instance )
-{
-    return DIERR_UNSUPPORTED;
-}
-
 static const struct dinput_device_vtbl keyboard_vtbl =
 {
     NULL,
@@ -306,7 +283,7 @@ static const struct dinput_device_vtbl keyboard_vtbl =
     keyboard_unacquire,
     keyboard_enum_objects,
     keyboard_get_property,
-    keyboard_set_property,
+    NULL,
     NULL,
     NULL,
     NULL,
