@@ -45,8 +45,6 @@ WINE_DEFAULT_DEBUG_CHANNEL(dinput);
 
 static const struct dinput_device_vtbl mouse_vtbl;
 
-typedef struct SysMouseImpl SysMouseImpl;
-
 typedef enum
 {
     WARP_DEFAULT,
@@ -54,11 +52,10 @@ typedef enum
     WARP_FORCE_ON
 } WARP_MOUSE;
 
-struct SysMouseImpl
+struct mouse
 {
-    struct IDirectInputDeviceImpl   base;
+    struct dinput_device base;
 
-    /* SysMouseAImpl */
     /* These are used in case of relative -> absolute transitions */
     POINT                           org_coords;
     BOOL                            clipped;
@@ -70,26 +67,16 @@ struct SysMouseImpl
     WARP_MOUSE                      warp_override;
 };
 
-static inline SysMouseImpl *impl_from_IDirectInputDevice8W(IDirectInputDevice8W *iface)
+static inline struct mouse *impl_from_IDirectInputDevice8W( IDirectInputDevice8W *iface )
 {
-    return CONTAINING_RECORD(CONTAINING_RECORD(iface, IDirectInputDeviceImpl, IDirectInputDevice8W_iface), SysMouseImpl, base);
+    return CONTAINING_RECORD( CONTAINING_RECORD( iface, struct dinput_device, IDirectInputDevice8W_iface ), struct mouse, base );
 }
 
-static HRESULT mouse_enum_device( DWORD type, DWORD flags, DIDEVICEINSTANCEW *instance, DWORD version, int index )
+HRESULT mouse_enum_device( DWORD type, DWORD flags, DIDEVICEINSTANCEW *instance, DWORD version )
 {
     DWORD size;
 
-    TRACE( "type %#x, flags %#x, instance %p, version %#04x, index %d\n", type, flags, instance, version, index );
-
-    if (index != 0) return DIERR_GENERIC;
-    if (flags & DIEDFL_FORCEFEEDBACK) return DI_NOEFFECT;
-    if (version < 0x0800 && type != 0 && type != DIDEVTYPE_MOUSE) return DI_NOEFFECT;
-    if (version >= 0x0800 && type != DI8DEVCLASS_ALL && type != DI8DEVCLASS_POINTER && type != DI8DEVTYPE_MOUSE)
-        return DI_NOEFFECT;
-
-    if (instance->dwSize != sizeof(DIDEVICEINSTANCEW) &&
-        instance->dwSize != sizeof(DIDEVICEINSTANCE_DX3W))
-        return DIERR_INVALIDPARAM;
+    TRACE( "type %#lx, flags %#lx, instance %p, version %#lx\n", type, flags, instance, version );
 
     size = instance->dwSize;
     memset( instance, 0, size );
@@ -104,9 +91,9 @@ static HRESULT mouse_enum_device( DWORD type, DWORD flags, DIDEVICEINSTANCEW *in
     return DI_OK;
 }
 
-static HRESULT mouse_create_device( IDirectInputImpl *dinput, const GUID *guid, IDirectInputDevice8W **out )
+HRESULT mouse_create_device( struct dinput *dinput, const GUID *guid, IDirectInputDevice8W **out )
 {
-    SysMouseImpl *impl;
+    struct mouse *impl;
     HKEY hkey, appkey;
     WCHAR buffer[20];
     HRESULT hr;
@@ -116,12 +103,11 @@ static HRESULT mouse_create_device( IDirectInputImpl *dinput, const GUID *guid,
     *out = NULL;
     if (!IsEqualGUID( &GUID_SysMouse, guid )) return DIERR_DEVICENOTREG;
 
-    if (FAILED(hr = direct_input_device_alloc( sizeof(SysMouseImpl), &mouse_vtbl,
-                                               guid, dinput, (void **)&impl )))
+    if (FAILED(hr = dinput_device_alloc( sizeof(struct mouse), &mouse_vtbl, guid, dinput, (void **)&impl )))
         return hr;
-    impl->base.crit.DebugInfo->Spare[0] = (DWORD_PTR)(__FILE__ ": SysMouseImpl*->base.crit");
+    impl->base.crit.DebugInfo->Spare[0] = (DWORD_PTR)(__FILE__ ": struct mouse*->base.crit");
 
-    mouse_enum_device( 0, 0, &impl->base.instance, dinput->dwVersion, 0 );
+    mouse_enum_device( 0, 0, &impl->base.instance, dinput->dwVersion );
     impl->base.caps.dwDevType = impl->base.instance.dwDevType;
     impl->base.caps.dwFirmwareRevision = 100;
     impl->base.caps.dwHardwareRevision = 100;
@@ -136,7 +122,7 @@ static HRESULT mouse_create_device( IDirectInputImpl *dinput, const GUID *guid,
     if (appkey) RegCloseKey(appkey);
     if (hkey) RegCloseKey(hkey);
 
-    if (FAILED(hr = direct_input_device_init( &impl->base.IDirectInputDevice8W_iface )))
+    if (FAILED(hr = dinput_device_init( &impl->base.IDirectInputDevice8W_iface )))
     {
         IDirectInputDevice_Release( &impl->base.IDirectInputDevice8W_iface );
         return hr;
@@ -153,20 +139,10 @@ static HRESULT mouse_create_device( IDirectInputImpl *dinput, const GUID *guid,
     return DI_OK;
 }
 
-const struct dinput_device mouse_device = {
-    "Wine mouse driver",
-    mouse_enum_device,
-    mouse_create_device
-};
-
-/******************************************************************************
- *	SysMouseA (DInput Mouse support)
- */
-
 void dinput_mouse_rawinput_hook( IDirectInputDevice8W *iface, WPARAM wparam, LPARAM lparam, RAWINPUT *ri )
 {
-    SysMouseImpl *This = impl_from_IDirectInputDevice8W( iface );
-    DIMOUSESTATE2 *state = (DIMOUSESTATE2 *)This->base.device_state;
+    struct mouse *impl = impl_from_IDirectInputDevice8W( iface );
+    DIMOUSESTATE2 *state = (DIMOUSESTATE2 *)impl->base.device_state;
     POINT rel, pt;
     DWORD seq;
     int i, wdata = 0;
@@ -181,15 +157,15 @@ void dinput_mouse_rawinput_hook( IDirectInputDevice8W *iface, WPARAM wparam, LPA
         RI_MOUSE_BUTTON_5_DOWN, RI_MOUSE_BUTTON_5_UP
     };
 
-    TRACE( "(%p) wp %08lx, lp %08lx\n", iface, wparam, lparam );
+    TRACE( "iface %p, wparam %#Ix, lparam %#Ix, ri %p.\n", iface, wparam, lparam, ri );
 
     if (ri->data.mouse.usFlags & MOUSE_VIRTUAL_DESKTOP)
         FIXME( "Unimplemented MOUSE_VIRTUAL_DESKTOP flag\n" );
     if (ri->data.mouse.usFlags & MOUSE_ATTRIBUTES_CHANGED)
         FIXME( "Unimplemented MOUSE_ATTRIBUTES_CHANGED flag\n" );
 
-    EnterCriticalSection( &This->base.crit );
-    seq = This->base.dinput->evsequence++;
+    EnterCriticalSection( &impl->base.crit );
+    seq = impl->base.dinput->evsequence++;
 
     rel.x = ri->data.mouse.lLastX;
     rel.y = ri->data.mouse.lLastY;
@@ -203,7 +179,7 @@ void dinput_mouse_rawinput_hook( IDirectInputDevice8W *iface, WPARAM wparam, LPA
     state->lX += rel.x;
     state->lY += rel.y;
 
-    if (This->base.data_format.user_df->dwFlags & DIDF_ABSAXIS)
+    if (impl->base.user_format->dwFlags & DIDF_ABSAXIS)
     {
         pt.x = state->lX;
         pt.y = state->lY;
@@ -229,9 +205,9 @@ void dinput_mouse_rawinput_hook( IDirectInputDevice8W *iface, WPARAM wparam, LPA
 
     if (rel.x || rel.y)
     {
-        if ((This->warp_override == WARP_FORCE_ON) ||
-            (This->warp_override != WARP_DISABLE && (This->base.dwCoopLevel & DISCL_EXCLUSIVE)))
-            This->need_warp = TRUE;
+        if ((impl->warp_override == WARP_FORCE_ON) ||
+            (impl->warp_override != WARP_DISABLE && (impl->base.dwCoopLevel & DISCL_EXCLUSIVE)))
+            impl->need_warp = TRUE;
     }
 
     if (ri->data.mouse.usButtonFlags & RI_MOUSE_WHEEL)
@@ -253,26 +229,26 @@ void dinput_mouse_rawinput_hook( IDirectInputDevice8W *iface, WPARAM wparam, LPA
         }
     }
 
-    TRACE( "buttons %02x %02x %02x %02x %02x, x %d, y %d, w %d\n", state->rgbButtons[0],
+    TRACE( "buttons %02x %02x %02x %02x %02x, x %+ld, y %+ld, w %+ld\n", state->rgbButtons[0],
            state->rgbButtons[1], state->rgbButtons[2], state->rgbButtons[3], state->rgbButtons[4],
            state->lX, state->lY, state->lZ );
 
-    if (notify && This->base.hEvent) SetEvent( This->base.hEvent );
-    LeaveCriticalSection( &This->base.crit );
+    if (notify && impl->base.hEvent) SetEvent( impl->base.hEvent );
+    LeaveCriticalSection( &impl->base.crit );
 }
 
 /* low-level mouse hook */
 int dinput_mouse_hook( IDirectInputDevice8W *iface, WPARAM wparam, LPARAM lparam )
 {
     MSLLHOOKSTRUCT *hook = (MSLLHOOKSTRUCT *)lparam;
-    SysMouseImpl *This = impl_from_IDirectInputDevice8W( iface );
-    DIMOUSESTATE2 *state = (DIMOUSESTATE2 *)This->base.device_state;
+    struct mouse *impl = impl_from_IDirectInputDevice8W( iface );
+    DIMOUSESTATE2 *state = (DIMOUSESTATE2 *)impl->base.device_state;
     int wdata = 0, inst_id = -1, ret = 0;
     BOOL notify = FALSE;
 
-    TRACE("msg %lx @ (%d %d)\n", wparam, hook->pt.x, hook->pt.y);
+    TRACE( "iface %p, msg %#Ix, x %+ld, y %+ld\n", iface, wparam, hook->pt.x, hook->pt.y );
 
-    EnterCriticalSection(&This->base.crit);
+    EnterCriticalSection( &impl->base.crit );
 
     switch(wparam) {
         case WM_MOUSEMOVE:
@@ -283,7 +259,7 @@ int dinput_mouse_hook( IDirectInputDevice8W *iface, WPARAM wparam, LPARAM lparam
             state->lX += pt.x = hook->pt.x - pt.x;
             state->lY += pt.y = hook->pt.y - pt.y;
 
-            if (This->base.data_format.user_df->dwFlags & DIDF_ABSAXIS)
+            if (impl->base.user_format->dwFlags & DIDF_ABSAXIS)
             {
                 pt1.x = state->lX;
                 pt1.y = state->lY;
@@ -300,8 +276,7 @@ int dinput_mouse_hook( IDirectInputDevice8W *iface, WPARAM wparam, LPARAM lparam
                 /* Already have X, need to queue it */
                 if (inst_id != -1)
                 {
-                    queue_event(iface, inst_id,
-                                wdata, GetCurrentTime(), This->base.dinput->evsequence);
+                    queue_event( iface, inst_id, wdata, GetCurrentTime(), impl->base.dinput->evsequence );
                     notify = TRUE;
                 }
                 inst_id = DIDFT_MAKEINSTANCE(WINE_MOUSE_Y_AXIS_INSTANCE) | DIDFT_RELAXIS;
@@ -310,9 +285,9 @@ int dinput_mouse_hook( IDirectInputDevice8W *iface, WPARAM wparam, LPARAM lparam
 
             if (pt.x || pt.y)
             {
-                if ((This->warp_override == WARP_FORCE_ON) ||
-                    (This->warp_override != WARP_DISABLE && (This->base.dwCoopLevel & DISCL_EXCLUSIVE)))
-                    This->need_warp = TRUE;
+                if ((impl->warp_override == WARP_FORCE_ON) ||
+                    (impl->warp_override != WARP_DISABLE && (impl->base.dwCoopLevel & DISCL_EXCLUSIVE)))
+                    impl->need_warp = TRUE;
             }
             break;
         }
@@ -321,7 +296,7 @@ int dinput_mouse_hook( IDirectInputDevice8W *iface, WPARAM wparam, LPARAM lparam
             state->lZ += wdata = (short)HIWORD( hook->mouseData );
             /* FarCry crashes if it gets a mouse wheel message */
             /* FIXME: should probably filter out other messages too */
-            ret = This->clipped;
+            ret = impl->clipped;
             break;
         case WM_LBUTTONDOWN:
             inst_id = DIDFT_MAKEINSTANCE(WINE_MOUSE_BUTTONS_INSTANCE + 0) | DIDFT_PSHBUTTON;
@@ -360,42 +335,41 @@ int dinput_mouse_hook( IDirectInputDevice8W *iface, WPARAM wparam, LPARAM lparam
 
     if (inst_id != -1)
     {
-        queue_event(iface, inst_id,
-                    wdata, GetCurrentTime(), This->base.dinput->evsequence++);
+        queue_event( iface, inst_id, wdata, GetCurrentTime(), impl->base.dinput->evsequence++ );
         notify = TRUE;
     }
 
-    TRACE( "buttons %02x %02x %02x %02x %02x, x %d, y %d, w %d\n", state->rgbButtons[0],
+    TRACE( "buttons %02x %02x %02x %02x %02x, x %+ld, y %+ld, w %+ld\n", state->rgbButtons[0],
            state->rgbButtons[1], state->rgbButtons[2], state->rgbButtons[3], state->rgbButtons[4],
            state->lX, state->lY, state->lZ );
 
-    if (notify && This->base.hEvent) SetEvent( This->base.hEvent );
-    LeaveCriticalSection(&This->base.crit);
+    if (notify && impl->base.hEvent) SetEvent( impl->base.hEvent );
+    LeaveCriticalSection( &impl->base.crit );
     return ret;
 }
 
-static void warp_check( SysMouseImpl* This, BOOL force )
+static void warp_check( struct mouse *impl, BOOL force )
 {
     DWORD now = GetCurrentTime();
-    const DWORD interval = This->clipped ? 500 : 10;
+    const DWORD interval = impl->clipped ? 500 : 10;
 
-    if (force || (This->need_warp && (now - This->last_warped > interval)))
+    if (force || (impl->need_warp && (now - impl->last_warped > interval)))
     {
         RECT rect, new_rect;
         POINT mapped_center;
 
-        This->last_warped = now;
-        This->need_warp = FALSE;
-        if (!GetClientRect(This->base.win, &rect)) return;
-        MapWindowPoints( This->base.win, 0, (POINT *)&rect, 2 );
-        if (!This->clipped)
+        impl->last_warped = now;
+        impl->need_warp = FALSE;
+        if (!GetClientRect( impl->base.win, &rect )) return;
+        MapWindowPoints( impl->base.win, 0, (POINT *)&rect, 2 );
+        if (!impl->clipped)
         {
             mapped_center.x = (rect.left + rect.right) / 2;
             mapped_center.y = (rect.top + rect.bottom) / 2;
-            TRACE("Warping mouse to %d - %d\n", mapped_center.x, mapped_center.y);
+            TRACE( "Warping mouse to x %+ld, y %+ld.\n", mapped_center.x, mapped_center.y );
             SetCursorPos( mapped_center.x, mapped_center.y );
         }
-        if (This->base.dwCoopLevel & DISCL_EXCLUSIVE)
+        if (impl->base.dwCoopLevel & DISCL_EXCLUSIVE)
         {
             /* make sure we clip even if the window covers the whole screen */
             rect.left = max( rect.left, GetSystemMetrics( SM_XVIRTUALSCREEN ) + 1 );
@@ -404,14 +378,14 @@ static void warp_check( SysMouseImpl* This, BOOL force )
             rect.bottom = min( rect.bottom, rect.top + GetSystemMetrics( SM_CYVIRTUALSCREEN ) - 2 );
             TRACE("Clipping mouse to %s\n", wine_dbgstr_rect( &rect ));
             ClipCursor( &rect );
-            This->clipped = GetClipCursor( &new_rect ) && EqualRect( &rect, &new_rect );
+            impl->clipped = GetClipCursor( &new_rect ) && EqualRect( &rect, &new_rect );
         }
     }
 }
 
 static HRESULT mouse_poll( IDirectInputDevice8W *iface )
 {
-    SysMouseImpl *impl = impl_from_IDirectInputDevice8W( iface );
+    struct mouse *impl = impl_from_IDirectInputDevice8W( iface );
     check_dinput_events();
     warp_check( impl, FALSE );
     return DI_OK;
@@ -419,13 +393,13 @@ static HRESULT mouse_poll( IDirectInputDevice8W *iface )
 
 static HRESULT mouse_acquire( IDirectInputDevice8W *iface )
 {
-    SysMouseImpl *impl = impl_from_IDirectInputDevice8W( iface );
+    struct mouse *impl = impl_from_IDirectInputDevice8W( iface );
     DIMOUSESTATE2 *state = (DIMOUSESTATE2 *)impl->base.device_state;
     POINT point;
 
     /* Init the mouse state */
     GetCursorPos( &point );
-    if (impl->base.data_format.user_df->dwFlags & DIDF_ABSAXIS)
+    if (impl->base.user_format->dwFlags & DIDF_ABSAXIS)
     {
         state->lX = point.x;
         state->lY = point.y;
@@ -463,7 +437,7 @@ static HRESULT mouse_acquire( IDirectInputDevice8W *iface )
 
 static HRESULT mouse_unacquire( IDirectInputDevice8W *iface )
 {
-    SysMouseImpl *impl = impl_from_IDirectInputDevice8W( iface );
+    struct mouse *impl = impl_from_IDirectInputDevice8W( iface );
 
     if (impl->base.dwCoopLevel & DISCL_EXCLUSIVE)
     {
@@ -579,35 +553,6 @@ static HRESULT mouse_enum_objects( IDirectInputDevice8W *iface, const DIPROPHEAD
     return DIENUM_CONTINUE;
 }
 
-static HRESULT mouse_get_property( IDirectInputDevice8W *iface, DWORD property,
-                                   DIPROPHEADER *header, DIDEVICEOBJECTINSTANCEW *instance )
-{
-    switch (property)
-    {
-    case (DWORD_PTR)DIPROP_RANGE:
-    {
-        DIPROPRANGE *range = (DIPROPRANGE *)header;
-        range->lMin = DIPROPRANGE_NOMIN;
-        range->lMax = DIPROPRANGE_NOMAX;
-        return DI_OK;
-    }
-    case (DWORD_PTR)DIPROP_GRANULARITY:
-    {
-        DIPROPDWORD *value = (DIPROPDWORD *)header;
-        if (instance->dwType == DIMOFS_Z) value->dwData = WHEEL_DELTA;
-        else value->dwData = 1;
-        return DI_OK;
-    }
-    }
-    return DIERR_UNSUPPORTED;
-}
-
-static HRESULT mouse_set_property( IDirectInputDevice8W *iface, DWORD property,
-                                   const DIPROPHEADER *header, const DIDEVICEOBJECTINSTANCEW *instance )
-{
-    return DIERR_UNSUPPORTED;
-}
-
 static const struct dinput_device_vtbl mouse_vtbl =
 {
     NULL,
@@ -616,8 +561,8 @@ static const struct dinput_device_vtbl mouse_vtbl =
     mouse_acquire,
     mouse_unacquire,
     mouse_enum_objects,
-    mouse_get_property,
-    mouse_set_property,
+    NULL,
+    NULL,
     NULL,
     NULL,
     NULL,
