@@ -32,11 +32,21 @@
 #include "dinputd.h"
 #include "devguid.h"
 #include "dbt.h"
+#include "unknwn.h"
+#include "winstring.h"
 
 #include "wine/hid.h"
 
 #include "dinput_test.h"
 
+#include "initguid.h"
+#include "roapi.h"
+#define WIDL_using_Windows_Foundation
+#define WIDL_using_Windows_Foundation_Collections
+#include "windows.foundation.h"
+#define WIDL_using_Windows_Gaming_Input
+#include "windows.gaming.input.h"
+
 static BOOL test_input_lost( DWORD version )
 {
 #include "psh_hid_macros.h"
@@ -86,7 +96,7 @@ static BOOL test_input_lost( DWORD version )
     DIJOYSTATE2 state;
     HRESULT hr;
 
-    winetest_push_context( "%#x", version );
+    winetest_push_context( "%#lx", version );
 
     GetCurrentDirectoryW( ARRAY_SIZE(cwd), cwd );
     GetTempPathW( ARRAY_SIZE(tempdir), tempdir );
@@ -97,53 +107,53 @@ static BOOL test_input_lost( DWORD version )
     if (FAILED(hr = dinput_test_create_device( version, &devinst, &device ))) goto done;
 
     hr = IDirectInputDevice8_SetDataFormat( device, &c_dfDIJoystick2 );
-    ok( hr == DI_OK, "SetDataFormat returned %#x\n", hr );
+    ok( hr == DI_OK, "SetDataFormat returned %#lx\n", hr );
     hr = IDirectInputDevice8_SetCooperativeLevel( device, 0, DISCL_NONEXCLUSIVE | DISCL_BACKGROUND );
-    ok( hr == DI_OK, "SetCooperativeLevel returned %#x\n", hr );
+    ok( hr == DI_OK, "SetCooperativeLevel returned %#lx\n", hr );
     hr = IDirectInputDevice8_SetProperty( device, DIPROP_BUFFERSIZE, &buffer_size.diph );
-    ok( hr == DI_OK, "SetProperty returned %#x\n", hr );
+    ok( hr == DI_OK, "SetProperty returned %#lx\n", hr );
 
     hr = IDirectInputDevice8_Acquire( device );
-    ok( hr == DI_OK, "Acquire returned %#x\n", hr );
+    ok( hr == DI_OK, "Acquire returned %#lx\n", hr );
     hr = IDirectInputDevice8_GetDeviceState( device, sizeof(state), &state );
-    ok( hr == DI_OK, "GetDeviceState returned %#x\n", hr );
+    ok( hr == DI_OK, "GetDeviceState returned %#lx\n", hr );
     size = version < 0x0800 ? sizeof(DIDEVICEOBJECTDATA_DX3) : sizeof(DIDEVICEOBJECTDATA);
     count = 1;
     hr = IDirectInputDevice8_GetDeviceData( device, size, objdata, &count, DIGDD_PEEK );
-    ok( hr == DI_OK, "GetDeviceData returned %#x\n", hr );
-    ok( count == 0, "got %u expected %u\n", count, 0 );
+    ok( hr == DI_OK, "GetDeviceData returned %#lx\n", hr );
+    ok( count == 0, "got %lu expected 0\n", count );
 
     pnp_driver_stop();
 
     hr = IDirectInputDevice8_GetDeviceState( device, sizeof(state), &state );
-    ok( hr == DIERR_INPUTLOST, "GetDeviceState returned %#x\n", hr );
+    ok( hr == DIERR_INPUTLOST, "GetDeviceState returned %#lx\n", hr );
     hr = IDirectInputDevice8_GetDeviceState( device, sizeof(state), &state );
-    ok( hr == DIERR_INPUTLOST, "GetDeviceState returned %#x\n", hr );
+    ok( hr == DIERR_INPUTLOST, "GetDeviceState returned %#lx\n", hr );
     hr = IDirectInputDevice8_GetDeviceData( device, size, objdata, &count, DIGDD_PEEK );
-    ok( hr == DIERR_INPUTLOST, "GetDeviceData returned %#x\n", hr );
+    ok( hr == DIERR_INPUTLOST, "GetDeviceData returned %#lx\n", hr );
     hr = IDirectInputDevice8_Poll( device );
-    ok( hr == DIERR_INPUTLOST, "Poll returned: %#x\n", hr );
+    ok( hr == DIERR_INPUTLOST, "Poll returned: %#lx\n", hr );
 
     hr = IDirectInputDevice8_Acquire( device );
-    ok( hr == DIERR_UNPLUGGED, "Acquire returned %#x\n", hr );
+    ok( hr == DIERR_UNPLUGGED, "Acquire returned %#lx\n", hr );
     hr = IDirectInputDevice8_GetDeviceState( device, sizeof(state), &state );
-    ok( hr == DIERR_NOTACQUIRED, "GetDeviceState returned %#x\n", hr );
+    ok( hr == DIERR_NOTACQUIRED, "GetDeviceState returned %#lx\n", hr );
     hr = IDirectInputDevice8_GetDeviceData( device, size, objdata, &count, DIGDD_PEEK );
-    ok( hr == DIERR_NOTACQUIRED, "GetDeviceData returned %#x\n", hr );
+    ok( hr == DIERR_NOTACQUIRED, "GetDeviceData returned %#lx\n", hr );
     hr = IDirectInputDevice8_Unacquire( device );
-    ok( hr == DI_NOEFFECT, "Unacquire returned: %#x\n", hr );
+    ok( hr == DI_NOEFFECT, "Unacquire returned: %#lx\n", hr );
 
     dinput_driver_start( report_desc, sizeof(report_desc), &hid_caps, NULL, 0 );
 
     hr = IDirectInputDevice8_Acquire( device );
     todo_wine
-    ok( hr == DIERR_UNPLUGGED, "Acquire returned %#x\n", hr );
+    ok( hr == DIERR_UNPLUGGED, "Acquire returned %#lx\n", hr );
     hr = IDirectInputDevice8_GetDeviceState( device, sizeof(state), &state );
     todo_wine
-    ok( hr == DIERR_NOTACQUIRED, "GetDeviceState returned %#x\n", hr );
+    ok( hr == DIERR_NOTACQUIRED, "GetDeviceState returned %#lx\n", hr );
 
     ref = IDirectInputDevice8_Release( device );
-    ok( ref == 0, "Release returned %d\n", ref );
+    ok( ref == 0, "Release returned %ld\n", ref );
 
 done:
     pnp_driver_stop();
@@ -192,7 +202,7 @@ static LRESULT CALLBACK devnotify_wndproc( HWND hwnd, UINT msg, WPARAM wparam, L
         }
 
         ok( hwnd == device_change_hwnd, "got hwnd %p\n", hwnd );
-        ok( header->dbch_devicetype == DBT_DEVTYP_DEVICEINTERFACE, "got dbch_devicetype %u\n",
+        ok( header->dbch_devicetype == DBT_DEVTYP_DEVICEINTERFACE, "got dbch_devicetype %lu\n",
             header->dbch_devicetype );
 
         winetest_push_context( "%u", device_change_count );
@@ -200,7 +210,7 @@ static LRESULT CALLBACK devnotify_wndproc( HWND hwnd, UINT msg, WPARAM wparam, L
         ok( IsEqualGUID( &iface->dbcc_classguid, &expect_guid ), "got dbch_classguid %s\n",
             debugstr_guid( &iface->dbcc_classguid ) );
         ok( iface->dbcc_size >= offsetof( DEV_BROADCAST_DEVICEINTERFACE_W, dbcc_name[wcslen( iface->dbcc_name ) + 1] ),
-            "got dbcc_size %u\n", iface->dbcc_size );
+            "got dbcc_size %lu\n", iface->dbcc_size );
         ok( !wcsncmp( iface->dbcc_name, expect_prefix, wcslen( expect_prefix ) ),
             "got dbcc_name %s\n", debugstr_w(iface->dbcc_name) );
 
@@ -211,9 +221,9 @@ static LRESULT CALLBACK devnotify_wndproc( HWND hwnd, UINT msg, WPARAM wparam, L
         ok( all_lower( upper_end, name_end ), "got dbcc_name %s\n", debugstr_w(iface->dbcc_name) );
 
         if (device_change_count++ >= device_change_expect / 2)
-            ok( wparam == DBT_DEVICEREMOVECOMPLETE, "got wparam %#x\n", (DWORD)wparam );
+            ok( wparam == DBT_DEVICEREMOVECOMPLETE, "got wparam %#Ix\n", wparam );
         else
-            ok( wparam == DBT_DEVICEARRIVAL, "got wparam %#x\n", (DWORD)wparam );
+            ok( wparam == DBT_DEVICEARRIVAL, "got wparam %#Ix\n", wparam );
 
         winetest_pop_context();
     }
@@ -245,22 +255,22 @@ static void test_RegisterDeviceNotification(void)
     RegisterClassExW( &class );
 
     hwnd = CreateWindowW( class.lpszClassName, NULL, 0, 0, 0, 0, 0, HWND_MESSAGE, NULL, NULL, NULL );
-    ok( !!hwnd, "CreateWindowW failed, error %u\n", GetLastError() );
+    ok( !!hwnd, "CreateWindowW failed, error %lu\n", GetLastError() );
 
     SetLastError( 0xdeadbeef );
     devnotify = RegisterDeviceNotificationA( NULL, NULL, 0 );
     ok( !devnotify, "RegisterDeviceNotificationA succeeded\n" );
-    ok( GetLastError() == ERROR_INVALID_PARAMETER, "got error %u\n", GetLastError() );
+    ok( GetLastError() == ERROR_INVALID_PARAMETER, "got error %lu\n", GetLastError() );
 
     SetLastError( 0xdeadbeef );
     devnotify = RegisterDeviceNotificationA( (HWND)0xdeadbeef, NULL, 0 );
     ok( !devnotify, "RegisterDeviceNotificationA succeeded\n" );
-    ok( GetLastError() == ERROR_INVALID_PARAMETER, "got error %u\n", GetLastError() );
+    ok( GetLastError() == ERROR_INVALID_PARAMETER, "got error %lu\n", GetLastError() );
 
     SetLastError( 0xdeadbeef );
     devnotify = RegisterDeviceNotificationA( hwnd, NULL, 2 );
     ok( !devnotify, "RegisterDeviceNotificationA succeeded\n" );
-    ok( GetLastError() == ERROR_INVALID_PARAMETER, "got error %u\n", GetLastError() );
+    ok( GetLastError() == ERROR_INVALID_PARAMETER, "got error %lu\n", GetLastError() );
 
     SetLastError( 0xdeadbeef );
     memset( header, 0, sizeof(DEV_BROADCAST_OEM) );
@@ -269,7 +279,7 @@ static void test_RegisterDeviceNotification(void)
     devnotify = RegisterDeviceNotificationA( hwnd, header, 0 );
     ok( !devnotify, "RegisterDeviceNotificationA succeeded\n" );
     ok( GetLastError() == ERROR_INVALID_DATA || GetLastError() == ERROR_SERVICE_SPECIFIC_ERROR,
-        "got error %u\n", GetLastError() );
+        "got error %lu\n", GetLastError() );
 
     SetLastError( 0xdeadbeef );
     memset( header, 0, sizeof(DEV_BROADCAST_DEVNODE) );
@@ -278,7 +288,7 @@ static void test_RegisterDeviceNotification(void)
     devnotify = RegisterDeviceNotificationA( hwnd, header, 0 );
     ok( !devnotify, "RegisterDeviceNotificationA succeeded\n" );
     ok( GetLastError() == ERROR_INVALID_DATA || GetLastError() == ERROR_SERVICE_SPECIFIC_ERROR,
-        "got error %u\n", GetLastError() );
+        "got error %lu\n", GetLastError() );
 
     SetLastError( 0xdeadbeef );
     memset( header, 0, sizeof(DEV_BROADCAST_VOLUME) );
@@ -287,7 +297,7 @@ static void test_RegisterDeviceNotification(void)
     devnotify = RegisterDeviceNotificationA( hwnd, header, 0 );
     ok( !devnotify, "RegisterDeviceNotificationA succeeded\n" );
     ok( GetLastError() == ERROR_INVALID_DATA || GetLastError() == ERROR_SERVICE_SPECIFIC_ERROR,
-        "got error %u\n", GetLastError() );
+        "got error %lu\n", GetLastError() );
 
     SetLastError( 0xdeadbeef );
     memset( header, 0, sizeof(DEV_BROADCAST_PORT_A) );
@@ -296,7 +306,7 @@ static void test_RegisterDeviceNotification(void)
     devnotify = RegisterDeviceNotificationA( hwnd, header, 0 );
     ok( !devnotify, "RegisterDeviceNotificationA succeeded\n" );
     ok( GetLastError() == ERROR_INVALID_DATA || GetLastError() == ERROR_SERVICE_SPECIFIC_ERROR,
-        "got error %u\n", GetLastError() );
+        "got error %lu\n", GetLastError() );
 
     SetLastError( 0xdeadbeef );
     memset( header, 0, sizeof(DEV_BROADCAST_NET) );
@@ -305,10 +315,10 @@ static void test_RegisterDeviceNotification(void)
     devnotify = RegisterDeviceNotificationA( hwnd, header, 0 );
     ok( !devnotify, "RegisterDeviceNotificationA succeeded\n" );
     ok( GetLastError() == ERROR_INVALID_DATA || GetLastError() == ERROR_SERVICE_SPECIFIC_ERROR,
-        "got error %u\n", GetLastError() );
+        "got error %lu\n", GetLastError() );
 
     devnotify = RegisterDeviceNotificationA( hwnd, &iface_filter_a, DEVICE_NOTIFY_WINDOW_HANDLE );
-    ok( !!devnotify, "RegisterDeviceNotificationA failed, error %u\n", GetLastError() );
+    ok( !!devnotify, "RegisterDeviceNotificationA failed, error %lu\n", GetLastError() );
     while (PeekMessageW( &msg, hwnd, 0, 0, PM_REMOVE )) DispatchMessageW( &msg );
 
     device_change_count = 0;
@@ -316,12 +326,13 @@ static void test_RegisterDeviceNotification(void)
     device_change_hwnd = hwnd;
     device_change_all = FALSE;
     stop_event = CreateEventW( NULL, FALSE, FALSE, NULL );
-    ok( !!stop_event, "CreateEventW failed, error %u\n", GetLastError() );
+    ok( !!stop_event, "CreateEventW failed, error %lu\n", GetLastError() );
     thread = CreateThread( NULL, 0, dinput_test_device_thread, stop_event, 0, NULL );
-    ok( !!thread, "CreateThread failed, error %u\n", GetLastError() );
+    ok( !!thread, "CreateThread failed, error %lu\n", GetLastError() );
 
     while (device_change_count < device_change_expect)
     {
+        MsgWaitForMultipleObjects( 0, NULL, FALSE, INFINITE, QS_ALLINPUT );
         while (PeekMessageW( &msg, hwnd, 0, 0, PM_REMOVE ))
         {
             TranslateMessage( &msg );
@@ -341,7 +352,7 @@ static void test_RegisterDeviceNotification(void)
     strcpy( ((DEV_BROADCAST_DEVICEINTERFACE_A *)buffer)->dbcc_name, "device name" );
     ((DEV_BROADCAST_DEVICEINTERFACE_A *)buffer)->dbcc_size += strlen( "device name" ) + 1;
     devnotify = RegisterDeviceNotificationA( hwnd, buffer, DEVICE_NOTIFY_WINDOW_HANDLE );
-    ok( !!devnotify, "RegisterDeviceNotificationA failed, error %u\n", GetLastError() );
+    ok( !!devnotify, "RegisterDeviceNotificationA failed, error %lu\n", GetLastError() );
     while (PeekMessageW( &msg, hwnd, 0, 0, PM_REMOVE )) DispatchMessageW( &msg );
 
     device_change_count = 0;
@@ -349,12 +360,13 @@ static void test_RegisterDeviceNotification(void)
     device_change_hwnd = hwnd;
     device_change_all = FALSE;
     stop_event = CreateEventW( NULL, FALSE, FALSE, NULL );
-    ok( !!stop_event, "CreateEventW failed, error %u\n", GetLastError() );
+    ok( !!stop_event, "CreateEventW failed, error %lu\n", GetLastError() );
     thread = CreateThread( NULL, 0, dinput_test_device_thread, stop_event, 0, NULL );
-    ok( !!thread, "CreateThread failed, error %u\n", GetLastError() );
+    ok( !!thread, "CreateThread failed, error %lu\n", GetLastError() );
 
     while (device_change_count < device_change_expect)
     {
+        MsgWaitForMultipleObjects( 0, NULL, FALSE, INFINITE, QS_ALLINPUT );
         while (PeekMessageW( &msg, hwnd, 0, 0, PM_REMOVE ))
         {
             TranslateMessage( &msg );
@@ -371,7 +383,7 @@ static void test_RegisterDeviceNotification(void)
     UnregisterDeviceNotification( devnotify );
 
     devnotify = RegisterDeviceNotificationA( hwnd, &iface_filter_a, DEVICE_NOTIFY_ALL_INTERFACE_CLASSES );
-    ok( !!devnotify, "RegisterDeviceNotificationA failed, error %u\n", GetLastError() );
+    ok( !!devnotify, "RegisterDeviceNotificationA failed, error %lu\n", GetLastError() );
     while (PeekMessageW( &msg, hwnd, 0, 0, PM_REMOVE )) DispatchMessageW( &msg );
 
     device_change_count = 0;
@@ -379,12 +391,13 @@ static void test_RegisterDeviceNotification(void)
     device_change_hwnd = hwnd;
     device_change_all = TRUE;
     stop_event = CreateEventW( NULL, FALSE, FALSE, NULL );
-    ok( !!stop_event, "CreateEventW failed, error %u\n", GetLastError() );
+    ok( !!stop_event, "CreateEventW failed, error %lu\n", GetLastError() );
     thread = CreateThread( NULL, 0, dinput_test_device_thread, stop_event, 0, NULL );
-    ok( !!thread, "CreateThread failed, error %u\n", GetLastError() );
+    ok( !!thread, "CreateThread failed, error %lu\n", GetLastError() );
 
     while (device_change_count < device_change_expect)
     {
+        MsgWaitForMultipleObjects( 0, NULL, FALSE, INFINITE, QS_ALLINPUT );
         while (PeekMessageW( &msg, hwnd, 0, 0, PM_REMOVE ))
         {
             TranslateMessage( &msg );
@@ -404,6 +417,236 @@ static void test_RegisterDeviceNotification(void)
     UnregisterClassW( class.lpszClassName, class.hInstance );
 }
 
+struct controller_handler
+{
+    IEventHandler_RawGameController IEventHandler_RawGameController_iface;
+    BOOL invoked;
+};
+
+static inline struct controller_handler *impl_from_IEventHandler_RawGameController( IEventHandler_RawGameController *iface )
+{
+    return CONTAINING_RECORD( iface, struct controller_handler, IEventHandler_RawGameController_iface );
+}
+
+static HRESULT WINAPI controller_handler_QueryInterface( IEventHandler_RawGameController *iface, REFIID iid, void **out )
+{
+    if (IsEqualGUID( iid, &IID_IUnknown ) ||
+        IsEqualGUID( iid, &IID_IAgileObject ) ||
+        IsEqualGUID( iid, &IID_IEventHandler_RawGameController ))
+    {
+        IUnknown_AddRef( iface );
+        *out = iface;
+        return S_OK;
+    }
+
+    trace( "%s not implemented, returning E_NOINTERFACE.\n", debugstr_guid( iid ) );
+    *out = NULL;
+    return E_NOINTERFACE;
+}
+
+static ULONG WINAPI controller_handler_AddRef( IEventHandler_RawGameController *iface )
+{
+    return 2;
+}
+
+static ULONG WINAPI controller_handler_Release( IEventHandler_RawGameController *iface )
+{
+    return 1;
+}
+
+static HRESULT WINAPI controller_handler_Invoke( IEventHandler_RawGameController *iface,
+                                                 IInspectable *sender, IRawGameController *controller )
+{
+    struct controller_handler *impl = impl_from_IEventHandler_RawGameController( iface );
+
+    trace( "iface %p, sender %p, controller %p\n", iface, sender, controller );
+
+    ok( sender == NULL, "got sender %p\n", sender );
+    impl->invoked = TRUE;
+
+    return S_OK;
+}
+
+static const IEventHandler_RawGameControllerVtbl controller_handler_vtbl =
+{
+    controller_handler_QueryInterface,
+    controller_handler_AddRef,
+    controller_handler_Release,
+    controller_handler_Invoke,
+};
+
+static struct controller_handler controller_removed = {{&controller_handler_vtbl}};
+static struct controller_handler controller_added = {{&controller_handler_vtbl}};
+
+static LRESULT CALLBACK windows_gaming_input_wndproc( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lparam )
+{
+    if (msg == WM_DEVICECHANGE)
+    {
+        winetest_push_context( "%u", device_change_count );
+        if (device_change_count++ >= device_change_expect / 2)
+        {
+            ok( wparam == DBT_DEVICEREMOVECOMPLETE, "got wparam %#Ix\n", wparam );
+            ok( controller_added.invoked, "controller added handler not invoked\n" );
+            ok( controller_removed.invoked, "controller removed handler not invoked\n" );
+        }
+        else
+        {
+            ok( wparam == DBT_DEVICEARRIVAL, "got wparam %#Ix\n", wparam );
+            ok( !controller_added.invoked, "controller added handler not invoked\n" );
+            ok( !controller_removed.invoked, "controller removed handler invoked\n" );
+        }
+        winetest_pop_context();
+    }
+
+    return DefWindowProcW( hwnd, msg, wparam, lparam );
+}
+
+static void test_windows_gaming_input(void)
+{
+    static const WCHAR *class_name = RuntimeClass_Windows_Gaming_Input_RawGameController;
+    DEV_BROADCAST_DEVICEINTERFACE_A iface_filter_a =
+    {
+        .dbcc_size = sizeof(DEV_BROADCAST_DEVICEINTERFACE_A),
+        .dbcc_devicetype = DBT_DEVTYP_DEVICEINTERFACE,
+        .dbcc_classguid = GUID_DEVINTERFACE_HID,
+    };
+    WNDCLASSEXW class =
+    {
+        .cbSize = sizeof(WNDCLASSEXW),
+        .hInstance = GetModuleHandleW( NULL ),
+        .lpszClassName = L"devnotify",
+        .lpfnWndProc = windows_gaming_input_wndproc,
+    };
+    EventRegistrationToken controller_removed_token;
+    IVectorView_RawGameController *controller_view;
+    EventRegistrationToken controller_added_token;
+    IRawGameControllerStatics *statics;
+    HANDLE hwnd, thread, stop_event;
+    HDEVNOTIFY devnotify;
+    BOOL removed;
+    HSTRING str;
+    UINT32 size;
+    HRESULT hr;
+    MSG msg;
+
+    hr = RoInitialize( RO_INIT_MULTITHREADED );
+    ok( hr == RPC_E_CHANGED_MODE, "RoInitialize failed, hr %#lx\n", hr );
+
+    hr = WindowsCreateString( class_name, wcslen( class_name ), &str );
+    ok( hr == S_OK, "WindowsCreateString failed, hr %#lx\n", hr );
+
+    hr = RoGetActivationFactory( str, &IID_IRawGameControllerStatics, (void **)&statics );
+    ok( hr == S_OK || broken( hr == REGDB_E_CLASSNOTREG ), "RoGetActivationFactory failed, hr %#lx\n", hr );
+    WindowsDeleteString( str );
+
+    if (hr == REGDB_E_CLASSNOTREG)
+    {
+        win_skip( "%s runtimeclass not registered, skipping tests.\n", wine_dbgstr_w( class_name ) );
+        RoUninitialize();
+        return;
+    }
+
+    hr = IRawGameControllerStatics_add_RawGameControllerAdded( statics, &controller_added.IEventHandler_RawGameController_iface,
+                                                               &controller_added_token );
+    ok( hr == S_OK, "add_RawGameControllerAdded returned %#lx\n", hr );
+    todo_wine
+    ok( controller_added_token.value, "got token %I64u\n", controller_added_token.value );
+    if (!controller_added_token.value) goto done;
+
+    hr = IRawGameControllerStatics_add_RawGameControllerRemoved( statics, &controller_removed.IEventHandler_RawGameController_iface,
+                                                                 &controller_removed_token );
+    ok( hr == S_OK, "add_RawGameControllerAdded returned %#lx\n", hr );
+
+    hr = IRawGameControllerStatics_get_RawGameControllers( statics, &controller_view );
+    ok( hr == S_OK, "get_RawGameControllers returned %#lx\n", hr );
+
+    RegisterClassExW( &class );
+
+    hwnd = CreateWindowW( class.lpszClassName, NULL, 0, 0, 0, 0, 0, HWND_MESSAGE, NULL, NULL, NULL );
+    ok( !!hwnd, "CreateWindowW failed, error %lu\n", GetLastError() );
+
+    devnotify = RegisterDeviceNotificationA( hwnd, &iface_filter_a, DEVICE_NOTIFY_WINDOW_HANDLE );
+    ok( !!devnotify, "RegisterDeviceNotificationA failed, error %lu\n", GetLastError() );
+    while (PeekMessageW( &msg, hwnd, 0, 0, PM_REMOVE )) DispatchMessageW( &msg );
+
+    device_change_count = 0;
+    device_change_expect = 2;
+    device_change_hwnd = hwnd;
+    device_change_all = FALSE;
+    stop_event = CreateEventW( NULL, FALSE, FALSE, NULL );
+    ok( !!stop_event, "CreateEventW failed, error %lu\n", GetLastError() );
+    thread = CreateThread( NULL, 0, dinput_test_device_thread, stop_event, 0, NULL );
+    ok( !!thread, "CreateThread failed, error %lu\n", GetLastError() );
+
+    removed = FALSE;
+    while (device_change_count < device_change_expect)
+    {
+        MsgWaitForMultipleObjects( 0, NULL, FALSE, 50, QS_ALLINPUT );
+        while (PeekMessageW( &msg, hwnd, 0, 0, PM_REMOVE ))
+        {
+            TranslateMessage( &msg );
+            ok( msg.message != WM_DEVICECHANGE, "got WM_DEVICECHANGE\n" );
+            DispatchMessageW( &msg );
+        }
+        if (controller_added.invoked && !removed)
+        {
+            ok( !controller_removed.invoked, "controller removed handler invoked\n" );
+            removed = TRUE;
+
+            hr = IVectorView_RawGameController_get_Size( controller_view, &size );
+            ok( hr == S_OK, "get_Size returned %#lx\n", hr );
+            ok( size == 0, "got size %u\n", size );
+
+            IVectorView_RawGameController_Release( controller_view );
+            hr = IRawGameControllerStatics_get_RawGameControllers( statics, &controller_view );
+            ok( hr == S_OK, "get_RawGameControllers returned %#lx\n", hr );
+
+            hr = IVectorView_RawGameController_get_Size( controller_view, &size );
+            ok( hr == S_OK, "get_Size returned %#lx\n", hr );
+            ok( size == 1, "got size %u\n", size );
+
+            SetEvent( stop_event );
+        }
+    }
+
+    ok( controller_added.invoked, "controller added handler not invoked\n" );
+    ok( controller_removed.invoked, "controller removed handler not invoked\n" );
+
+    hr = IVectorView_RawGameController_get_Size( controller_view, &size );
+    ok( hr == S_OK, "get_Size returned %#lx\n", hr );
+    ok( size == 1, "got size %u\n", size );
+
+    IVectorView_RawGameController_Release( controller_view );
+    hr = IRawGameControllerStatics_get_RawGameControllers( statics, &controller_view );
+    ok( hr == S_OK, "get_RawGameControllers returned %#lx\n", hr );
+
+    hr = IVectorView_RawGameController_get_Size( controller_view, &size );
+    ok( hr == S_OK, "get_Size returned %#lx\n", hr );
+    ok( size == 0, "got size %u\n", size );
+
+    hr = IRawGameControllerStatics_remove_RawGameControllerAdded( statics, controller_added_token );
+    ok( hr == S_OK, "remove_RawGameControllerAdded returned %#lx\n", hr );
+    hr = IRawGameControllerStatics_remove_RawGameControllerRemoved( statics, controller_removed_token );
+    ok( hr == S_OK, "remove_RawGameControllerRemoved returned %#lx\n", hr );
+    hr = IRawGameControllerStatics_remove_RawGameControllerRemoved( statics, controller_removed_token );
+    ok( hr == S_OK, "remove_RawGameControllerRemoved returned %#lx\n", hr );
+
+    IVectorView_RawGameController_Release( controller_view );
+    IRawGameControllerStatics_Release( statics );
+
+    WaitForSingleObject( thread, INFINITE );
+    CloseHandle( thread );
+    CloseHandle( stop_event );
+
+    UnregisterDeviceNotification( devnotify );
+
+    DestroyWindow( hwnd );
+    UnregisterClassW( class.lpszClassName, class.hInstance );
+
+done:
+    RoUninitialize();
+}
+
 START_TEST( hotplug )
 {
     if (!dinput_test_init()) return;
@@ -415,6 +658,7 @@ START_TEST( hotplug )
         test_input_lost( 0x800 );
 
         test_RegisterDeviceNotification();
+        test_windows_gaming_input();
     }
     CoUninitialize();
 
