@@ -75,7 +75,7 @@ ULONG WINAPI update_manager_AddRef(IDirectManipulationUpdateManager *iface)
     struct directupdatemanager *This = impl_from_IDirectManipulationUpdateManager(iface);
     ULONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%u\n", This, ref);
+    TRACE("(%p) ref=%lu\n", This, ref);
 
     return ref;
 }
@@ -85,7 +85,7 @@ ULONG WINAPI update_manager_Release(IDirectManipulationUpdateManager *iface)
     struct directupdatemanager *This = impl_from_IDirectManipulationUpdateManager(iface);
     ULONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%u\n", This, ref);
+    TRACE("(%p) ref=%lu\n", This, ref);
 
     if (!ref)
     {
@@ -105,7 +105,7 @@ static HRESULT WINAPI update_manager_RegisterWaitHandleCallback(IDirectManipulat
 static HRESULT WINAPI update_manager_UnregisterWaitHandleCallback(IDirectManipulationUpdateManager *iface, DWORD cookie)
 {
     struct directupdatemanager *This = impl_from_IDirectManipulationUpdateManager(iface);
-    FIXME("%p, %x\n", This, cookie);
+    FIXME("%p, %lx\n", This, cookie);
     return E_NOTIMPL;
 }
 
@@ -187,7 +187,7 @@ static ULONG WINAPI primary_AddRef(IDirectManipulationPrimaryContent *iface)
     struct primarycontext *This = impl_from_IDirectManipulationPrimaryContent(iface);
     ULONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%u\n", This, ref);
+    TRACE("(%p) ref=%lu\n", This, ref);
 
     return ref;
 }
@@ -197,7 +197,7 @@ static ULONG WINAPI primary_Release(IDirectManipulationPrimaryContent *iface)
     struct primarycontext *This = impl_from_IDirectManipulationPrimaryContent(iface);
     ULONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%u\n", This, ref);
+    TRACE("(%p) ref=%lu\n", This, ref);
 
     if (!ref)
     {
@@ -218,7 +218,7 @@ static HRESULT WINAPI primary_SetSnapPoints(IDirectManipulationPrimaryContent *i
             const float *points, DWORD count)
 {
     struct primarycontext *This = impl_from_IDirectManipulationPrimaryContent(iface);
-    FIXME("%p, %d, %p, %d\n", This, motion, points, count);
+    FIXME("%p, %d, %p, %ld\n", This, motion, points, count);
     return E_NOTIMPL;
 }
 
@@ -262,7 +262,7 @@ static HRESULT WINAPI primary_SetVerticalAlignment(IDirectManipulationPrimaryCon
 static HRESULT WINAPI primary_GetInertiaEndTransform(IDirectManipulationPrimaryContent *iface, float *matrix, DWORD count)
 {
     struct primarycontext *This = impl_from_IDirectManipulationPrimaryContent(iface);
-    FIXME("%p,  %p, %d\n", This, matrix, count);
+    FIXME("%p,  %p, %ld\n", This, matrix, count);
     return E_NOTIMPL;
 }
 
@@ -350,7 +350,7 @@ static HRESULT WINAPI content_GetOutputTransform(IDirectManipulationContent *ifa
                     float *matrix, DWORD count)
 {
     struct primarycontext *This = impl_from_IDirectManipulationContent(iface);
-    FIXME("%p, %p, %d\n", This, matrix, count);
+    FIXME("%p, %p, %ld\n", This, matrix, count);
     return E_NOTIMPL;
 }
 
@@ -358,7 +358,7 @@ static HRESULT WINAPI content_GetContentTransform(IDirectManipulationContent *if
                     float *matrix, DWORD count)
 {
     struct primarycontext *This = impl_from_IDirectManipulationContent(iface);
-    FIXME("%p, %p, %d\n", This, matrix, count);
+    FIXME("%p, %p, %ld\n", This, matrix, count);
     return E_NOTIMPL;
 }
 
@@ -366,7 +366,7 @@ static HRESULT WINAPI content_SyncContentTransform(IDirectManipulationContent *i
                     const float *matrix, DWORD count)
 {
     struct primarycontext *This = impl_from_IDirectManipulationContent(iface);
-    FIXME("%p, %p, %d\n", This, matrix, count);
+    FIXME("%p, %p, %ld\n", This, matrix, count);
     return E_NOTIMPL;
 }
 
@@ -419,7 +419,7 @@ static ULONG WINAPI viewport_AddRef(IDirectManipulationViewport2 *iface)
     struct directviewport *This = impl_from_IDirectManipulationViewport2(iface);
     ULONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%u\n", This, ref);
+    TRACE("(%p) ref=%lu\n", This, ref);
 
     return ref;
 }
@@ -429,7 +429,7 @@ static ULONG WINAPI viewport_Release(IDirectManipulationViewport2 *iface)
     struct directviewport *This = impl_from_IDirectManipulationViewport2(iface);
     ULONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%u\n", This, ref);
+    TRACE("(%p) ref=%lu\n", This, ref);
 
     if (!ref)
     {
@@ -520,7 +520,7 @@ static HRESULT WINAPI viewport_SetViewportTransform(IDirectManipulationViewport2
                     const float *matrix, DWORD count)
 {
     struct directviewport *This = impl_from_IDirectManipulationViewport2(iface);
-    FIXME("%p, %p, %d\n", This, matrix, count);
+    FIXME("%p, %p, %ld\n", This, matrix, count);
     return E_NOTIMPL;
 }
 
@@ -528,7 +528,7 @@ static HRESULT WINAPI viewport_SyncDisplayTransform(IDirectManipulationViewport2
                     const float *matrix, DWORD count)
 {
     struct directviewport *This = impl_from_IDirectManipulationViewport2(iface);
-    FIXME("%p, %p, %d\n", This, matrix, count);
+    FIXME("%p, %p, %ld\n", This, matrix, count);
     return E_NOTIMPL;
 }
 
@@ -624,7 +624,7 @@ static HRESULT WINAPI viewport_AddEventHandler(IDirectManipulationViewport2 *ifa
 static HRESULT WINAPI viewport_RemoveEventHandler(IDirectManipulationViewport2 *iface, DWORD cookie)
 {
     struct directviewport *This = impl_from_IDirectManipulationViewport2(iface);
-    FIXME("%p, %d\n", This, cookie);
+    FIXME("%p, %ld\n", This, cookie);
     return E_NOTIMPL;
 }
 
@@ -666,7 +666,7 @@ static HRESULT WINAPI viewport_AddBehavior(IDirectManipulationViewport2 *iface,
 static HRESULT WINAPI viewport_RemoveBehavior(IDirectManipulationViewport2 *iface, DWORD cookie)
 {
     struct directviewport *This = impl_from_IDirectManipulationViewport2(iface);
-    FIXME("%p, %d\n", This, cookie);
+    FIXME("%p, %ld\n", This, cookie);
     return E_NOTIMPL;
 }
 
@@ -750,7 +750,7 @@ static ULONG WINAPI direct_manip_AddRef(IDirectManipulationManager2 *iface)
     struct directmanipulation *This = impl_from_IDirectManipulationManager2(iface);
     ULONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%u\n", This, ref);
+    TRACE("(%p) ref=%lu\n", This, ref);
 
     return ref;
 }
@@ -760,7 +760,7 @@ static ULONG WINAPI direct_manip_Release(IDirectManipulationManager2 *iface)
     struct directmanipulation *This = impl_from_IDirectManipulationManager2(iface);
     ULONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%u\n", This, ref);
+    TRACE("(%p) ref=%lu\n", This, ref);
 
     if (!ref)
     {
@@ -946,7 +946,7 @@ static ULONG WINAPI compositor_AddRef(IDirectManipulationCompositor2 *iface)
     struct directcompositor *This = impl_from_IDirectManipulationCompositor2(iface);
     ULONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%u\n", This, ref);
+    TRACE("(%p) ref=%lu\n", This, ref);
 
     return ref;
 }
@@ -956,7 +956,7 @@ static ULONG WINAPI compositor_Release(IDirectManipulationCompositor2 *iface)
     struct directcompositor *This = impl_from_IDirectManipulationCompositor2(iface);
     ULONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%u\n", This, ref);
+    TRACE("(%p) ref=%lu\n", This, ref);
 
     if (!ref)
     {
