@@ -44,8 +44,7 @@ struct scriptshaping_cache *create_scriptshaping_cache(void *context, const stru
 {
     struct scriptshaping_cache *cache;
 
-    cache = heap_alloc_zero(sizeof(*cache));
-    if (!cache)
+    if (!(cache = calloc(1, sizeof(*cache))))
         return NULL;
 
     cache->font = font_ops;
@@ -65,13 +64,13 @@ void release_scriptshaping_cache(struct scriptshaping_cache *cache)
     cache->font->release_font_table(cache->context, cache->gdef.table.context);
     cache->font->release_font_table(cache->context, cache->gsub.table.context);
     cache->font->release_font_table(cache->context, cache->gpos.table.context);
-    heap_free(cache);
+    free(cache);
 }
 
-static unsigned int shape_select_script(const struct scriptshaping_cache *cache, DWORD kind, const DWORD *scripts,
+static unsigned int shape_select_script(const struct scriptshaping_cache *cache, DWORD kind, const unsigned int *scripts,
         unsigned int *script_index)
 {
-    static const DWORD fallback_scripts[] =
+    static const unsigned int fallback_scripts[] =
     {
         DWRITE_MAKE_OPENTYPE_TAG('D','F','L','T'),
         DWRITE_MAKE_OPENTYPE_TAG('d','f','l','t'),
@@ -148,7 +147,7 @@ void shape_start_next_stage(struct shaping_features *features, stage_func func)
     features->stage++;
 }
 
-static int features_sorting_compare(const void *a, const void *b)
+static int __cdecl features_sorting_compare(const void *a, const void *b)
 {
     const struct shaping_feature *left = a, *right = b;
     return left->tag != right->tag ? (left->tag < right->tag ? -1 : 1) : 0;
@@ -269,7 +268,7 @@ HRESULT shape_get_positions(struct scriptshaping_context *context, const unsigne
         if (context->u.pos.glyph_props[i].isZeroWidthSpace)
             context->advances[i] = 0.0f;
 
-    heap_free(features.features);
+    free(features.features);
 
     return S_OK;
 }
@@ -347,12 +346,12 @@ HRESULT shape_get_glyphs(struct scriptshaping_context *context, const unsigned i
     shape_get_script_lang_index(context, scripts, MS_GSUB_TAG, &script_index, &language_index);
     opentype_layout_apply_gsub_features(context, script_index, language_index, &features);
 
-    heap_free(features.features);
+    free(features.features);
 
     return (context->glyph_count <= context->u.subst.max_glyph_count) ? S_OK : E_NOT_SUFFICIENT_BUFFER;
 }
 
-static int tag_array_sorting_compare(const void *a, const void *b)
+static int __cdecl tag_array_sorting_compare(const void *a, const void *b)
 {
     unsigned int left = GET_BE_DWORD(*(unsigned int *)a), right = GET_BE_DWORD(*(unsigned int *)b);
     return left != right ? (left < right ? -1 : 1) : 0;
@@ -372,6 +371,12 @@ HRESULT shape_get_typographic_features(struct scriptshaping_context *context, co
     shape_get_script_lang_index(context, scripts, MS_GPOS_TAG, &script_index, &language_index);
     opentype_get_typographic_features(&context->cache->gpos, script_index, language_index, &t);
 
+    if (t.count == 0)
+    {
+        *actual_tagcount = 0;
+        return S_OK;
+    }
+
     /* Sort and remove duplicates. */
     qsort(t.tags, t.count, sizeof(*t.tags), tag_array_sorting_compare);
 
@@ -387,7 +392,7 @@ HRESULT shape_get_typographic_features(struct scriptshaping_context *context, co
 
     *actual_tagcount = t.count;
 
-    heap_free(t.tags);
+    free(t.tags);
 
     return t.count <= max_tagcount ? S_OK : E_NOT_SUFFICIENT_BUFFER;
 }
