@@ -192,7 +192,7 @@ static DWORD treeview_style_from_nstcs(NSTC2Impl *This, NSTCSTYLE nstcs,
                                        NSTCSTYLE nstcs_mask, DWORD *new_style)
 {
     DWORD old_style, tv_mask = 0;
-    TRACE("%p, %x, %x, %p\n", This, nstcs, nstcs_mask, new_style);
+    TRACE("%p, %lx, %lx, %p\n", This, nstcs, nstcs_mask, new_style);
 
     if(This->hwnd_tv)
         old_style = GetWindowLongPtrW(This->hwnd_tv, GWL_STYLE);
@@ -232,7 +232,7 @@ static DWORD treeview_style_from_nstcs(NSTC2Impl *This, NSTCSTYLE nstcs,
 
     *new_style = (old_style & ~tv_mask) | (*new_style & tv_mask);
 
-    TRACE("old: %08x, new: %08x\n", old_style, *new_style);
+    TRACE("old: %08lx, new: %08lx\n", old_style, *new_style);
 
     return old_style^*new_style;
 }
@@ -397,22 +397,22 @@ static UINT fill_sublevel(NSTC2Impl *This, HTREEITEM hitem)
                         IShellItem_Release(psi);
                     }
                     else
-                        ERR("SHCreateShellItem failed with 0x%08x\n", hr);
+                        ERR("SHCreateShellItem failed with 0x%08lx\n", hr);
                 }
                 IEnumIDList_Release(peidl);
             }
             else
-                ERR("EnumObjects failed with 0x%08x\n", hr);
+                ERR("EnumObjects failed with 0x%08lx\n", hr);
 
             IShellFolder_Release(psf);
         }
         else
-            ERR("BindToHandler failed with 0x%08x\n", hr);
+            ERR("BindToHandler failed with 0x%08lx\n", hr);
 
         ILFree(pidl_parent);
     }
     else
-        ERR("SHGetIDListFromObject failed with 0x%08x\n", hr);
+        ERR("SHGetIDListFromObject failed with 0x%08lx\n", hr);
 
     return added;
 }
@@ -590,7 +590,7 @@ static LRESULT on_tvn_getdispinfow(NSTC2Impl *This, LPARAM lParam)
                 ILFree(pidl);
             }
             else
-                ERR("Failed to get IDList (%08x).\n", hr);
+                ERR("Failed to get IDList (%08lx).\n", hr);
         }
     }
 
@@ -606,7 +606,7 @@ static LRESULT on_tvn_getdispinfow(NSTC2Impl *This, LPARAM lParam)
             CoTaskMemFree(display_name);
         }
         else
-            ERR("Failed to get display name (%08x).\n", hr);
+            ERR("Failed to get display name (%08lx).\n", hr);
     }
 
     return TRUE;
@@ -700,7 +700,7 @@ static LRESULT on_wm_mbuttonup(NSTC2Impl *This, WPARAM wParam, LPARAM lParam)
     TVHITTESTINFO tvhit;
     IShellItem *psi;
     HRESULT hr;
-    TRACE("%p (%lx, %lx)\n", This, wParam, lParam);
+    TRACE("%p (%Ix, %Ix)\n", This, wParam, lParam);
 
     tvhit.pt.x = (int)(short)LOWORD(lParam);
     tvhit.pt.y = (int)(short)HIWORD(lParam);
@@ -724,7 +724,7 @@ static LRESULT on_kbd_event(NSTC2Impl *This, UINT uMsg, WPARAM wParam, LPARAM lP
 {
     IShellItem *psi;
     HTREEITEM hitem;
-    TRACE("%p : %d, %lx, %lx\n", This, uMsg, wParam, lParam);
+    TRACE("%p : %d, %Ix, %Ix\n", This, uMsg, wParam, lParam);
 
     /* Handled by the client? */
     if(FAILED(events_OnKeyboardInput(This, uMsg, wParam, lParam)))
@@ -837,7 +837,7 @@ static ULONG WINAPI NSTC2_fnAddRef(INameSpaceTreeControl2* iface)
     NSTC2Impl *This = impl_from_INameSpaceTreeControl2(iface);
     LONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("%p - ref %d\n", This, ref);
+    TRACE("%p - ref %ld\n", This, ref);
 
     return ref;
 }
@@ -847,7 +847,7 @@ static ULONG WINAPI NSTC2_fnRelease(INameSpaceTreeControl2* iface)
     NSTC2Impl *This = impl_from_INameSpaceTreeControl2(iface);
     LONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("%p - ref: %d\n", This, ref);
+    TRACE("%p - ref: %ld\n", This, ref);
 
     if(!ref)
     {
@@ -871,10 +871,10 @@ static HRESULT WINAPI NSTC2_fnInitialize(INameSpaceTreeControl2* iface,
     RECT rc;
     static const WCHAR NSTC2_CLASS_NAME[] = L"NamespaceTreeControl";
 
-    TRACE("%p (%p, %p, %x)\n", This, hwndParent, prc, nstcsFlags);
+    TRACE("%p (%p, %p, %lx)\n", This, hwndParent, prc, nstcsFlags);
 
     if(nstcsFlags & unsupported_styles)
-        FIXME("0x%08x contains the unsupported style(s) 0x%08x\n",
+        FIXME("0x%08lx contains the unsupported style(s) 0x%08lx\n",
               nstcsFlags, nstcsFlags & unsupported_styles);
 
     This->style = nstcsFlags;
@@ -949,7 +949,7 @@ static HRESULT WINAPI NSTC2_fnTreeUnadvise(INameSpaceTreeControl2* iface, DWORD
 {
     NSTC2Impl *This = impl_from_INameSpaceTreeControl2(iface);
 
-    TRACE("%p (%x)\n", This, cookie);
+    TRACE("%p (%lx)\n", This, cookie);
 
     /* The cookie is ignored. */
 
@@ -987,7 +987,7 @@ static HRESULT WINAPI NSTC2_fnInsertRoot(INameSpaceTreeControl2* iface,
     HTREEITEM add_after_hitem;
     int i;
 
-    TRACE("%p, %d, %p, %x, %x, %p\n", This, iIndex, psiRoot, grfEnumFlags, grfRootStyle, pif);
+    TRACE("%p, %d, %p, %lx, %lx, %p\n", This, iIndex, psiRoot, grfEnumFlags, grfRootStyle, pif);
 
     new_root = heap_alloc(sizeof(*new_root));
     if(!new_root)
@@ -1045,7 +1045,7 @@ static HRESULT WINAPI NSTC2_fnAppendRoot(INameSpaceTreeControl2* iface,
 {
     NSTC2Impl *This = impl_from_INameSpaceTreeControl2(iface);
     UINT root_count;
-    TRACE("%p, %p, %x, %x, %p\n",
+    TRACE("%p, %p, %lx, %lx, %p\n",
           This, psiRoot, grfEnumFlags, grfRootStyle, pif);
 
     root_count = list_count(&This->roots);
@@ -1151,7 +1151,7 @@ static HRESULT WINAPI NSTC2_fnSetItemState(INameSpaceTreeControl2* iface,
     TVITEMEXW tvi;
     HTREEITEM hitem;
 
-    TRACE("%p (%p, %x, %x)\n", This, psi, nstcisMask, nstcisFlags);
+    TRACE("%p (%p, %lx, %lx)\n", This, psi, nstcisMask, nstcisFlags);
 
     hitem = treeitem_from_shellitem(This, psi);
     if(!hitem) return E_INVALIDARG;
@@ -1213,7 +1213,7 @@ static HRESULT WINAPI NSTC2_fnGetItemState(INameSpaceTreeControl2* iface,
     NSTC2Impl *This = impl_from_INameSpaceTreeControl2(iface);
     HTREEITEM hitem;
     TVITEMEXW tvi;
-    TRACE("%p (%p, %x, %p)\n", This, psi, nstcisMask, pnstcisFlags);
+    TRACE("%p (%p, %lx, %p)\n", This, psi, nstcisMask, pnstcisFlags);
 
     hitem = treeitem_from_shellitem(This, psi);
     if(!hitem)
@@ -1425,7 +1425,7 @@ static HRESULT WINAPI NSTC2_fnSetControlStyle(INameSpaceTreeControl2* iface,
         NSTCS_SINGLECLICKEXPAND | NSTCS_NOREPLACEOPEN | NSTCS_NOORDERSTREAM |
         NSTCS_FAVORITESMODE | NSTCS_EMPTYTEXT | NSTCS_ALLOWJUNCTIONS |
         NSTCS_SHOWTABSBUTTON | NSTCS_SHOWDELETEBUTTON | NSTCS_SHOWREFRESHBUTTON;
-    TRACE("%p (%x, %x)\n", This, nstcsMask, nstcsStyle);
+    TRACE("%p (%lx, %lx)\n", This, nstcsMask, nstcsStyle);
 
     /* Fail if there is an attempt to set an unknown style. */
     if(nstcsMask & ~(tv_style_flags | host_style_flags | nstc_flags))
@@ -1455,7 +1455,7 @@ static HRESULT WINAPI NSTC2_fnSetControlStyle(INameSpaceTreeControl2* iface,
     }
 
     if((nstcsStyle & nstcsMask) & unsupported_styles)
-        FIXME("mask & style (0x%08x) contains unsupported style(s): 0x%08x\n",
+        FIXME("mask & style (0x%08lx) contains unsupported style(s): 0x%08lx\n",
               (nstcsStyle & nstcsMask),
               (nstcsStyle & nstcsMask) & unsupported_styles);
 
@@ -1470,7 +1470,7 @@ static HRESULT WINAPI NSTC2_fnGetControlStyle(INameSpaceTreeControl2* iface,
                                               NSTCSTYLE *pnstcsStyle)
 {
     NSTC2Impl *This = impl_from_INameSpaceTreeControl2(iface);
-    TRACE("%p (%x, %p)\n", This, nstcsMask, pnstcsStyle);
+    TRACE("%p (%lx, %p)\n", This, nstcsMask, pnstcsStyle);
 
     *pnstcsStyle = (This->style & nstcsMask);
 
@@ -1485,7 +1485,7 @@ static HRESULT WINAPI NSTC2_fnSetControlStyle2(INameSpaceTreeControl2* iface,
     TRACE("%p (%x, %x)\n", This, nstcsMask, nstcsStyle);
 
     if((nstcsStyle & nstcsMask) & unsupported_styles2)
-        FIXME("mask & style (0x%08x) contains unsupported style(s): 0x%08x\n",
+        FIXME("mask & style (0x%08x) contains unsupported style(s): 0x%08lx\n",
               (nstcsStyle & nstcsMask),
               (nstcsStyle & nstcsMask) & unsupported_styles2);
 
