@@ -28,8 +28,6 @@
 
 WINE_DEFAULT_DEBUG_CHANNEL(hlink);
 
-static HINSTANCE instance;
-
 typedef HRESULT (*LPFNCREATEINSTANCE)(IUnknown*, REFIID, LPVOID*);
 
 typedef struct
@@ -43,28 +41,6 @@ static inline CFImpl *impl_from_IClassFactory(IClassFactory *iface)
     return CONTAINING_RECORD(iface, CFImpl, IClassFactory_iface);
 }
 
-BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved)
-{
-    TRACE("%p %d %p\n", hinstDLL, fdwReason, lpvReserved);
-
-    switch (fdwReason)
-    {
-    case DLL_PROCESS_ATTACH:
-        instance = hinstDLL;
-        DisableThreadLibraryCalls(hinstDLL);
-        break;
-    }
-    return TRUE;
-}
-
-/***********************************************************************
- *             DllCanUnloadNow (HLINK.@)
- */
-HRESULT WINAPI DllCanUnloadNow( void )
-{
-    return S_FALSE;
-}
-
 /***********************************************************************
  *             HlinkCreateFromMoniker (HLINK.@)
  */
@@ -75,7 +51,7 @@ HRESULT WINAPI HlinkCreateFromMoniker( IMoniker *pimkTrgt, LPCWSTR pwzLocation,
     IHlink *hl = NULL;
     HRESULT r;
 
-    TRACE("%p %s %s %p %i %p %s %p\n", pimkTrgt, debugstr_w(pwzLocation),
+    TRACE("%p %s %s %p %li %p %s %p\n", pimkTrgt, debugstr_w(pwzLocation),
             debugstr_w(pwzFriendlyName), pihlsite, dwSiteData, piunkOuter,
             debugstr_guid(riid), ppvObj);
 
@@ -92,7 +68,7 @@ HRESULT WINAPI HlinkCreateFromMoniker( IMoniker *pimkTrgt, LPCWSTR pwzLocation,
 
     *ppvObj = hl;
 
-    TRACE("Returning %i\n",r);
+    TRACE("Returning %lx\n",r);
 
     return r;
 }
@@ -109,7 +85,7 @@ HRESULT WINAPI HlinkCreateFromString( LPCWSTR pwzTarget, LPCWSTR pwzLocation,
     WCHAR *hash, *tgt;
     const WCHAR *loc;
 
-    TRACE("%s %s %s %p %i %p %s %p\n", debugstr_w(pwzTarget),
+    TRACE("%s %s %s %p %li %p %s %p\n", debugstr_w(pwzTarget),
             debugstr_w(pwzLocation), debugstr_w(pwzFriendlyName), pihlsite,
             dwSiteData, piunkOuter, debugstr_guid(riid), ppvObj);
 
@@ -162,7 +138,7 @@ HRESULT WINAPI HlinkCreateFromString( LPCWSTR pwzTarget, LPCWSTR pwzLocation,
     if (pihlsite)
         IHlink_SetHlinkSite(hl, pihlsite, dwSiteData);
 
-    TRACE("Returning %i\n",r);
+    TRACE("Returning %lx\n",r);
     *ppvObj = hl;
 
     return r;
@@ -187,7 +163,7 @@ HRESULT WINAPI HlinkNavigate(IHlink *phl, IHlinkFrame *phlFrame,
 {
     HRESULT r = S_OK;
 
-    TRACE("%p %p %i %p %p %p\n", phl, phlFrame, grfHLNF, pbc, pbsc, phlbc);
+    TRACE("%p %p %li %p %p %p\n", phl, phlFrame, grfHLNF, pbc, pbsc, phlbc);
 
     if (phlFrame)
         r = IHlinkFrame_Navigate(phlFrame, grfHLNF, pbc, pbsc, phl);
@@ -206,7 +182,7 @@ HRESULT WINAPI HlinkOnNavigate( IHlinkFrame *phlFrame,
 {
     HRESULT r;
 
-    TRACE("%p %p %i %p %s %s %p\n",phlFrame, phlbc, grfHLNF, pmkTarget,
+    TRACE("%p %p %li %p %s %s %p\n",phlFrame, phlbc, grfHLNF, pmkTarget,
             debugstr_w(pwzLocation), debugstr_w(pwzFriendlyName), puHLID);
 
     r = IHlinkBrowseContext_OnNavigateHlink(phlbc, grfHLNF, pmkTarget,
@@ -226,7 +202,7 @@ HRESULT WINAPI HlinkCreateFromData(IDataObject *piDataObj,
         IHlinkSite *pihlsite, DWORD dwSiteData, IUnknown *piunkOuter,
         REFIID riid, void **ppvObj)
 {
-    FIXME("%p, %p, %d, %p, %s, %p\n", piDataObj, pihlsite, dwSiteData,
+    FIXME("%p, %p, %ld, %p, %s, %p\n", piDataObj, pihlsite, dwSiteData,
            piunkOuter, debugstr_guid(riid), ppvObj);
     *ppvObj = NULL;
     return E_NOTIMPL;
@@ -252,7 +228,7 @@ HRESULT WINAPI HlinkNavigateToStringReference( LPCWSTR pwzTarget,
     HRESULT r;
     IHlink *hlink = NULL;
 
-    TRACE("%s %s %p %08x %p %08x %p %p %p\n",
+    TRACE("%s %s %p %08lx %p %08lx %p %p %p\n",
           debugstr_w(pwzTarget), debugstr_w(pwzLocation), pihlsite,
           dwSiteData, pihlframe, grfHLNF, pibc, pibsc, pihlbc);
 
@@ -295,7 +271,7 @@ HRESULT WINAPI HlinkGetSpecialReference(ULONG uReference, LPWSTR *ppwzReference)
     WCHAR *buf;
     HKEY hkey;
 
-    TRACE("(%u %p)\n", uReference, ppwzReference);
+    TRACE("(%lu %p)\n", uReference, ppwzReference);
 
     *ppwzReference = NULL;
 
@@ -314,7 +290,7 @@ HRESULT WINAPI HlinkGetSpecialReference(ULONG uReference, LPWSTR *ppwzReference)
 
     res = RegOpenKeyW(HKEY_CURRENT_USER, L"Software\\Microsoft\\Internet Explorer\\Main", &hkey);
     if(res != ERROR_SUCCESS) {
-        WARN("Could not open key: %u\n", res);
+        WARN("Could not open key: %lu\n", res);
         return HRESULT_FROM_WIN32(res);
     }
 
@@ -325,7 +301,7 @@ HRESULT WINAPI HlinkGetSpecialReference(ULONG uReference, LPWSTR *ppwzReference)
         res = RegQueryValueExW(hkey, value_name, NULL, &type, (PBYTE)buf, &size);
     RegCloseKey(hkey);
     if(res != ERROR_SUCCESS) {
-        WARN("Could not query value %s: %u\n", debugstr_w(value_name), res);
+        WARN("Could not query value %s: %lu\n", debugstr_w(value_name), res);
         CoTaskMemFree(buf);
         return HRESULT_FROM_WIN32(res);
     }
@@ -339,7 +315,7 @@ HRESULT WINAPI HlinkGetSpecialReference(ULONG uReference, LPWSTR *ppwzReference)
  */
 HRESULT WINAPI HlinkTranslateURL(LPCWSTR pwzURL, DWORD grfFlags, LPWSTR *ppwzTranslatedURL)
 {
-    FIXME("(%s %08x %p)\n", debugstr_w(pwzURL), grfFlags, ppwzTranslatedURL);
+    FIXME("(%s %08lx %p)\n", debugstr_w(pwzURL), grfFlags, ppwzTranslatedURL);
     return E_NOTIMPL;
 }
 
@@ -351,7 +327,7 @@ HRESULT WINAPI HlinkUpdateStackItem(IHlinkFrame *frame, IHlinkBrowseContext *bc,
 {
     HRESULT hr;
 
-    TRACE("(%p %p 0x%x %p %s %s)\n", frame, bc, hlid, target, debugstr_w(location), debugstr_w(friendly_name));
+    TRACE("(%p %p 0x%lx %p %s %s)\n", frame, bc, hlid, target, debugstr_w(location), debugstr_w(friendly_name));
 
     if (!frame && !bc) return E_INVALIDARG;
 
@@ -415,7 +391,7 @@ HRESULT WINAPI HlinkResolveMonikerForData(LPMONIKER pimkReference, DWORD reserve
     void *obj = NULL;
     HRESULT hres;
 
-    TRACE("(%p %x %p %d %p %p %p)\n", pimkReference, reserved, pibc, cFmtetc, rgFmtetc, pibsc, pimkBase);
+    TRACE("(%p %lx %p %ld %p %p %p)\n", pimkReference, reserved, pibc, cFmtetc, rgFmtetc, pibsc, pimkBase);
 
     if(cFmtetc || rgFmtetc || pimkBase)
         FIXME("Unsupported args\n");
@@ -426,7 +402,7 @@ HRESULT WINAPI HlinkResolveMonikerForData(LPMONIKER pimkReference, DWORD reserve
 
     hres = IMoniker_IsSystemMoniker(pimkReference, &mksys);
     if(SUCCEEDED(hres) && mksys != MKSYS_URLMONIKER)
-        WARN("sysmk = %x\n", mksys);
+        WARN("sysmk = %lx\n", mksys);
 
     /* FIXME: What is it for? */
     CreateBindCtx(0, &bctx);
@@ -587,19 +563,3 @@ HRESULT WINAPI DllGetClassObject(REFCLSID rclsid, REFIID iid, LPVOID *ppv)
 
     return IClassFactory_QueryInterface(pcf, iid, ppv);
 }
-
-/***********************************************************************
- *		DllRegisterServer (HLINK.@)
- */
-HRESULT WINAPI DllRegisterServer(void)
-{
-    return __wine_register_resources( instance );
-}
-
-/***********************************************************************
- *		DllUnregisterServer (HLINK.@)
- */
-HRESULT WINAPI DllUnregisterServer(void)
-{
-    return __wine_unregister_resources( instance );
-}
