@@ -154,7 +154,7 @@ static ULONG WINAPI IHlink_fnAddRef (IHlink* iface)
     HlinkImpl  *This = impl_from_IHlink(iface);
     ULONG refCount = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p)->(count=%u)\n", This, refCount - 1);
+    TRACE("(%p)->(count=%lu)\n", This, refCount - 1);
 
     return refCount;
 }
@@ -164,7 +164,7 @@ static ULONG WINAPI IHlink_fnRelease (IHlink* iface)
     HlinkImpl  *This = impl_from_IHlink(iface);
     ULONG refCount = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p)->(count=%u)\n", This, refCount + 1);
+    TRACE("(%p)->(count=%lu)\n", This, refCount + 1);
     if (refCount)
         return refCount;
 
@@ -185,7 +185,7 @@ static HRESULT WINAPI IHlink_fnSetHlinkSite( IHlink* iface,
 {
     HlinkImpl  *This = impl_from_IHlink(iface);
 
-    TRACE("(%p)->(%p %i)\n", This, pihlSite, dwSiteData);
+    TRACE("(%p)->(%p %li)\n", This, pihlSite, dwSiteData);
 
     if (This->Site)
         IHlinkSite_Release(This->Site);
@@ -221,7 +221,7 @@ static HRESULT WINAPI IHlink_fnSetMonikerReference( IHlink* iface,
 {
     HlinkImpl  *This = impl_from_IHlink(iface);
 
-    TRACE("(%p)->(%i %p %s)\n", This, rfHLSETF, pmkTarget,
+    TRACE("(%p)->(%li %p %s)\n", This, rfHLSETF, pmkTarget,
             debugstr_w(pwzLocation));
 
     if(rfHLSETF == 0)
@@ -260,7 +260,7 @@ static HRESULT WINAPI IHlink_fnSetStringReference(IHlink* iface,
 {
     HlinkImpl  *This = impl_from_IHlink(iface);
 
-    TRACE("(%p)->(%i %s %s)\n", This, grfHLSETF, debugstr_w(pwzTarget),
+    TRACE("(%p)->(%li %s %s)\n", This, grfHLSETF, debugstr_w(pwzTarget),
             debugstr_w(pwzLocation));
 
     if(grfHLSETF > (HLINKSETF_TARGET | HLINKSETF_LOCATION) &&
@@ -297,7 +297,7 @@ static HRESULT WINAPI IHlink_fnSetStringReference(IHlink* iface,
                     r = CreateFileMoniker(pwzTarget, &pMon);
                 if (FAILED(r))
                 {
-                    ERR("couldn't create moniker for %s, failed with error 0x%08x\n",
+                    ERR("couldn't create moniker for %s, failed with error 0x%08lx\n",
                         debugstr_w(pwzTarget), r);
                     return r;
                 }
@@ -324,7 +324,7 @@ static HRESULT WINAPI IHlink_fnGetMonikerReference(IHlink* iface,
 {
     HlinkImpl  *This = impl_from_IHlink(iface);
 
-    TRACE("(%p) -> (%i %p %p)\n", This, dwWhichRef, ppimkTarget,
+    TRACE("(%p) -> (%li %p %p)\n", This, dwWhichRef, ppimkTarget,
             ppwzLocation);
 
     if (ppimkTarget)
@@ -349,7 +349,7 @@ static HRESULT WINAPI IHlink_fnGetStringReference (IHlink* iface,
 {
     HlinkImpl  *This = impl_from_IHlink(iface);
 
-    TRACE("(%p) -> (%i %p %p)\n", This, dwWhichRef, ppwzTarget, ppwzLocation);
+    TRACE("(%p) -> (%li %p %p)\n", This, dwWhichRef, ppwzTarget, ppwzLocation);
 
     if(dwWhichRef != -1 && dwWhichRef & ~(HLINKGETREF_DEFAULT | HLINKGETREF_ABSOLUTE | HLINKGETREF_RELATIVE))
     {
@@ -410,7 +410,7 @@ static HRESULT WINAPI IHlink_fnGetFriendlyName (IHlink* iface,
 {
     HlinkImpl  *This = impl_from_IHlink(iface);
 
-    TRACE("(%p) -> (%i %p)\n", This, grfHLFNAMEF, ppwzFriendlyName);
+    TRACE("(%p) -> (%li %p)\n", This, grfHLFNAMEF, ppwzFriendlyName);
 
     /* FIXME: Only using explicitly set and cached friendly names */
 
@@ -485,7 +485,7 @@ static HRESULT WINAPI IHlink_fnNavigate(IHlink *iface, DWORD flags, IBindCtx *us
     IMoniker *mon = NULL;
     HRESULT r;
 
-    TRACE("hlink %p, flags %#x, user_bind_ctx %p, bind_callback %p, browse_ctx %p.\n",
+    TRACE("hlink %p, flags %#lx, user_bind_ctx %p, bind_callback %p, browse_ctx %p.\n",
             This, flags, user_bind_ctx, bind_callback, browse_ctx);
 
     if (This->async_bind_ctx)
@@ -765,7 +765,7 @@ static HRESULT read_hlink_string(IStream *pStm, LPWSTR *out_str)
     if (FAILED(hr)) return hr;
     if (read != sizeof(len)) return STG_E_READFAULT;
 
-    TRACE("read len %d\n", len);
+    TRACE("read len %ld\n", len);
 
     str = heap_alloc(len * sizeof(WCHAR));
     if (!str) return E_OUTOFMEMORY;
@@ -802,7 +802,7 @@ static HRESULT WINAPI IPersistStream_fnLoad(IPersistStream* iface,
         goto end;
     }
     if (hdr[1] & ~HLINK_SAVE_ALL)
-        FIXME("unknown flag(s) 0x%x\n", hdr[1] & ~HLINK_SAVE_ALL);
+        FIXME("unknown flag(s) 0x%lx\n", hdr[1] & ~HLINK_SAVE_ALL);
 
     if (hdr[1] & HLINK_SAVE_TARGET_FRAME_PRESENT)
     {
@@ -837,7 +837,7 @@ static HRESULT WINAPI IPersistStream_fnLoad(IPersistStream* iface,
     }
 
 end:
-    TRACE("Load Result 0x%x (%p)\n", r, This->Moniker);
+    TRACE("Load Result 0x%lx (%p)\n", r, This->Moniker);
 
     return r;
 }
@@ -908,7 +908,7 @@ static HRESULT WINAPI IPersistStream_fnSave(IPersistStream* iface,
 
 end:
     if (moniker) IMoniker_Release(moniker);
-    TRACE("Save Result 0x%x\n", r);
+    TRACE("Save Result 0x%lx\n", r);
 
     return r;
 }
@@ -1002,7 +1002,7 @@ static HRESULT WINAPI bind_callback_OnStartBinding(IBindStatusCallback *iface,
 {
     HlinkImpl *hlink = impl_from_IBindStatusCallback(iface);
 
-    TRACE("hlink %p, reserved %#x, binding %p.\n", hlink, reserved, binding);
+    TRACE("hlink %p, reserved %#lx, binding %p.\n", hlink, reserved, binding);
 
     if (hlink->bind_callback)
         return IBindStatusCallback_OnStartBinding(hlink->bind_callback, reserved, binding);
@@ -1019,7 +1019,7 @@ static HRESULT WINAPI bind_callback_OnLowResource(IBindStatusCallback *iface, DW
 {
     HlinkImpl *hlink = impl_from_IBindStatusCallback(iface);
 
-    TRACE("hlink %p, reserved %#x.\n", hlink, reserved);
+    TRACE("hlink %p, reserved %#lx.\n", hlink, reserved);
 
     if (hlink->bind_callback)
         return IBindStatusCallback_OnLowResource(hlink->bind_callback, reserved);
@@ -1031,7 +1031,7 @@ static HRESULT WINAPI bind_callback_OnProgress(IBindStatusCallback *iface,
 {
     HlinkImpl *hlink = impl_from_IBindStatusCallback(iface);
 
-    TRACE("hlink %p, progress %u, max %u, status %u, text %s.\n",
+    TRACE("hlink %p, progress %lu, max %lu, status %lu, text %s.\n",
             hlink, progress, max, status, debugstr_w(text));
 
     if (hlink->bind_callback)
@@ -1044,7 +1044,7 @@ static HRESULT WINAPI bind_callback_OnStopBinding(IBindStatusCallback *iface,
 {
     HlinkImpl *hlink = impl_from_IBindStatusCallback(iface);
 
-    TRACE("hlink %p, hr %#x, error %s.\n", hlink, hr, debugstr_w(error));
+    TRACE("hlink %p, hr %#lx, error %s.\n", hlink, hr, debugstr_w(error));
 
     if (hlink->bind_callback)
         IBindStatusCallback_OnStopBinding(hlink->bind_callback, hr, error);
@@ -1076,7 +1076,7 @@ static HRESULT WINAPI bind_callback_GetBindInfo(IBindStatusCallback *iface,
 static HRESULT WINAPI bind_callback_OnDataAvailable(IBindStatusCallback *iface,
         DWORD flags, DWORD size, FORMATETC *formatetc, STGMEDIUM *stgmed)
 {
-    FIXME("iface %p, flags %#x, size %d, formatetc %p, stgmed %p, stub!\n",
+    FIXME("iface %p, flags %#lx, size %ld, formatetc %p, stgmed %p, stub!\n",
             iface, flags, size, formatetc, stgmed);
     return E_NOTIMPL;
 }
