@@ -147,7 +147,7 @@ static inline HRESULT stack_pop_int(script_ctx_t *ctx, INT *r)
     return to_int32(ctx, stack_pop(ctx), r);
 }
 
-static inline HRESULT stack_pop_uint(script_ctx_t *ctx, DWORD *r)
+static inline HRESULT stack_pop_uint(script_ctx_t *ctx, UINT32 *r)
 {
     return to_uint32(ctx, stack_pop(ctx), r);
 }
@@ -171,7 +171,10 @@ static HRESULT stack_push_exprval(script_ctx_t *ctx, exprval_t *val)
 
     switch(val->type) {
     case EXPRVAL_JSVAL:
-        assert(0);
+        hres = stack_push(ctx, jsval_null());
+        if(SUCCEEDED(hres))
+            hres = stack_push(ctx, val->u.val);
+        return hres;
     case EXPRVAL_IDREF:
         hres = stack_push(ctx, jsval_disp(val->u.idref.disp));
         if(SUCCEEDED(hres))
@@ -202,30 +205,45 @@ static BOOL stack_topn_exprval(script_ctx_t *ctx, unsigned n, exprval_t *r)
     switch(jsval_type(v)) {
     case JSV_NUMBER: {
         call_frame_t *frame = ctx->call_ctx;
+        scope_chain_t *scope;
         unsigned off = get_number(v);
 
         if(!frame->base_scope->frame && off >= frame->arguments_off) {
             DISPID id;
             BSTR name;
-            HRESULT hres;
+            HRESULT hres = E_FAIL;
 
             /* Got stack reference in deoptimized code. Need to convert it back to variable object reference. */
 
             assert(off < frame->variables_off + frame->function->var_cnt);
-            name = off >= frame->variables_off
-                ? frame->function->variables[off - frame->variables_off].name
-                : frame->function->params[off - frame->arguments_off];
-            hres = jsdisp_get_id(ctx->call_ctx->base_scope->jsobj, name, 0, &id);
-            if(FAILED(hres)) {
-                r->type = EXPRVAL_INVALID;
-                r->u.hres = hres;
-                return FALSE;
+            if (off >= frame->variables_off)
+            {
+                name = frame->function->variables[off - frame->variables_off].name;
+                scope = frame->scope;
+            }
+            else
+            {
+                name = frame->function->params[off - frame->arguments_off];
+                scope = frame->base_scope;
             }
 
-            *stack_top_ref(ctx, n+1) = jsval_obj(jsdisp_addref(frame->base_scope->jsobj));
+            while (1)
+            {
+                if (scope->jsobj && SUCCEEDED(hres = jsdisp_get_id(scope->jsobj, name, 0, &id)))
+                    break;
+                if (scope == frame->base_scope)
+                {
+                    r->type = EXPRVAL_INVALID;
+                    r->u.hres = hres;
+                    return FALSE;
+                }
+                scope = scope->next;
+            }
+
+            *stack_top_ref(ctx, n+1) = jsval_obj(jsdisp_addref(scope->jsobj));
             *stack_top_ref(ctx, n) = jsval_number(id);
             r->type = EXPRVAL_IDREF;
-            r->u.idref.disp = frame->base_scope->obj;
+            r->u.idref.disp = scope->obj;
             r->u.idref.id = id;
             return TRUE;
         }
@@ -245,6 +263,10 @@ static BOOL stack_topn_exprval(script_ctx_t *ctx, unsigned n, exprval_t *r)
         assert(is_number(stack_topn(ctx, n)));
         r->u.hres = get_number(stack_topn(ctx, n));
         return FALSE;
+    case JSV_NULL:
+        r->type = EXPRVAL_JSVAL;
+        r->u.val = stack_topn(ctx, n);
+        return TRUE;
     default:
         assert(0);
         return FALSE;
@@ -268,6 +290,9 @@ static HRESULT exprval_propput(script_ctx_t *ctx, exprval_t *ref, jsval_t v)
     }
     case EXPRVAL_IDREF:
         return disp_propput(ctx, ref->u.idref.disp, ref->u.idref.id, v);
+    case EXPRVAL_JSVAL:
+        WARN("ignoring an attempt to set value reference\n");
+        return S_OK;
     default:
         assert(0);
         return E_FAIL;
@@ -281,6 +306,8 @@ static HRESULT exprval_propget(script_ctx_t *ctx, exprval_t *ref, jsval_t *r)
         return jsval_copy(ctx->stack[ref->u.off], r);
     case EXPRVAL_IDREF:
         return disp_propget(ctx, ref->u.idref.disp, ref->u.idref.id, r);
+    case EXPRVAL_JSVAL:
+        return jsval_copy(ref->u.val, r);
     default:
         assert(0);
         return E_FAIL;
@@ -302,6 +329,17 @@ static HRESULT exprval_call(script_ctx_t *ctx, exprval_t *ref, WORD flags, unsig
     }
     case EXPRVAL_IDREF:
         return disp_call(ctx, ref->u.idref.disp, ref->u.idref.id, flags, argc, argv, r);
+    case EXPRVAL_JSVAL: {
+        IDispatch *obj;
+        HRESULT hres;
+
+        hres = to_object(ctx, ref->u.val, &obj);
+        if(SUCCEEDED(hres)) {
+            hres = disp_call_value(ctx, obj, NULL, flags, argc, argv, r);
+            IDispatch_Release(obj);
+        }
+        return hres;
+    }
     default:
         assert(0);
         return E_FAIL;
@@ -378,11 +416,13 @@ static HRESULT scope_push(scope_chain_t *scope, jsdisp_t *jsobj, IDispatch *obj,
 
     new_scope->ref = 1;
 
-    IDispatch_AddRef(obj);
+    if (obj)
+        IDispatch_AddRef(obj);
     new_scope->jsobj = jsobj;
     new_scope->obj = obj;
     new_scope->frame = NULL;
     new_scope->next = scope ? scope_addref(scope) : NULL;
+    new_scope->scope_index = 0;
 
     *ret = new_scope;
     return S_OK;
@@ -405,7 +445,8 @@ void scope_release(scope_chain_t *scope)
     if(scope->next)
         scope_release(scope->next);
 
-    IDispatch_Release(scope->obj);
+    if (scope->obj)
+        IDispatch_Release(scope->obj);
     heap_free(scope);
 }
 
@@ -530,13 +571,60 @@ HRESULT jsval_strict_equal(jsval_t lval, jsval_t rval, BOOL *ret)
     return S_OK;
 }
 
+static HRESULT detach_scope(script_ctx_t *ctx, call_frame_t *frame, scope_chain_t *scope)
+{
+    function_code_t *func = frame->function;
+    unsigned int i, index;
+    HRESULT hres;
+
+    if (!scope->frame)
+        return S_OK;
+
+    assert(scope->frame == frame);
+    scope->frame = NULL;
+
+    if (!scope->jsobj)
+    {
+        assert(!scope->obj);
+
+        if (FAILED(hres = create_object(ctx, NULL, &scope->jsobj)))
+            return hres;
+        scope->obj = to_disp(scope->jsobj);
+    }
+
+    if (scope == frame->base_scope && func->name && ctx->version >= SCRIPTLANGUAGEVERSION_ES5)
+        jsdisp_propput_name(scope->jsobj, func->name, jsval_obj(jsdisp_addref(frame->function_instance)));
+
+    index = scope->scope_index;
+    for(i = 0; i < frame->function->local_scopes[index].locals_cnt; i++)
+    {
+        WCHAR *name = frame->function->local_scopes[index].locals[i].name;
+        int ref = frame->function->local_scopes[index].locals[i].ref;
+
+        if (FAILED(hres = jsdisp_propput_name(scope->jsobj, name, ctx->stack[local_off(frame, ref)])))
+            return hres;
+        if (frame->function->variables[ref].func_id != -1 && scope != frame->base_scope
+                && FAILED(hres = jsdisp_propput_name(frame->variable_obj, name, ctx->stack[local_off(frame, ref)])))
+            return hres;
+    }
+    return S_OK;
+}
+
+static HRESULT detach_scope_chain(script_ctx_t *ctx, call_frame_t *frame, scope_chain_t *scope)
+{
+    HRESULT hres;
+
+    if (scope != frame->base_scope && FAILED(hres = detach_scope_chain(ctx, frame, scope->next)))
+        return hres;
+    return detach_scope(ctx, frame, scope);
+}
+
 /*
  * Transfers local variables from stack to variable object.
  * It's slow, so we want to avoid it as much as possible.
  */
 static HRESULT detach_variable_object(script_ctx_t *ctx, call_frame_t *frame, BOOL from_release)
 {
-    unsigned i;
     HRESULT hres;
 
     if(!frame->base_scope || !frame->base_scope->frame)
@@ -553,16 +641,8 @@ static HRESULT detach_variable_object(script_ctx_t *ctx, call_frame_t *frame, BO
             return hres;
     }
 
-    frame->base_scope->frame = NULL;
-
-    for(i = 0; i < frame->function->locals_cnt; i++) {
-        hres = jsdisp_propput_name(frame->variable_obj, frame->function->locals[i].name,
-                                   ctx->stack[local_off(frame, frame->function->locals[i].ref)]);
-        if(FAILED(hres))
-            return hres;
-    }
-
-    return S_OK;
+    TRACE("detaching scope chain %p, frame %p.\n", ctx->call_ctx->scope, frame);
+    return detach_scope_chain(ctx, frame, ctx->call_ctx->scope);
 }
 
 static BOOL lookup_global_members(script_ctx_t *ctx, BSTR identifier, exprval_t *ret)
@@ -605,9 +685,10 @@ static int __cdecl local_ref_cmp(const void *key, const void *ref)
     return wcscmp((const WCHAR*)key, ((const local_ref_t*)ref)->name);
 }
 
-local_ref_t *lookup_local(const function_code_t *function, const WCHAR *identifier)
+local_ref_t *lookup_local(const function_code_t *function, const WCHAR *identifier, unsigned int scope)
 {
-    return bsearch(identifier, function->locals, function->locals_cnt, sizeof(*function->locals), local_ref_cmp);
+    return bsearch(identifier, function->local_scopes[scope].locals, function->local_scopes[scope].locals_cnt,
+            sizeof(*function->local_scopes[scope].locals), local_ref_cmp);
 }
 
 /* ECMA-262 3rd Edition    10.1.4 */
@@ -624,7 +705,7 @@ static HRESULT identifier_eval(script_ctx_t *ctx, BSTR identifier, exprval_t *re
         for(scope = ctx->call_ctx->scope; scope; scope = scope->next) {
             if(scope->frame) {
                 function_code_t *func = scope->frame->function;
-                local_ref_t *ref = lookup_local(func, identifier);
+                local_ref_t *ref = lookup_local(func, identifier, scope->scope_index);
 
                 if(ref) {
                     ret->type = EXPRVAL_STACK_REF;
@@ -638,7 +719,19 @@ static HRESULT identifier_eval(script_ctx_t *ctx, BSTR identifier, exprval_t *re
                     if(FAILED(hres))
                         return hres;
                 }
+
+                /* ECMA-262 5.1 Edition    13 */
+                if(func->name && ctx->version >= SCRIPTLANGUAGEVERSION_ES5 && !wcscmp(identifier, func->name)) {
+                    TRACE("returning a function from scope chain\n");
+                    ret->type = EXPRVAL_JSVAL;
+                    ret->u.val = jsval_obj(jsdisp_addref(scope->frame->function_instance));
+                    return S_OK;
+                }
             }
+
+            if (!scope->jsobj && !scope->obj)
+                continue;
+
             if(scope->jsobj)
                 hres = jsdisp_get_id(scope->jsobj, identifier, fdexNameImplicit, &id);
             else
@@ -744,7 +837,7 @@ static HRESULT interp_forin(script_ctx_t *ctx)
     id = get_number(stack_top(ctx));
 
     if(!stack_topn_exprval(ctx, 1, &prop_ref)) {
-        FIXME("invalid ref: %08x\n", prop_ref.u.hres);
+        FIXME("invalid ref: %08lx\n", prop_ref.u.hres);
         return E_FAIL;
     }
 
@@ -789,8 +882,71 @@ static HRESULT interp_forin(script_ctx_t *ctx)
     return S_OK;
 }
 
+static HRESULT scope_init_locals(script_ctx_t *ctx)
+{
+    call_frame_t *frame = ctx->call_ctx;
+    unsigned int i, off, index;
+    scope_chain_t *scope;
+    BOOL detached_vars;
+    HRESULT hres;
+
+    scope = frame->scope;
+    index = scope->scope_index;
+    detached_vars = !(frame->base_scope && frame->base_scope->frame);
+
+    if (!detached_vars)
+    {
+        assert(frame->base_scope->frame == frame);
+        frame->scope->frame = ctx->call_ctx;
+    }
+    else if (!scope->jsobj)
+    {
+        assert(!scope->obj);
+        if (FAILED(hres = create_object(ctx, NULL, &scope->jsobj)))
+            return hres;
+        scope->obj = to_disp(scope->jsobj);
+    }
+
+    for(i = 0; i < frame->function->local_scopes[index].locals_cnt; i++)
+    {
+        WCHAR *name = frame->function->local_scopes[index].locals[i].name;
+        int ref = frame->function->local_scopes[index].locals[i].ref;
+        jsdisp_t *func_obj;
+        jsval_t val;
+
+        if (frame->function->variables[ref].func_id != -1)
+        {
+            TRACE("function %s %d\n", debugstr_w(name), i);
+
+            if (FAILED(hres = create_source_function(ctx, frame->bytecode, frame->function->funcs
+                    + frame->function->variables[ref].func_id, ctx->call_ctx->scope, &func_obj)))
+                return hres;
+            val = jsval_obj(func_obj);
+            if (detached_vars && FAILED(hres = jsdisp_propput_name(frame->variable_obj, name, jsval_obj(func_obj))))
+                return hres;
+        }
+        else
+        {
+            val = jsval_undefined();
+        }
+
+        if (detached_vars)
+        {
+            if (FAILED(hres = jsdisp_propput_name(scope->jsobj, name, val)))
+                return hres;
+        }
+        else
+        {
+            off = local_off(frame, ref);
+            jsval_release(ctx->stack[off]);
+            ctx->stack[off] = val;
+        }
+    }
+    return S_OK;
+}
+
 /* ECMA-262 3rd Edition    12.10 */
-static HRESULT interp_push_scope(script_ctx_t *ctx)
+static HRESULT interp_push_with_scope(script_ctx_t *ctx)
 {
     IDispatch *disp;
     jsval_t v;
@@ -809,11 +965,36 @@ static HRESULT interp_push_scope(script_ctx_t *ctx)
     return hres;
 }
 
+/* ECMA-262 10th Edition   13.3.1 */
+static HRESULT interp_push_block_scope(script_ctx_t *ctx)
+{
+    unsigned int scope_index = get_op_uint(ctx, 0);
+    call_frame_t *frame = ctx->call_ctx;
+    HRESULT hres;
+
+    TRACE("scope_index %u.\n", scope_index);
+
+    hres = scope_push(ctx->call_ctx->scope, NULL, NULL, &frame->scope);
+
+    if (FAILED(hres) || !scope_index)
+        return hres;
+
+    frame->scope->scope_index = scope_index;
+
+    return scope_init_locals(ctx);
+}
+
 /* ECMA-262 3rd Edition    12.10 */
 static HRESULT interp_pop_scope(script_ctx_t *ctx)
 {
     TRACE("\n");
 
+    if(ctx->call_ctx->scope->ref > 1) {
+        HRESULT hres = detach_variable_object(ctx, ctx->call_ctx, FALSE);
+        if(FAILED(hres))
+            ERR("Failed to detach variable object: %08lx\n", hres);
+    }
+
     scope_pop(&ctx->call_ctx->scope);
     return S_OK;
 }
@@ -892,7 +1073,7 @@ static HRESULT interp_throw_ref(script_ctx_t *ctx)
 {
     const HRESULT arg = get_op_uint(ctx, 0);
 
-    TRACE("%08x\n", arg);
+    TRACE("%08lx\n", arg);
 
     return arg;
 }
@@ -903,7 +1084,7 @@ static HRESULT interp_throw_type(script_ctx_t *ctx)
     jsstr_t *str = get_op_str(ctx, 1);
     const WCHAR *ptr;
 
-    TRACE("%08x %s\n", hres, debugstr_jsstr(str));
+    TRACE("%08lx %s\n", hres, debugstr_jsstr(str));
 
     ptr = jsstr_flatten(str);
     return ptr ? throw_error(ctx, hres, ptr) : E_OUTOFMEMORY;
@@ -1139,7 +1320,7 @@ static HRESULT interp_memberid(script_ctx_t *ctx)
             exprval_set_exception(&ref, JS_E_INVALID_PROPERTY);
             hres = S_OK;
         }else {
-            ERR("failed %08x\n", hres);
+            ERR("failed %08lx\n", hres);
             return hres;
         }
     }
@@ -1268,7 +1449,8 @@ static HRESULT interp_identifier_ref(script_ctx_t *ctx, BSTR identifier, unsigne
         exprval_set_disp_ref(&exprval, to_disp(script_obj), id);
     }
 
-    if(exprval.type == EXPRVAL_JSVAL || exprval.type == EXPRVAL_INVALID) {
+    if(exprval.type == EXPRVAL_INVALID ||
+       (exprval.type == EXPRVAL_JSVAL && ctx->version < SCRIPTLANGUAGEVERSION_ES5)) {
         WARN("invalid ref\n");
         exprval_release(&exprval);
         exprval_set_exception(&exprval, JS_E_OBJECT_EXPECTED);
@@ -2461,7 +2643,7 @@ static HRESULT interp_neg(script_ctx_t *ctx)
 /* ECMA-262 3rd Edition    11.7.1 */
 static HRESULT interp_lshift(script_ctx_t *ctx)
 {
-    DWORD r;
+    UINT32 r;
     INT l;
     HRESULT hres;
 
@@ -2479,7 +2661,7 @@ static HRESULT interp_lshift(script_ctx_t *ctx)
 /* ECMA-262 3rd Edition    11.7.2 */
 static HRESULT interp_rshift(script_ctx_t *ctx)
 {
-    DWORD r;
+    UINT32 r;
     INT l;
     HRESULT hres;
 
@@ -2497,7 +2679,7 @@ static HRESULT interp_rshift(script_ctx_t *ctx)
 /* ECMA-262 3rd Edition    11.7.3 */
 static HRESULT interp_rshift2(script_ctx_t *ctx)
 {
-    DWORD r, l;
+    UINT32 r, l;
     HRESULT hres;
 
     hres = stack_pop_uint(ctx, &r);
@@ -2523,7 +2705,7 @@ static HRESULT interp_to_string(script_ctx_t *ctx)
     hres = to_string(ctx, v, &str);
     jsval_release(v);
     if(FAILED(hres)) {
-        WARN("failed %08x\n", hres);
+        WARN("failed %08lx\n", hres);
         return hres;
     }
 
@@ -2583,7 +2765,7 @@ static HRESULT interp_set_member(script_ctx_t *ctx)
         jsstr_release(get_string(namev));
     }
     if(FAILED(hres)) {
-        WARN("failed %08x\n", hres);
+        WARN("failed %08lx\n", hres);
         jsval_release(value);
         return hres;
     }
@@ -2731,7 +2913,7 @@ static void pop_call_frame(script_ctx_t *ctx)
     if(frame->scope && frame->scope->ref > 1) {
         HRESULT hres = detach_variable_object(ctx, frame, TRUE);
         if(FAILED(hres))
-            ERR("Failed to detach variable object: %08x\n", hres);
+            ERR("Failed to detach variable object: %08lx\n", hres);
     }
 
     if(frame->arguments_obj)
@@ -2802,7 +2984,7 @@ static HRESULT unwind_exception(script_ctx_t *ctx, HRESULT exception_hres)
         jsdisp_t *error_obj;
         jsval_t msg;
 
-        WARN("Exception %08x %s", exception_hres, debugstr_jsval(ei->valid_value ? ei->value : jsval_undefined()));
+        WARN("Exception %08lx %s", exception_hres, debugstr_jsval(ei->valid_value ? ei->value : jsval_undefined()));
         if(ei->valid_value && jsval_type(ei->value) == JSV_OBJECT) {
             error_obj = to_jsdisp(get_object(ei->value));
             if(error_obj) {
@@ -2943,7 +3125,7 @@ static HRESULT bind_event_target(script_ctx_t *ctx, function_code_t *func, jsdis
         hres = IBindEventHandler_BindHandler(target, func->name, (IDispatch*)&func_obj->IDispatchEx_iface);
         IBindEventHandler_Release(target);
         if(FAILED(hres))
-            WARN("BindEvent failed: %08x\n", hres);
+            WARN("BindEvent failed: %08lx\n", hres);
     }else {
         FIXME("No IBindEventHandler, not yet supported binding\n");
     }
@@ -3007,7 +3189,9 @@ static HRESULT setup_scope(script_ctx_t *ctx, call_frame_t *frame, scope_chain_t
     }
 
     for(i = 0; i < frame->function->func_cnt; i++) {
-        if(frame->function->funcs[i].name && !frame->function->funcs[i].event_target) {
+        if(frame->function->funcs[i].local_ref != INVALID_LOCAL_REF
+                && !frame->function->funcs[i].scope_index)
+        {
             jsdisp_t *func_obj;
             unsigned off;
 
@@ -3061,6 +3245,12 @@ HRESULT exec_source(script_ctx_t *ctx, DWORD flags, bytecode_t *bytecode, functi
         if(!function->funcs[i].event_target)
             continue;
 
+        if (function->funcs[i].scope_index)
+        {
+            /* TODO: Add tests and handle in interp_push_scope(). */
+            FIXME("Event target with scope index are not properly handled.\n");
+        }
+
         hres = create_source_function(ctx, bytecode, function->funcs+i, scope, &func_obj);
         if(FAILED(hres))
             return hres;
@@ -3091,6 +3281,12 @@ HRESULT exec_source(script_ctx_t *ctx, DWORD flags, bytecode_t *bytecode, functi
             if(function->variables[i].func_id != -1) {
                 jsdisp_t *func_obj;
 
+                if (function->funcs[function->variables[i].func_id].scope_index && flags & EXEC_EVAL)
+                {
+                    /* TODO: Add tests and handle in interp_push_scope(). */
+                    FIXME("Functions with scope index inside eval() are not properly handled.\n");
+                }
+
                 hres = create_source_function(ctx, bytecode, function->funcs+function->variables[i].func_id, scope, &func_obj);
                 if(FAILED(hres))
                     goto fail;
