@@ -26,10 +26,13 @@
 #endif
 
 #include "config.h"
+
 #if defined(SONAME_LIBKRB5) && defined(SONAME_LIBGSSAPI_KRB5)
-#include "wine/port.h"
 
 #include <stdarg.h>
+#include <sys/types.h>
+#include <dlfcn.h>
+
 #ifdef HAVE_KRB5_KRB5_H
 # include <krb5/krb5.h>
 #endif
@@ -148,15 +151,21 @@ static NTSTATUS krb5_error_to_status( krb5_error_code err )
     }
 }
 
-static WCHAR *utf8_to_wstr( const char *src )
+struct ticket_list
+{
+    ULONG count;
+    ULONG allocated;
+    KERB_TICKET_CACHE_INFO *tickets;
+};
+
+static void utf8_to_wstr( UNICODE_STRING *strW, const char *src )
 {
     ULONG dstlen, srclen = strlen( src ) + 1;
-    WCHAR *dst;
 
-    RtlUTF8ToUnicodeN( NULL, 0, &dstlen, src, srclen );
-    if ((dst = RtlAllocateHeap( GetProcessHeap(), 0, dstlen )))
-        RtlUTF8ToUnicodeN( dst, dstlen, &dstlen, src, srclen );
-    return dst;
+    strW->Buffer = malloc( srclen * sizeof(WCHAR) );
+    RtlUTF8ToUnicodeN( strW->Buffer, srclen * sizeof(WCHAR), &dstlen, src, srclen );
+    strW->MaximumLength = dstlen;
+    strW->Length = dstlen - sizeof(WCHAR);
 }
 
 static NTSTATUS copy_tickets_from_cache( krb5_context ctx, krb5_ccache cache, struct ticket_list *list )
@@ -167,7 +176,6 @@ static NTSTATUS copy_tickets_from_cache( krb5_context ctx, krb5_ccache cache, st
     krb5_creds creds;
     krb5_ticket *ticket;
     char *name_with_realm, *name_without_realm, *realm_name;
-    WCHAR *realm_nameW, *name_without_realmW;
 
     if ((err = p_krb5_cc_start_seq_get( ctx, cache, &cursor ))) return krb5_error_to_status( err );
     for (;;)
@@ -189,19 +197,8 @@ static NTSTATUS copy_tickets_from_cache( krb5_context ctx, krb5_ccache cache, st
 
         if (list->count == list->allocated)
         {
-            KERB_TICKET_CACHE_INFO *new_tickets;
-            ULONG new_allocated;
-
-            if (list->allocated)
-            {
-                new_allocated = list->allocated * 2;
-                new_tickets = RtlReAllocateHeap( GetProcessHeap(), 0, list->tickets, sizeof(*new_tickets) * new_allocated );
-            }
-            else
-            {
-                new_allocated = 16;
-                new_tickets = RtlAllocateHeap( GetProcessHeap(), 0, sizeof(*new_tickets) * new_allocated );
-            }
+            ULONG new_allocated = max( 16, list->allocated * 2 );
+            KERB_TICKET_CACHE_INFO *new_tickets = realloc( list->tickets, sizeof(*new_tickets) * new_allocated );
             if (!new_tickets)
             {
                 p_krb5_free_cred_contents( ctx, &creds );
@@ -230,8 +227,7 @@ static NTSTATUS copy_tickets_from_cache( krb5_context ctx, krb5_ccache cache, st
         }
         TRACE( "name_without_realm: %s\n", debugstr_a(name_without_realm) );
 
-        name_without_realmW = utf8_to_wstr( name_without_realm );
-        RtlInitUnicodeString( &list->tickets[list->count].ServerName, name_without_realmW );
+        utf8_to_wstr( &list->tickets[list->count].ServerName, name_without_realm );
 
         if (!(realm_name = strchr( name_with_realm, '@' )))
         {
@@ -241,17 +237,17 @@ static NTSTATUS copy_tickets_from_cache( krb5_context ctx, krb5_ccache cache, st
         else realm_name++;
 
         /* realm_name - now contains only realm! */
-        realm_nameW = utf8_to_wstr( realm_name );
-        RtlInitUnicodeString( &list->tickets[list->count].RealmName, realm_nameW );
+        utf8_to_wstr( &list->tickets[list->count].RealmName, realm_name );
 
         if (!creds.times.starttime) creds.times.starttime = creds.times.authtime;
 
         /* TODO: if krb5_is_config_principal = true */
-        RtlSecondsSince1970ToTime( creds.times.starttime, &list->tickets[list->count].StartTime );
-        RtlSecondsSince1970ToTime( creds.times.endtime, &list->tickets[list->count].EndTime );
-        RtlSecondsSince1970ToTime( creds.times.renew_till, &list->tickets[list->count].RenewTime );
 
-        list->tickets[list->count].TicketFlags = creds.ticket_flags;
+        /* note: store times as seconds, they will be converted to NT timestamps on the PE side */
+        list->tickets[list->count].StartTime.QuadPart = creds.times.starttime;
+        list->tickets[list->count].EndTime.QuadPart   = creds.times.endtime;
+        list->tickets[list->count].RenewTime.QuadPart = creds.times.renew_till;
+        list->tickets[list->count].TicketFlags        = creds.ticket_flags;
 
         err = p_krb5_decode_ticket( &creds.ticket, &ticket );
         p_krb5_free_unparsed_name( ctx, name_with_realm );
@@ -272,17 +268,51 @@ static NTSTATUS copy_tickets_from_cache( krb5_context ctx, krb5_ccache cache, st
     return status;
 }
 
-static NTSTATUS CDECL query_ticket_cache( struct ticket_list *list )
+static NTSTATUS copy_tickets_to_client( struct ticket_list *list, KERB_QUERY_TKT_CACHE_RESPONSE *resp,
+                                        ULONG *out_size )
 {
+    char *client_str;
+    ULONG i, size = offsetof( KERB_QUERY_TKT_CACHE_RESPONSE, Tickets[list->count] );
+
+    for (i = 0; i < list->count; i++)
+    {
+        size += list->tickets[i].RealmName.MaximumLength;
+        size += list->tickets[i].ServerName.MaximumLength;
+    }
+    if (!resp || size > *out_size)
+    {
+        *out_size = size;
+        return STATUS_BUFFER_TOO_SMALL;
+    }
+    *out_size = size;
+
+    resp->MessageType = KerbQueryTicketCacheMessage;
+    resp->CountOfTickets = list->count;
+    memcpy( resp->Tickets, list->tickets, list->count * sizeof(list->tickets[0]) );
+    client_str = (char *)&resp->Tickets[list->count];
+
+    for (i = 0; i < list->count; i++)
+    {
+        resp->Tickets[i].RealmName.Buffer = (WCHAR *)client_str;
+        memcpy( client_str, list->tickets[i].RealmName.Buffer, list->tickets[i].RealmName.MaximumLength );
+        client_str += list->tickets[i].RealmName.MaximumLength;
+        resp->Tickets[i].ServerName.Buffer = (WCHAR *)client_str;
+        memcpy( client_str, list->tickets[i].ServerName.Buffer, list->tickets[i].ServerName.MaximumLength );
+        client_str += list->tickets[i].ServerName.MaximumLength;
+    }
+    return STATUS_SUCCESS;
+}
+
+static NTSTATUS query_ticket_cache( void *args )
+{
+    struct query_ticket_cache_params *params = args;
     NTSTATUS status;
     krb5_error_code err;
     krb5_context ctx;
     krb5_cccol_cursor cursor = NULL;
     krb5_ccache cache;
-
-    list->count     = 0;
-    list->allocated = 0;
-    list->tickets   = NULL;
+    ULONG i;
+    struct ticket_list list = { 0 };
 
     if ((err = p_krb5_init_context( &ctx ))) return krb5_error_to_status( err );
     if ((err = p_krb5_cccol_cursor_new( ctx, &cursor )))
@@ -300,7 +330,7 @@ static NTSTATUS CDECL query_ticket_cache( struct ticket_list *list )
         }
         if (!cache) break;
 
-        status = copy_tickets_from_cache( ctx, cache, list );
+        status = copy_tickets_from_cache( ctx, cache, &list );
         p_krb5_cc_close( ctx, cache );
         if (status != STATUS_SUCCESS) goto done;
     }
@@ -308,6 +338,14 @@ static NTSTATUS CDECL query_ticket_cache( struct ticket_list *list )
 done:
     if (cursor) p_krb5_cccol_cursor_free( ctx, &cursor );
     if (ctx) p_krb5_free_context( ctx );
+
+    if (status == STATUS_SUCCESS) status = copy_tickets_to_client( &list, params->resp, params->out_size );
+
+    for (i = 0; i < list.count; i++)
+    {
+        free( list.tickets[i].RealmName.Buffer );
+        free( list.tickets[i].ServerName.Buffer );
+    }
     return status;
 }
 
@@ -414,7 +452,7 @@ static NTSTATUS status_gss_to_sspi( OM_uint32 status )
     case GSS_S_FAILURE:              return SEC_E_INTERNAL_ERROR;
 
     default:
-        FIXME( "couldn't convert status 0x%08x to NTSTATUS\n", status );
+        FIXME( "couldn't convert status %#x to NTSTATUS\n", status );
         return SEC_E_INTERNAL_ERROR;
     }
 }
@@ -430,10 +468,10 @@ static void trace_gss_status_ex( OM_uint32 code, int type )
         ret = pgss_display_status( &minor_status, code, type, GSS_C_NULL_OID, &msg_ctx, &buf );
         if (GSS_ERROR( ret ))
         {
-            TRACE( "gss_display_status(0x%08x,%d) returned %08x minor status %08x\n", code, type, ret, minor_status );
+            TRACE( "gss_display_status(%#x, %d) returned %#x minor status %#x\n", code, type, ret, minor_status );
             return;
         }
-        TRACE( "GSS-API error: 0x%08x: %s\n", code, debugstr_an(buf.value, buf.length) );
+        TRACE( "GSS-API error: %#x: %s\n", code, debugstr_an(buf.value, buf.length) );
         pgss_release_buffer( &minor_status, &buf );
         if (!msg_ctx) return;
     }
@@ -468,16 +506,6 @@ static inline void credhandle_gss_to_sspi( gss_cred_id_t handle, LSA_SEC_HANDLE
     *cred = (LSA_SEC_HANDLE)handle;
 }
 
-static void expirytime_gss_to_sspi( OM_uint32 expirytime, TimeStamp *timestamp )
-{
-    LARGE_INTEGER time;
-
-    NtQuerySystemTime( &time );
-    RtlSystemTimeToLocalTime( &time, &time );
-    timestamp->LowPart  = time.QuadPart;
-    timestamp->HighPart = time.QuadPart >> 32;
-}
-
 static ULONG flags_gss_to_asc_ret( ULONG flags )
 {
     ULONG ret = 0;
@@ -493,48 +521,48 @@ static ULONG flags_gss_to_asc_ret( ULONG flags )
     return ret;
 }
 
-static NTSTATUS CDECL accept_context( LSA_SEC_HANDLE credential, LSA_SEC_HANDLE context, SecBufferDesc *input,
-                               LSA_SEC_HANDLE *new_context, SecBufferDesc *output, ULONG *context_attr,
-                               TimeStamp *expiry )
+static NTSTATUS accept_context( void *args )
 {
+    struct accept_context_params *params = args;
     OM_uint32 ret, minor_status, ret_flags = 0, expiry_time;
-    gss_cred_id_t cred_handle = credhandle_sspi_to_gss( credential );
-    gss_ctx_id_t ctx_handle = ctxhandle_sspi_to_gss( context );
+    gss_cred_id_t cred_handle = credhandle_sspi_to_gss( params->credential );
+    gss_ctx_id_t ctx_handle = ctxhandle_sspi_to_gss( params->context );
     gss_buffer_desc input_token, output_token;
     int idx;
 
-    if (!input) input_token.length = 0;
+    if (!params->input) input_token.length = 0;
     else
     {
-        if ((idx = get_buffer_index( input, SECBUFFER_TOKEN )) == -1) return SEC_E_INVALID_TOKEN;
-        input_token.length = input->pBuffers[idx].cbBuffer;
-        input_token.value  = input->pBuffers[idx].pvBuffer;
+        if ((idx = get_buffer_index( params->input, SECBUFFER_TOKEN )) == -1) return SEC_E_INVALID_TOKEN;
+        input_token.length = params->input->pBuffers[idx].cbBuffer;
+        input_token.value  = params->input->pBuffers[idx].pvBuffer;
     }
 
-    if ((idx = get_buffer_index( output, SECBUFFER_TOKEN )) == -1) return SEC_E_INVALID_TOKEN;
+    if ((idx = get_buffer_index( params->output, SECBUFFER_TOKEN )) == -1) return SEC_E_INVALID_TOKEN;
     output_token.length = 0;
     output_token.value  = NULL;
 
     ret = pgss_accept_sec_context( &minor_status, &ctx_handle, cred_handle, &input_token, GSS_C_NO_CHANNEL_BINDINGS,
                                    NULL, NULL, &output_token, &ret_flags, &expiry_time, NULL );
-    TRACE( "gss_accept_sec_context returned %08x minor status %08x ret_flags %08x\n", ret, minor_status, ret_flags );
+    TRACE( "gss_accept_sec_context returned %#x minor status %#x ret_flags %#x\n", ret, minor_status, ret_flags );
     if (GSS_ERROR( ret )) trace_gss_status( ret, minor_status );
     if (ret == GSS_S_COMPLETE || ret == GSS_S_CONTINUE_NEEDED)
     {
-        if (output_token.length > output->pBuffers[idx].cbBuffer) /* FIXME: check if larger buffer exists */
+        if (output_token.length > params->output->pBuffers[idx].cbBuffer) /* FIXME: check if larger buffer exists */
         {
-            TRACE( "buffer too small %lu > %u\n", (SIZE_T)output_token.length, output->pBuffers[idx].cbBuffer );
+            TRACE( "buffer too small %lu > %u\n",
+                   (SIZE_T)output_token.length, (unsigned int)params->output->pBuffers[idx].cbBuffer );
             pgss_release_buffer( &minor_status, &output_token );
             pgss_delete_sec_context( &minor_status, &ctx_handle, GSS_C_NO_BUFFER );
             return SEC_E_BUFFER_TOO_SMALL;
         }
-        output->pBuffers[idx].cbBuffer = output_token.length;
-        memcpy( output->pBuffers[idx].pvBuffer, output_token.value, output_token.length );
+        params->output->pBuffers[idx].cbBuffer = output_token.length;
+        memcpy( params->output->pBuffers[idx].pvBuffer, output_token.value, output_token.length );
         pgss_release_buffer( &minor_status, &output_token );
 
-        ctxhandle_gss_to_sspi( ctx_handle, new_context );
-        if (context_attr) *context_attr = flags_gss_to_asc_ret( ret_flags );
-        expirytime_gss_to_sspi( expiry_time, expiry );
+        ctxhandle_gss_to_sspi( ctx_handle, params->new_context );
+        if (params->context_attr) *params->context_attr = flags_gss_to_asc_ret( ret_flags );
+        *params->expiry = expiry_time;
     }
 
     return status_gss_to_sspi( ret );
@@ -578,28 +606,28 @@ static NTSTATUS import_name( const char *src, gss_name_t *dst )
     buf.length = strlen( src );
     buf.value  = (void *)src;
     ret = pgss_import_name( &minor_status, &buf, GSS_C_NO_OID, dst );
-    TRACE( "gss_import_name returned %08x minor status %08x\n", ret, minor_status );
+    TRACE( "gss_import_name returned %#x minor status %#x\n", ret, minor_status );
     if (GSS_ERROR( ret )) trace_gss_status( ret, minor_status );
     return status_gss_to_sspi( ret );
 }
 
-static NTSTATUS CDECL acquire_credentials_handle( const char *principal, ULONG credential_use, const char *username,
-                                                  const char *password, LSA_SEC_HANDLE *credential, TimeStamp *expiry )
+static NTSTATUS acquire_credentials_handle( void *args )
 {
+    struct acquire_credentials_handle_params *params = args;
     OM_uint32 ret, minor_status, expiry_time;
     gss_name_t name = GSS_C_NO_NAME;
     gss_cred_usage_t cred_usage;
     gss_cred_id_t cred_handle;
     NTSTATUS status;
 
-    switch (credential_use)
+    switch (params->credential_use)
     {
     case SECPKG_CRED_INBOUND:
         cred_usage = GSS_C_ACCEPT;
         break;
 
     case SECPKG_CRED_OUTBOUND:
-        if ((status = init_creds( username, password )) != STATUS_SUCCESS) return status;
+        if ((status = init_creds( params->username, params->password )) != STATUS_SUCCESS) return status;
         cred_usage = GSS_C_INITIATE;
         break;
 
@@ -608,40 +636,40 @@ static NTSTATUS CDECL acquire_credentials_handle( const char *principal, ULONG c
         return SEC_E_UNKNOWN_CREDENTIALS;
     }
 
-    if (principal && (status = import_name( principal, &name ))) return status;
+    if (params->principal && (status = import_name( params->principal, &name ))) return status;
 
     ret = pgss_acquire_cred( &minor_status, name, GSS_C_INDEFINITE, GSS_C_NULL_OID_SET, cred_usage, &cred_handle,
                              NULL, &expiry_time );
-    TRACE( "gss_acquire_cred returned %08x minor status %08x\n", ret, minor_status );
+    TRACE( "gss_acquire_cred returned %#x minor status %#x\n", ret, minor_status );
     if (GSS_ERROR( ret )) trace_gss_status( ret, minor_status );
     if (ret == GSS_S_COMPLETE)
     {
-        credhandle_gss_to_sspi( cred_handle, credential );
-        expirytime_gss_to_sspi( expiry_time, expiry );
+        credhandle_gss_to_sspi( cred_handle, params->credential );
+        *params->expiry = expiry_time;
     }
 
     if (name != GSS_C_NO_NAME) pgss_release_name( &minor_status, &name );
     return status_gss_to_sspi( ret );
 }
 
-static NTSTATUS CDECL delete_context( LSA_SEC_HANDLE context )
+static NTSTATUS delete_context( void *args )
 {
     OM_uint32 ret, minor_status;
-    gss_ctx_id_t ctx_handle = ctxhandle_sspi_to_gss( context );
+    gss_ctx_id_t ctx_handle = ctxhandle_sspi_to_gss( (LSA_SEC_HANDLE)args );
 
     ret = pgss_delete_sec_context( &minor_status, &ctx_handle, GSS_C_NO_BUFFER );
-    TRACE( "gss_delete_sec_context returned %08x minor status %08x\n", ret, minor_status );
+    TRACE( "gss_delete_sec_context returned %#x minor status %#x\n", ret, minor_status );
     if (GSS_ERROR( ret )) trace_gss_status( ret, minor_status );
     return status_gss_to_sspi( ret );
 }
 
-static NTSTATUS CDECL free_credentials_handle( LSA_SEC_HANDLE handle )
+static NTSTATUS free_credentials_handle( void *args )
 {
     OM_uint32 ret, minor_status;
-    gss_cred_id_t cred = credhandle_sspi_to_gss( handle );
+    gss_cred_id_t cred = credhandle_sspi_to_gss( (LSA_SEC_HANDLE)args );
 
     ret = pgss_release_cred( &minor_status, &cred );
-    TRACE( "gss_release_cred returned %08x minor status %08x\n", ret, minor_status );
+    TRACE( "gss_release_cred returned %#x minor status %#x\n", ret, minor_status );
     if (GSS_ERROR( ret )) trace_gss_status( ret, minor_status );
     return status_gss_to_sspi( ret );
 }
@@ -676,63 +704,65 @@ static ULONG flags_gss_to_isc_ret( ULONG flags )
     return ret;
 }
 
-static NTSTATUS CDECL initialize_context( LSA_SEC_HANDLE credential, LSA_SEC_HANDLE context, const char *target_name,
-                                          ULONG context_req, SecBufferDesc *input, LSA_SEC_HANDLE *new_context,
-                                          SecBufferDesc *output, ULONG *context_attr, TimeStamp *expiry )
+static NTSTATUS initialize_context( void *args )
 {
-    OM_uint32 ret, minor_status, ret_flags = 0, expiry_time, req_flags = flags_isc_req_to_gss( context_req );
-    gss_cred_id_t cred_handle = credhandle_sspi_to_gss( credential );
-    gss_ctx_id_t ctx_handle = ctxhandle_sspi_to_gss( context );
+    struct initialize_context_params *params = args;
+    OM_uint32 ret, minor_status, ret_flags = 0, expiry_time, req_flags = flags_isc_req_to_gss( params->context_req );
+    gss_cred_id_t cred_handle = credhandle_sspi_to_gss( params->credential );
+    gss_ctx_id_t ctx_handle = ctxhandle_sspi_to_gss( params->context );
     gss_buffer_desc input_token, output_token;
     gss_name_t target = GSS_C_NO_NAME;
     NTSTATUS status;
     int idx;
 
-    if ((idx = get_buffer_index( input, SECBUFFER_TOKEN )) == -1) input_token.length = 0;
+    if ((idx = get_buffer_index( params->input, SECBUFFER_TOKEN )) == -1) input_token.length = 0;
     else
     {
-        input_token.length = input->pBuffers[idx].cbBuffer;
-        input_token.value  = input->pBuffers[idx].pvBuffer;
+        input_token.length = params->input->pBuffers[idx].cbBuffer;
+        input_token.value  = params->input->pBuffers[idx].pvBuffer;
     }
 
-    if ((idx = get_buffer_index( output, SECBUFFER_TOKEN )) == -1) return SEC_E_INVALID_TOKEN;
+    if ((idx = get_buffer_index( params->output, SECBUFFER_TOKEN )) == -1) return SEC_E_INVALID_TOKEN;
     output_token.length = 0;
     output_token.value  = NULL;
 
-    if (target_name && (status = import_name( target_name, &target ))) return status;
+    if (params->target_name && (status = import_name( params->target_name, &target ))) return status;
 
     ret = pgss_init_sec_context( &minor_status, cred_handle, &ctx_handle, target, GSS_C_NO_OID, req_flags, 0,
                                  GSS_C_NO_CHANNEL_BINDINGS, &input_token, NULL, &output_token, &ret_flags,
                                  &expiry_time );
-    TRACE( "gss_init_sec_context returned %08x minor status %08x ret_flags %08x\n", ret, minor_status, ret_flags );
+    TRACE( "gss_init_sec_context returned %#x minor status %#x ret_flags %#x\n", ret, minor_status, ret_flags );
     if (GSS_ERROR( ret )) trace_gss_status( ret, minor_status );
     if (ret == GSS_S_COMPLETE || ret == GSS_S_CONTINUE_NEEDED)
     {
-        if (output_token.length > output->pBuffers[idx].cbBuffer) /* FIXME: check if larger buffer exists */
+        if (output_token.length > params->output->pBuffers[idx].cbBuffer) /* FIXME: check if larger buffer exists */
         {
-            TRACE( "buffer too small %lu > %u\n", (SIZE_T)output_token.length, output->pBuffers[idx].cbBuffer );
+            TRACE( "buffer too small %lu > %u\n",
+                   (SIZE_T)output_token.length, (unsigned int)params->output->pBuffers[idx].cbBuffer );
             pgss_release_buffer( &minor_status, &output_token );
             pgss_delete_sec_context( &minor_status, &ctx_handle, GSS_C_NO_BUFFER );
             return SEC_E_INCOMPLETE_MESSAGE;
         }
-        output->pBuffers[idx].cbBuffer = output_token.length;
-        memcpy( output->pBuffers[idx].pvBuffer, output_token.value, output_token.length );
+        params->output->pBuffers[idx].cbBuffer = output_token.length;
+        memcpy( params->output->pBuffers[idx].pvBuffer, output_token.value, output_token.length );
         pgss_release_buffer( &minor_status, &output_token );
 
-        ctxhandle_gss_to_sspi( ctx_handle, new_context );
-        if (context_attr) *context_attr = flags_gss_to_isc_ret( ret_flags );
-        expirytime_gss_to_sspi( expiry_time, expiry );
+        ctxhandle_gss_to_sspi( ctx_handle, params->new_context );
+        if (params->context_attr) *params->context_attr = flags_gss_to_isc_ret( ret_flags );
+        *params->expiry = expiry_time;
     }
 
     if (target != GSS_C_NO_NAME) pgss_release_name( &minor_status, &target );
     return status_gss_to_sspi( ret );
 }
 
-static NTSTATUS CDECL make_signature( LSA_SEC_HANDLE context, SecBufferDesc *msg )
+static NTSTATUS make_signature( void *args )
 {
+    struct make_signature_params *params = args;
+    SecBufferDesc *msg = params->msg;
     OM_uint32 ret, minor_status;
     gss_buffer_desc data_buffer, token_buffer;
-    gss_ctx_id_t ctx_handle = ctxhandle_sspi_to_gss( context );
+    gss_ctx_id_t ctx_handle = ctxhandle_sspi_to_gss( params->context );
     int data_idx, token_idx;
 
     /* FIXME: multiple data buffers, read-only buffers */
@@ -745,7 +775,7 @@ static NTSTATUS CDECL make_signature( LSA_SEC_HANDLE context, SecBufferDesc *msg
     token_buffer.value  = NULL;
 
     ret = pgss_get_mic( &minor_status, ctx_handle, GSS_C_QOP_DEFAULT, &data_buffer, &token_buffer );
-    TRACE( "gss_get_mic returned %08x minor status %08x\n", ret, minor_status );
+    TRACE( "gss_get_mic returned %#x minor status %#x\n", ret, minor_status );
     if (GSS_ERROR( ret )) trace_gss_status( ret, minor_status );
     if (ret == GSS_S_COMPLETE)
     {
@@ -762,15 +792,16 @@ static NTSTATUS CDECL make_signature( LSA_SEC_HANDLE context, SecBufferDesc *msg
 #define KERBEROS_MAX_SIGNATURE_DCE    28
 #define KERBEROS_SECURITY_TRAILER_DCE 76
 
-static NTSTATUS CDECL query_context_attributes( LSA_SEC_HANDLE context, ULONG attr, void *buf )
+static NTSTATUS query_context_attributes( void *args )
 {
-    switch (attr)
+    struct query_context_attributes_params *params = args;
+    switch (params->attr)
     {
     case SECPKG_ATTR_SIZES:
     {
-        SecPkgContext_Sizes *sizes = (SecPkgContext_Sizes *)buf;
+        SecPkgContext_Sizes *sizes = (SecPkgContext_Sizes *)params->buf;
         ULONG size_max_signature, size_security_trailer;
-        gss_ctx_id_t ctx  = ctxhandle_sspi_to_gss( context );
+        gss_ctx_id_t ctx  = ctxhandle_sspi_to_gss( params->context );
 
         if (is_dce_style_context( ctx ))
         {
@@ -789,14 +820,14 @@ static NTSTATUS CDECL query_context_attributes( LSA_SEC_HANDLE context, ULONG at
         return SEC_E_OK;
     }
     default:
-        FIXME( "unhandled attribute %u\n", attr );
+        FIXME( "unhandled attribute %u\n", params->attr );
         break;
     }
 
     return SEC_E_UNSUPPORTED_FUNCTION;
 }
 
-static NTSTATUS seal_message_vector( gss_ctx_id_t ctx, SecBufferDesc *msg, ULONG qop )
+static NTSTATUS seal_message_vector( gss_ctx_id_t ctx, SecBufferDesc *msg, unsigned qop )
 {
     gss_iov_buffer_desc iov[4];
     OM_uint32 ret, minor_status;
@@ -808,7 +839,7 @@ static NTSTATUS seal_message_vector( gss_ctx_id_t ctx, SecBufferDesc *msg, ULONG
         conf_flag = 0; /* only integrity */
     else
     {
-        FIXME( "QOP %08x not supported\n", qop );
+        FIXME( "QOP %#x not supported\n", qop );
         return SEC_E_UNSUPPORTED_FUNCTION;
     }
 
@@ -833,7 +864,7 @@ static NTSTATUS seal_message_vector( gss_ctx_id_t ctx, SecBufferDesc *msg, ULONG
     iov[3].buffer.value  = NULL;
 
     ret = pgss_wrap_iov( &minor_status, ctx, conf_flag, GSS_C_QOP_DEFAULT, &conf_state, iov, 4 );
-    TRACE( "gss_wrap_iov returned %08x minor status %08x\n", ret, minor_status );
+    TRACE( "gss_wrap_iov returned %#x minor status %#x\n", ret, minor_status );
     if (GSS_ERROR( ret )) trace_gss_status( ret, minor_status );
     if (ret == GSS_S_COMPLETE)
     {
@@ -845,7 +876,7 @@ static NTSTATUS seal_message_vector( gss_ctx_id_t ctx, SecBufferDesc *msg, ULONG
     return status_gss_to_sspi( ret );
 }
 
-static NTSTATUS seal_message_no_vector( gss_ctx_id_t ctx, SecBufferDesc *msg, ULONG qop )
+static NTSTATUS seal_message_no_vector( gss_ctx_id_t ctx, SecBufferDesc *msg, unsigned qop )
 {
     gss_buffer_desc input, output;
     OM_uint32 ret, minor_status;
@@ -857,7 +888,7 @@ static NTSTATUS seal_message_no_vector( gss_ctx_id_t ctx, SecBufferDesc *msg, UL
         conf_flag = 0; /* only integrity */
     else
     {
-        FIXME( "QOP %08x not supported\n", qop );
+        FIXME( "QOP %#x not supported\n", qop );
         return SEC_E_UNSUPPORTED_FUNCTION;
     }
 
@@ -869,11 +900,11 @@ static NTSTATUS seal_message_no_vector( gss_ctx_id_t ctx, SecBufferDesc *msg, UL
     input.value  = msg->pBuffers[data_idx].pvBuffer;
 
     ret = pgss_wrap( &minor_status, ctx, conf_flag, GSS_C_QOP_DEFAULT, &input, &conf_state, &output );
-    TRACE( "gss_wrap returned %08x minor status %08x\n", ret, minor_status );
+    TRACE( "gss_wrap returned %#x minor status %#x\n", ret, minor_status );
     if (GSS_ERROR( ret )) trace_gss_status( ret, minor_status );
     if (ret == GSS_S_COMPLETE)
     {
-        DWORD len_data = msg->pBuffers[data_idx].cbBuffer, len_token = msg->pBuffers[token_idx].cbBuffer;
+        unsigned len_data = msg->pBuffers[data_idx].cbBuffer, len_token = msg->pBuffers[token_idx].cbBuffer;
         if (len_token < output.length - len_data)
         {
             TRACE( "buffer too small %lu > %u\n", (SIZE_T)output.length - len_data, len_token );
@@ -889,12 +920,13 @@ static NTSTATUS seal_message_no_vector( gss_ctx_id_t ctx, SecBufferDesc *msg, UL
     return status_gss_to_sspi( ret );
 }
 
-static NTSTATUS CDECL seal_message( LSA_SEC_HANDLE context, SecBufferDesc *msg, ULONG qop )
+static NTSTATUS seal_message( void *args )
 {
-    gss_ctx_id_t ctx = ctxhandle_sspi_to_gss( context );
+    struct seal_message_params *params = args;
+    gss_ctx_id_t ctx = ctxhandle_sspi_to_gss( params->context );
 
-    if (is_dce_style_context( ctx )) return seal_message_vector( ctx, msg, qop );
-    return seal_message_no_vector( ctx, msg, qop );
+    if (is_dce_style_context( ctx )) return seal_message_vector( ctx, params->msg, params->qop );
+    return seal_message_no_vector( ctx, params->msg, params->qop );
 }
 
 static NTSTATUS unseal_message_vector( gss_ctx_id_t ctx, SecBufferDesc *msg, ULONG *qop )
@@ -923,7 +955,7 @@ static NTSTATUS unseal_message_vector( gss_ctx_id_t ctx, SecBufferDesc *msg, ULO
     iov[3].buffer.value  = msg->pBuffers[token_idx].pvBuffer;
 
     ret = pgss_unwrap_iov( &minor_status, ctx, &conf_state, NULL, iov, 4 );
-    TRACE( "gss_unwrap_iov returned %08x minor status %08x\n", ret, minor_status );
+    TRACE( "gss_unwrap_iov returned %#x minor status %#x\n", ret, minor_status );
     if (GSS_ERROR( ret )) trace_gss_status( ret, minor_status );
     if (ret == GSS_S_COMPLETE && qop)
     {
@@ -946,13 +978,13 @@ static NTSTATUS unseal_message_no_vector( gss_ctx_id_t ctx, SecBufferDesc *msg,
     len_token = msg->pBuffers[token_idx].cbBuffer;
 
     input.length = len_data + len_token;
-    if (!(input.value = RtlAllocateHeap( GetProcessHeap(), 0, input.length ))) return SEC_E_INSUFFICIENT_MEMORY;
+    if (!(input.value = malloc( input.length ))) return SEC_E_INSUFFICIENT_MEMORY;
     memcpy( input.value, msg->pBuffers[data_idx].pvBuffer, len_data );
     memcpy( (char *)input.value + len_data, msg->pBuffers[token_idx].pvBuffer, len_token );
 
     ret = pgss_unwrap( &minor_status, ctx, &input, &output, &conf_state, NULL );
-    RtlFreeHeap( GetProcessHeap(), 0, input.value );
-    TRACE( "gss_unwrap returned %08x minor status %08x\n", ret, minor_status );
+    free( input.value );
+    TRACE( "gss_unwrap returned %#x minor status %#x\n", ret, minor_status );
     if (GSS_ERROR( ret )) trace_gss_status( ret, minor_status );
     if (ret == GSS_S_COMPLETE)
     {
@@ -964,19 +996,22 @@ static NTSTATUS unseal_message_no_vector( gss_ctx_id_t ctx, SecBufferDesc *msg,
     return status_gss_to_sspi( ret );
 }
 
-static NTSTATUS CDECL unseal_message( LSA_SEC_HANDLE context, SecBufferDesc *msg, ULONG *qop )
+static NTSTATUS unseal_message( void *args )
 {
-    gss_ctx_id_t ctx = ctxhandle_sspi_to_gss( context );
+    struct unseal_message_params *params = args;
+    gss_ctx_id_t ctx = ctxhandle_sspi_to_gss( params->context );
 
-    if (is_dce_style_context( ctx )) return unseal_message_vector( ctx, msg, qop );
-    return unseal_message_no_vector( ctx, msg, qop );
+    if (is_dce_style_context( ctx )) return unseal_message_vector( ctx, params->msg, params->qop );
+    return unseal_message_no_vector( ctx, params->msg, params->qop );
 }
 
-static NTSTATUS CDECL verify_signature( LSA_SEC_HANDLE context, SecBufferDesc *msg, ULONG *qop )
+static NTSTATUS verify_signature( void *args )
 {
+    struct verify_signature_params *params = args;
+    SecBufferDesc *msg = params->msg;
     OM_uint32 ret, minor_status;
     gss_buffer_desc data_buffer, token_buffer;
-    gss_ctx_id_t ctx_handle = ctxhandle_sspi_to_gss( context );
+    gss_ctx_id_t ctx_handle = ctxhandle_sspi_to_gss( params->context );
     int data_idx, token_idx;
 
     if ((data_idx = get_buffer_index( msg, SECBUFFER_DATA )) == -1) return SEC_E_INVALID_TOKEN;
@@ -988,15 +1023,23 @@ static NTSTATUS CDECL verify_signature( LSA_SEC_HANDLE context, SecBufferDesc *m
     token_buffer.value  = msg->pBuffers[token_idx].pvBuffer;
 
     ret = pgss_verify_mic( &minor_status, ctx_handle, &data_buffer, &token_buffer, NULL );
-    TRACE( "gss_verify_mic returned %08x minor status %08x\n", ret, minor_status );
+    TRACE( "gss_verify_mic returned %#x minor status %#x\n", ret, minor_status );
     if (GSS_ERROR( ret )) trace_gss_status( ret, minor_status );
-    if (ret == GSS_S_COMPLETE && qop) *qop = 0;
+    if (ret == GSS_S_COMPLETE && params->qop) *params->qop = 0;
 
     return status_gss_to_sspi( ret );
 }
 
-static const struct krb5_funcs funcs =
+static NTSTATUS process_attach( void *args )
 {
+    if (load_krb5() && load_gssapi_krb5()) return STATUS_SUCCESS;
+    if (libkrb5_handle) unload_krb5();
+    return STATUS_DLL_NOT_FOUND;
+}
+
+unixlib_entry_t __wine_unix_call_funcs[] =
+{
+    process_attach,
     accept_context,
     acquire_credentials_handle,
     delete_context,
@@ -1010,15 +1053,4 @@ static const struct krb5_funcs funcs =
     verify_signature,
 };
 
-NTSTATUS CDECL __wine_init_unix_lib( HMODULE module, DWORD reason, const void *ptr_in, void *ptr_out )
-{
-    if (reason != DLL_PROCESS_ATTACH) return STATUS_SUCCESS;
-    if (load_krb5() && load_gssapi_krb5())
-    {
-        *(const struct krb5_funcs **)ptr_out = &funcs;
-        return STATUS_SUCCESS;
-    }
-    if (libkrb5_handle) unload_krb5();
-    return STATUS_DLL_NOT_FOUND;
-}
 #endif /* defined(SONAME_LIBKRB5) && defined(SONAME_LIBGSSAPI_KRB5) */
