@@ -72,7 +72,7 @@ struct ctrl_handler
 
 static BOOL WINAPI default_ctrl_handler( DWORD type )
 {
-    FIXME( "Terminating process %x on event %x\n", GetCurrentProcessId(), type );
+    FIXME( "Terminating process %lx on event %lx\n", GetCurrentProcessId(), type );
     RtlExitUserProcess( 0 );
     return TRUE;
 }
@@ -175,6 +175,27 @@ static COORD get_largest_console_window_size( HANDLE handle )
     return c;
 }
 
+/* helper function for GetConsoleFontSize */
+static COORD get_console_font_size( HANDLE handle, DWORD index )
+{
+    struct condrv_output_info info;
+    COORD c = {0,0};
+
+    if (index >= 1 /* number of console fonts */)
+    {
+        SetLastError(ERROR_INVALID_PARAMETER);
+        return c;
+    }
+
+    if (DeviceIoControl( handle, IOCTL_CONDRV_GET_OUTPUT_INFO, NULL, 0, &info, sizeof(info), NULL, NULL ))
+    {
+        c.X = info.font_width;
+        c.Y = info.font_height;
+    }
+    else SetLastError( ERROR_INVALID_HANDLE );
+    return c;
+}
+
 static HANDLE create_console_server( void )
 {
     OBJECT_ATTRIBUTES attr = {sizeof(attr)};
@@ -278,6 +299,29 @@ static BOOL init_console_std_handles( BOOL override_all )
     return TRUE;
 }
 
+
+/******************************************************************
+ *	AddConsoleAliasA   (kernelbase.@)
+ */
+BOOL WINAPI AddConsoleAliasA( LPSTR source, LPSTR target, LPSTR exename )
+{
+    FIXME( ": (%s, %s, %s) stub!\n", debugstr_a(source), debugstr_a(target), debugstr_a(exename) );
+    SetLastError( ERROR_CALL_NOT_IMPLEMENTED );
+    return FALSE;
+}
+
+
+/******************************************************************
+ *	AddConsoleAliasW   (kernelbase.@)
+ */
+BOOL WINAPI AddConsoleAliasW( LPWSTR source, LPWSTR target, LPWSTR exename )
+{
+    FIXME( ": (%s, %s, %s) stub!\n", debugstr_w(source), debugstr_w(target), debugstr_w(exename) );
+    SetLastError( ERROR_CALL_NOT_IMPLEMENTED );
+    return FALSE;
+}
+
+
 /******************************************************************
  *	AttachConsole   (kernelbase.@)
  */
@@ -285,7 +329,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH AttachConsole( DWORD pid )
 {
     BOOL ret;
 
-    TRACE( "(%x)\n", pid );
+    TRACE( "(%lx)\n", pid );
 
     RtlEnterCriticalSection( &console_section );
 
@@ -383,7 +427,7 @@ BOOL WINAPI AllocConsole(void)
     if (!init_console_std_handles( !(app_si.dwFlags & STARTF_USESTDHANDLES) )) goto error;
 
     RtlGetCurrentPeb()->ProcessParameters->ConsoleHandle = console;
-    TRACE( "Started conhost pid=%08x tid=%08x\n", pi.dwProcessId, pi.dwThreadId );
+    TRACE( "Started conhost pid=%08lx tid=%08lx\n", pi.dwProcessId, pi.dwThreadId );
 
     CloseHandle( server );
     RtlLeaveCriticalSection( &console_section );
@@ -413,7 +457,7 @@ HANDLE WINAPI DECLSPEC_HOTPATCH CreateConsoleScreenBuffer( DWORD access, DWORD s
     HANDLE handle;
     NTSTATUS status;
 
-    TRACE( "(%x,%x,%p,%x,%p)\n", access, share, sa, flags, data );
+    TRACE( "(%lx,%lx,%p,%lx,%p)\n", access, share, sa, flags, data );
 
     if (flags != CONSOLE_TEXTMODE_BUFFER || data)
     {
@@ -470,17 +514,23 @@ DWORD WINAPI CtrlRoutine( void *arg )
 }
 
 
-static LONG WINAPI handle_ctrl_c( EXCEPTION_POINTERS *eptr )
+/******************************************************************
+ *	ExpungeConsoleCommandHistoryA   (kernelbase.@)
+ */
+void WINAPI ExpungeConsoleCommandHistoryA( LPCSTR exename )
 {
-    if (eptr->ExceptionRecord->ExceptionCode != CONTROL_C_EXIT) return EXCEPTION_CONTINUE_SEARCH;
-    if (!RtlGetCurrentPeb()->ProcessParameters->ConsoleHandle)  return EXCEPTION_CONTINUE_SEARCH;
+    FIXME( ": (%s) stub!\n", debugstr_a(exename) );
+    SetLastError( ERROR_CALL_NOT_IMPLEMENTED );
+}
 
-    if (!(NtCurrentTeb()->Peb->ProcessParameters->ConsoleFlags & 1))
-    {
-        HANDLE thread = CreateThread( NULL, 0, CtrlRoutine, (void*)CTRL_C_EVENT, 0, NULL );
-        if (thread) CloseHandle( thread );
-    }
-    return EXCEPTION_CONTINUE_EXECUTION;
+
+/******************************************************************
+ *	ExpungeConsoleCommandHistoryW   (kernelbase.@)
+ */
+void WINAPI ExpungeConsoleCommandHistoryW( LPCWSTR exename )
+{
+    FIXME( ": (%s) stub!\n", debugstr_w(exename) );
+    SetLastError( ERROR_CALL_NOT_IMPLEMENTED );
 }
 
 
@@ -492,7 +542,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH FillConsoleOutputAttribute( HANDLE handle, WORD at
 {
     struct condrv_fill_output_params params;
 
-    TRACE( "(%p,%d,%d,(%dx%d),%p)\n", handle, attr, length, coord.X, coord.Y, written );
+    TRACE( "(%p,%d,%ld,(%dx%d),%p)\n", handle, attr, length, coord.X, coord.Y, written );
 
     if (!written)
     {
@@ -535,7 +585,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH FillConsoleOutputCharacterW( HANDLE handle, WCHAR
 {
     struct condrv_fill_output_params params;
 
-    TRACE( "(%p,%s,%d,(%dx%d),%p)\n", handle, debugstr_wn(&ch, 1), length, coord.X, coord.Y, written );
+    TRACE( "(%p,%s,%ld,(%dx%d),%p)\n", handle, debugstr_wn(&ch, 1), length, coord.X, coord.Y, written );
 
     if (!written)
     {
@@ -587,11 +637,11 @@ BOOL WINAPI DECLSPEC_HOTPATCH GenerateConsoleCtrlEvent( DWORD event, DWORD group
 {
     struct condrv_ctrl_event ctrl_event;
 
-    TRACE( "(%d, %x)\n", event, group );
+    TRACE( "(%ld, %lx)\n", event, group );
 
     if (event != CTRL_C_EVENT && event != CTRL_BREAK_EVENT)
     {
-	ERR( "Invalid event %d for PGID %x\n", event, group );
+	ERR( "Invalid event %ld for PGID %lx\n", event, group );
 	return FALSE;
     }
 
@@ -602,6 +652,116 @@ BOOL WINAPI DECLSPEC_HOTPATCH GenerateConsoleCtrlEvent( DWORD event, DWORD group
 }
 
 
+/******************************************************************
+ *	GetConsoleAliasA   (kernelbase.@)
+ */
+DWORD WINAPI GetConsoleAliasA( LPSTR source, LPSTR buffer, DWORD len, LPSTR exename )
+{
+    FIXME( "(%s,%p,%ld,%s): stub\n", debugstr_a(source), buffer, len, debugstr_a(exename) );
+    SetLastError( ERROR_CALL_NOT_IMPLEMENTED );
+    return 0;
+}
+
+
+/******************************************************************
+ *	GetConsoleAliasW   (kernelbase.@)
+ */
+DWORD WINAPI GetConsoleAliasW( LPWSTR source, LPWSTR buffer, DWORD len, LPWSTR exename )
+{
+    FIXME( "(%s,%p,%ld,%s): stub\n", debugstr_w(source), buffer, len, debugstr_w(exename) );
+    SetLastError( ERROR_CALL_NOT_IMPLEMENTED );
+    return 0;
+}
+
+
+/******************************************************************
+ *	GetConsoleAliasExesLengthA   (kernelbase.@)
+ */
+DWORD WINAPI GetConsoleAliasExesLengthA(void)
+{
+    FIXME( ": stub\n" );
+    SetLastError( ERROR_CALL_NOT_IMPLEMENTED );
+    return 0;
+}
+
+
+/******************************************************************
+ *	GetConsoleAliasExesLengthW   (kernelbase.@)
+ */
+DWORD WINAPI GetConsoleAliasExesLengthW(void)
+{
+    FIXME( ": stub\n" );
+    SetLastError( ERROR_CALL_NOT_IMPLEMENTED );
+    return 0;
+}
+
+
+/******************************************************************
+ *	GetConsoleAliasesLengthA   (kernelbase.@)
+ */
+DWORD WINAPI GetConsoleAliasesLengthA( LPSTR unknown )
+{
+    FIXME( ": (%s) stub!\n", debugstr_a(unknown) );
+    SetLastError( ERROR_CALL_NOT_IMPLEMENTED );
+    return 0;
+}
+
+
+/******************************************************************
+ *	GetConsoleAliasesLengthW   (kernelbase.@)
+ */
+DWORD WINAPI GetConsoleAliasesLengthW( LPWSTR unknown )
+{
+    FIXME( ": (%s) stub!\n", debugstr_w(unknown) );
+    SetLastError( ERROR_CALL_NOT_IMPLEMENTED );
+    return 0;
+}
+
+
+/******************************************************************
+ *	GetConsoleCommandHistoryA   (kernelbase.@)
+ */
+DWORD WINAPI GetConsoleCommandHistoryA( LPSTR buffer, DWORD len, LPCSTR exename )
+{
+    FIXME( ": (%p, 0x%lx, %s) stub\n", buffer, len, debugstr_a(exename) );
+    SetLastError( ERROR_CALL_NOT_IMPLEMENTED );
+    return 0;
+}
+
+
+/******************************************************************
+ *	GetConsoleCommandHistoryW   (kernelbase.@)
+ */
+DWORD WINAPI GetConsoleCommandHistoryW( LPWSTR buffer, DWORD len, LPCWSTR exename )
+{
+    FIXME( ": (%p, 0x%lx, %s) stub\n", buffer, len, debugstr_w(exename) );
+    SetLastError( ERROR_CALL_NOT_IMPLEMENTED );
+    return 0;
+}
+
+
+/******************************************************************
+ *	GetConsoleCommandHistoryLengthA   (kernelbase.@)
+ */
+DWORD WINAPI GetConsoleCommandHistoryLengthA( LPCSTR exename )
+{
+    FIXME( ": (%s) stub!\n", debugstr_a(exename) );
+    SetLastError( ERROR_CALL_NOT_IMPLEMENTED );
+    return 0;
+}
+
+
+/******************************************************************
+ *	GetConsoleCommandHistoryLengthW   (kernelbase.@)
+ */
+DWORD WINAPI GetConsoleCommandHistoryLengthW( LPCWSTR exename )
+{
+    FIXME( ": (%s) stub!\n", debugstr_w(exename) );
+    SetLastError( ERROR_CALL_NOT_IMPLEMENTED );
+    return 0;
+}
+
+
 /******************************************************************************
  *	GetConsoleCP   (kernelbase.@)
  */
@@ -634,11 +794,46 @@ BOOL WINAPI DECLSPEC_HOTPATCH GetConsoleCursorInfo( HANDLE handle, CONSOLE_CURSO
 
     info->dwSize   = condrv_info.cursor_size;
     info->bVisible = condrv_info.cursor_visible;
-    TRACE("(%p) returning (%d,%d)\n", handle, info->dwSize, info->bVisible);
+    TRACE("(%p) returning (%ld,%d)\n", handle, info->dwSize, info->bVisible);
     return TRUE;
 }
 
 
+/***********************************************************************
+ *	GetConsoleDisplayMode   (kernelbase.@)
+ */
+BOOL WINAPI GetConsoleDisplayMode( LPDWORD flags )
+{
+    TRACE( "semi-stub: %p\n", flags );
+    /* It is safe to successfully report windowed mode */
+    *flags = 0;
+    return TRUE;
+}
+
+
+/***********************************************************************
+ *	GetConsoleFontSize   (kernelbase.@)
+ */
+#if defined(__i386__) && !defined(__MINGW32__) && !defined(_MSC_VER)
+#undef GetConsoleFontSize
+DWORD WINAPI GetConsoleFontSize( HANDLE handle, DWORD index )
+{
+    union {
+        COORD c;
+        DWORD w;
+    } x;
+
+    x.c = get_console_font_size( handle, index );
+    return x.w;
+}
+#else
+COORD WINAPI GetConsoleFontSize( HANDLE handle, DWORD index )
+{
+    return get_console_font_size( handle, index );
+}
+#endif /* !defined(__i386__) */
+
+
 /***********************************************************************
  *	GetConsoleInputExeNameA   (kernelbase.@)
  */
@@ -689,6 +884,42 @@ UINT WINAPI DECLSPEC_HOTPATCH GetConsoleOutputCP(void)
 }
 
 
+/***********************************************************************
+ *	GetConsoleProcessList   (kernelbase.@)
+ */
+DWORD WINAPI GetConsoleProcessList( DWORD *list, DWORD count )
+{
+    DWORD saved;
+    NTSTATUS status;
+    IO_STATUS_BLOCK io;
+
+    TRACE( "(%p,%ld)\n", list, count);
+
+    if (!list || count < 1)
+    {
+        SetLastError(ERROR_INVALID_PARAMETER);
+        return 0;
+    }
+
+    saved = *list;
+    status = NtDeviceIoControlFile( RtlGetCurrentPeb()->ProcessParameters->ConsoleHandle,
+                                    NULL, NULL, NULL, &io, IOCTL_CONDRV_GET_PROCESS_LIST,
+                                    NULL, 0, list, count * sizeof(DWORD) );
+
+    if (!status) return io.Information / sizeof(DWORD);
+    if (status == STATUS_BUFFER_TOO_SMALL)
+    {
+        DWORD ret = *list;
+        *list = saved;
+        return ret;
+    }
+
+    *list = saved;
+    set_ntstatus( status );
+    return 0;
+}
+
+
 /***********************************************************************
  *	GetConsoleScreenBufferInfo   (kernelbase.@)
  */
@@ -756,6 +987,26 @@ BOOL WINAPI DECLSPEC_HOTPATCH GetConsoleScreenBufferInfoEx( HANDLE handle,
 }
 
 
+/******************************************************************************
+ *	GetConsoleTitleA   (kernelbase.@)
+ */
+DWORD WINAPI DECLSPEC_HOTPATCH GetConsoleTitleA( LPSTR title, DWORD size )
+{
+    WCHAR *ptr = HeapAlloc( GetProcessHeap(), 0, sizeof(WCHAR) * size );
+    DWORD ret;
+
+    if (!ptr) return 0;
+    ret = GetConsoleTitleW( ptr, size );
+    if (ret)
+    {
+        WideCharToMultiByte( GetConsoleOutputCP(), 0, ptr, ret + 1, title, size, NULL, NULL);
+        ret = strlen(title);
+    }
+    HeapFree( GetProcessHeap(), 0, ptr );
+    return ret;
+}
+
+
 /******************************************************************************
  *	GetConsoleTitleW   (kernelbase.@)
  */
@@ -773,6 +1024,86 @@ DWORD WINAPI DECLSPEC_HOTPATCH GetConsoleTitleW( LPWSTR title, DWORD size )
 }
 
 
+/******************************************************************************
+ *	GetConsoleWindow   (kernelbase.@)
+ */
+HWND WINAPI GetConsoleWindow(void)
+{
+    condrv_handle_t win;
+    BOOL ret;
+
+    ret = DeviceIoControl( RtlGetCurrentPeb()->ProcessParameters->ConsoleHandle,
+                           IOCTL_CONDRV_GET_WINDOW, NULL, 0, &win, sizeof(win), NULL, NULL );
+    return ret ? LongToHandle( win ) : NULL;
+}
+
+
+/***********************************************************************
+ *	GetCurrentConsoleFontEx   (kernelbase.@)
+ */
+BOOL WINAPI GetCurrentConsoleFontEx( HANDLE handle, BOOL maxwindow, CONSOLE_FONT_INFOEX *info )
+{
+    DWORD size;
+    struct
+    {
+        struct condrv_output_info info;
+        WCHAR face_name[LF_FACESIZE - 1];
+    } data;
+
+    if (info->cbSize != sizeof(CONSOLE_FONT_INFOEX))
+    {
+        SetLastError(ERROR_INVALID_PARAMETER);
+        return FALSE;
+    }
+
+    if (!DeviceIoControl( handle, IOCTL_CONDRV_GET_OUTPUT_INFO, NULL, 0,
+                          &data, sizeof(data), &size, NULL ))
+    {
+        SetLastError( ERROR_INVALID_HANDLE );
+        return FALSE;
+    }
+
+    info->nFont = 0;
+    if (maxwindow)
+    {
+        info->dwFontSize.X = min( data.info.width, data.info.max_width );
+        info->dwFontSize.Y = min( data.info.height, data.info.max_height );
+    }
+    else
+    {
+        info->dwFontSize.X = data.info.font_width;
+        info->dwFontSize.Y = data.info.font_height;
+    }
+    size -= sizeof(data.info);
+    if (size) memcpy( info->FaceName, data.face_name, size );
+    info->FaceName[size / sizeof(WCHAR)] = 0;
+    info->FontFamily = data.info.font_pitch_family;
+    info->FontWeight = data.info.font_weight;
+    return TRUE;
+}
+
+
+/***********************************************************************
+ *	GetCurrentConsoleFont   (kernelbase.@)
+ */
+BOOL WINAPI GetCurrentConsoleFont( HANDLE handle, BOOL maxwindow, CONSOLE_FONT_INFO *info )
+{
+    BOOL ret;
+    CONSOLE_FONT_INFOEX res;
+
+    res.cbSize = sizeof(CONSOLE_FONT_INFOEX);
+
+    ret = GetCurrentConsoleFontEx( handle, maxwindow, &res );
+    if (ret)
+    {
+        info->nFont = res.nFont;
+        info->dwFontSize.X = res.dwFontSize.X;
+        info->dwFontSize.Y = res.dwFontSize.Y;
+    }
+    return ret;
+}
+
+
 /***********************************************************************
  *	GetLargestConsoleWindowSize   (kernelbase.@)
  */
@@ -811,6 +1142,17 @@ BOOL WINAPI DECLSPEC_HOTPATCH GetNumberOfConsoleInputEvents( HANDLE handle, DWOR
 }
 
 
+/***********************************************************************
+ *	GetNumberOfConsoleMouseButtons   (kernelbase.@)
+ */
+BOOL WINAPI GetNumberOfConsoleMouseButtons( DWORD *count )
+{
+    FIXME( "(%p): stub\n", count );
+    *count = 2;
+    return TRUE;
+}
+
+
 /***********************************************************************
  *	PeekConsoleInputA   (kernelbase.@)
  */
@@ -849,7 +1191,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH ReadConsoleOutputAttribute( HANDLE handle, WORD *a
     struct condrv_output_params params;
     BOOL ret;
 
-    TRACE( "(%p,%p,%d,%dx%d,%p)\n", handle, attr, length, coord.X, coord.Y, count );
+    TRACE( "(%p,%p,%ld,%dx%d,%p)\n", handle, attr, length, coord.X, coord.Y, count );
 
     if (!count)
     {
@@ -909,7 +1251,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH ReadConsoleOutputCharacterW( HANDLE handle, LPWSTR
     struct condrv_output_params params;
     BOOL ret;
 
-    TRACE( "(%p,%p,%d,%dx%d,%p)\n", handle, buffer, length, coord.X, coord.Y, count );
+    TRACE( "(%p,%p,%ld,%dx%d,%p)\n", handle, buffer, length, coord.X, coord.Y, count );
 
     if (!count)
     {
@@ -1131,7 +1473,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH SetConsoleCursorInfo( HANDLE handle, CONSOLE_CURSO
 {
     struct condrv_output_info_params params = { SET_CONSOLE_OUTPUT_INFO_CURSOR_GEOM };
 
-    TRACE( "(%p,%d,%d)\n", handle, info->dwSize, info->bVisible);
+    TRACE( "(%p,%ld,%d)\n", handle, info->dwSize, info->bVisible);
 
     params.info.cursor_size    = info->dwSize;
     params.info.cursor_visible = info->bVisible;
@@ -1155,6 +1497,21 @@ BOOL WINAPI DECLSPEC_HOTPATCH SetConsoleCursorPosition( HANDLE handle, COORD pos
 }
 
 
+/***********************************************************************
+ *	SetConsoleDisplayMode   (kernelbase.@)
+ */
+BOOL WINAPI SetConsoleDisplayMode( HANDLE handle, DWORD flags, COORD *size )
+{
+    TRACE( "(%p, %lx, (%d, %d))\n", handle, flags, size->X, size->Y );
+    if (flags == 1)
+    {
+        /* We cannot switch to fullscreen */
+        return FALSE;
+    }
+    return TRUE;
+}
+
+
 /******************************************************************************
  *	SetConsoleInputExeNameA   (kernelbase.@)
  */
@@ -1194,7 +1551,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH SetConsoleInputExeNameW( LPCWSTR name )
  */
 BOOL WINAPI DECLSPEC_HOTPATCH SetConsoleMode( HANDLE handle, DWORD mode )
 {
-    TRACE( "(%p,%x)\n", handle, mode );
+    TRACE( "(%p,%lx)\n", handle, mode );
     return console_ioctl( handle, IOCTL_CONDRV_SET_MODE, &mode, sizeof(mode), NULL, 0, NULL );
 }
 
@@ -1276,6 +1633,22 @@ BOOL WINAPI DECLSPEC_HOTPATCH SetConsoleTextAttribute( HANDLE handle, WORD attr
 }
 
 
+/******************************************************************************
+ *	SetConsoleTitleA   (kernelbase.@)
+ */
+BOOL WINAPI SetConsoleTitleA( LPCSTR title )
+{
+    LPWSTR titleW;
+    BOOL ret;
+    DWORD len = MultiByteToWideChar( GetConsoleOutputCP(), 0, title, -1, NULL, 0 );
+    if (!(titleW = HeapAlloc( GetProcessHeap(), 0, len * sizeof(WCHAR) ))) return FALSE;
+    MultiByteToWideChar( GetConsoleOutputCP(), 0, title, -1, titleW, len );
+    ret = SetConsoleTitleW(titleW);
+    HeapFree( GetProcessHeap(), 0, titleW );
+    return ret;
+}
+
+
 /******************************************************************************
  *	SetConsoleTitleW   (kernelbase.@)
  */
@@ -1317,6 +1690,42 @@ BOOL WINAPI DECLSPEC_HOTPATCH SetConsoleWindowInfo( HANDLE handle, BOOL absolute
 }
 
 
+/******************************************************************************
+ *	SetCurrentConsoleFontEx   (kernelbase.@)
+ */
+BOOL WINAPI SetCurrentConsoleFontEx( HANDLE handle, BOOL maxwindow, CONSOLE_FONT_INFOEX *info )
+{
+    struct
+    {
+        struct condrv_output_info_params params;
+        WCHAR face_name[LF_FACESIZE];
+    } data;
+
+    size_t size;
+
+    TRACE( "(%p %d %p)\n", handle, maxwindow, info );
+
+    if (info->cbSize != sizeof(*info))
+    {
+        SetLastError(ERROR_INVALID_PARAMETER);
+        return FALSE;
+    }
+
+    data.params.mask = SET_CONSOLE_OUTPUT_INFO_FONT;
+
+    data.params.info.font_width  = info->dwFontSize.X;
+    data.params.info.font_height = info->dwFontSize.Y;
+    data.params.info.font_pitch_family = info->FontFamily;
+    data.params.info.font_weight = info->FontWeight;
+
+    size = wcsnlen( info->FaceName, LF_FACESIZE - 1 ) * sizeof(WCHAR);
+    memcpy( data.face_name, info->FaceName, size );
+
+    size += sizeof(struct condrv_output_info_params);
+    return console_ioctl( handle, IOCTL_CONDRV_SET_OUTPUT_INFO, &data, size, NULL, 0, NULL );
+}
+
+
 /***********************************************************************
  *            ReadConsoleInputA   (kernelbase.@)
  */
@@ -1380,7 +1789,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH WriteConsoleInputA( HANDLE handle, const INPUT_REC
 BOOL WINAPI DECLSPEC_HOTPATCH WriteConsoleInputW( HANDLE handle, const INPUT_RECORD *buffer,
                                                   DWORD count, DWORD *written )
 {
-    TRACE( "(%p,%p,%d,%p)\n", handle, buffer, count, written );
+    TRACE( "(%p,%p,%ld,%p)\n", handle, buffer, count, written );
 
     if (count > 0 && !buffer)
     {
@@ -1493,7 +1902,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH WriteConsoleOutputAttribute( HANDLE handle, const
     size_t size;
     BOOL ret;
 
-    TRACE( "(%p,%p,%d,%dx%d,%p)\n", handle, attr, length, coord.X, coord.Y, written );
+    TRACE( "(%p,%p,%ld,%dx%d,%p)\n", handle, attr, length, coord.X, coord.Y, written );
 
     if ((length > 0 && !attr) || !written)
     {
@@ -1525,7 +1934,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH WriteConsoleOutputCharacterA( HANDLE handle, LPCST
     LPWSTR strW = NULL;
     DWORD lenW = 0;
 
-    TRACE( "(%p,%s,%d,%dx%d,%p)\n", handle, debugstr_an(str, length), length, coord.X, coord.Y, written );
+    TRACE( "(%p,%s,%ld,%dx%d,%p)\n", handle, debugstr_an(str, length), length, coord.X, coord.Y, written );
 
     if (length > 0)
     {
@@ -1560,7 +1969,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH WriteConsoleOutputCharacterW( HANDLE handle, LPCWS
     size_t size;
     BOOL ret;
 
-    TRACE( "(%p,%s,%d,%dx%d,%p)\n", handle, debugstr_wn(str, length), length, coord.X, coord.Y, written );
+    TRACE( "(%p,%s,%ld,%dx%d,%p)\n", handle, debugstr_wn(str, length), length, coord.X, coord.Y, written );
 
     if ((length > 0 && !str) || !written)
     {
@@ -1604,7 +2013,7 @@ BOOL WINAPI ReadConsoleW( HANDLE handle, void *buffer, DWORD length, DWORD *coun
 {
     BOOL ret;
 
-    TRACE( "(%p,%p,%d,%p,%p)\n", handle, buffer, length, count, reserved );
+    TRACE( "(%p,%p,%ld,%p,%p)\n", handle, buffer, length, count, reserved );
 
     if (length > INT_MAX)
     {
@@ -1627,7 +2036,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH WriteConsoleA( HANDLE handle, const void *buffer,
 {
     BOOL ret;
 
-    TRACE( "(%p,%s,%d,%p,%p)\n", handle, debugstr_an(buffer, length), length, written, reserved );
+    TRACE( "(%p,%s,%ld,%p,%p)\n", handle, debugstr_an(buffer, length), length, written, reserved );
 
     ret = console_ioctl( handle, IOCTL_CONDRV_WRITE_FILE, (void *)buffer, length, NULL, 0, NULL );
     if (written) *written = ret ? length : 0;
@@ -1643,7 +2052,7 @@ BOOL WINAPI DECLSPEC_HOTPATCH WriteConsoleW( HANDLE handle, const void *buffer,
 {
     BOOL ret;
 
-    TRACE( "(%p,%s,%d,%p,%p)\n", handle, debugstr_wn(buffer, length), length, written, reserved );
+    TRACE( "(%p,%s,%ld,%p,%p)\n", handle, debugstr_wn(buffer, length), length, written, reserved );
 
     ret = console_ioctl( handle, IOCTL_CONDRV_WRITE_CONSOLE, (void *)buffer,
                          length * sizeof(WCHAR), NULL, 0, NULL );
@@ -1738,11 +2147,11 @@ HRESULT WINAPI CreatePseudoConsole( COORD size, HANDLE input, HANDLE output, DWO
     HANDLE signal = NULL;
     WCHAR pipe_name[64];
 
-    TRACE( "(%u,%u) %p %p %x %p\n", size.X, size.Y, input, output, flags, ret );
+    TRACE( "(%u,%u) %p %p %lx %p\n", size.X, size.Y, input, output, flags, ret );
 
     if (!size.X || !size.Y || !ret) return E_INVALIDARG;
 
-    if (!(pseudo_console = HeapAlloc( GetProcessHeap(), 0, HEAP_ZERO_MEMORY ))) return E_OUTOFMEMORY;
+    if (!(pseudo_console = HeapAlloc( GetProcessHeap(), HEAP_ZERO_MEMORY, sizeof(*pseudo_console) ))) return E_OUTOFMEMORY;
 
     swprintf( pipe_name, ARRAY_SIZE(pipe_name),  L"\\\\.\\pipe\\wine_pty_signal_pipe%x",
               GetCurrentThreadId() );
@@ -1854,6 +2263,4 @@ void init_console( void )
             AllocConsole();
     }
     else if (params->ConsoleHandle) create_console_connection( params->ConsoleHandle );
-
-    RtlAddVectoredExceptionHandler( FALSE, handle_ctrl_c );
 }
