@@ -206,7 +206,7 @@ static HRESULT WINAPI sample_grabber_stream_GetEvent(IMFStreamSink *iface, DWORD
 {
     struct sample_grabber *grabber = impl_from_IMFStreamSink(iface);
 
-    TRACE("%p, %#x, %p.\n", iface, flags, event);
+    TRACE("%p, %#lx, %p.\n", iface, flags, event);
 
     if (grabber->is_shut_down)
         return MF_E_STREAMSINK_REMOVED;
@@ -245,7 +245,7 @@ static HRESULT WINAPI sample_grabber_stream_QueueEvent(IMFStreamSink *iface, Med
 {
     struct sample_grabber *grabber = impl_from_IMFStreamSink(iface);
 
-    TRACE("%p, %u, %s, %#x, %p.\n", iface, event_type, debugstr_guid(ext_type), hr, value);
+    TRACE("%p, %lu, %s, %#lx, %p.\n", iface, event_type, debugstr_guid(ext_type), hr, value);
 
     if (grabber->is_shut_down)
         return MF_E_STREAMSINK_REMOVED;
@@ -614,7 +614,7 @@ static HRESULT WINAPI sample_grabber_stream_type_handler_GetMediaTypeCount(IMFMe
 static HRESULT WINAPI sample_grabber_stream_type_handler_GetMediaTypeByIndex(IMFMediaTypeHandler *iface, DWORD index,
         IMFMediaType **media_type)
 {
-    TRACE("%p, %u, %p.\n", iface, index, media_type);
+    TRACE("%p, %lu, %p.\n", iface, index, media_type);
 
     if (!media_type)
         return E_POINTER;
@@ -741,14 +741,14 @@ static HRESULT WINAPI sample_grabber_stream_timer_callback_Invoke(IMFAsyncCallba
             if (!sample_reported)
             {
                 if (FAILED(hr = sample_grabber_report_sample(grabber, item->u.sample, &sample_delivered)))
-                    WARN("Failed to report a sample, hr %#x.\n", hr);
+                    WARN("Failed to report a sample, hr %#lx.\n", hr);
                 stream_release_pending_item(item);
                 sample_reported = TRUE;
             }
             else
             {
                 if (FAILED(hr = stream_schedule_sample(grabber, item)))
-                    WARN("Failed to schedule a sample, hr %#x.\n", hr);
+                    WARN("Failed to schedule a sample, hr %#lx.\n", hr);
                 break;
             }
         }
@@ -814,7 +814,7 @@ static ULONG WINAPI sample_grabber_sink_AddRef(IMFMediaSink *iface)
     struct sample_grabber *grabber = impl_from_IMFMediaSink(iface);
     ULONG refcount = InterlockedIncrement(&grabber->refcount);
 
-    TRACE("%p, refcount %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     return refcount;
 }
@@ -834,7 +834,7 @@ static ULONG WINAPI sample_grabber_sink_Release(IMFMediaSink *iface)
     struct sample_grabber *grabber = impl_from_IMFMediaSink(iface);
     ULONG refcount = InterlockedDecrement(&grabber->refcount);
 
-    TRACE("%p, refcount %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     if (!refcount)
     {
@@ -888,7 +888,7 @@ static HRESULT WINAPI sample_grabber_sink_AddStreamSink(IMFMediaSink *iface, DWO
 {
     struct sample_grabber *grabber = impl_from_IMFMediaSink(iface);
 
-    TRACE("%p, %#x, %p, %p.\n", iface, stream_sink_id, media_type, stream_sink);
+    TRACE("%p, %#lx, %p, %p.\n", iface, stream_sink_id, media_type, stream_sink);
 
     return grabber->is_shut_down ? MF_E_SHUTDOWN : MF_E_STREAMSINKS_FIXED;
 }
@@ -897,7 +897,7 @@ static HRESULT WINAPI sample_grabber_sink_RemoveStreamSink(IMFMediaSink *iface,
 {
     struct sample_grabber *grabber = impl_from_IMFMediaSink(iface);
 
-    TRACE("%p, %#x.\n", iface, stream_sink_id);
+    TRACE("%p, %#lx.\n", iface, stream_sink_id);
 
     return grabber->is_shut_down ? MF_E_SHUTDOWN : MF_E_STREAMSINKS_FIXED;
 }
@@ -922,7 +922,7 @@ static HRESULT WINAPI sample_grabber_sink_GetStreamSinkByIndex(IMFMediaSink *ifa
     struct sample_grabber *grabber = impl_from_IMFMediaSink(iface);
     HRESULT hr = S_OK;
 
-    TRACE("%p, %u, %p.\n", iface, index, stream);
+    TRACE("%p, %lu, %p.\n", iface, index, stream);
 
     if (grabber->is_shut_down)
         return MF_E_SHUTDOWN;
@@ -950,7 +950,7 @@ static HRESULT WINAPI sample_grabber_sink_GetStreamSinkById(IMFMediaSink *iface,
     struct sample_grabber *grabber = impl_from_IMFMediaSink(iface);
     HRESULT hr = S_OK;
 
-    TRACE("%p, %#x, %p.\n", iface, stream_sink_id, stream);
+    TRACE("%p, %#lx, %p.\n", iface, stream_sink_id, stream);
 
     EnterCriticalSection(&grabber->cs);
 
@@ -1233,7 +1233,7 @@ static HRESULT WINAPI sample_grabber_events_GetEvent(IMFMediaEventGenerator *ifa
 {
     struct sample_grabber *grabber = impl_from_IMFMediaEventGenerator(iface);
 
-    TRACE("%p, %#x, %p.\n", iface, flags, event);
+    TRACE("%p, %#lx, %p.\n", iface, flags, event);
 
     return IMFMediaEventQueue_GetEvent(grabber->event_queue, flags, event);
 }
@@ -1263,7 +1263,7 @@ static HRESULT WINAPI sample_grabber_events_QueueEvent(IMFMediaEventGenerator *i
 {
     struct sample_grabber *grabber = impl_from_IMFMediaEventGenerator(iface);
 
-    TRACE("%p, %u, %s, %#x, %p.\n", iface, event_type, debugstr_guid(ext_type), hr, value);
+    TRACE("%p, %lu, %s, %#lx, %p.\n", iface, event_type, debugstr_guid(ext_type), hr, value);
 
     return IMFMediaEventQueue_QueueEventParamVar(grabber->event_queue, event_type, ext_type, hr, value);
 }
