@@ -53,11 +53,24 @@ static void platform_shutdown(void)
         MFShutdown();
 }
 
+static inline const char *debugstr_normalized_rect(const MFVideoNormalizedRect *rect)
+{
+    if (!rect) return "(null)";
+    return wine_dbg_sprintf("(%.8e,%.8e)-(%.8e,%.8e)", rect->left, rect->top, rect->right, rect->bottom);
+}
+
+struct media_player;
+
+enum media_item_flags
+{
+    MEDIA_ITEM_SOURCE_NEEDS_SHUTDOWN = 0x1,
+};
+
 struct media_item
 {
     IMFPMediaItem IMFPMediaItem_iface;
     LONG refcount;
-    IMFPMediaPlayer *player;
+    struct media_player *player;
     IMFMediaSource *source;
     IMFPresentationDescriptor *pd;
     DWORD_PTR user_data;
@@ -65,6 +78,7 @@ struct media_item
     IUnknown *object;
     LONGLONG start_position;
     LONGLONG stop_position;
+    unsigned int flags;
 };
 
 struct media_player
@@ -169,7 +183,7 @@ static ULONG WINAPI media_event_AddRef(IUnknown *iface)
     struct media_event *event = impl_event_from_IUnknown(iface);
     ULONG refcount = InterlockedIncrement(&event->refcount);
 
-    TRACE("%p, refcount %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     return refcount;
 }
@@ -179,7 +193,7 @@ static ULONG WINAPI media_event_Release(IUnknown *iface)
     struct media_event *event = impl_event_from_IUnknown(iface);
     ULONG refcount = InterlockedDecrement(&event->refcount);
 
-    TRACE("%p, refcount %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     if (!refcount)
     {
@@ -302,6 +316,16 @@ static void media_player_set_state(struct media_player *player, MFP_MEDIAPLAYER_
     }
 }
 
+static HRESULT media_item_get_pd(const struct media_item *item, IMFPresentationDescriptor **pd)
+{
+    if (item->player->state == MFP_MEDIAPLAYER_STATE_SHUTDOWN)
+        return MF_E_SHUTDOWN;
+
+    *pd = item->pd;
+    IMFPresentationDescriptor_AddRef(*pd);
+    return S_OK;
+}
+
 static HRESULT WINAPI media_item_QueryInterface(IMFPMediaItem *iface, REFIID riid, void **obj)
 {
     TRACE("%p, %s, %p.\n", iface, debugstr_guid(riid), obj);
@@ -324,7 +348,7 @@ static ULONG WINAPI media_item_AddRef(IMFPMediaItem *iface)
     struct media_item *item = impl_from_IMFPMediaItem(iface);
     ULONG refcount = InterlockedIncrement(&item->refcount);
 
-    TRACE("%p, refcount %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     return refcount;
 }
@@ -334,14 +358,18 @@ static ULONG WINAPI media_item_Release(IMFPMediaItem *iface)
     struct media_item *item = impl_from_IMFPMediaItem(iface);
     ULONG refcount = InterlockedDecrement(&item->refcount);
 
-    TRACE("%p, refcount %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     if (!refcount)
     {
         if (item->player)
-            IMFPMediaPlayer_Release(item->player);
+            IMFPMediaPlayer_Release(&item->player->IMFPMediaPlayer_iface);
         if (item->source)
+        {
+            if (item->flags & MEDIA_ITEM_SOURCE_NEEDS_SHUTDOWN)
+                IMFMediaSource_Shutdown(item->source);
             IMFMediaSource_Release(item->source);
+        }
         if (item->pd)
             IMFPresentationDescriptor_Release(item->pd);
         if (item->object)
@@ -357,45 +385,70 @@ static HRESULT WINAPI media_item_GetMediaPlayer(IMFPMediaItem *iface,
         IMFPMediaPlayer **player)
 {
     struct media_item *item = impl_from_IMFPMediaItem(iface);
+    HRESULT hr = S_OK;
 
     TRACE("%p, %p.\n", iface, player);
 
-    *player = item->player;
-    IMFPMediaPlayer_AddRef(*player);
+    EnterCriticalSection(&item->player->cs);
+    if (item->player->state == MFP_MEDIAPLAYER_STATE_SHUTDOWN)
+    {
+        hr = MF_E_SHUTDOWN;
+        *player = NULL;
+    }
+    else
+    {
+        *player = &item->player->IMFPMediaPlayer_iface;
+        IMFPMediaPlayer_AddRef(*player);
+    }
+    LeaveCriticalSection(&item->player->cs);
 
-    return S_OK;
+    return hr;
 }
 
 static HRESULT WINAPI media_item_GetURL(IMFPMediaItem *iface, LPWSTR *url)
 {
     struct media_item *item = impl_from_IMFPMediaItem(iface);
+    HRESULT hr = S_OK;
 
     TRACE("%p, %p.\n", iface, url);
 
-    if (!item->url)
-        return MF_E_NOT_FOUND;
+    EnterCriticalSection(&item->player->cs);
+    if (item->player->state == MFP_MEDIAPLAYER_STATE_SHUTDOWN)
+        hr = MF_E_SHUTDOWN;
+    else if (!item->url)
+        hr = MF_E_NOT_FOUND;
+    else
+    {
+        if (!(*url = CoTaskMemAlloc((wcslen(item->url) + 1) * sizeof(*item->url))))
+            hr = E_OUTOFMEMORY;
+        if (*url)
+            wcscpy(*url, item->url);
+    }
+    LeaveCriticalSection(&item->player->cs);
 
-    if (!(*url = CoTaskMemAlloc((wcslen(item->url) + 1) * sizeof(*item->url))))
-        return E_OUTOFMEMORY;
-
-    wcscpy(*url, item->url);
-
-    return S_OK;
+    return hr;
 }
 
 static HRESULT WINAPI media_item_GetObject(IMFPMediaItem *iface, IUnknown **object)
 {
     struct media_item *item = impl_from_IMFPMediaItem(iface);
+    HRESULT hr = S_OK;
 
     TRACE("%p, %p.\n", iface, object);
 
-    if (!item->object)
-        return MF_E_NOT_FOUND;
+    EnterCriticalSection(&item->player->cs);
+    if (item->player->state == MFP_MEDIAPLAYER_STATE_SHUTDOWN)
+        hr = MF_E_SHUTDOWN;
+    else if (!item->object)
+        hr = MF_E_NOT_FOUND;
+    else
+    {
+        *object = item->object;
+        IUnknown_AddRef(*object);
+    }
+    LeaveCriticalSection(&item->player->cs);
 
-    *object = item->object;
-    IUnknown_AddRef(*object);
-
-    return S_OK;
+    return hr;
 }
 
 static HRESULT WINAPI media_item_GetUserData(IMFPMediaItem *iface, DWORD_PTR *user_data)
@@ -413,7 +466,7 @@ static HRESULT WINAPI media_item_SetUserData(IMFPMediaItem *iface, DWORD_PTR use
 {
     struct media_item *item = impl_from_IMFPMediaItem(iface);
 
-    TRACE("%p, %lx.\n", iface, user_data);
+    TRACE("%p, %Ix.\n", iface, user_data);
 
     item->user_data = user_data;
 
@@ -524,28 +577,38 @@ static HRESULT media_item_get_stream_type(IMFStreamDescriptor *sd, GUID *major)
 
 static HRESULT media_item_has_stream(struct media_item *item, const GUID *major, BOOL *has_stream, BOOL *is_selected)
 {
+    IMFPresentationDescriptor *pd;
     IMFStreamDescriptor *sd;
     unsigned int idx = 0;
     BOOL selected;
+    HRESULT hr;
     GUID guid;
 
-    *has_stream = *is_selected = FALSE;
+    EnterCriticalSection(&item->player->cs);
 
-    while (SUCCEEDED(IMFPresentationDescriptor_GetStreamDescriptorByIndex(item->pd, idx++, &selected, &sd)))
+    if (SUCCEEDED(hr = media_item_get_pd(item, &pd)))
     {
-        if (SUCCEEDED(media_item_get_stream_type(sd, &guid)) && IsEqualGUID(&guid, major))
+        *has_stream = *is_selected = FALSE;
+
+        while (SUCCEEDED(IMFPresentationDescriptor_GetStreamDescriptorByIndex(pd, idx++, &selected, &sd)))
         {
-            *has_stream = TRUE;
-            *is_selected = selected;
+            if (SUCCEEDED(media_item_get_stream_type(sd, &guid)) && IsEqualGUID(&guid, major))
+            {
+                *has_stream = TRUE;
+                *is_selected = selected;
+            }
+
+            IMFStreamDescriptor_Release(sd);
+
+            if (*has_stream && *is_selected)
+                break;
         }
-
-        IMFStreamDescriptor_Release(sd);
-
-        if (*has_stream && *is_selected)
-            break;
+        IMFPresentationDescriptor_Release(pd);
     }
 
-    return S_OK;
+    LeaveCriticalSection(&item->player->cs);
+
+    return hr;
 }
 
 static HRESULT WINAPI media_item_HasVideo(IMFPMediaItem *iface, BOOL *has_video, BOOL *selected)
@@ -569,42 +632,80 @@ static HRESULT WINAPI media_item_HasAudio(IMFPMediaItem *iface, BOOL *has_audio,
 static HRESULT WINAPI media_item_IsProtected(IMFPMediaItem *iface, BOOL *protected)
 {
     struct media_item *item = impl_from_IMFPMediaItem(iface);
+    IMFPresentationDescriptor *pd;
+    HRESULT hr;
 
     TRACE("%p, %p.\n", iface, protected);
 
-    *protected = MFRequireProtectedEnvironment(item->pd) == S_OK;
+    if (!protected)
+        return E_POINTER;
 
-    return S_OK;
+    EnterCriticalSection(&item->player->cs);
+    if (SUCCEEDED(hr = media_item_get_pd(item, &pd)))
+    {
+        *protected = (hr = MFRequireProtectedEnvironment(pd)) == S_OK;
+        IMFPresentationDescriptor_Release(pd);
+    }
+    LeaveCriticalSection(&item->player->cs);
+
+    return hr;
 }
 
 static HRESULT WINAPI media_item_GetDuration(IMFPMediaItem *iface, REFGUID format, PROPVARIANT *value)
 {
     struct media_item *item = impl_from_IMFPMediaItem(iface);
+    IMFPresentationDescriptor *pd;
+    HRESULT hr;
 
     TRACE("%p, %s, %p.\n", iface, debugstr_guid(format), value);
 
-    return IMFPresentationDescriptor_GetItem(item->pd, &MF_PD_DURATION, value);
+    EnterCriticalSection(&item->player->cs);
+    if (SUCCEEDED(hr = media_item_get_pd(item, &pd)))
+    {
+        hr = IMFPresentationDescriptor_GetItem(pd, &MF_PD_DURATION, value);
+        IMFPresentationDescriptor_Release(pd);
+    }
+    LeaveCriticalSection(&item->player->cs);
+
+    return hr;
 }
 
 static HRESULT WINAPI media_item_GetNumberOfStreams(IMFPMediaItem *iface, DWORD *count)
 {
     struct media_item *item = impl_from_IMFPMediaItem(iface);
+    IMFPresentationDescriptor *pd;
+    HRESULT hr;
 
     TRACE("%p, %p.\n", iface, count);
 
-    return IMFPresentationDescriptor_GetStreamDescriptorCount(item->pd, count);
+    EnterCriticalSection(&item->player->cs);
+    if (SUCCEEDED(hr = media_item_get_pd(item, &pd)))
+    {
+        hr = IMFPresentationDescriptor_GetStreamDescriptorCount(pd, count);
+        IMFPresentationDescriptor_Release(pd);
+    }
+    LeaveCriticalSection(&item->player->cs);
+
+    return hr;
 }
 
 static HRESULT WINAPI media_item_GetStreamSelection(IMFPMediaItem *iface, DWORD index, BOOL *selected)
 {
     struct media_item *item = impl_from_IMFPMediaItem(iface);
+    IMFPresentationDescriptor *pd;
     IMFStreamDescriptor *sd;
     HRESULT hr;
 
-    TRACE("%p, %u, %p.\n", iface, index, selected);
+    TRACE("%p, %lu, %p.\n", iface, index, selected);
 
-    if (SUCCEEDED(hr = IMFPresentationDescriptor_GetStreamDescriptorByIndex(item->pd, index, selected, &sd)))
-        IMFStreamDescriptor_Release(sd);
+    EnterCriticalSection(&item->player->cs);
+    if (SUCCEEDED(hr = media_item_get_pd(item, &pd)))
+    {
+        if (SUCCEEDED(hr = IMFPresentationDescriptor_GetStreamDescriptorByIndex(pd, index, selected, &sd)))
+            IMFStreamDescriptor_Release(sd);
+        IMFPresentationDescriptor_Release(pd);
+    }
+    LeaveCriticalSection(&item->player->cs);
 
     return hr;
 }
@@ -612,28 +713,45 @@ static HRESULT WINAPI media_item_GetStreamSelection(IMFPMediaItem *iface, DWORD
 static HRESULT WINAPI media_item_SetStreamSelection(IMFPMediaItem *iface, DWORD index, BOOL select)
 {
     struct media_item *item = impl_from_IMFPMediaItem(iface);
+    IMFPresentationDescriptor *pd;
+    HRESULT hr;
 
-    TRACE("%p, %u, %d.\n", iface, index, select);
+    TRACE("%p, %lu, %d.\n", iface, index, select);
 
-    return select ? IMFPresentationDescriptor_SelectStream(item->pd, index) :
-            IMFPresentationDescriptor_DeselectStream(item->pd, index);
+    EnterCriticalSection(&item->player->cs);
+    if (SUCCEEDED(hr = media_item_get_pd(item, &pd)))
+    {
+        hr = select ? IMFPresentationDescriptor_SelectStream(pd, index) :
+                IMFPresentationDescriptor_DeselectStream(pd, index);
+        IMFPresentationDescriptor_Release(pd);
+    }
+    LeaveCriticalSection(&item->player->cs);
+
+    return hr;
 }
 
 static HRESULT WINAPI media_item_GetStreamAttribute(IMFPMediaItem *iface, DWORD index, REFGUID key,
         PROPVARIANT *value)
 {
     struct media_item *item = impl_from_IMFPMediaItem(iface);
+    IMFPresentationDescriptor *pd;
     IMFStreamDescriptor *sd;
     BOOL selected;
     HRESULT hr;
 
-    TRACE("%p, %u, %s, %p.\n", iface, index, debugstr_guid(key), value);
+    TRACE("%p, %lu, %s, %p.\n", iface, index, debugstr_guid(key), value);
 
-    if (SUCCEEDED(hr = IMFPresentationDescriptor_GetStreamDescriptorByIndex(item->pd, index, &selected, &sd)))
+    EnterCriticalSection(&item->player->cs);
+    if (SUCCEEDED(hr = media_item_get_pd(item, &pd)))
     {
-        hr = IMFStreamDescriptor_GetItem(sd, key, value);
-        IMFStreamDescriptor_Release(sd);
+        if (SUCCEEDED(hr = IMFPresentationDescriptor_GetStreamDescriptorByIndex(pd, index, &selected, &sd)))
+        {
+            hr = IMFStreamDescriptor_GetItem(sd, key, value);
+            IMFStreamDescriptor_Release(sd);
+        }
+        IMFPresentationDescriptor_Release(pd);
     }
+    LeaveCriticalSection(&item->player->cs);
 
     return hr;
 }
@@ -642,26 +760,44 @@ static HRESULT WINAPI media_item_GetPresentationAttribute(IMFPMediaItem *iface,
         PROPVARIANT *value)
 {
     struct media_item *item = impl_from_IMFPMediaItem(iface);
+    IMFPresentationDescriptor *pd;
+    HRESULT hr;
 
     TRACE("%p, %s, %p.\n", iface, debugstr_guid(key), value);
 
-    return IMFPresentationDescriptor_GetItem(item->pd, key, value);
+    EnterCriticalSection(&item->player->cs);
+    if (SUCCEEDED(hr = media_item_get_pd(item, &pd)))
+    {
+        hr = IMFPresentationDescriptor_GetItem(pd, key, value);
+        IMFPresentationDescriptor_Release(pd);
+    }
+    LeaveCriticalSection(&item->player->cs);
+
+    return hr;
 }
 
 static HRESULT WINAPI media_item_GetCharacteristics(IMFPMediaItem *iface, MFP_MEDIAITEM_CHARACTERISTICS *flags)
 {
     struct media_item *item = impl_from_IMFPMediaItem(iface);
+    DWORD value = 0;
     HRESULT hr;
 
     TRACE("%p, %p.\n", iface, flags);
 
     *flags = 0;
 
-    if (SUCCEEDED(hr = IMFMediaSource_GetCharacteristics(item->source, flags)))
+    EnterCriticalSection(&item->player->cs);
+    if (item->player->state == MFP_MEDIAPLAYER_STATE_SHUTDOWN)
+        hr = MF_E_SHUTDOWN;
+    else
     {
-        *flags &= (MFP_MEDIAITEM_IS_LIVE | MFP_MEDIAITEM_CAN_SEEK |
-                MFP_MEDIAITEM_CAN_PAUSE | MFP_MEDIAITEM_HAS_SLOW_SEEK);
+        if (SUCCEEDED(hr = IMFMediaSource_GetCharacteristics(item->source, &value)))
+        {
+            *flags = value & (MFP_MEDIAITEM_IS_LIVE | MFP_MEDIAITEM_CAN_SEEK
+                    | MFP_MEDIAITEM_CAN_PAUSE | MFP_MEDIAITEM_HAS_SLOW_SEEK);
+        }
     }
+    LeaveCriticalSection(&item->player->cs);
 
     return hr;
 }
@@ -674,7 +810,7 @@ static HRESULT WINAPI media_item_SetStreamSink(IMFPMediaItem *iface, DWORD index
     BOOL selected;
     HRESULT hr;
 
-    TRACE("%p, %u, %p.\n", iface, index, sink);
+    TRACE("%p, %lu, %p.\n", iface, index, sink);
 
     if (FAILED(hr = IMFPresentationDescriptor_GetStreamDescriptorByIndex(item->pd, index, &selected, &sd)))
         return hr;
@@ -705,7 +841,7 @@ static HRESULT WINAPI media_item_GetMetadata(IMFPMediaItem *iface, IPropertyStor
     TRACE("%p, %p.\n", iface, metadata);
 
     return MFGetService((IUnknown *)item->source, &MF_PROPERTY_HANDLER_SERVICE,
-            &IID_IPropertyStore, (void **)&metadata);
+            &IID_IPropertyStore, (void **)metadata);
 }
 
 static const IMFPMediaItemVtbl media_item_vtbl =
@@ -742,7 +878,7 @@ static struct media_item *unsafe_impl_from_IMFPMediaItem(IMFPMediaItem *iface)
     return CONTAINING_RECORD(iface, struct media_item, IMFPMediaItem_iface);
 }
 
-static HRESULT create_media_item(IMFPMediaPlayer *player, DWORD_PTR user_data, struct media_item **item)
+static HRESULT create_media_item(struct media_player *player, DWORD_PTR user_data, struct media_item **item)
 {
     struct media_item *object;
 
@@ -753,7 +889,7 @@ static HRESULT create_media_item(IMFPMediaPlayer *player, DWORD_PTR user_data, s
     object->refcount = 1;
     object->user_data = user_data;
     object->player = player;
-    IMFPMediaPlayer_AddRef(object->player);
+    IMFPMediaPlayer_AddRef(&object->player->IMFPMediaPlayer_iface);
 
     *item = object;
 
@@ -771,7 +907,7 @@ static HRESULT media_item_set_source(struct media_item *item, IUnknown *object)
 
     if (FAILED(hr = IMFMediaSource_CreatePresentationDescriptor(source, &pd)))
     {
-        WARN("Failed to get presentation descriptor, hr %#x.\n", hr);
+        WARN("Failed to get presentation descriptor, hr %#lx.\n", hr);
         IMFMediaSource_Release(source);
         return hr;
     }
@@ -827,7 +963,7 @@ static ULONG WINAPI media_player_AddRef(IMFPMediaPlayer *iface)
     struct media_player *player = impl_from_IMFPMediaPlayer(iface);
     ULONG refcount = InterlockedIncrement(&player->refcount);
 
-    TRACE("%p, refcount %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     return refcount;
 }
@@ -837,7 +973,7 @@ static ULONG WINAPI media_player_Release(IMFPMediaPlayer *iface)
     struct media_player *player = impl_from_IMFPMediaPlayer(iface);
     ULONG refcount = InterlockedDecrement(&player->refcount);
 
-    TRACE("%p, refcount %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     if (!refcount)
     {
@@ -904,30 +1040,108 @@ static HRESULT WINAPI media_player_SetPosition(IMFPMediaPlayer *iface, REFGUID p
 
 static HRESULT WINAPI media_player_GetPosition(IMFPMediaPlayer *iface, REFGUID postype, PROPVARIANT *position)
 {
-    FIXME("%p, %s, %p.\n", iface, debugstr_guid(postype), position);
+    struct media_player *player = impl_from_IMFPMediaPlayer(iface);
+    IMFPresentationClock *presentation_clock;
+    IMFClock *clock;
+    HRESULT hr;
 
-    return E_NOTIMPL;
+    TRACE("%p, %s, %p.\n", iface, debugstr_guid(postype), position);
+
+    if (!position)
+        return E_POINTER;
+
+    if (!IsEqualGUID(postype, &MFP_POSITIONTYPE_100NS))
+        return E_INVALIDARG;
+
+    EnterCriticalSection(&player->cs);
+    if (player->state == MFP_MEDIAPLAYER_STATE_SHUTDOWN)
+        hr = MF_E_SHUTDOWN;
+    else if (!player->item)
+        hr = MF_E_INVALIDREQUEST;
+    else
+    {
+        if (SUCCEEDED(hr = IMFMediaSession_GetClock(player->session, &clock)))
+        {
+            if (SUCCEEDED(hr = IMFClock_QueryInterface(clock, &IID_IMFPresentationClock, (void **)&presentation_clock)))
+            {
+                position->vt = VT_UI8;
+                hr = IMFPresentationClock_GetTime(presentation_clock, (MFTIME *)&position->uhVal.QuadPart);
+                IMFPresentationClock_Release(presentation_clock);
+            }
+            IMFClock_Release(clock);
+        }
+    }
+    LeaveCriticalSection(&player->cs);
+
+    return hr;
 }
 
-static HRESULT WINAPI media_player_GetDuration(IMFPMediaPlayer *iface, REFGUID postype, PROPVARIANT *position)
+static HRESULT WINAPI media_player_GetDuration(IMFPMediaPlayer *iface, REFGUID postype, PROPVARIANT *duration)
 {
-    FIXME("%p, %s, %p.\n", iface, debugstr_guid(postype), position);
+    struct media_player *player = impl_from_IMFPMediaPlayer(iface);
+    HRESULT hr;
 
-    return E_NOTIMPL;
+    TRACE("%p, %s, %p.\n", iface, debugstr_guid(postype), duration);
+
+    if (!duration)
+        return E_POINTER;
+
+    if (!IsEqualGUID(postype, &MFP_POSITIONTYPE_100NS))
+        return E_INVALIDARG;
+
+    EnterCriticalSection(&player->cs);
+    if (player->state == MFP_MEDIAPLAYER_STATE_SHUTDOWN)
+        hr = MF_E_SHUTDOWN;
+    else if (!player->item)
+        hr = MF_E_INVALIDREQUEST;
+    else
+        /* FIXME: use start/stop markers for resulting duration */
+        hr = IMFPMediaItem_GetDuration(player->item, postype, duration);
+    LeaveCriticalSection(&player->cs);
+
+    return hr;
 }
 
 static HRESULT WINAPI media_player_SetRate(IMFPMediaPlayer *iface, float rate)
 {
-    FIXME("%p, %f.\n", iface, rate);
+    struct media_player *player = impl_from_IMFPMediaPlayer(iface);
+    IMFRateControl *rate_control;
+    HRESULT hr;
 
-    return E_NOTIMPL;
+    TRACE("%p, %f.\n", iface, rate);
+
+    if (rate == 0.0f)
+        return MF_E_OUT_OF_RANGE;
+
+    if (SUCCEEDED(hr = MFGetService((IUnknown *)player->session, &MF_RATE_CONTROL_SERVICE, &IID_IMFRateControl,
+            (void **)&rate_control)))
+    {
+        hr = IMFRateControl_SetRate(rate_control, FALSE, rate);
+        IMFRateControl_Release(rate_control);
+    }
+
+    return hr;
 }
 
 static HRESULT WINAPI media_player_GetRate(IMFPMediaPlayer *iface, float *rate)
 {
-    FIXME("%p, %p.\n", iface, rate);
+    struct media_player *player = impl_from_IMFPMediaPlayer(iface);
+    IMFRateControl *rate_control;
+    HRESULT hr;
 
-    return E_NOTIMPL;
+    TRACE("%p, %p.\n", iface, rate);
+
+    if (!rate)
+        return E_POINTER;
+
+    if (SUCCEEDED(hr = MFGetService((IUnknown *)player->session, &MF_RATE_CONTROL_SERVICE, &IID_IMFRateControl,
+            (void **)&rate_control)))
+    {
+        hr = IMFRateControl_GetRate(rate_control, NULL, rate);
+        IMFRateControl_Release(rate_control);
+    }
+
+    return hr;
 }
 
 static HRESULT WINAPI media_player_GetSupportedRates(IMFPMediaPlayer *iface, BOOL forward,
@@ -968,9 +1182,16 @@ static HRESULT media_player_create_item_from_url(struct media_player *player,
     IUnknown *object;
     HRESULT hr;
 
-    *ret = NULL;
+    if (sync && !ret)
+        return E_POINTER;
 
-    if (FAILED(hr = create_media_item(&player->IMFPMediaPlayer_iface, user_data, &item)))
+    if (!sync && !player->callback)
+    {
+        WARN("Asynchronous item creation is not supported without user callback.\n");
+        return MF_E_INVALIDREQUEST;
+    }
+
+    if (FAILED(hr = create_media_item(player, user_data, &item)))
         return hr;
 
     if (url && !(item->url = wcsdup(url)))
@@ -978,11 +1199,14 @@ static HRESULT media_player_create_item_from_url(struct media_player *player,
         IMFPMediaItem_Release(&item->IMFPMediaItem_iface);
         return E_OUTOFMEMORY;
     }
+    item->flags |= MEDIA_ITEM_SOURCE_NEEDS_SHUTDOWN;
 
     if (sync)
     {
-        if (SUCCEEDED(hr = IMFSourceResolver_CreateObjectFromURL(player->resolver, url, MF_RESOLUTION_MEDIASOURCE,
-                player->propstore, &obj_type, &object)))
+        *ret = NULL;
+
+        if (SUCCEEDED(hr = IMFSourceResolver_CreateObjectFromURL(player->resolver, url, MF_RESOLUTION_MEDIASOURCE
+                | MF_RESOLUTION_CONTENT_DOES_NOT_HAVE_TO_MATCH_EXTENSION_OR_MIME_TYPE, player->propstore, &obj_type, &object)))
         {
             hr = media_item_set_source(item, object);
             IUnknown_Release(object);
@@ -995,13 +1219,14 @@ static HRESULT media_player_create_item_from_url(struct media_player *player,
         }
 
         IMFPMediaItem_Release(&item->IMFPMediaItem_iface);
-
-        return hr;
     }
     else
     {
-        hr = IMFSourceResolver_BeginCreateObjectFromURL(player->resolver, url, MF_RESOLUTION_MEDIASOURCE,
-            player->propstore, NULL, &player->resolver_callback, (IUnknown *)&item->IMFPMediaItem_iface);
+        if (ret) *ret = NULL;
+
+        hr = IMFSourceResolver_BeginCreateObjectFromURL(player->resolver, url, MF_RESOLUTION_MEDIASOURCE
+                | MF_RESOLUTION_CONTENT_DOES_NOT_HAVE_TO_MATCH_EXTENSION_OR_MIME_TYPE, player->propstore, NULL,
+                &player->resolver_callback, (IUnknown *)&item->IMFPMediaItem_iface);
 
         IMFPMediaItem_Release(&item->IMFPMediaItem_iface);
     }
@@ -1015,7 +1240,7 @@ static HRESULT WINAPI media_player_CreateMediaItemFromURL(IMFPMediaPlayer *iface
     struct media_player *player = impl_from_IMFPMediaPlayer(iface);
     HRESULT hr;
 
-    TRACE("%p, %s, %d, %lx, %p.\n", iface, debugstr_w(url), sync, user_data, item);
+    TRACE("%p, %s, %d, %Ix, %p.\n", iface, debugstr_w(url), sync, user_data, item);
 
     EnterCriticalSection(&player->cs);
     if (player->state == MFP_MEDIAPLAYER_STATE_SHUTDOWN)
@@ -1030,15 +1255,15 @@ static HRESULT WINAPI media_player_CreateMediaItemFromURL(IMFPMediaPlayer *iface
 static HRESULT media_player_create_item_from_object(struct media_player *player,
         IUnknown *object, BOOL sync, DWORD_PTR user_data, IMFPMediaItem **ret)
 {
+    IMFMediaSource *source = NULL;
+    IMFByteStream *stream = NULL;
     struct media_item *item;
     MF_OBJECT_TYPE obj_type;
     HRESULT hr;
-    IMFByteStream *stream = NULL;
-    IMFMediaSource *source = NULL;
 
     *ret = NULL;
 
-    if (FAILED(hr = create_media_item(&player->IMFPMediaPlayer_iface, user_data, &item)))
+    if (FAILED(hr = create_media_item(player, user_data, &item)))
         return hr;
 
     item->object = object;
@@ -1054,11 +1279,14 @@ static HRESULT media_player_create_item_from_object(struct media_player *player,
         return E_UNEXPECTED;
     }
 
+    if (source)
+        item->flags |= MEDIA_ITEM_SOURCE_NEEDS_SHUTDOWN;
+
     if (sync)
     {
         if (stream)
-            hr = IMFSourceResolver_CreateObjectFromByteStream(player->resolver, stream, NULL,
-                    MF_RESOLUTION_MEDIASOURCE, player->propstore, &obj_type, &object);
+            hr = IMFSourceResolver_CreateObjectFromByteStream(player->resolver, stream, NULL, MF_RESOLUTION_MEDIASOURCE
+                    | MF_RESOLUTION_CONTENT_DOES_NOT_HAVE_TO_MATCH_EXTENSION_OR_MIME_TYPE, player->propstore, &obj_type, &object);
         else
             IUnknown_AddRef(object);
 
@@ -1079,8 +1307,9 @@ static HRESULT media_player_create_item_from_object(struct media_player *player,
     {
         if (stream)
         {
-            hr = IMFSourceResolver_BeginCreateObjectFromByteStream(player->resolver, stream, NULL, MF_RESOLUTION_MEDIASOURCE,
-                    player->propstore, NULL, &player->resolver_callback, (IUnknown *)&item->IMFPMediaItem_iface);
+            hr = IMFSourceResolver_BeginCreateObjectFromByteStream(player->resolver, stream, NULL, MF_RESOLUTION_MEDIASOURCE
+                    | MF_RESOLUTION_CONTENT_DOES_NOT_HAVE_TO_MATCH_EXTENSION_OR_MIME_TYPE, player->propstore, NULL,
+                    &player->resolver_callback, (IUnknown *)&item->IMFPMediaItem_iface);
         }
         else
         {
@@ -1106,7 +1335,7 @@ static HRESULT WINAPI media_player_CreateMediaItemFromObject(IMFPMediaPlayer *if
     struct media_player *player = impl_from_IMFPMediaPlayer(iface);
     HRESULT hr;
 
-    TRACE("%p, %p, %d, %lx, %p.\n", iface, object, sync, user_data, item);
+    TRACE("%p, %p, %d, %Ix, %p.\n", iface, object, sync, user_data, item);
 
     EnterCriticalSection(&player->cs);
     if (player->state == MFP_MEDIAPLAYER_STATE_SHUTDOWN)
@@ -1181,12 +1410,12 @@ static HRESULT media_item_create_topology(struct media_player *player, struct me
         else if (IsEqualGUID(&major, &MFMediaType_Audio))
         {
             if (FAILED(hr = MFCreateAudioRendererActivate((IMFActivate **)&sink)))
-                WARN("Failed to create SAR activation object, hr %#x.\n", hr);
+                WARN("Failed to create SAR activation object, hr %#lx.\n", hr);
         }
         else if (IsEqualGUID(&major, &MFMediaType_Video) && player->output_window && !video_added)
         {
             if (FAILED(hr = MFCreateVideoRendererActivate(player->output_window, (IMFActivate **)&sink)))
-                WARN("Failed to create EVR activation object, hr %#x.\n", hr);
+                WARN("Failed to create EVR activation object, hr %#lx.\n", hr);
             video_added = SUCCEEDED(hr);
         }
 
@@ -1234,7 +1463,7 @@ static HRESULT WINAPI media_player_SetMediaItem(IMFPMediaPlayer *iface, IMFPMedi
         return E_POINTER;
 
     item = unsafe_impl_from_IMFPMediaItem(item_iface);
-    if (item->player != iface)
+    if (item->player != player)
         return E_INVALIDARG;
 
     if (FAILED(hr = media_item_create_topology(player, item, &topology)))
@@ -1323,6 +1552,15 @@ static HRESULT WINAPI media_player_SetMute(IMFPMediaPlayer *iface, BOOL mute)
     return E_NOTIMPL;
 }
 
+static HRESULT media_player_get_display_control(const struct media_player *player,
+        IMFVideoDisplayControl **display_control)
+{
+    HRESULT hr = MFGetService((IUnknown *)player->session, &MR_VIDEO_RENDER_SERVICE,
+            &IID_IMFVideoDisplayControl, (void **)display_control);
+    if (SUCCEEDED(hr)) return hr;
+    return hr == MF_E_SHUTDOWN ? hr : MF_E_INVALIDREQUEST;
+}
+
 static HRESULT WINAPI media_player_GetNativeVideoSize(IMFPMediaPlayer *iface,
         SIZE *video, SIZE *arvideo)
 {
@@ -1332,8 +1570,7 @@ static HRESULT WINAPI media_player_GetNativeVideoSize(IMFPMediaPlayer *iface,
 
     TRACE("%p, %p, %p.\n", iface, video, arvideo);
 
-    if (SUCCEEDED(hr = MFGetService((IUnknown *)player->session, &MR_VIDEO_RENDER_SERVICE,
-            &IID_IMFVideoDisplayControl, (void **)&display_control)))
+    if (SUCCEEDED(hr = media_player_get_display_control(player, &display_control)))
     {
         hr = IMFVideoDisplayControl_GetNativeVideoSize(display_control, video, arvideo);
         IMFVideoDisplayControl_Release(display_control);
@@ -1351,8 +1588,7 @@ static HRESULT WINAPI media_player_GetIdealVideoSize(IMFPMediaPlayer *iface,
 
     TRACE("%p, %p, %p.\n", iface, min_size, max_size);
 
-    if (SUCCEEDED(hr = MFGetService((IUnknown *)player->session, &MR_VIDEO_RENDER_SERVICE,
-            &IID_IMFVideoDisplayControl, (void **)&display_control)))
+    if (SUCCEEDED(hr = media_player_get_display_control(player, &display_control)))
     {
         hr = IMFVideoDisplayControl_GetIdealVideoSize(display_control, min_size, max_size);
         IMFVideoDisplayControl_Release(display_control);
@@ -1366,14 +1602,16 @@ static HRESULT WINAPI media_player_SetVideoSourceRect(IMFPMediaPlayer *iface,
 {
     struct media_player *player = impl_from_IMFPMediaPlayer(iface);
     IMFVideoDisplayControl *display_control;
+    RECT dst_rect;
     HRESULT hr;
 
-    TRACE("%p, %p.\n", iface, rect);
+    TRACE("%p, %s.\n", iface, debugstr_normalized_rect(rect));
 
-    if (SUCCEEDED(hr = MFGetService((IUnknown *)player->session, &MR_VIDEO_RENDER_SERVICE,
-            &IID_IMFVideoDisplayControl, (void **)&display_control)))
+    if (!GetClientRect(player->output_window, &dst_rect))
+        hr = HRESULT_FROM_WIN32(GetLastError());
+    else if (SUCCEEDED(hr = media_player_get_display_control(player, &display_control)))
     {
-        hr = IMFVideoDisplayControl_SetVideoPosition(display_control, rect, NULL);
+        hr = IMFVideoDisplayControl_SetVideoPosition(display_control, rect, &dst_rect);
         IMFVideoDisplayControl_Release(display_control);
     }
 
@@ -1390,8 +1628,7 @@ static HRESULT WINAPI media_player_GetVideoSourceRect(IMFPMediaPlayer *iface,
 
     TRACE("%p, %p.\n", iface, rect);
 
-    if (SUCCEEDED(hr = MFGetService((IUnknown *)player->session, &MR_VIDEO_RENDER_SERVICE,
-            &IID_IMFVideoDisplayControl, (void **)&display_control)))
+    if (SUCCEEDED(hr = media_player_get_display_control(player, &display_control)))
     {
         hr = IMFVideoDisplayControl_GetVideoPosition(display_control, rect, &dest);
         IMFVideoDisplayControl_Release(display_control);
@@ -1406,10 +1643,9 @@ static HRESULT WINAPI media_player_SetAspectRatioMode(IMFPMediaPlayer *iface, DW
     IMFVideoDisplayControl *display_control;
     HRESULT hr;
 
-    TRACE("%p, %u.\n", iface, mode);
+    TRACE("%p, %lu.\n", iface, mode);
 
-    if (SUCCEEDED(hr = MFGetService((IUnknown *)player->session, &MR_VIDEO_RENDER_SERVICE,
-            &IID_IMFVideoDisplayControl, (void **)&display_control)))
+    if (SUCCEEDED(hr = media_player_get_display_control(player, &display_control)))
     {
         hr = IMFVideoDisplayControl_SetAspectRatioMode(display_control, mode);
         IMFVideoDisplayControl_Release(display_control);
@@ -1427,8 +1663,7 @@ static HRESULT WINAPI media_player_GetAspectRatioMode(IMFPMediaPlayer *iface,
 
     TRACE("%p, %p.\n", iface, mode);
 
-    if (SUCCEEDED(hr = MFGetService((IUnknown *)player->session, &MR_VIDEO_RENDER_SERVICE,
-            &IID_IMFVideoDisplayControl, (void **)&display_control)))
+    if (SUCCEEDED(hr = media_player_get_display_control(player, &display_control)))
     {
         hr = IMFVideoDisplayControl_GetAspectRatioMode(display_control, mode);
         IMFVideoDisplayControl_Release(display_control);
@@ -1450,9 +1685,23 @@ static HRESULT WINAPI media_player_GetVideoWindow(IMFPMediaPlayer *iface, HWND *
 
 static HRESULT WINAPI media_player_UpdateVideo(IMFPMediaPlayer *iface)
 {
-    FIXME("%p.\n", iface);
+    struct media_player *player = impl_from_IMFPMediaPlayer(iface);
+    IMFVideoDisplayControl *display_control;
+    HRESULT hr;
+    RECT rect;
 
-    return E_NOTIMPL;
+    TRACE("%p.\n", iface);
+
+    if (SUCCEEDED(hr = media_player_get_display_control(player, &display_control)))
+    {
+        if (GetClientRect(player->output_window, &rect))
+            hr = IMFVideoDisplayControl_SetVideoPosition(display_control, NULL, &rect);
+        if (SUCCEEDED(hr))
+            hr = IMFVideoDisplayControl_RepaintVideo(display_control);
+        IMFVideoDisplayControl_Release(display_control);
+    }
+
+    return hr;
 }
 
 static HRESULT WINAPI media_player_SetBorderColor(IMFPMediaPlayer *iface, COLORREF color)
@@ -1461,10 +1710,9 @@ static HRESULT WINAPI media_player_SetBorderColor(IMFPMediaPlayer *iface, COLORR
     IMFVideoDisplayControl *display_control;
     HRESULT hr;
 
-    TRACE("%p, %#x.\n", iface, color);
+    TRACE("%p, %#lx.\n", iface, color);
 
-    if (SUCCEEDED(hr = MFGetService((IUnknown *)player->session, &MR_VIDEO_RENDER_SERVICE,
-            &IID_IMFVideoDisplayControl, (void **)&display_control)))
+    if (SUCCEEDED(hr = media_player_get_display_control(player, &display_control)))
     {
         hr = IMFVideoDisplayControl_SetBorderColor(display_control, color);
         IMFVideoDisplayControl_Release(display_control);
@@ -1481,8 +1729,7 @@ static HRESULT WINAPI media_player_GetBorderColor(IMFPMediaPlayer *iface, COLORR
 
     TRACE("%p, %p.\n", iface, color);
 
-    if (SUCCEEDED(hr = MFGetService((IUnknown *)player->session, &MR_VIDEO_RENDER_SERVICE,
-            &IID_IMFVideoDisplayControl, (void **)&display_control)))
+    if (SUCCEEDED(hr = media_player_get_display_control(player, &display_control)))
     {
         hr = IMFVideoDisplayControl_GetBorderColor(display_control, color);
         IMFVideoDisplayControl_Release(display_control);
@@ -1606,7 +1853,7 @@ static HRESULT WINAPI media_player_propstore_GetAt(IPropertyStore *iface, DWORD
 {
     struct media_player *player = impl_from_IPropertyStore(iface);
 
-    TRACE("%p, %u, %p.\n", iface, prop, key);
+    TRACE("%p, %lu, %p.\n", iface, prop, key);
 
     return IPropertyStore_GetAt(player->propstore, prop, key);
 }
@@ -1712,7 +1959,7 @@ static HRESULT WINAPI media_player_resolver_callback_Invoke(IMFAsyncCallback *if
     }
 
     if (FAILED(hr))
-        WARN("Failed to set media source, hr %#x.\n", hr);
+        WARN("Failed to set media source, hr %#lx.\n", hr);
 
     if (FAILED(media_event_create(player, MFP_EVENT_TYPE_MEDIAITEM_CREATED, hr,
             &item->IMFPMediaItem_iface, &event)))
@@ -1864,6 +2111,28 @@ static void media_player_create_forward_event(struct media_player *player, HRESU
     LeaveCriticalSection(&player->cs);
 }
 
+static void media_player_playback_ended(struct media_player *player, HRESULT event_status,
+        struct media_event **event)
+{
+    EnterCriticalSection(&player->cs);
+
+    media_player_set_state(player, MFP_MEDIAPLAYER_STATE_STOPPED);
+    media_event_create(player, MFP_EVENT_TYPE_PLAYBACK_ENDED, event_status, player->item, event);
+
+    LeaveCriticalSection(&player->cs);
+}
+
+static void media_player_rate_changed(struct media_player *player, HRESULT event_status,
+        float rate, struct media_event **event)
+{
+    EnterCriticalSection(&player->cs);
+
+    if (SUCCEEDED(media_event_create(player, MFP_EVENT_TYPE_RATE_SET, event_status, player->item, event)))
+        (*event)->u.rate_set.flRate = rate;
+
+    LeaveCriticalSection(&player->cs);
+}
+
 static HRESULT WINAPI media_player_session_events_callback_Invoke(IMFAsyncCallback *iface,
         IMFAsyncResult *result)
 {
@@ -1876,6 +2145,7 @@ static HRESULT WINAPI media_player_session_events_callback_Invoke(IMFAsyncCallba
     IMFTopology *topology;
     unsigned int status;
     PROPVARIANT value;
+    float rate;
 
     if (FAILED(hr = IMFMediaSession_EndGetEvent(player->session, result, &session_event)))
         return S_OK;
@@ -1925,11 +2195,25 @@ static HRESULT WINAPI media_player_session_events_callback_Invoke(IMFAsyncCallba
             if (SUCCEEDED(IMFMediaEvent_GetUINT32(session_event, &MF_EVENT_TOPOLOGY_STATUS, &status)) &&
                     status == MF_TOPOSTATUS_ENDED)
             {
-                media_event_create(player, MFP_EVENT_TYPE_PLAYBACK_ENDED, event_status, player->item, &event);
+                media_player_playback_ended(player, event_status, &event);
             }
 
             break;
 
+        case MESessionRateChanged:
+
+            rate = 0.0f;
+            if (SUCCEEDED(IMFMediaEvent_GetValue(session_event, &value)))
+            {
+                if (value.vt == VT_R4)
+                    rate = value.fltVal;
+                PropVariantClear(&value);
+            }
+
+            media_player_rate_changed(player, event_status, rate, &event);
+
+            break;
+
         case MEBufferingStarted:
         case MEBufferingStopped:
         case MEExtendedType:
@@ -2028,7 +2312,7 @@ HRESULT WINAPI MFPCreateMediaPlayer(const WCHAR *url, BOOL start_playback, MFP_C
     {
         if (FAILED(hr = media_player_create_item_from_url(object, url, TRUE, 0, &item)))
         {
-            WARN("Failed to create media item, hr %#x.\n", hr);
+            WARN("Failed to create media item, hr %#lx.\n", hr);
             goto failed;
         }
 
@@ -2036,7 +2320,7 @@ HRESULT WINAPI MFPCreateMediaPlayer(const WCHAR *url, BOOL start_playback, MFP_C
         IMFPMediaItem_Release(item);
         if (FAILED(hr))
         {
-            WARN("Failed to set media item, hr %#x.\n", hr);
+            WARN("Failed to set media item, hr %#lx.\n", hr);
             goto failed;
         }
 
