@@ -59,16 +59,15 @@ typedef struct MMDevEnumImpl
     LONG ref;
 } MMDevEnumImpl;
 
-static MMDevEnumImpl *MMDevEnumerator;
-static MMDevice **MMDevice_head;
 static MMDevice *MMDevice_def_rec, *MMDevice_def_play;
-static DWORD MMDevice_count;
 static const IMMDeviceEnumeratorVtbl MMDevEnumVtbl;
 static const IMMDeviceCollectionVtbl MMDevColVtbl;
 static const IMMDeviceVtbl MMDeviceVtbl;
 static const IPropertyStoreVtbl MMDevPropVtbl;
 static const IMMEndpointVtbl MMEndpointVtbl;
 
+static MMDevEnumImpl enumerator;
+static struct list device_list = LIST_INIT(device_list);
 static IMMDevice info_device;
 
 typedef struct MMDevColImpl
@@ -118,14 +117,14 @@ static HRESULT MMDevPropStore_OpenPropKey(const GUID *guid, DWORD flow, HKEY *pr
     StringFromGUID2(guid, buffer, 39);
     if ((ret = RegOpenKeyExW(flow == eRender ? key_render : key_capture, buffer, 0, KEY_READ|KEY_WRITE|KEY_WOW64_64KEY, &key)) != ERROR_SUCCESS)
     {
-        WARN("Opening key %s failed with %u\n", debugstr_w(buffer), ret);
+        WARN("Opening key %s failed with %lu\n", debugstr_w(buffer), ret);
         return E_FAIL;
     }
     ret = RegOpenKeyExW(key, L"Properties", 0, KEY_READ|KEY_WRITE|KEY_WOW64_64KEY, propkey);
     RegCloseKey(key);
     if (ret != ERROR_SUCCESS)
     {
-        WARN("Opening key Properties failed with %u\n", ret);
+        WARN("Opening key Properties failed with %lu\n", ret);
         return E_FAIL;
     }
     return S_OK;
@@ -149,7 +148,7 @@ static HRESULT MMDevice_GetPropValue(const GUID *devguid, DWORD flow, REFPROPERT
     ret = RegGetValueW(regkey, NULL, buffer, RRF_RT_ANY, &type, NULL, &size);
     if (ret != ERROR_SUCCESS)
     {
-        WARN("Reading %s returned %d\n", debugstr_w(buffer), ret);
+        WARN("Reading %s returned %ld\n", debugstr_w(buffer), ret);
         RegCloseKey(regkey);
         PropVariantClear(pv);
         return S_OK;
@@ -185,7 +184,7 @@ static HRESULT MMDevice_GetPropValue(const GUID *devguid, DWORD flow, REFPROPERT
             break;
         }
         default:
-            ERR("Unknown/unhandled type: %u\n", type);
+            ERR("Unknown/unhandled type: %lu\n", type);
             PropVariantClear(pv);
             break;
     }
@@ -217,7 +216,7 @@ static HRESULT MMDevice_SetPropValue(const GUID *devguid, DWORD flow, REFPROPERT
         case VT_BLOB:
         {
             ret = RegSetValueExW(regkey, buffer, 0, REG_BINARY, pv->blob.pBlobData, pv->blob.cbSize);
-            TRACE("Blob %p %u\n", pv->blob.pBlobData, pv->blob.cbSize);
+            TRACE("Blob %p %lu\n", pv->blob.pBlobData, pv->blob.cbSize);
 
             break;
         }
@@ -233,7 +232,7 @@ static HRESULT MMDevice_SetPropValue(const GUID *devguid, DWORD flow, REFPROPERT
             break;
     }
     RegCloseKey(regkey);
-    TRACE("Writing %s returned %u\n", debugstr_w(buffer), ret);
+    TRACE("Writing %s returned %lu\n", debugstr_w(buffer), ret);
     return hr;
 }
 
@@ -263,9 +262,8 @@ static HRESULT set_driver_prop_value(GUID *id, const EDataFlow flow, const PROPE
 static MMDevice *MMDevice_Create(WCHAR *name, GUID *id, EDataFlow flow, DWORD state, BOOL setdefault)
 {
     HKEY key, root;
-    MMDevice *cur = NULL;
+    MMDevice *device, *cur = NULL;
     WCHAR guidstr[39];
-    DWORD i;
 
     static const PROPERTYKEY deviceinterface_key = {
         {0x233164c8, 0x1b2c, 0x4c7d, {0xbc, 0x68, 0xb6, 0x71, 0x68, 0x7a, 0x25, 0x67}}, 1
@@ -275,9 +273,8 @@ static MMDevice *MMDevice_Create(WCHAR *name, GUID *id, EDataFlow flow, DWORD st
         {0xb3f8fa53, 0x0004, 0x438e, {0x90, 0x03, 0x51, 0xa4, 0x6e, 0x13, 0x9b, 0xfc}}, 2
     };
 
-    for (i = 0; i < MMDevice_count; ++i)
+    LIST_FOR_EACH_ENTRY(device, &device_list, MMDevice, entry)
     {
-        MMDevice *device = MMDevice_head[i];
         if (device->flow == flow && IsEqualGUID(&device->devguid, id)){
             cur = device;
             break;
@@ -296,11 +293,7 @@ static MMDevice *MMDevice_Create(WCHAR *name, GUID *id, EDataFlow flow, DWORD st
         InitializeCriticalSection(&cur->crst);
         cur->crst.DebugInfo->Spare[0] = (DWORD_PTR)(__FILE__ ": MMDevice.crst");
 
-        if (!MMDevice_head)
-            MMDevice_head = HeapAlloc(GetProcessHeap(), 0, sizeof(*MMDevice_head));
-        else
-            MMDevice_head = HeapReAlloc(GetProcessHeap(), 0, MMDevice_head, sizeof(*MMDevice_head)*(1+MMDevice_count));
-        MMDevice_head[MMDevice_count++] = cur;
+        list_add_tail(&device_list, &cur->entry);
     }else if(cur->ref > 0)
         WARN("Modifying an MMDevice with postitive reference count!\n");
 
@@ -373,7 +366,7 @@ static MMDevice *MMDevice_Create(WCHAR *name, GUID *id, EDataFlow flow, DWORD st
     return cur;
 }
 
-static HRESULT load_devices_from_reg(void)
+HRESULT load_devices_from_reg(void)
 {
     DWORD i = 0;
     HKEY root, cur;
@@ -394,7 +387,7 @@ static HRESULT load_devices_from_reg(void)
     {
         RegCloseKey(key_capture);
         key_render = key_capture = NULL;
-        WARN("Couldn't create key: %u\n", ret);
+        WARN("Couldn't create key: %lu\n", ret);
         return E_FAIL;
     }
 
@@ -466,7 +459,7 @@ static HRESULT set_format(MMDevice *dev)
     return S_OK;
 }
 
-static HRESULT load_driver_devices(EDataFlow flow)
+HRESULT load_driver_devices(EDataFlow flow)
 {
     WCHAR **ids;
     GUID *guids;
@@ -495,17 +488,8 @@ static HRESULT load_driver_devices(EDataFlow flow)
 
 static void MMDevice_Destroy(MMDevice *This)
 {
-    DWORD i;
     TRACE("Freeing %s\n", debugstr_w(This->drv_id));
-    /* Since this function is called at destruction time, reordering of the list is unimportant */
-    for (i = 0; i < MMDevice_count; ++i)
-    {
-        if (MMDevice_head[i] == This)
-        {
-            MMDevice_head[i] = MMDevice_head[--MMDevice_count];
-            break;
-        }
-    }
+    list_remove(&This->entry);
     This->crst.DebugInfo->Spare[0] = 0;
     DeleteCriticalSection(&This->crst);
     HeapFree(GetProcessHeap(), 0, This->drv_id);
@@ -545,7 +529,7 @@ static ULONG WINAPI MMDevice_AddRef(IMMDevice *iface)
     LONG ref;
 
     ref = InterlockedIncrement(&This->ref);
-    TRACE("Refcount now %i\n", ref);
+    TRACE("Refcount now %li\n", ref);
     return ref;
 }
 
@@ -555,7 +539,7 @@ static ULONG WINAPI MMDevice_Release(IMMDevice *iface)
     LONG ref;
 
     ref = InterlockedDecrement(&This->ref);
-    TRACE("Refcount now %i\n", ref);
+    TRACE("Refcount now %li\n", ref);
     return ref;
 }
 
@@ -564,7 +548,7 @@ static HRESULT WINAPI MMDevice_Activate(IMMDevice *iface, REFIID riid, DWORD cls
     HRESULT hr = E_NOINTERFACE;
     MMDevice *This = impl_from_IMMDevice(iface);
 
-    TRACE("(%p)->(%s, %x, %p, %p)\n", iface, debugstr_guid(riid), clsctx, params, ppv);
+    TRACE("(%p)->(%s, %lx, %p, %p)\n", iface, debugstr_guid(riid), clsctx, params, ppv);
 
     if (!ppv)
         return E_POINTER;
@@ -646,14 +630,14 @@ static HRESULT WINAPI MMDevice_Activate(IMMDevice *iface, REFIID riid, DWORD cls
     if (FAILED(hr))
         *ppv = NULL;
 
-    TRACE("Returning %08x\n", hr);
+    TRACE("Returning %08lx\n", hr);
     return hr;
 }
 
 static HRESULT WINAPI MMDevice_OpenPropertyStore(IMMDevice *iface, DWORD access, IPropertyStore **ppv)
 {
     MMDevice *This = impl_from_IMMDevice(iface);
-    TRACE("(%p)->(%x,%p)\n", This, access, ppv);
+    TRACE("(%p)->(%lx,%p)\n", This, access, ppv);
 
     if (!ppv)
         return E_POINTER;
@@ -789,7 +773,7 @@ static ULONG WINAPI MMDevCol_AddRef(IMMDeviceCollection *iface)
 {
     MMDevColImpl *This = impl_from_IMMDeviceCollection(iface);
     LONG ref = InterlockedIncrement(&This->ref);
-    TRACE("Refcount now %i\n", ref);
+    TRACE("Refcount now %li\n", ref);
     return ref;
 }
 
@@ -797,7 +781,7 @@ static ULONG WINAPI MMDevCol_Release(IMMDeviceCollection *iface)
 {
     MMDevColImpl *This = impl_from_IMMDeviceCollection(iface);
     LONG ref = InterlockedDecrement(&This->ref);
-    TRACE("Refcount now %i\n", ref);
+    TRACE("Refcount now %li\n", ref);
     if (!ref)
         MMDevCol_Destroy(This);
     return ref;
@@ -806,16 +790,15 @@ static ULONG WINAPI MMDevCol_Release(IMMDeviceCollection *iface)
 static HRESULT WINAPI MMDevCol_GetCount(IMMDeviceCollection *iface, UINT *numdevs)
 {
     MMDevColImpl *This = impl_from_IMMDeviceCollection(iface);
-    DWORD i;
+    MMDevice *cur;
 
     TRACE("(%p)->(%p)\n", This, numdevs);
     if (!numdevs)
         return E_POINTER;
 
     *numdevs = 0;
-    for (i = 0; i < MMDevice_count; ++i)
+    LIST_FOR_EACH_ENTRY(cur, &device_list, MMDevice, entry)
     {
-        MMDevice *cur = MMDevice_head[i];
         if ((cur->flow == This->flow || This->flow == eAll)
             && (cur->state & This->state))
             ++(*numdevs);
@@ -826,15 +809,15 @@ static HRESULT WINAPI MMDevCol_GetCount(IMMDeviceCollection *iface, UINT *numdev
 static HRESULT WINAPI MMDevCol_Item(IMMDeviceCollection *iface, UINT n, IMMDevice **dev)
 {
     MMDevColImpl *This = impl_from_IMMDeviceCollection(iface);
-    DWORD i = 0, j = 0;
+    MMDevice *cur;
+    DWORD i = 0;
 
     TRACE("(%p)->(%u, %p)\n", This, n, dev);
     if (!dev)
         return E_POINTER;
 
-    for (j = 0; j < MMDevice_count; ++j)
+    LIST_FOR_EACH_ENTRY(cur, &device_list, MMDevice, entry)
     {
-        MMDevice *cur = MMDevice_head[j];
         if ((cur->flow == This->flow || This->flow == eAll)
             && (cur->state & This->state)
             && i++ == n)
@@ -860,34 +843,17 @@ static const IMMDeviceCollectionVtbl MMDevColVtbl =
 
 HRESULT MMDevEnum_Create(REFIID riid, void **ppv)
 {
-    MMDevEnumImpl *This = MMDevEnumerator;
-
-    if (!This)
-    {
-        This = HeapAlloc(GetProcessHeap(), 0, sizeof(*This));
-        *ppv = NULL;
-        if (!This)
-            return E_OUTOFMEMORY;
-        This->ref = 1;
-        This->IMMDeviceEnumerator_iface.lpVtbl = &MMDevEnumVtbl;
-        MMDevEnumerator = This;
-
-        load_devices_from_reg();
-        load_driver_devices(eRender);
-        load_driver_devices(eCapture);
-    }
-    return IMMDeviceEnumerator_QueryInterface(&This->IMMDeviceEnumerator_iface, riid, ppv);
+    return IMMDeviceEnumerator_QueryInterface(&enumerator.IMMDeviceEnumerator_iface, riid, ppv);
 }
 
 void MMDevEnum_Free(void)
 {
-    while (MMDevice_count)
-        MMDevice_Destroy(MMDevice_head[0]);
+    MMDevice *device, *next;
+    LIST_FOR_EACH_ENTRY_SAFE(device, next, &device_list, MMDevice, entry)
+        MMDevice_Destroy(device);
     RegCloseKey(key_render);
     RegCloseKey(key_capture);
     key_render = key_capture = NULL;
-    HeapFree(GetProcessHeap(), 0, MMDevEnumerator);
-    MMDevEnumerator = NULL;
 }
 
 static HRESULT WINAPI MMDevEnum_QueryInterface(IMMDeviceEnumerator *iface, REFIID riid, void **ppv)
@@ -912,7 +878,7 @@ static ULONG WINAPI MMDevEnum_AddRef(IMMDeviceEnumerator *iface)
 {
     MMDevEnumImpl *This = impl_from_IMMDeviceEnumerator(iface);
     LONG ref = InterlockedIncrement(&This->ref);
-    TRACE("Refcount now %i\n", ref);
+    TRACE("Refcount now %li\n", ref);
     return ref;
 }
 
@@ -920,16 +886,14 @@ static ULONG WINAPI MMDevEnum_Release(IMMDeviceEnumerator *iface)
 {
     MMDevEnumImpl *This = impl_from_IMMDeviceEnumerator(iface);
     LONG ref = InterlockedDecrement(&This->ref);
-    if (!ref)
-        MMDevEnum_Free();
-    TRACE("Refcount now %i\n", ref);
+    TRACE("Refcount now %li\n", ref);
     return ref;
 }
 
 static HRESULT WINAPI MMDevEnum_EnumAudioEndpoints(IMMDeviceEnumerator *iface, EDataFlow flow, DWORD mask, IMMDeviceCollection **devices)
 {
     MMDevEnumImpl *This = impl_from_IMMDeviceEnumerator(iface);
-    TRACE("(%p)->(%u,%u,%p)\n", This, flow, mask, devices);
+    TRACE("(%p)->(%u,%lu,%p)\n", This, flow, mask, devices);
     if (!devices)
         return E_POINTER;
     *devices = NULL;
@@ -1026,7 +990,7 @@ static HRESULT WINAPI MMDevEnum_GetDefaultAudioEndpoint(IMMDeviceEnumerator *ifa
 static HRESULT WINAPI MMDevEnum_GetDevice(IMMDeviceEnumerator *iface, const WCHAR *name, IMMDevice **device)
 {
     MMDevEnumImpl *This = impl_from_IMMDeviceEnumerator(iface);
-    DWORD i=0;
+    MMDevice *impl;
     IMMDevice *dev = NULL;
 
     TRACE("(%p)->(%s,%p)\n", This, debugstr_w(name), device);
@@ -1039,15 +1003,15 @@ static HRESULT WINAPI MMDevEnum_GetDevice(IMMDeviceEnumerator *iface, const WCHA
         return S_OK;
     }
 
-    for (i = 0; i < MMDevice_count; ++i)
+    LIST_FOR_EACH_ENTRY(impl, &device_list, MMDevice, entry)
     {
         HRESULT hr;
         WCHAR *str;
-        dev = &MMDevice_head[i]->IMMDevice_iface;
+        dev = &impl->IMMDevice_iface;
         hr = IMMDevice_GetId(dev, &str);
         if (FAILED(hr))
         {
-            WARN("GetId failed: %08x\n", hr);
+            WARN("GetId failed: %08lx\n", hr);
             continue;
         }
 
@@ -1109,7 +1073,7 @@ static BOOL notify_if_changed(EDataFlow flow, ERole role, HKEY key,
             if(def_dev){
                 hr = IMMDevice_GetId(def_dev, &id);
                 if(FAILED(hr)){
-                    ERR("GetId failed: %08x\n", hr);
+                    ERR("GetId failed: %08lx\n", hr);
                     return FALSE;
                 }
             }else
@@ -1142,7 +1106,7 @@ static BOOL notify_if_changed(EDataFlow flow, ERole role, HKEY key,
     if(def_dev){
         hr = IMMDevice_GetId(def_dev, &id);
         if(FAILED(hr)){
-            ERR("GetId failed: %08x\n", hr);
+            ERR("GetId failed: %08lx\n", hr);
             return FALSE;
         }
     }else
@@ -1168,7 +1132,7 @@ static DWORD WINAPI notif_thread_proc(void *user)
 
     if(RegCreateKeyExW(HKEY_CURRENT_USER, reg_key, 0, NULL, 0,
                 MAXIMUM_ALLOWED, NULL, &key, NULL) != ERROR_SUCCESS){
-        ERR("RegCreateKeyEx failed: %u\n", GetLastError());
+        ERR("RegCreateKeyEx failed: %lu\n", GetLastError());
         return 1;
     }
 
@@ -1191,7 +1155,7 @@ static DWORD WINAPI notif_thread_proc(void *user)
     while(1){
         if(RegNotifyChangeKeyValue(key, FALSE, REG_NOTIFY_CHANGE_LAST_SET,
                     NULL, FALSE) != ERROR_SUCCESS){
-            ERR("RegNotifyChangeKeyValue failed: %u\n", GetLastError());
+            ERR("RegNotifyChangeKeyValue failed: %lu\n", GetLastError());
             RegCloseKey(key);
             g_notif_thread = NULL;
             return 1;
@@ -1241,7 +1205,7 @@ static HRESULT WINAPI MMDevEnum_RegisterEndpointNotificationCallback(IMMDeviceEn
     if(!g_notif_thread){
         g_notif_thread = CreateThread(NULL, 0, notif_thread_proc, NULL, 0, NULL);
         if(!g_notif_thread)
-            ERR("CreateThread failed: %u\n", GetLastError());
+            ERR("CreateThread failed: %lu\n", GetLastError());
     }
 
     LeaveCriticalSection(&g_notif_lock);
@@ -1287,6 +1251,12 @@ static const IMMDeviceEnumeratorVtbl MMDevEnumVtbl =
     MMDevEnum_UnregisterEndpointNotificationCallback
 };
 
+static MMDevEnumImpl enumerator =
+{
+    {&MMDevEnumVtbl},
+    1,
+};
+
 static HRESULT MMDevPropStore_Create(MMDevice *parent, DWORD access, IPropertyStore **ppv)
 {
     MMDevPropStore *This;
@@ -1294,7 +1264,7 @@ static HRESULT MMDevPropStore_Create(MMDevice *parent, DWORD access, IPropertySt
         && access != STGM_WRITE
         && access != STGM_READWRITE)
     {
-        WARN("Invalid access %08x\n", access);
+        WARN("Invalid access %08lx\n", access);
         return E_INVALIDARG;
     }
     This = HeapAlloc(GetProcessHeap(), 0, sizeof(*This));
@@ -1335,7 +1305,7 @@ static ULONG WINAPI MMDevPropStore_AddRef(IPropertyStore *iface)
 {
     MMDevPropStore *This = impl_from_IPropertyStore(iface);
     LONG ref = InterlockedIncrement(&This->ref);
-    TRACE("Refcount now %i\n", ref);
+    TRACE("Refcount now %li\n", ref);
     return ref;
 }
 
@@ -1343,7 +1313,7 @@ static ULONG WINAPI MMDevPropStore_Release(IPropertyStore *iface)
 {
     MMDevPropStore *This = impl_from_IPropertyStore(iface);
     LONG ref = InterlockedDecrement(&This->ref);
-    TRACE("Refcount now %i\n", ref);
+    TRACE("Refcount now %li\n", ref);
     if (!ref)
         MMDevPropStore_Destroy(This);
     return ref;
@@ -1371,7 +1341,7 @@ static HRESULT WINAPI MMDevPropStore_GetCount(IPropertyStore *iface, DWORD *npro
         i++;
     } while (1);
     RegCloseKey(propkey);
-    TRACE("Returning %i\n", i);
+    TRACE("Returning %li\n", i);
     *nprops = i;
     return S_OK;
 }
@@ -1384,7 +1354,7 @@ static HRESULT WINAPI MMDevPropStore_GetAt(IPropertyStore *iface, DWORD prop, PR
     HRESULT hr;
     HKEY propkey;
 
-    TRACE("(%p)->(%u,%p)\n", iface, prop, key);
+    TRACE("(%p)->(%lu,%p)\n", iface, prop, key);
     if (!key)
         return E_POINTER;
 
@@ -1395,7 +1365,7 @@ static HRESULT WINAPI MMDevPropStore_GetAt(IPropertyStore *iface, DWORD prop, PR
     if (RegEnumValueW(propkey, prop, buffer, &len, NULL, NULL, NULL, NULL) != ERROR_SUCCESS
         || len <= 39)
     {
-        WARN("GetAt %u failed\n", prop);
+        WARN("GetAt %lu failed\n", prop);
         return E_INVALIDARG;
     }
     RegCloseKey(propkey);
@@ -1408,7 +1378,7 @@ static HRESULT WINAPI MMDevPropStore_GetAt(IPropertyStore *iface, DWORD prop, PR
 static HRESULT WINAPI MMDevPropStore_GetValue(IPropertyStore *iface, REFPROPERTYKEY key, PROPVARIANT *pv)
 {
     MMDevPropStore *This = impl_from_IPropertyStore(iface);
-    TRACE("(%p)->(\"%s,%u\", %p)\n", This, key ? debugstr_guid(&key->fmtid) : NULL, key ? key->pid : 0, pv);
+    TRACE("(%p)->(\"%s,%lu\", %p)\n", This, key ? debugstr_guid(&key->fmtid) : NULL, key ? key->pid : 0, pv);
 
     if (!key || !pv)
         return E_POINTER;
@@ -1433,7 +1403,7 @@ static HRESULT WINAPI MMDevPropStore_GetValue(IPropertyStore *iface, REFPROPERTY
 static HRESULT WINAPI MMDevPropStore_SetValue(IPropertyStore *iface, REFPROPERTYKEY key, REFPROPVARIANT pv)
 {
     MMDevPropStore *This = impl_from_IPropertyStore(iface);
-    TRACE("(%p)->(\"%s,%u\", %p)\n", This, key ? debugstr_guid(&key->fmtid) : NULL, key ? key->pid : 0, pv);
+    TRACE("(%p)->(\"%s,%lu\", %p)\n", This, key ? debugstr_guid(&key->fmtid) : NULL, key ? key->pid : 0, pv);
 
     if (!key || !pv)
         return E_POINTER;
@@ -1536,7 +1506,7 @@ static ULONG WINAPI info_device_ps_Release(IPropertyStore *iface)
 static HRESULT WINAPI info_device_ps_GetValue(IPropertyStore *iface,
         REFPROPERTYKEY key, PROPVARIANT *pv)
 {
-    TRACE("(static)->(\"%s,%u\", %p)\n", debugstr_guid(&key->fmtid), key ? key->pid : 0, pv);
+    TRACE("(static)->(\"%s,%lu\", %p)\n", debugstr_guid(&key->fmtid), key ? key->pid : 0, pv);
 
     if (!key || !pv)
         return E_POINTER;
@@ -1584,7 +1554,7 @@ static ULONG WINAPI info_device_Release(IMMDevice *iface)
 static HRESULT WINAPI info_device_OpenPropertyStore(IMMDevice *iface,
         DWORD access, IPropertyStore **ppv)
 {
-    TRACE("(static)->(%x, %p)\n", access, ppv);
+    TRACE("(static)->(%lx, %p)\n", access, ppv);
     *ppv = &info_device_ps;
     return S_OK;
 }
