@@ -43,24 +43,6 @@ static BOOL is_eof( _Recordset *recordset )
     return eof == VARIANT_TRUE;
 }
 
-static LONG get_refs_field( Field *field )
-{
-    Field_AddRef( field );
-    return Field_Release( field );
-}
-
-static LONG get_refs_fields( Fields *fields )
-{
-    Fields_AddRef( fields );
-    return Fields_Release( fields );
-}
-
-static LONG get_refs_recordset( _Recordset *recordset )
-{
-    _Recordset_AddRef( recordset );
-    return _Recordset_Release( recordset );
-}
-
 static void test_Recordset(void)
 {
     _Recordset *recordset;
@@ -68,7 +50,10 @@ static void test_Recordset(void)
     ISupportErrorInfo *errorinfo;
     Fields *fields, *fields2;
     Field *field;
-    LONG refs, count, state;
+    Properties *props;
+    Property *prop;
+    LONG count, state;
+    ADO_LONGPTR rec_count;
     VARIANT missing, val, index;
     CursorLocationEnum location;
     CursorTypeEnum cursor;
@@ -87,39 +72,15 @@ static void test_Recordset(void)
     errorinfo = NULL;
     hr = _Recordset_QueryInterface( recordset, &IID_ISupportErrorInfo, (void **)&errorinfo );
     ok( hr == S_OK, "got %08x\n", hr );
-    refs = get_refs_recordset( recordset );
-    ok( refs == 2, "got %d\n", refs );
     if (errorinfo) ISupportErrorInfo_Release( errorinfo );
-    refs = get_refs_recordset( recordset );
-    ok( refs == 1, "got %d\n", refs );
 
-    /* handing out fields object increases recordset refcount */
-    refs = get_refs_recordset( recordset );
-    ok( refs == 1, "got %d\n", refs );
     hr = _Recordset_get_Fields( recordset, &fields );
     ok( hr == S_OK, "got %08x\n", hr );
-    refs = get_refs_recordset( recordset );
-    ok( refs == 2, "got %d\n", refs );
-    refs = get_refs_fields( fields );
-    ok( refs == 1, "got %d\n", refs );
 
-    /* releasing fields object decreases recordset refcount, but fields refcount doesn't drop to zero */
-    Fields_Release( fields );
-    refs = get_refs_recordset( recordset );
-    ok( refs == 1, "got %d\n", refs );
-    refs = get_refs_fields( fields );
-    ok( refs == 1, "got %d\n", refs );
-
-    /* calling get_Fields again returns the same object with the same refcount and increases recordset refcount  */
+    /* calling get_Fields again returns the same object */
     hr = _Recordset_get_Fields( recordset, &fields2 );
     ok( hr == S_OK, "got %08x\n", hr );
-    refs = get_refs_recordset( recordset );
-    ok( refs == 2, "got %d\n", refs );
-    refs = get_refs_fields( fields2 );
-    ok( refs == 1, "got %d\n", refs );
     ok( fields2 == fields, "expected same object\n" );
-    refs = Fields_Release( fields2 );
-    ok( refs == 1, "got %d\n", refs );
 
     count = -1;
     hr = Fields_get_Count( fields2, &count );
@@ -129,12 +90,7 @@ static void test_Recordset(void)
     hr = _Recordset_Close( recordset );
     ok( hr == MAKE_ADO_HRESULT( adErrObjectClosed ), "got %08x\n", hr );
 
-    refs = _Recordset_Release( recordset );
-    ok( !refs, "got %d\n", refs );
-
-    /* fields object still has a reference */
-    refs = Fields_Release( fields2 );
-    ok( refs == 1, "got %d\n", refs );
+    Fields_Release( fields2 );
 
     hr = CoCreateInstance( &CLSID_Recordset, NULL, CLSCTX_INPROC_SERVER, &IID__Recordset, (void **)&recordset );
     ok( hr == S_OK, "got %08x\n", hr );
@@ -178,12 +134,64 @@ static void test_Recordset(void)
     hr = Fields__Append( fields, name, adInteger, 4, adFldUnspecified );
     ok( hr == S_OK, "got %08x\n", hr );
 
+    V_VT( &index ) = VT_I4;
+    V_I4( &index ) = 1000;
+    hr = Fields_get_Item( fields, index, &field );
+    ok( hr == MAKE_ADO_HRESULT(adErrItemNotFound), "got %08x\n", hr );
+
+    V_VT( &index ) = VT_I4;
+    V_I4( &index ) = 0;
+    hr = Fields_get_Item( fields, index, &field );
+    ok( hr == S_OK, "got %08x\n", hr );
+    Field_Release(field);
+
+    V_VT( &index ) = VT_I2;
+    V_I4( &index ) = 0;
+    hr = Fields_get_Item( fields, index, &field );
+    ok( hr == S_OK, "got %08x\n", hr );
+    Field_Release(field);
+
+    V_VT( &index ) = VT_I1;
+    V_I1( &index ) = 0;
+    hr = Fields_get_Item( fields, index, &field );
+    ok( hr == S_OK, "got %08x\n", hr );
+    Field_Release(field);
+
+    V_VT( &index ) = VT_R8;
+    V_R8( &index ) = 0.1;
+    hr = Fields_get_Item( fields, index, &field );
+    ok( hr == S_OK, "got %08x\n", hr );
+    Field_Release(field);
+
+    V_VT( &index ) = VT_UNKNOWN;
+    V_UNKNOWN( &index ) = NULL;
+    hr = Fields_get_Item( fields, index, &field );
+    ok( hr == MAKE_ADO_HRESULT(adErrItemNotFound), "got %08x\n", hr );
+
     V_VT( &index ) = VT_BSTR;
     V_BSTR( &index ) = name;
     hr = Fields_get_Item( fields, index, &field );
     ok( hr == S_OK, "got %08x\n", hr );
     SysFreeString( name );
 
+    hr = Field_QueryInterface(field, &IID_Properties, (void**)&props);
+    ok( hr == E_NOINTERFACE, "got %08x\n", hr );
+
+    hr = Field_get_Properties(field, &props);
+    ok( hr == S_OK, "got %08x\n", hr );
+
+    count = -1;
+    hr = Properties_get_Count(props, &count);
+    ok( hr == S_OK, "got %08x\n", hr );
+    ok( !count, "got %d\n", count );
+
+    V_VT( &index ) = VT_I4;
+    V_I4( &index ) = 1000;
+    hr = Properties_get_Item(props, index, &prop);
+    ok( hr == MAKE_ADO_HRESULT(adErrItemNotFound), "got %08x\n", hr );
+
+    Properties_Release(props);
+
     hr = _Recordset_Open( recordset, missing, missing, adOpenStatic, adLockBatchOptimistic, adCmdUnspecified );
     ok( hr == S_OK, "got %08x\n", hr );
     ok( is_eof( recordset ), "not eof\n" );
@@ -205,20 +213,20 @@ static void test_Recordset(void)
     hr = _Recordset_put_Bookmark( recordset, bookmark );
     ok( hr == MAKE_ADO_HRESULT( adErrInvalidArgument ), "got %08x\n", hr );
 
-    count = -1;
-    hr = _Recordset_get_RecordCount( recordset, &count );
+    rec_count = -1;
+    hr = _Recordset_get_RecordCount( recordset, &rec_count );
     ok( hr == S_OK, "got %08x\n", hr );
-    ok( !count, "got %d\n", count );
+    ok( !rec_count, "got %ld\n", rec_count );
 
     hr = _Recordset_AddNew( recordset, missing, missing );
     ok( hr == S_OK, "got %08x\n", hr );
     ok( !is_eof( recordset ), "eof\n" );
     ok( !is_bof( recordset ), "bof\n" );
 
-    count = -1;
-    hr = _Recordset_get_RecordCount( recordset, &count );
+    rec_count = -1;
+    hr = _Recordset_get_RecordCount( recordset, &rec_count );
     ok( hr == S_OK, "got %08x\n", hr );
-    ok( count == 1, "got %d\n", count );
+    ok( rec_count == 1, "got %ld\n", rec_count );
 
     /* get_Fields still returns the same object */
     hr = _Recordset_get_Fields( recordset, &fields2 );
@@ -298,6 +306,13 @@ static void test_Recordset(void)
     hr = _Recordset_Close( recordset );
     ok( hr == S_OK, "got %08x\n", hr );
 
+    count = -1;
+    hr = Fields_get_Count( fields, &count );
+    ok( !count, "got %d\n", count );
+
+    hr = Field_get_Name(field, &name);
+    todo_wine ok( hr == MAKE_ADO_HRESULT( adErrObjectNotSet ), "got %08x\n", hr );
+
     state = -1;
     hr = _Recordset_get_State( recordset, &state );
     ok( hr == S_OK, "got %08x\n", hr );
@@ -617,7 +632,7 @@ static void test_ADORecordsetConstruction(void)
     if (count > 0)
     {
         VARIANT index;
-        LONG size;
+        ADO_LONGPTR size;
         DataTypeEnum type;
 
         V_VT( &index ) = VT_BSTR;
@@ -632,7 +647,7 @@ static void test_ADORecordsetConstruction(void)
         size = -1;
         hr = Field_get_DefinedSize( field, &size );
         ok( hr == S_OK, "got %08x\n", hr );
-        ok( size == 5, "got %d\n", size );
+        ok( size == 5, "got %ld\n", size );
 
         VariantClear(&index);
 
@@ -658,7 +673,8 @@ static void test_Fields(void)
     Field *field, *field2;
     VARIANT val, index;
     BSTR name;
-    LONG refs, count, size;
+    LONG count;
+    ADO_LONGPTR size;
     DataTypeEnum type;
     FieldAttributeEnum attrs;
     HRESULT hr;
@@ -666,6 +682,9 @@ static void test_Fields(void)
     hr = CoCreateInstance( &CLSID_Recordset, NULL, CLSCTX_INPROC_SERVER, &IID__Recordset, (void **)&recordset );
     ok( hr == S_OK, "got %08x\n", hr );
 
+    hr = _Recordset_QueryInterface( recordset, &IID_Fields, (void **)&fields );
+    ok( hr == E_NOINTERFACE, "got %08x\n", hr );
+
     hr = _Recordset_get_Fields( recordset, &fields );
     ok( hr == S_OK, "got %08x\n", hr );
 
@@ -673,11 +692,7 @@ static void test_Fields(void)
     errorinfo = NULL;
     hr = Fields_QueryInterface( fields, &IID_ISupportErrorInfo, (void **)&errorinfo );
     ok( hr == S_OK, "got %08x\n", hr );
-    refs = get_refs_fields( fields );
-    ok( refs == 2, "got %d\n", refs );
     if (errorinfo) ISupportErrorInfo_Release( errorinfo );
-    refs = get_refs_fields( fields );
-    ok( refs == 1, "got %d\n", refs );
 
     count = -1;
     hr = Fields_get_Count( fields, &count );
@@ -707,29 +722,12 @@ static void test_Fields(void)
     name = SysAllocString( L"field" );
     V_VT( &index ) = VT_BSTR;
     V_BSTR( &index ) = name;
-    refs = get_refs_recordset( recordset );
-    ok( refs == 2, "got %d\n", refs );
-    refs = get_refs_fields( fields );
-    ok( refs == 1, "got %d\n", refs );
     hr = Fields_get_Item( fields, index, &field );
-    ok( hr == S_OK, "got %08x\n", hr );
-    refs = get_refs_field( field );
-    ok( refs == 1, "got %d\n", refs );
-    refs = get_refs_recordset( recordset );
-    ok( refs == 2, "got %d\n", refs );
-    refs = get_refs_fields( fields );
-    ok( refs == 1, "got %d\n", refs );
 
     /* calling get_Item again returns the same object and adds reference */
     hr = Fields_get_Item( fields, index, &field2 );
     ok( hr == S_OK, "got %08x\n", hr );
     ok( field2 == field, "expected same object\n" );
-    refs = get_refs_field( field2 );
-    ok( refs == 2, "got %d\n", refs );
-    refs = get_refs_recordset( recordset );
-    ok( refs == 2, "got %d\n", refs );
-    refs = get_refs_fields( fields );
-    ok( refs == 1, "got %d\n", refs );
     Field_Release( field2 );
     SysFreeString( name );
 
@@ -737,11 +735,7 @@ static void test_Fields(void)
     errorinfo = NULL;
     hr = Field_QueryInterface( field, &IID_ISupportErrorInfo, (void **)&errorinfo );
     ok( hr == S_OK, "got %08x\n", hr );
-    refs = get_refs_field( field );
-    ok( refs == 2, "got %d\n", refs );
     if (errorinfo) ISupportErrorInfo_Release( errorinfo );
-    refs = get_refs_field( field );
-    ok( refs == 1, "got %d\n", refs );
 
     /* verify values set with _Append */
     hr = Field_get_Name( field, &name );
@@ -755,7 +749,7 @@ static void test_Fields(void)
     size = -1;
     hr = Field_get_DefinedSize( field, &size );
     ok( hr == S_OK, "got %08x\n", hr );
-    ok( size == 4, "got %d\n", size );
+    ok( size == 4, "got %ld\n", size );
     attrs = 0xdead;
     hr = Field_get_Attributes( field, &attrs );
     ok( hr == S_OK, "got %08x\n", hr );
@@ -793,7 +787,8 @@ static void test_Stream(void)
     VARIANT_BOOL eos;
     StreamTypeEnum type;
     LineSeparatorEnum sep;
-    LONG refs, size, pos;
+    LONG refs;
+    ADO_LONGPTR size, pos;
     ObjectStateEnum state;
     ConnectModeEnum mode;
     BSTR charset, str;
@@ -883,7 +878,7 @@ static void test_Stream(void)
     size = -1;
     hr = _Stream_get_Size( stream, &size );
     ok( hr == S_OK, "got %08x\n", hr );
-    ok( !size, "got %d\n", size );
+    ok( !size, "got %ld\n", size );
 
     eos = VARIANT_FALSE;
     hr = _Stream_get_EOS( stream, &eos );
@@ -893,12 +888,12 @@ static void test_Stream(void)
     pos = -1;
     hr = _Stream_get_Position( stream, &pos );
     ok( hr == S_OK, "got %08x\n", hr );
-    ok( !pos, "got %d\n", pos );
+    ok( !pos, "got %ld\n", pos );
 
     size = -1;
     hr = _Stream_get_Size( stream, &size );
     ok( hr == S_OK, "got %08x\n", hr );
-    ok( !size, "got %d\n", size );
+    ok( !size, "got %ld\n", size );
 
     hr = _Stream_Read( stream, 2, &val );
     ok( hr == MAKE_ADO_HRESULT( adErrIllegalOperation ), "got %08x\n", hr );
@@ -911,7 +906,7 @@ static void test_Stream(void)
     pos = -1;
     hr = _Stream_get_Position( stream, &pos );
     ok( hr == S_OK, "got %08x\n", hr );
-    ok( !pos, "got %d\n", pos );
+    ok( !pos, "got %ld\n", pos );
 
     str = SysAllocString( L"test" );
     hr = _Stream_WriteText( stream, str, adWriteChar );
@@ -933,7 +928,7 @@ static void test_Stream(void)
     pos = -1;
     hr = _Stream_get_Position( stream, &pos );
     ok( hr == S_OK, "got %08x\n", hr );
-    ok( pos == 10, "got %d\n", pos );
+    ok( pos == 10, "got %ld\n", pos );
 
     eos = VARIANT_FALSE;
     hr = _Stream_get_EOS( stream, &eos );
@@ -946,7 +941,7 @@ static void test_Stream(void)
     size = -1;
     hr = _Stream_get_Size( stream, &size );
     ok( hr == S_OK, "got %08x\n", hr );
-    ok( size == 10, "got %d\n", size );
+    ok( size == 10, "got %ld\n", size );
 
     hr = _Stream_put_Position( stream, 2 );
     ok( hr == S_OK, "got %08x\n", hr );
@@ -957,12 +952,12 @@ static void test_Stream(void)
     pos = -1;
     hr = _Stream_get_Position( stream, &pos );
     ok( hr == S_OK, "got %08x\n", hr );
-    ok( pos == 2, "got %d\n", pos );
+    ok( pos == 2, "got %ld\n", pos );
 
     size = -1;
     hr = _Stream_get_Size( stream, &size );
     ok( hr == S_OK, "got %08x\n", hr );
-    ok( size == 2, "got %d\n", size );
+    ok( size == 2, "got %ld\n", size );
 
     hr = _Stream_Close( stream );
     ok( hr == S_OK, "got %08x\n", hr );
@@ -1014,7 +1009,7 @@ static void test_Stream(void)
     pos = -1;
     hr = _Stream_get_Position( stream, &pos );
     ok( hr == S_OK, "got %08x\n", hr );
-    ok( pos == 4, "got %d\n", pos );
+    ok( pos == 4, "got %ld\n", pos );
 
     hr = _Stream_put_Position( stream, 0 );
     ok( hr == S_OK, "got %08x\n", hr );
@@ -1028,7 +1023,7 @@ static void test_Stream(void)
     pos = -1;
     hr = _Stream_get_Position( stream, &pos );
     ok( hr == S_OK, "got %08x\n", hr );
-    ok( pos == 4, "got %d\n", pos );
+    ok( pos == 4, "got %ld\n", pos );
 
     refs = _Stream_Release( stream );
     ok( !refs, "got %d\n", refs );
@@ -1195,7 +1190,7 @@ if (0) /* Crashes on windows */
     todo_wine ok(!wcscmp(str3, str2) || broken(!wcscmp(str, str2)) /* XP */, "wrong string %s\n", wine_dbgstr_w(str2));
 
     hr = _Connection_Open(connection, str, NULL, NULL, adConnectUnspecified);
-    todo_wine ok(hr == E_FAIL, "Failed, hr 0x%08x\n", hr);
+    ok(hr == E_FAIL, "Failed, hr 0x%08x\n", hr);
     SysFreeString(str);
 
     str2 = NULL;
