@@ -102,7 +102,7 @@ static ULONG WINAPI HTMLStyleSheetRule_AddRef(IHTMLStyleSheetRule *iface)
     HTMLStyleSheetRule *This = impl_from_IHTMLStyleSheetRule(iface);
     LONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     return ref;
 }
@@ -112,7 +112,7 @@ static ULONG WINAPI HTMLStyleSheetRule_Release(IHTMLStyleSheetRule *iface)
     HTMLStyleSheetRule *This = impl_from_IHTMLStyleSheetRule(iface);
     LONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     if(!ref) {
         release_dispex(&This->dispex);
@@ -229,7 +229,7 @@ static HRESULT create_style_sheet_rule(nsIDOMCSSRule *nsstylesheetrule, compat_m
         nsres = nsIDOMCSSRule_QueryInterface(nsstylesheetrule, &IID_nsIDOMCSSRule,
                 (void **)&rule->nsstylesheetrule);
         if (NS_FAILED(nsres))
-            ERR("Could not get nsIDOMCSSRule interface: %08x\n", nsres);
+            ERR("Could not get nsIDOMCSSRule interface: %08lx\n", nsres);
     }
 
     *ret = &rule->IHTMLStyleSheetRule_iface;
@@ -269,7 +269,7 @@ static ULONG WINAPI HTMLStyleSheetRulesCollection_AddRef(IHTMLStyleSheetRulesCol
     HTMLStyleSheetRulesCollection *This = impl_from_IHTMLStyleSheetRulesCollection(iface);
     LONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     return ref;
 }
@@ -279,7 +279,7 @@ static ULONG WINAPI HTMLStyleSheetRulesCollection_Release(IHTMLStyleSheetRulesCo
     HTMLStyleSheetRulesCollection *This = impl_from_IHTMLStyleSheetRulesCollection(iface);
     LONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     if(!ref) {
         release_dispex(&This->dispex);
@@ -335,7 +335,7 @@ static HRESULT WINAPI HTMLStyleSheetRulesCollection_get_length(IHTMLStyleSheetRu
 
         nsres = nsIDOMCSSRuleList_GetLength(This->nslist, &len);
         if(NS_FAILED(nsres))
-            ERR("GetLength failed: %08x\n", nsres);
+            ERR("GetLength failed: %08lx\n", nsres);
     }
 
     *p = len;
@@ -350,7 +350,7 @@ static HRESULT WINAPI HTMLStyleSheetRulesCollection_item(IHTMLStyleSheetRulesCol
     nsresult nsres;
     HRESULT hres;
 
-    TRACE("(%p)->(%d %p)\n", This, index, p);
+    TRACE("(%p)->(%ld %p)\n", This, index, p);
 
     nsres = nsIDOMCSSRuleList_Item(This->nslist, index, &nsstylesheetrule);
     if(NS_FAILED(nsres))
@@ -375,13 +375,84 @@ static const IHTMLStyleSheetRulesCollectionVtbl HTMLStyleSheetRulesCollectionVtb
     HTMLStyleSheetRulesCollection_item
 };
 
+static inline HTMLStyleSheetRulesCollection *HTMLStyleSheetRulesCollection_from_DispatchEx(DispatchEx *iface)
+{
+    return CONTAINING_RECORD(iface, HTMLStyleSheetRulesCollection, dispex);
+}
+
+static HRESULT HTMLStyleSheetRulesCollection_get_dispid(DispatchEx *dispex, BSTR name, DWORD flags, DISPID *dispid)
+{
+    HTMLStyleSheetRulesCollection *This = HTMLStyleSheetRulesCollection_from_DispatchEx(dispex);
+    UINT32 len = 0;
+    DWORD idx = 0;
+    WCHAR *ptr;
+
+    for(ptr = name; *ptr && is_digit(*ptr); ptr++)
+        idx = idx*10 + (*ptr-'0');
+    if(*ptr)
+        return DISP_E_UNKNOWNNAME;
+
+    nsIDOMCSSRuleList_GetLength(This->nslist, &len);
+    if(idx >= len)
+        return DISP_E_UNKNOWNNAME;
+
+    *dispid = MSHTML_DISPID_CUSTOM_MIN + idx;
+    TRACE("ret %lx\n", *dispid);
+    return S_OK;
+}
+
+static HRESULT HTMLStyleSheetRulesCollection_invoke(DispatchEx *dispex, DISPID id, LCID lcid, WORD flags, DISPPARAMS *params,
+        VARIANT *res, EXCEPINFO *ei, IServiceProvider *caller)
+{
+    HTMLStyleSheetRulesCollection *This = HTMLStyleSheetRulesCollection_from_DispatchEx(dispex);
+
+    TRACE("(%p)->(%lx %lx %x %p %p %p %p)\n", This, id, lcid, flags, params, res, ei, caller);
+
+    switch(flags) {
+    case DISPATCH_PROPERTYGET: {
+        IHTMLStyleSheetRule *stylesheetrule;
+        nsIDOMCSSRule *nsstylesheetrule;
+        nsresult nsres;
+        HRESULT hres;
+
+        nsres = nsIDOMCSSRuleList_Item(This->nslist, id - MSHTML_DISPID_CUSTOM_MIN, &nsstylesheetrule);
+        if(NS_FAILED(nsres))
+            return DISP_E_MEMBERNOTFOUND;
+        if(!nsstylesheetrule) {
+            V_VT(res) = VT_EMPTY;
+            return S_OK;
+        }
+
+        hres = create_style_sheet_rule(nsstylesheetrule, dispex_compat_mode(&This->dispex), &stylesheetrule);
+        nsIDOMCSSRule_Release(nsstylesheetrule);
+        if(FAILED(hres))
+            return hres;
+
+        V_VT(res) = VT_DISPATCH;
+        V_DISPATCH(res) = (IDispatch*)stylesheetrule;
+        break;
+    }
+
+    default:
+        FIXME("unimplemented flags %x\n", flags);
+        return E_NOTIMPL;
+    }
+
+    return S_OK;
+}
+
+static const dispex_static_data_vtbl_t HTMLStyleSheetRulesCollection_dispex_vtbl = {
+    NULL,
+    HTMLStyleSheetRulesCollection_get_dispid,
+    HTMLStyleSheetRulesCollection_invoke
+};
 static const tid_t HTMLStyleSheetRulesCollection_iface_tids[] = {
     IHTMLStyleSheetRulesCollection_tid,
     0
 };
 static dispex_static_data_t HTMLStyleSheetRulesCollection_dispex = {
     L"MSCSSRuleList",
-    NULL,
+    &HTMLStyleSheetRulesCollection_dispex_vtbl,
     DispHTMLStyleSheetRulesCollection_tid,
     HTMLStyleSheetRulesCollection_iface_tids
 };
@@ -443,7 +514,7 @@ static ULONG WINAPI HTMLStyleSheetsCollection_AddRef(IHTMLStyleSheetsCollection
     HTMLStyleSheetsCollection *This = impl_from_IHTMLStyleSheetsCollection(iface);
     LONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     return ref;
 }
@@ -453,7 +524,7 @@ static ULONG WINAPI HTMLStyleSheetsCollection_Release(IHTMLStyleSheetsCollection
     HTMLStyleSheetsCollection *This = impl_from_IHTMLStyleSheetsCollection(iface);
     LONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     if(!ref) {
         release_dispex(&This->dispex);
@@ -533,11 +604,11 @@ static HRESULT WINAPI HTMLStyleSheetsCollection_item(IHTMLStyleSheetsCollection
         nsresult nsres;
         HRESULT hres;
 
-        TRACE("index=%d\n", V_I4(pvarIndex));
+        TRACE("index=%ld\n", V_I4(pvarIndex));
 
         nsres = nsIDOMStyleSheetList_Item(This->nslist, V_I4(pvarIndex), &nsstylesheet);
         if(NS_FAILED(nsres) || !nsstylesheet) {
-            WARN("Item failed: %08x\n", nsres);
+            WARN("Item failed: %08lx\n", nsres);
             V_VT(pvarResult) = VT_EMPTY;
             return E_INVALIDARG;
         }
@@ -576,13 +647,84 @@ static const IHTMLStyleSheetsCollectionVtbl HTMLStyleSheetsCollectionVtbl = {
     HTMLStyleSheetsCollection_item
 };
 
+static inline HTMLStyleSheetsCollection *HTMLStyleSheetsCollection_from_DispatchEx(DispatchEx *iface)
+{
+    return CONTAINING_RECORD(iface, HTMLStyleSheetsCollection, dispex);
+}
+
+static HRESULT HTMLStyleSheetsCollection_get_dispid(DispatchEx *dispex, BSTR name, DWORD flags, DISPID *dispid)
+{
+    HTMLStyleSheetsCollection *This = HTMLStyleSheetsCollection_from_DispatchEx(dispex);
+    UINT32 len = 0;
+    DWORD idx = 0;
+    WCHAR *ptr;
+
+    for(ptr = name; *ptr && is_digit(*ptr); ptr++)
+        idx = idx*10 + (*ptr-'0');
+    if(*ptr)
+        return DISP_E_UNKNOWNNAME;
+
+    nsIDOMStyleSheetList_GetLength(This->nslist, &len);
+    if(idx >= len)
+        return DISP_E_UNKNOWNNAME;
+
+    *dispid = MSHTML_DISPID_CUSTOM_MIN + idx;
+    TRACE("ret %lx\n", *dispid);
+    return S_OK;
+}
+
+static HRESULT HTMLStyleSheetsCollection_invoke(DispatchEx *dispex, DISPID id, LCID lcid, WORD flags, DISPPARAMS *params,
+        VARIANT *res, EXCEPINFO *ei, IServiceProvider *caller)
+{
+    HTMLStyleSheetsCollection *This = HTMLStyleSheetsCollection_from_DispatchEx(dispex);
+
+    TRACE("(%p)->(%lx %lx %x %p %p %p %p)\n", This, id, lcid, flags, params, res, ei, caller);
+
+    switch(flags) {
+    case DISPATCH_PROPERTYGET: {
+        nsIDOMStyleSheet *nsstylesheet;
+        IHTMLStyleSheet *stylesheet;
+        nsresult nsres;
+        HRESULT hres;
+
+        nsres = nsIDOMStyleSheetList_Item(This->nslist, id - MSHTML_DISPID_CUSTOM_MIN, &nsstylesheet);
+        if(NS_FAILED(nsres))
+            return DISP_E_MEMBERNOTFOUND;
+        if(!nsstylesheet) {
+            V_VT(res) = VT_EMPTY;
+            return S_OK;
+        }
+
+        hres = create_style_sheet(nsstylesheet, dispex_compat_mode(&This->dispex), &stylesheet);
+        nsIDOMStyleSheet_Release(nsstylesheet);
+        if(FAILED(hres))
+            return hres;
+
+        V_VT(res) = VT_DISPATCH;
+        V_DISPATCH(res) = (IDispatch*)stylesheet;
+        break;
+    }
+
+    default:
+        FIXME("unimplemented flags %x\n", flags);
+        return E_NOTIMPL;
+    }
+
+    return S_OK;
+}
+
+static const dispex_static_data_vtbl_t HTMLStyleSheetsCollection_dispex_vtbl = {
+    NULL,
+    HTMLStyleSheetsCollection_get_dispid,
+    HTMLStyleSheetsCollection_invoke
+};
 static const tid_t HTMLStyleSheetsCollection_iface_tids[] = {
     IHTMLStyleSheetsCollection_tid,
     0
 };
 static dispex_static_data_t HTMLStyleSheetsCollection_dispex = {
     L"StyleSheetList",
-    NULL,
+    &HTMLStyleSheetsCollection_dispex_vtbl,
     DispHTMLStyleSheetsCollection_tid,
     HTMLStyleSheetsCollection_iface_tids
 };
@@ -645,7 +787,7 @@ static ULONG WINAPI HTMLStyleSheet_AddRef(IHTMLStyleSheet *iface)
     HTMLStyleSheet *This = impl_from_IHTMLStyleSheet(iface);
     LONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     return ref;
 }
@@ -655,7 +797,7 @@ static ULONG WINAPI HTMLStyleSheet_Release(IHTMLStyleSheet *iface)
     HTMLStyleSheet *This = impl_from_IHTMLStyleSheet(iface);
     LONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) ref=%d\n", This, ref);
+    TRACE("(%p) ref=%ld\n", This, ref);
 
     if(!ref) {
         release_dispex(&This->dispex);
@@ -794,7 +936,7 @@ static HRESULT WINAPI HTMLStyleSheet_addImport(IHTMLStyleSheet *iface, BSTR bstr
                                                LONG lIndex, LONG *plIndex)
 {
     HTMLStyleSheet *This = impl_from_IHTMLStyleSheet(iface);
-    FIXME("(%p)->(%s %d %p)\n", This, debugstr_w(bstrURL), lIndex, plIndex);
+    FIXME("(%p)->(%s %ld %p)\n", This, debugstr_w(bstrURL), lIndex, plIndex);
     return E_NOTIMPL;
 }
 
@@ -810,7 +952,7 @@ static HRESULT WINAPI HTMLStyleSheet_addRule(IHTMLStyleSheet *iface, BSTR bstrSe
     WCHAR *rule;
     size_t len;
 
-    TRACE("(%p)->(%s %s %d %p)\n", This, debugstr_w(bstrSelector), debugstr_w(bstrStyle),
+    TRACE("(%p)->(%s %s %ld %p)\n", This, debugstr_w(bstrSelector), debugstr_w(bstrStyle),
           lIndex, plIndex);
 
     if(!bstrSelector || !bstrStyle || !bstrSelector[0] || !bstrStyle[0])
@@ -831,7 +973,7 @@ static HRESULT WINAPI HTMLStyleSheet_addRule(IHTMLStyleSheet *iface, BSTR bstrSe
 
     nsAString_InitDepend(&nsstr, rule);
     nsres = nsIDOMCSSStyleSheet_InsertRule(This->nsstylesheet, &nsstr, lIndex, &new_index);
-    if(NS_FAILED(nsres)) WARN("failed: %08x\n", nsres);
+    if(NS_FAILED(nsres)) WARN("failed: %08lx\n", nsres);
     nsAString_Finish(&nsstr);
     heap_free(rule);
 
@@ -842,14 +984,14 @@ static HRESULT WINAPI HTMLStyleSheet_addRule(IHTMLStyleSheet *iface, BSTR bstrSe
 static HRESULT WINAPI HTMLStyleSheet_removeImport(IHTMLStyleSheet *iface, LONG lIndex)
 {
     HTMLStyleSheet *This = impl_from_IHTMLStyleSheet(iface);
-    FIXME("(%p)->(%d)\n", This, lIndex);
+    FIXME("(%p)->(%ld)\n", This, lIndex);
     return E_NOTIMPL;
 }
 
 static HRESULT WINAPI HTMLStyleSheet_removeRule(IHTMLStyleSheet *iface, LONG lIndex)
 {
     HTMLStyleSheet *This = impl_from_IHTMLStyleSheet(iface);
-    FIXME("(%p)->(%d)\n", This, lIndex);
+    FIXME("(%p)->(%ld)\n", This, lIndex);
     return E_NOTIMPL;
 }
 
@@ -908,7 +1050,7 @@ static HRESULT WINAPI HTMLStyleSheet_get_cssText(IHTMLStyleSheet *iface, BSTR *p
 
     nsres = nsIDOMCSSStyleSheet_GetCssRules(This->nsstylesheet, &nslist);
     if(NS_FAILED(nsres)) {
-        ERR("GetCssRules failed: %08x\n", nsres);
+        ERR("GetCssRules failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -918,7 +1060,7 @@ static HRESULT WINAPI HTMLStyleSheet_get_cssText(IHTMLStyleSheet *iface, BSTR *p
     if(len) {
         nsres = nsIDOMCSSRuleList_Item(nslist, 0, &nsrule);
         if(NS_FAILED(nsres))
-            ERR("Item failed: %08x\n", nsres);
+            ERR("Item failed: %08lx\n", nsres);
     }
 
     nsIDOMCSSRuleList_Release(nslist);
@@ -948,7 +1090,7 @@ static HRESULT WINAPI HTMLStyleSheet_get_rules(IHTMLStyleSheet *iface,
 
     nsres = nsIDOMCSSStyleSheet_GetCssRules(This->nsstylesheet, &nslist);
     if(NS_FAILED(nsres)) {
-        ERR("GetCssRules failed: %08x\n", nsres);
+        ERR("GetCssRules failed: %08lx\n", nsres);
         return E_FAIL;
     }
 
@@ -1104,11 +1246,11 @@ static HRESULT WINAPI HTMLStyleSheet4_insertRule(IHTMLStyleSheet4 *iface, BSTR r
     nsAString nsstr;
     nsresult nsres;
 
-    TRACE("(%p)->(%s %d %p)\n", This, debugstr_w(rule), index, p);
+    TRACE("(%p)->(%s %ld %p)\n", This, debugstr_w(rule), index, p);
 
     nsAString_InitDepend(&nsstr, rule);
     nsres = nsIDOMCSSStyleSheet_InsertRule(This->nsstylesheet, &nsstr, index, &new_index);
-    if(NS_FAILED(nsres)) WARN("failed: %08x\n", nsres);
+    if(NS_FAILED(nsres)) WARN("failed: %08lx\n", nsres);
     nsAString_Finish(&nsstr);
     *p = new_index;
     return map_nsresult(nsres);
@@ -1117,7 +1259,7 @@ static HRESULT WINAPI HTMLStyleSheet4_insertRule(IHTMLStyleSheet4 *iface, BSTR r
 static HRESULT WINAPI HTMLStyleSheet4_deleteRule(IHTMLStyleSheet4 *iface, LONG index)
 {
     HTMLStyleSheet *This = impl_from_IHTMLStyleSheet4(iface);
-    FIXME("(%p)->(%d)\n", This, index);
+    FIXME("(%p)->(%ld)\n", This, index);
     return E_NOTIMPL;
 }
 
@@ -1178,7 +1320,7 @@ HRESULT create_style_sheet(nsIDOMStyleSheet *nsstylesheet, compat_mode_t compat_
         nsres = nsIDOMStyleSheet_QueryInterface(nsstylesheet, &IID_nsIDOMCSSStyleSheet,
                 (void**)&style_sheet->nsstylesheet);
         if(NS_FAILED(nsres))
-            ERR("Could not get nsICSSStyleSheet interface: %08x\n", nsres);
+            ERR("Could not get nsICSSStyleSheet interface: %08lx\n", nsres);
     }
 
     *ret = &style_sheet->IHTMLStyleSheet_iface;
