@@ -265,7 +265,7 @@ static HRESULT WINAPI AutomationObject_GetTypeInfo(
     AutomationObject *This = impl_from_IDispatch(iface);
     HRESULT hr;
 
-    TRACE("(%p/%p)->(%d,%d,%p)\n", iface, This, iTInfo, lcid, ppTInfo);
+    TRACE( "(%p/%p)->(%u, %ld, %p)\n", iface, This, iTInfo, lcid, ppTInfo );
 
     hr = get_typeinfo(This->tid, ppTInfo);
     if (FAILED(hr))
@@ -287,7 +287,7 @@ static HRESULT WINAPI AutomationObject_GetIDsOfNames(
     ITypeInfo *ti;
     HRESULT hr;
 
-    TRACE("(%p/%p)->(%s, %p, %d, %d, %p)\n", iface, This,
+    TRACE("(%p/%p)->(%s, %p, %u, %ld, %p)\n", iface, This,
             debugstr_guid(riid), rgszNames, cNames, lcid, rgDispId);
 
     if (!IsEqualGUID(riid, &IID_NULL)) return E_INVALIDARG;
@@ -331,7 +331,7 @@ static HRESULT WINAPI AutomationObject_Invoke(
     BSTR bstrName = NULL;
     ITypeInfo *ti;
 
-    TRACE("(%p/%p)->(%d, %s, %d, %d, %p, %p, %p, %p)\n", iface, This,
+    TRACE("(%p/%p)->(%ld, %s, %ld, %d, %p, %p, %p, %p)\n", iface, This,
             dispIdMember, debugstr_guid(riid), lcid, wFlags,
             pDispParams, pVarResult, pExcepInfo, puArgErr);
 
@@ -362,14 +362,14 @@ static HRESULT WINAPI AutomationObject_Invoke(
     if (TRACE_ON(msi))
     {
         ITypeInfo_GetDocumentation(ti, dispIdMember, &bstrName, NULL, NULL, NULL);
-        TRACE("Method %d, %s\n", dispIdMember, debugstr_w(bstrName));
+        TRACE("method %ld, %s\n", dispIdMember, debugstr_w(bstrName));
     }
 
     hr = tid_ids[This->tid].fn_invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr);
 
     if (hr == DISP_E_MEMBERNOTFOUND) {
         if (bstrName == NULL) ITypeInfo_GetDocumentation(ti, dispIdMember, &bstrName, NULL, NULL, NULL);
-        FIXME("Method %d, %s wflags %d not implemented, clsid %s\n", dispIdMember, debugstr_w(bstrName), wFlags,
+        FIXME("method %ld, %s wflags %d not implemented, clsid %s\n", dispIdMember, debugstr_w(bstrName), wFlags,
             debugstr_guid(get_riid_from_tid(This->tid)));
     }
     else if (pExcepInfo &&
@@ -383,7 +383,7 @@ static HRESULT WINAPI AutomationObject_Invoke(
         if (FAILED(ITypeInfo_GetNames(ti, dispIdMember, bstrParamNames,
                                       MAX_FUNC_PARAMS, &namesNo)))
         {
-            TRACE("Failed to retrieve names for dispIdMember %d\n", dispIdMember);
+            TRACE("failed to retrieve names for dispIdMember %ld\n", dispIdMember);
         }
         else
         {
@@ -412,7 +412,7 @@ static HRESULT WINAPI AutomationObject_Invoke(
     /* Free function name if we retrieved it */
     SysFreeString(bstrName);
 
-    TRACE("Returning 0x%08x, %s\n", hr, SUCCEEDED(hr) ? "ok" : "not ok");
+    TRACE("returning %#lx, %s\n", hr, SUCCEEDED(hr) ? "ok" : "not ok");
 
     return hr;
 }
@@ -470,7 +470,7 @@ static HRESULT WINAPI ProvideMultipleClassInfo_GetClassInfo(IProvideMultipleClas
 static HRESULT WINAPI ProvideMultipleClassInfo_GetGUID(IProvideMultipleClassInfo* iface, DWORD dwGuidKind, GUID* pGUID)
 {
     AutomationObject *This = impl_from_IProvideMultipleClassInfo(iface);
-    TRACE("(%p/%p)->(%d,%s)\n", iface, This, dwGuidKind, debugstr_guid(pGUID));
+    TRACE("(%p/%p)->(%lu, %s)\n", iface, This, dwGuidKind, debugstr_guid(pGUID));
 
     if (dwGuidKind != GUIDKIND_DEFAULT_SOURCE_DISP_IID)
         return E_INVALIDARG;
@@ -500,7 +500,8 @@ static HRESULT WINAPI ProvideMultipleClassInfo_GetInfoOfIndex(IProvideMultipleCl
 {
     AutomationObject *This = impl_from_IProvideMultipleClassInfo(iface);
 
-    TRACE("(%p/%p)->(%d,%d,%p,%p,%p,%p,%p)\n", iface, This, iti, dwFlags, ti, pdwTIFlags, pcdispidReserved, piidPrimary, piidSource);
+    TRACE("(%p/%p)->(%lu, %#lx, %p, %p, %p, %p, %p)\n", iface, This, iti, dwFlags, ti, pdwTIFlags, pcdispidReserved,
+          piidPrimary, piidSource);
 
     if (iti != 0)
         return E_INVALIDARG;
@@ -542,7 +543,7 @@ static const IProvideMultipleClassInfoVtbl ProvideMultipleClassInfoVtbl =
 
 static void init_automation_object(AutomationObject *This, MSIHANDLE msiHandle, tid_t tid)
 {
-    TRACE("(%p, %d, %s)\n", This, msiHandle, debugstr_guid(get_riid_from_tid(tid)));
+    TRACE("%p, %lu, %s\n", This, msiHandle, debugstr_guid(get_riid_from_tid(tid)));
 
     This->IDispatch_iface.lpVtbl = &AutomationObjectVtbl;
     This->IProvideMultipleClassInfo_iface.lpVtbl = &ProvideMultipleClassInfoVtbl;
@@ -618,7 +619,7 @@ static HRESULT WINAPI ListEnumerator_Next(IEnumVARIANT* iface, ULONG celt, VARIA
     ListEnumerator *This = impl_from_IEnumVARIANT(iface);
     ULONG i, local;
 
-    TRACE("(%p, %uld, %p, %p)\n", iface, celt, rgVar, fetched);
+    TRACE("%p, %lu, %p, %p\n", iface, celt, rgVar, fetched);
 
     if (fetched) *fetched = 0;
 
@@ -641,7 +642,7 @@ static HRESULT WINAPI ListEnumerator_Skip(IEnumVARIANT* iface, ULONG celt)
 {
     ListEnumerator *This = impl_from_IEnumVARIANT(iface);
 
-    TRACE("(%p,%uld)\n", iface, celt);
+    TRACE("%p, %lu\n", iface, celt);
 
     This->pos += celt;
     if (This->pos >= This->list->count)
@@ -1030,7 +1031,7 @@ static HRESULT list_invoke(
                  if (SUCCEEDED(hr = create_list_enumerator(list, (LPVOID *)&pUnk)))
                      V_UNKNOWN(pVarResult) = pUnk;
                  else
-                     ERR("Failed to create IEnumVARIANT object, hresult 0x%08x\n", hr);
+                     ERR("failed to create IEnumVARIANT object, hresult %#lx\n", hr);
              }
              else return DISP_E_MEMBERNOTFOUND;
              break;
@@ -1189,7 +1190,7 @@ static HRESULT view_invoke(
                 if ((ret = MsiViewFetch(This->msiHandle, &msiHandle)) == ERROR_SUCCESS)
                 {
                     if (FAILED(hr = create_record(msiHandle, &V_DISPATCH(pVarResult))))
-                        ERR("Failed to create Record object, hresult 0x%08x\n", hr);
+                        ERR("failed to create Record object, hresult %#lx\n", hr);
                 }
                 else if (ret == ERROR_NO_MORE_ITEMS)
                     V_DISPATCH(pVarResult) = NULL;
@@ -1289,7 +1290,7 @@ HRESULT database_invoke(
                     if (SUCCEEDED(hr))
                         V_DISPATCH(pVarResult) = dispatch;
                     else
-                        ERR("Failed to create SummaryInfo object: 0x%08x\n", hr);
+                        ERR("failed to create SummaryInfo object: %#lx\n", hr);
                 }
                 else
                 {
@@ -1311,7 +1312,7 @@ HRESULT database_invoke(
                     if (SUCCEEDED(hr = create_view(msiHandle, &dispatch)))
                         V_DISPATCH(pVarResult) = dispatch;
                     else
-                        ERR("Failed to create View object, hresult 0x%08x\n", hr);
+                        ERR("failed to create View object, hresult %#lx\n", hr);
                 }
                 else
                 {
@@ -1447,7 +1448,7 @@ static HRESULT session_invoke(
                     if (SUCCEEDED(hr = create_database(msiHandle, &dispatch)))
                         V_DISPATCH(pVarResult) = dispatch;
                     else
-                        ERR("Failed to create Database object, hresult 0x%08x\n", hr);
+                        ERR("failed to create Database object, hresult %#lx\n", hr);
                 }
                 else
                 {
@@ -1617,11 +1618,11 @@ static void variant_from_registry_value(VARIANT *pVarResult, DWORD dwType, LPBYT
 
         case REG_EXPAND_SZ:
             if (!(dwNewSize = ExpandEnvironmentStringsW(szString, szNewString, dwNewSize)))
-                ERR("ExpandEnvironmentStrings returned error %d\n", GetLastError());
+                ERR("ExpandEnvironmentStrings returned error %lu\n", GetLastError());
             else if (!(szNewString = msi_alloc(dwNewSize * sizeof(WCHAR))))
                 ERR("Out of memory\n");
             else if (!(dwNewSize = ExpandEnvironmentStringsW(szString, szNewString, dwNewSize)))
-                ERR("ExpandEnvironmentStrings returned error %d\n", GetLastError());
+                ERR("ExpandEnvironmentStrings returned error %lu\n", GetLastError());
             else
             {
                 V_VT(pVarResult) = VT_BSTR;
@@ -1650,7 +1651,7 @@ static void variant_from_registry_value(VARIANT *pVarResult, DWORD dwType, LPBYT
             break;
 
         default:
-            FIXME("Unhandled registry value type %d\n", dwType);
+            FIXME("Unhandled registry value type %lu\n", dwType);
     }
 }
 
@@ -2455,7 +2456,7 @@ static HRESULT create_database(MSIHANDLE msiHandle, IDispatch **dispatch)
 {
     AutomationObject *database;
 
-    TRACE("(%d %p)\n", msiHandle, dispatch);
+    TRACE("%lu %p\n", msiHandle, dispatch);
 
     database = msi_alloc(sizeof(AutomationObject));
     if (!database) return E_OUTOFMEMORY;
@@ -2471,7 +2472,7 @@ static HRESULT create_view(MSIHANDLE msiHandle, IDispatch **dispatch)
 {
     AutomationObject *view;
 
-    TRACE("(%d %p)\n", msiHandle, dispatch);
+    TRACE("%lu %p\n", msiHandle, dispatch);
 
     view = msi_alloc(sizeof(AutomationObject));
     if (!view) return E_OUTOFMEMORY;
