@@ -196,6 +196,7 @@ static int (__cdecl *p_To_wide)(const char *src, WCHAR *dst);
 static int (__cdecl *p_Unlink)(WCHAR const*);
 static ULONG (__cdecl *p__Winerror_message)(ULONG, char*, ULONG);
 static int (__cdecl *p__Winerror_map)(int);
+static const char* (__cdecl *p__Syserror_map)(int err);
 
 static BOOLEAN (WINAPI *pCreateSymbolicLinkW)(const WCHAR *, const WCHAR *, DWORD);
 
@@ -234,6 +235,7 @@ static BOOL init(void)
         SET(p__Reschedule_chore, "?_Reschedule_chore@details@Concurrency@@YAHPEBU_Threadpool_chore@12@@Z");
         SET(p__Release_chore, "?_Release_chore@details@Concurrency@@YAXPEAU_Threadpool_chore@12@@Z");
         SET(p__Winerror_message, "?_Winerror_message@std@@YAKKPEADK@Z");
+        SET(p__Syserror_map, "?_Syserror_map@std@@YAPEBDH@Z");
     } else {
 #ifdef __arm__
         SET(p_task_continuation_context_ctor, "??0task_continuation_context@Concurrency@@AAA@XZ");
@@ -264,6 +266,7 @@ static BOOL init(void)
         SET(p__Reschedule_chore, "?_Reschedule_chore@details@Concurrency@@YAHPBU_Threadpool_chore@12@@Z");
         SET(p__Release_chore, "?_Release_chore@details@Concurrency@@YAXPAU_Threadpool_chore@12@@Z");
         SET(p__Winerror_message, "?_Winerror_message@std@@YAKKPADK@Z");
+        SET(p__Syserror_map, "?_Syserror_map@std@@YAPBDH@Z");
     }
 
     SET(p_Close_dir, "_Close_dir");
@@ -298,7 +301,7 @@ static BOOL init(void)
 static void test_thrd(void)
 {
     ok(p__Thrd_id() == GetCurrentThreadId(),
-        "expected same id, got _Thrd_id %u GetCurrentThreadId %u\n",
+        "expected same id, got _Thrd_id %u GetCurrentThreadId %lu\n",
         p__Thrd_id(), GetCurrentThreadId());
 }
 
@@ -526,7 +529,7 @@ static void test_chore(void)
     ok(chore.callback == chore_callback, "chore.callback = %p, expected %p\n", chore.callback, chore_callback);
     ok(chore.arg == event, "chore.arg = %p, expected %p\n", chore.arg, event);
     wait = WaitForSingleObject(event, 500);
-    ok(wait == WAIT_OBJECT_0, "WaitForSingleObject returned %d\n", wait);
+    ok(wait == WAIT_OBJECT_0, "WaitForSingleObject returned %ld\n", wait);
 
     if(!GetProcAddress(GetModuleHandleA("kernel32"), "CreateThreadpoolWork"))
     {
@@ -542,12 +545,12 @@ static void test_chore(void)
     ok(old_chore.work != chore.work, "new threadpool work was not created\n");
     p__Release_chore(&old_chore);
     wait = WaitForSingleObject(event, 500);
-    ok(wait == WAIT_OBJECT_0, "WaitForSingleObject returned %d\n", wait);
+    ok(wait == WAIT_OBJECT_0, "WaitForSingleObject returned %ld\n", wait);
 
     ret = p__Reschedule_chore(&chore);
     ok(!ret, "_Reschedule_chore returned %d\n", ret);
     wait = WaitForSingleObject(event, 500);
-    ok(wait == WAIT_OBJECT_0, "WaitForSingleObject returned %d\n", wait);
+    ok(wait == WAIT_OBJECT_0, "WaitForSingleObject returned %ld\n", wait);
 
     p__Release_chore(&chore);
     ok(!chore.work, "chore.work != NULL\n");
@@ -1251,12 +1254,14 @@ static void test__Winerror_message(void)
 
     memset(buf, 'a', sizeof(buf));
     ret = p__Winerror_message(0, buf, sizeof(buf));
-    ok(ret == ret_fm, "ret = %u, expected %u\n", ret, ret_fm);
-    ok(!strcmp(buf, buf_fm), "buf = %s, expected %s\n", buf, buf_fm);
+    ok(ret == ret_fm || (ret_fm > 2 && buf_fm[ret_fm - 1] == '\n' &&
+                buf_fm[ret_fm - 2] == '\r' && ret + 2 == ret_fm),
+            "ret = %lu, expected %lu\n", ret, ret_fm);
+    ok(!strncmp(buf, buf_fm, ret), "buf = %s, expected %s\n", buf, buf_fm);
 
     memset(buf, 'a', sizeof(buf));
     ret = p__Winerror_message(0, buf, 2);
-    ok(!ret, "ret = %u\n", ret);
+    ok(!ret, "ret = %lu\n", ret);
     ok(buf[0] == 'a', "buf = %s\n", buf);
 }
 
@@ -1265,6 +1270,7 @@ static void test__Winerror_map(void)
     static struct {
         int winerr, doserr;
         BOOL broken;
+        int broken_doserr;
     } tests[] = {
         {ERROR_INVALID_FUNCTION, ENOSYS}, {ERROR_FILE_NOT_FOUND, ENOENT},
         {ERROR_PATH_NOT_FOUND, ENOENT}, {ERROR_TOO_MANY_OPEN_FILES, EMFILE},
@@ -1280,7 +1286,7 @@ static void test__Winerror_map(void)
         {ERROR_FILE_EXISTS, EEXIST}, {ERROR_CANNOT_MAKE, EACCES},
         {ERROR_INVALID_PARAMETER, EINVAL, TRUE}, {ERROR_OPEN_FAILED, EIO},
         {ERROR_BUFFER_OVERFLOW, ENAMETOOLONG}, {ERROR_DISK_FULL, ENOSPC},
-        {ERROR_INVALID_NAME, EINVAL}, {ERROR_NEGATIVE_SEEK, EINVAL},
+        {ERROR_INVALID_NAME, ENOENT, TRUE, EINVAL}, {ERROR_NEGATIVE_SEEK, EINVAL},
         {ERROR_BUSY_DRIVE, EBUSY}, {ERROR_DIR_NOT_EMPTY, ENOTEMPTY},
         {ERROR_BUSY, EBUSY}, {ERROR_ALREADY_EXISTS, EEXIST},
         {ERROR_LOCKED, ENOLCK}, {ERROR_DIRECTORY, EINVAL},
@@ -1308,12 +1314,23 @@ static void test__Winerror_map(void)
     for(i=0; i<ARRAY_SIZE(tests); i++)
     {
         ret = p__Winerror_map(tests[i].winerr);
-        ok(ret == tests[i].doserr || broken(tests[i].broken && !ret),
+        ok(ret == tests[i].doserr || broken(tests[i].broken && ret == tests[i].broken_doserr),
                 "_Winerror_map(%d) returned %d, expected %d\n",
                 tests[i].winerr, ret, tests[i].doserr);
     }
 }
 
+static void test__Syserror_map(void)
+{
+    const char *r1, *r2;
+
+    r1 = p__Syserror_map(0);
+    ok(r1 != NULL, "_Syserror_map(0) returned NULL\n");
+    r2 = p__Syserror_map(1234);
+    ok(r2 != NULL, "_Syserror_map(1234) returned NULL\n");
+    ok(r1 == r2, "r1 = %p(%s), r2 = %p(%s)\n", r1, r1, r2, r2);
+}
+
 static void test_Equivalent(void)
 {
     int val, i;
@@ -1391,6 +1408,7 @@ START_TEST(msvcp140)
     test_Last_write_time();
     test__Winerror_message();
     test__Winerror_map();
+    test__Syserror_map();
     test_Equivalent();
     FreeLibrary(msvcp);
 }
