@@ -186,11 +186,12 @@ static int (CDECL *p_fegetexceptflag)(fexcept_t*,int);
 static int (CDECL *p_fesetexceptflag)(const fexcept_t*,int);
 static int (CDECL *p_fetestexcept)(int);
 static int (CDECL *p_feclearexcept)(int);
+static int (CDECL *p_feupdateenv)(fenv_t*);
 static int (CDECL *p__clearfp)(void);
 static _locale_t (__cdecl *p_wcreate_locale)(int, const wchar_t *);
 static void (__cdecl *p_free_locale)(_locale_t);
 static unsigned short (__cdecl *p_wctype)(const char*);
-static int (__cdecl *p_vsscanf)(const char*, const char *, __ms_va_list valist);
+static int (__cdecl *p_vsscanf)(const char*, const char *, va_list valist);
 static _Dcomplex* (__cdecl *p__Cbuild)(_Dcomplex*, double, double);
 static double (__cdecl *p_creal)(_Dcomplex);
 static double (__cdecl *p_nexttoward)(double, double);
@@ -265,6 +266,7 @@ static BOOL init(void)
     SET(p_fesetexceptflag, "fesetexceptflag");
     SET(p_fetestexcept, "fetestexcept");
     SET(p_feclearexcept, "feclearexcept");
+    SET(p_feupdateenv, "feupdateenv");
 
     SET(p__clearfp, "_clearfp");
     SET(p_vsscanf, "vsscanf");
@@ -538,7 +540,7 @@ static void test__GetConcurrency(void)
 
     GetSystemInfo(&si);
     c = (*p__GetConcurrency)();
-    ok(c == si.dwNumberOfProcessors, "expected %u, got %u\n", si.dwNumberOfProcessors, c);
+    ok(c == si.dwNumberOfProcessors, "expected %lu, got %u\n", si.dwNumberOfProcessors, c);
 }
 
 static void test_gettnames(void* (CDECL *p_gettnames)(void))
@@ -585,7 +587,7 @@ static void test_gettnames(void* (CDECL *p_gettnames)(void))
 
     ok(ret->str[42] + strlen(ret->str[42]) + 1 == (char*)ret->wstr[0] ||
             ret->str[42] + strlen(ret->str[42]) + 2 == (char*)ret->wstr[0],
-            "ret->str[42] = %p len = %d, ret->wstr[0] = %p\n",
+            "ret->str[42] = %p len = %Id, ret->wstr[0] = %p\n",
             ret->str[42], strlen(ret->str[42]), ret->wstr[0]);
     p_free(ret);
 
@@ -599,6 +601,7 @@ static void test__strtof(void)
     const char float3[] = "-3.402823466e+38";
     const char float4[] = "1.7976931348623158e+308";  /* DBL_MAX */
 
+    BOOL is_arabic;
     char *end;
     float f;
 
@@ -636,8 +639,12 @@ static void test__strtof(void)
     f = p_wcstof(L"12.0", NULL);
     ok(f == 12.0, "f = %lf\n", f);
 
-    f = p_wcstof(L"\x0662\x0663", NULL);
-    ok(f == 0, "f = %lf\n", f);
+    f = p_wcstof(L"\x0662\x0663", NULL); /* 23 in Arabic numerals */
+    is_arabic = (PRIMARYLANGID(GetSystemDefaultLangID()) == LANG_ARABIC);
+    todo_wine_if(is_arabic) ok(f == (is_arabic ? 23.0 : 0.0), "f = %lf\n", f);
+
+    f = p_wcstof(L"\x0662\x34\x0663", NULL); /* Arabic + Roman numerals mix */
+    todo_wine_if(is_arabic) ok(f == (is_arabic ? 243.0 : 0.0), "f = %lf\n", f);
 
     if(!p_setlocale(LC_ALL, "Arabic")) {
         win_skip("Arabic locale not available\n");
@@ -647,8 +654,8 @@ static void test__strtof(void)
     f = p_wcstof(L"12.0", NULL);
     ok(f == 12.0, "f = %lf\n", f);
 
-    f = p_wcstof(L"\x0662\x0663", NULL);
-    ok(f == 0, "f = %lf\n", f);
+    f = p_wcstof(L"\x0662\x0663", NULL); /* 23 in Arabic numerals */
+    todo_wine_if(is_arabic) ok(f == (is_arabic ? 23.0 : 0.0), "f = %lf\n", f);
 
     p_setlocale(LC_ALL, "C");
 }
@@ -742,11 +749,11 @@ static void test_critical_section(void)
     thread = (HANDLE)_beginthreadex(NULL, 0, test_critical_section_lock, NULL, 0, NULL);
     ok(thread != INVALID_HANDLE_VALUE, "_beginthread failed (%d)\n", errno);
     ret = WaitForSingleObject(thread, 100);
-    ok(ret == WAIT_TIMEOUT, "WaitForSingleObject returned  %d\n", ret);
+    ok(ret == WAIT_TIMEOUT, "WaitForSingleObject returned  %ld\n", ret);
     enter_flag = 1;
     call_func1(p_critical_section_unlock, &cs);
     ret = WaitForSingleObject(thread, INFINITE);
-    ok(ret == WAIT_OBJECT_0, "WaitForSingleObject returned %d\n", ret);
+    ok(ret == WAIT_OBJECT_0, "WaitForSingleObject returned %ld\n", ret);
     ret = CloseHandle(thread);
     ok(ret, "CloseHandle failed\n");
 
@@ -755,7 +762,7 @@ static void test_critical_section(void)
     thread = (HANDLE)_beginthreadex(NULL, 0, test_critical_section_try_lock, NULL, 0, NULL);
     ok(thread != INVALID_HANDLE_VALUE, "_beginthread failed (%d)\n", errno);
     ret = WaitForSingleObject(thread, INFINITE);
-    ok(ret == WAIT_OBJECT_0, "WaitForSingleObject returned %d\n", ret);
+    ok(ret == WAIT_OBJECT_0, "WaitForSingleObject returned %ld\n", ret);
     ret = CloseHandle(thread);
     ok(ret, "CloseHandle failed\n");
     call_func1(p_critical_section_unlock, &cs);
@@ -766,7 +773,7 @@ static void test_critical_section(void)
     thread = (HANDLE)_beginthreadex(NULL, 0, test_critical_section_try_lock, NULL, 0, NULL);
     ok(thread != INVALID_HANDLE_VALUE, "_beginthread failed (%d)\n", errno);
     ret = WaitForSingleObject(thread, INFINITE);
-    ok(ret == WAIT_OBJECT_0, "WaitForSingleObject returned %d\n", ret);
+    ok(ret == WAIT_OBJECT_0, "WaitForSingleObject returned %ld\n", ret);
     ret = CloseHandle(thread);
     ok(ret, "CloseHandle failed\n");
     thread = (HANDLE)_beginthreadex(NULL, 0, test_critical_section_try_lock_for, NULL, 0, NULL);
@@ -775,7 +782,7 @@ static void test_critical_section(void)
     Sleep(10);
     call_func1(p_critical_section_unlock, &cs);
     ret = WaitForSingleObject(thread, INFINITE);
-    ok(ret == WAIT_OBJECT_0, "WaitForSingleObject returned %d\n", ret);
+    ok(ret == WAIT_OBJECT_0, "WaitForSingleObject returned %ld\n", ret);
     ret = CloseHandle(thread);
     ok(ret, "CloseHandle failed\n");
 
@@ -784,11 +791,11 @@ static void test_critical_section(void)
     thread = (HANDLE)_beginthreadex(NULL, 0, test_critical_section_scoped_lock, NULL, 0, NULL);
     ok(thread != INVALID_HANDLE_VALUE, "_beginthread failed (%d)\n", errno);
     ret = WaitForSingleObject(thread, 100);
-    ok(ret == WAIT_TIMEOUT, "WaitForSingleObject returned  %d\n", ret);
+    ok(ret == WAIT_TIMEOUT, "WaitForSingleObject returned  %ld\n", ret);
     enter_flag = 1;
     call_func1(p_critical_section_unlock, &cs);
     ret = WaitForSingleObject(thread, INFINITE);
-    ok(ret == WAIT_OBJECT_0, "WaitForSingleObject returned %d\n", ret);
+    ok(ret == WAIT_OBJECT_0, "WaitForSingleObject returned %ld\n", ret);
     ret = CloseHandle(thread);
     ok(ret, "CloseHandle failed\n");
     call_func1(p_critical_section_dtor, &cs);
@@ -945,6 +952,22 @@ static void test_feenv(void)
     ok(!ret, "feclearexceptflag returned %x\n", ret);
     except = p_fetestexcept(FE_ALL_EXCEPT);
     ok(!except, "expected 0, got %lx\n", except);
+
+    p__clearfp();
+    except = FE_DIVBYZERO;
+    ret = p_fesetexceptflag(&except, FE_DIVBYZERO);
+    ok(!ret, "fesetexceptflag returned %x\n", ret);
+    ret = p_fegetenv(&env);
+    ok(!ret, "fegetenv returned %x\n", ret);
+    p__clearfp();
+    except = FE_INVALID;
+    ret = p_fesetexceptflag(&except, FE_INVALID);
+    ok(!ret, "fesetexceptflag returned %x\n", ret);
+    ret = p_feupdateenv(&env);
+    ok(!ret, "feupdateenv returned %x\n", ret);
+    ret = _statusfp();
+    ok(ret == (_EM_ZERODIVIDE | _EM_INVALID), "_statusfp returned %x\n", ret);
+    p__clearfp();
 }
 
 static void test__wcreate_locale(void)
@@ -1040,10 +1063,10 @@ static void test__Condition_variable(void)
 
     call_func1(p__Condition_variable_notify_one, &cv);
     ret = WaitForSingleObject(threads[1], 500);
-    ok(ret == WAIT_OBJECT_0, "WaitForSingleObject returned %d\n", ret);
+    ok(ret == WAIT_OBJECT_0, "WaitForSingleObject returned %ld\n", ret);
     call_func1(p__Condition_variable_notify_one, &cv);
     ret = WaitForSingleObject(threads[0], 500);
-    ok(ret == WAIT_OBJECT_0, "WaitForSingleObject returned %d\n", ret);
+    ok(ret == WAIT_OBJECT_0, "WaitForSingleObject returned %ld\n", ret);
 
     CloseHandle(threads[0]);
     CloseHandle(threads[1]);
@@ -1091,10 +1114,10 @@ static void test_wctype(void)
 static int WINAPIV _vsscanf_wrapper(const char *buffer, const char *format, ...)
 {
     int ret;
-    __ms_va_list valist;
-    __ms_va_start(valist, format);
+    va_list valist;
+    va_start(valist, format);
     ret = p_vsscanf(buffer, format, valist);
-    __ms_va_end(valist);
+    va_end(valist);
     return ret;
 }
 
