@@ -429,13 +429,13 @@ static void copy_threadlocinfo_category(pthreadlocinfo locinfo,
     if(!locinfo->lc_category[category].locale) {
         locinfo->lc_category[category].locale = old_locinfo->lc_category[category].locale;
         locinfo->lc_category[category].refcount = old_locinfo->lc_category[category].refcount;
-        InterlockedIncrement(locinfo->lc_category[category].refcount);
+        InterlockedIncrement((LONG *)locinfo->lc_category[category].refcount);
     }
 #if _MSVCR_VER >= 110
     locinfo->lc_name[category] = old_locinfo->lc_name[category];
     locinfo->lc_category[category].wrefcount = old_locinfo->lc_category[category].wrefcount;
     if(locinfo->lc_category[category].wrefcount)
-        InterlockedIncrement(locinfo->lc_category[category].wrefcount);
+        InterlockedIncrement((LONG *)locinfo->lc_category[category].wrefcount);
 #endif
 }
 
@@ -556,29 +556,29 @@ void CDECL _unlock_locales(void)
     _unlock(_SETLOCALE_LOCK);
 }
 
-static void CDECL grab_locinfo(pthreadlocinfo locinfo)
+static void grab_locinfo(pthreadlocinfo locinfo)
 {
     int i;
 
-    InterlockedIncrement(&locinfo->refcount);
+    InterlockedIncrement((LONG *)&locinfo->refcount);
     for(i=LC_MIN+1; i<=LC_MAX; i++)
     {
-        InterlockedIncrement(locinfo->lc_category[i].refcount);
+        InterlockedIncrement((LONG *)locinfo->lc_category[i].refcount);
         if(locinfo->lc_category[i].wrefcount)
-            InterlockedIncrement(locinfo->lc_category[i].wrefcount);
+            InterlockedIncrement((LONG *)locinfo->lc_category[i].wrefcount);
     }
     if(locinfo->lconv_intl_refcount)
-        InterlockedIncrement(locinfo->lconv_intl_refcount);
+        InterlockedIncrement((LONG *)locinfo->lconv_intl_refcount);
     if(locinfo->lconv_num_refcount)
-        InterlockedIncrement(locinfo->lconv_num_refcount);
+        InterlockedIncrement((LONG *)locinfo->lconv_num_refcount);
     if(locinfo->lconv_mon_refcount)
-        InterlockedIncrement(locinfo->lconv_mon_refcount);
+        InterlockedIncrement((LONG *)locinfo->lconv_mon_refcount);
     if(locinfo->ctype1_refcount)
-        InterlockedIncrement(locinfo->ctype1_refcount);
+        InterlockedIncrement((LONG *)locinfo->ctype1_refcount);
     InterlockedIncrement(&locinfo->lc_time_curr->refcount);
 }
 
-static void CDECL update_thread_locale(thread_data_t *data)
+static void update_thread_locale(thread_data_t *data)
 {
     if((data->locale_flags & LOCALE_FREE) && ((data->locale_flags & LOCALE_THREAD) ||
                 (data->locinfo == MSVCRT_locale->locinfo && data->mbcinfo == MSVCRT_locale->mbcinfo)))
@@ -854,7 +854,7 @@ int CDECL __crtLCMapStringA(
     WCHAR buf_out[32], *out = buf_out;
     int in_len, out_len, r;
 
-    TRACE("(lcid %x, flags %x, %s(%d), %p(%d), %x, %d), partial stub!\n",
+    TRACE("(lcid %lx, flags %lx, %s(%d), %p(%d), %x, %d), partial stub!\n",
             lcid, mapflags, src, srclen, dst, dstlen, codepage, xflag);
 
     in_len = MultiByteToWideChar(codepage, MB_ERR_INVALID_CHARS, src, srclen, NULL, 0);
@@ -904,7 +904,7 @@ done:
 int CDECL __crtLCMapStringW(LCID lcid, DWORD mapflags, const wchar_t *src,
         int srclen, wchar_t *dst, int dstlen, unsigned int codepage, int xflag)
 {
-    FIXME("(lcid %x, flags %x, %s(%d), %p(%d), %x, %d), partial stub!\n",
+    FIXME("(lcid %lx, flags %lx, %s(%d), %p(%d), %x, %d), partial stub!\n",
             lcid, mapflags, debugstr_w(src), srclen, dst, dstlen, codepage, xflag);
 
     return LCMapStringW(lcid, mapflags, src, srclen, dst, dstlen);
@@ -916,7 +916,7 @@ int CDECL __crtLCMapStringW(LCID lcid, DWORD mapflags, const wchar_t *src,
 int CDECL __crtCompareStringA( LCID lcid, DWORD flags, const char *src1, int len1,
                                const char *src2, int len2 )
 {
-    FIXME("(lcid %x, flags %x, %s(%d), %s(%d), partial stub\n",
+    FIXME("(lcid %lx, flags %lx, %s(%d), %s(%d), partial stub\n",
           lcid, flags, debugstr_a(src1), len1, debugstr_a(src2), len2 );
     /* FIXME: probably not entirely right */
     return CompareStringA( lcid, flags, src1, len1, src2, len2 );
@@ -928,7 +928,7 @@ int CDECL __crtCompareStringA( LCID lcid, DWORD flags, const char *src1, int len
 int CDECL __crtCompareStringW( LCID lcid, DWORD flags, const wchar_t *src1, int len1,
                                const wchar_t *src2, int len2 )
 {
-    FIXME("(lcid %x, flags %x, %s(%d), %s(%d), partial stub\n",
+    FIXME("(lcid %lx, flags %lx, %s(%d), %s(%d), partial stub\n",
           lcid, flags, debugstr_w(src1), len1, debugstr_w(src2), len2 );
     /* FIXME: probably not entirely right */
     return CompareStringW( lcid, flags, src1, len1, src2, len2 );
@@ -939,7 +939,7 @@ int CDECL __crtCompareStringW( LCID lcid, DWORD flags, const wchar_t *src1, int
  */
 int CDECL __crtGetLocaleInfoW( LCID lcid, LCTYPE type, wchar_t *buffer, int len )
 {
-    FIXME("(lcid %x, type %x, %p(%d), partial stub\n", lcid, type, buffer, len );
+    FIXME("(lcid %lx, type %lx, %p(%d), partial stub\n", lcid, type, buffer, len );
     /* FIXME: probably not entirely right */
     return GetLocaleInfoW( lcid, type, buffer, len );
 }
@@ -950,7 +950,7 @@ int CDECL __crtGetLocaleInfoW( LCID lcid, LCTYPE type, wchar_t *buffer, int len
  */
 int CDECL __crtGetLocaleInfoEx( const WCHAR *locale, LCTYPE type, wchar_t *buffer, int len )
 {
-    TRACE("(%s, %x, %p, %d)\n", debugstr_w(locale), type, buffer, len);
+    TRACE("(%s, %lx, %p, %d)\n", debugstr_w(locale), type, buffer, len);
     return GetLocaleInfoEx(locale, type, buffer, len);
 }
 #endif
@@ -964,7 +964,7 @@ int CDECL __crtGetLocaleInfoEx( const WCHAR *locale, LCTYPE type, wchar_t *buffe
 BOOL CDECL __crtGetStringTypeW(DWORD unk, DWORD type,
         wchar_t *buffer, int len, WORD *out)
 {
-    FIXME("(unk %x, type %x, wstr %p(%d), %p) partial stub\n",
+    FIXME("(unk %lx, type %lx, wstr %p(%d), %p) partial stub\n",
             unk, type, buffer, len, out);
 
     return GetStringTypeW(type, buffer, len, out);
@@ -1039,12 +1039,12 @@ void free_locinfo(pthreadlocinfo locinfo)
 
     for(i=LC_MIN+1; i<=LC_MAX; i++) {
         if(!locinfo->lc_category[i].refcount
-                || !InterlockedDecrement(locinfo->lc_category[i].refcount)) {
+                || !InterlockedDecrement((LONG *)locinfo->lc_category[i].refcount)) {
             free(locinfo->lc_category[i].locale);
             free(locinfo->lc_category[i].refcount);
         }
         if(!locinfo->lc_category[i].wrefcount
-                || !InterlockedDecrement(locinfo->lc_category[i].wrefcount)) {
+                || !InterlockedDecrement((LONG *)locinfo->lc_category[i].wrefcount)) {
 #if _MSVCR_VER >= 110
             free(locinfo->lc_name[i]);
 #endif
@@ -1053,7 +1053,7 @@ void free_locinfo(pthreadlocinfo locinfo)
     }
 
     if(locinfo->lconv_num_refcount
-            && !InterlockedDecrement(locinfo->lconv_num_refcount)) {
+            && !InterlockedDecrement((LONG *)locinfo->lconv_num_refcount)) {
         free(locinfo->lconv->decimal_point);
         free(locinfo->lconv->thousands_sep);
         free(locinfo->lconv->grouping);
@@ -1064,7 +1064,7 @@ void free_locinfo(pthreadlocinfo locinfo)
         free(locinfo->lconv_num_refcount);
     }
     if(locinfo->lconv_mon_refcount
-            && !InterlockedDecrement(locinfo->lconv_mon_refcount)) {
+            && !InterlockedDecrement((LONG *)locinfo->lconv_mon_refcount)) {
         free(locinfo->lconv->int_curr_symbol);
         free(locinfo->lconv->currency_symbol);
         free(locinfo->lconv->mon_decimal_point);
@@ -1083,13 +1083,13 @@ void free_locinfo(pthreadlocinfo locinfo)
         free(locinfo->lconv_mon_refcount);
     }
     if(locinfo->lconv_intl_refcount
-            && !InterlockedDecrement(locinfo->lconv_intl_refcount)) {
+            && !InterlockedDecrement((LONG *)locinfo->lconv_intl_refcount)) {
         free(locinfo->lconv_intl_refcount);
         free(locinfo->lconv);
     }
 
     if(locinfo->ctype1_refcount
-            && !InterlockedDecrement(locinfo->ctype1_refcount)) {
+            && !InterlockedDecrement((LONG *)locinfo->ctype1_refcount)) {
         free(locinfo->ctype1_refcount);
         free(locinfo->ctype1);
         free((void*)locinfo->pclmap);
@@ -1100,7 +1100,7 @@ void free_locinfo(pthreadlocinfo locinfo)
             && locinfo->lc_time_curr != &cloc_time_data)
         free(locinfo->lc_time_curr);
 
-    if(InterlockedDecrement(&locinfo->refcount))
+    if(InterlockedDecrement((LONG *)&locinfo->refcount))
         return;
 
     free(locinfo);
@@ -1398,7 +1398,7 @@ static pthreadlocinfo create_locinfo(int category,
         locinfo->pclmap = old_locinfo->pclmap;
         locinfo->pcumap = old_locinfo->pcumap;
         if(locinfo->ctype1_refcount)
-            InterlockedIncrement(locinfo->ctype1_refcount);
+            InterlockedIncrement((LONG *)locinfo->ctype1_refcount);
     } else if(lcid[LC_CTYPE]) {
         CPINFO cp_info;
         int j;
@@ -1480,7 +1480,7 @@ static pthreadlocinfo create_locinfo(int category,
         locinfo->lconv = old_locinfo->lconv;
         locinfo->lconv_intl_refcount = old_locinfo->lconv_intl_refcount;
         if(locinfo->lconv_intl_refcount)
-            InterlockedIncrement(locinfo->lconv_intl_refcount);
+            InterlockedIncrement((LONG *)locinfo->lconv_intl_refcount);
     } else if(lcid[LC_MONETARY] || lcid[LC_NUMERIC]) {
         locinfo->lconv = malloc(sizeof(struct lconv));
         locinfo->lconv_intl_refcount = malloc(sizeof(int));
@@ -1510,7 +1510,7 @@ static pthreadlocinfo create_locinfo(int category,
         copy_threadlocinfo_category(locinfo, old_locinfo, LC_MONETARY);
         locinfo->lconv_mon_refcount = old_locinfo->lconv_mon_refcount;
         if(locinfo->lconv_mon_refcount)
-            InterlockedIncrement(locinfo->lconv_mon_refcount);
+            InterlockedIncrement((LONG *)locinfo->lconv_mon_refcount);
         if(locinfo->lconv != &cloc_lconv && locinfo->lconv != old_locinfo->lconv) {
             locinfo->lconv->int_curr_symbol = old_locinfo->lconv->int_curr_symbol;
             locinfo->lconv->currency_symbol = old_locinfo->lconv->currency_symbol;
@@ -1785,7 +1785,7 @@ static pthreadlocinfo create_locinfo(int category,
         copy_threadlocinfo_category(locinfo, old_locinfo, LC_NUMERIC);
         locinfo->lconv_num_refcount = old_locinfo->lconv_num_refcount;
         if(locinfo->lconv_num_refcount)
-            InterlockedIncrement(locinfo->lconv_num_refcount);
+            InterlockedIncrement((LONG *)locinfo->lconv_num_refcount);
         if(locinfo->lconv != &cloc_lconv && locinfo->lconv != old_locinfo->lconv) {
             locinfo->lconv->decimal_point = old_locinfo->lconv->decimal_point;
             locinfo->lconv->thousands_sep = old_locinfo->lconv->thousands_sep;
