@@ -377,8 +377,8 @@ int fpnum_double(struct fpnum *fp, double *d)
         return 0;
     }
 
-    TRACE("%c %s *2^%d (round %d)\n", fp->sign == -1 ? '-' : '+',
-            wine_dbgstr_longlong(fp->m), fp->exp, fp->mod);
+    TRACE("%c %#I64x *2^%d (round %d)\n", fp->sign == -1 ? '-' : '+',
+            fp->m, fp->exp, fp->mod);
     if (!fp->m)
     {
         *d = fp->sign * 0.0;
@@ -467,7 +467,7 @@ int fpnum_double(struct fpnum *fp, double *d)
     bits |= (ULONGLONG)fp->exp << (MANT_BITS - 1);
     bits |= fp->m & (((ULONGLONG)1 << (MANT_BITS - 1)) - 1);
 
-    TRACE("returning %s\n", wine_dbgstr_longlong(bits));
+    TRACE("returning %#I64x\n", bits);
     *d = *(double*)&bits;
     return 0;
 }
@@ -496,8 +496,8 @@ int fpnum_ldouble(struct fpnum *fp, MSVCRT__LDOUBLE *d)
         return 0;
     }
 
-    TRACE("%c %s *2^%d (round %d)\n", fp->sign == -1 ? '-' : '+',
-            wine_dbgstr_longlong(fp->m), fp->exp, fp->mod);
+    TRACE("%c %#I64x *2^%d (round %d)\n", fp->sign == -1 ? '-' : '+',
+            fp->m, fp->exp, fp->mod);
     if (!fp->m)
     {
         d->x80[0] = 0;
@@ -1922,26 +1922,7 @@ static int ltoa_helper(__msvcrt_long value, char *str, size_t size, int radix)
     return 0;
 }
 
-/*********************************************************************
- *  _ltoa_s (MSVCRT.@)
- */
-int CDECL _ltoa_s(__msvcrt_long value, char *str, size_t size, int radix)
-{
-    if (!MSVCRT_CHECK_PMT(str != NULL)) return EINVAL;
-    if (!MSVCRT_CHECK_PMT(size > 0)) return EINVAL;
-    if (!MSVCRT_CHECK_PMT(radix >= 2 && radix <= 36))
-    {
-        str[0] = '\0';
-        return EINVAL;
-    }
-
-    return ltoa_helper(value, str, size, radix);
-}
-
-/*********************************************************************
- *  _ltow_s (MSVCRT.@)
- */
-int CDECL _ltow_s(__msvcrt_long value, wchar_t *str, size_t size, int radix)
+static int ltow_helper(__msvcrt_long value, wchar_t *str, size_t size, int radix)
 {
     __msvcrt_ulong val;
     unsigned int digit;
@@ -1949,14 +1930,6 @@ int CDECL _ltow_s(__msvcrt_long value, wchar_t *str, size_t size, int radix)
     wchar_t buffer[33], *pos;
     size_t len;
 
-    if (!MSVCRT_CHECK_PMT(str != NULL)) return EINVAL;
-    if (!MSVCRT_CHECK_PMT(size > 0)) return EINVAL;
-    if (!MSVCRT_CHECK_PMT(radix >= 2 && radix <= 36))
-    {
-        str[0] = '\0';
-        return EINVAL;
-    }
-
     if (value < 0 && radix == 10)
     {
         is_negative = TRUE;
@@ -2013,6 +1986,38 @@ int CDECL _ltow_s(__msvcrt_long value, wchar_t *str, size_t size, int radix)
     return 0;
 }
 
+/*********************************************************************
+ *  _ltoa_s (MSVCRT.@)
+ */
+int CDECL _ltoa_s(__msvcrt_long value, char *str, size_t size, int radix)
+{
+    if (!MSVCRT_CHECK_PMT(str != NULL)) return EINVAL;
+    if (!MSVCRT_CHECK_PMT(size > 0)) return EINVAL;
+    if (!MSVCRT_CHECK_PMT(radix >= 2 && radix <= 36))
+    {
+        str[0] = '\0';
+        return EINVAL;
+    }
+
+    return ltoa_helper(value, str, size, radix);
+}
+
+/*********************************************************************
+ *  _ltow_s (MSVCRT.@)
+ */
+int CDECL _ltow_s(__msvcrt_long value, wchar_t *str, size_t size, int radix)
+{
+    if (!MSVCRT_CHECK_PMT(str != NULL)) return EINVAL;
+    if (!MSVCRT_CHECK_PMT(size > 0)) return EINVAL;
+    if (!MSVCRT_CHECK_PMT(radix >= 2 && radix <= 36))
+    {
+        str[0] = '\0';
+        return EINVAL;
+    }
+
+    return ltow_helper(value, str, size, radix);
+}
+
 /*********************************************************************
  *  _itoa_s (MSVCRT.@)
  */
@@ -2029,6 +2034,14 @@ char* CDECL _itoa(int value, char *str, int radix)
     return ltoa_helper(value, str, SIZE_MAX, radix) ? NULL : str;
 }
 
+/*********************************************************************
+ *  _ltoa (MSVCRT.@)
+ */
+char* CDECL _ltoa(__msvcrt_long value, char *str, int radix)
+{
+    return ltoa_helper(value, str, SIZE_MAX, radix) ? NULL : str;
+}
+
 /*********************************************************************
  *  _itow_s (MSVCRT.@)
  */
@@ -2037,6 +2050,202 @@ int CDECL _itow_s(int value, wchar_t *str, size_t size, int radix)
     return _ltow_s(value, str, size, radix);
 }
 
+/*********************************************************************
+ *  _itow (MSVCRT.@)
+ */
+wchar_t* CDECL _itow(int value, wchar_t *str, int radix)
+{
+    return ltow_helper(value, str, SIZE_MAX, radix) ? NULL : str;
+}
+
+/*********************************************************************
+ *  _ltow (MSVCRT.@)
+ */
+wchar_t* CDECL _ltow(__msvcrt_long value, wchar_t *str, int radix)
+{
+    return ltow_helper(value, str, SIZE_MAX, radix) ? NULL : str;
+}
+
+/*********************************************************************
+ *  _ultoa (MSVCRT.@)
+ */
+char* CDECL _ultoa(__msvcrt_ulong value, char *str, int radix)
+{
+    char buffer[33], *pos;
+
+    pos = &buffer[32];
+    *pos = '\0';
+
+    do {
+	int digit = value % radix;
+	value /= radix;
+
+	if (digit < 10)
+	    *--pos = '0' + digit;
+        else
+	    *--pos = 'a' + digit - 10;
+    } while (value != 0);
+
+    memcpy(str, pos, buffer + 33 - pos);
+    return str;
+}
+
+/*********************************************************************
+ *  _ui64toa (MSVCRT.@)
+ */
+char* CDECL _ui64toa(unsigned __int64 value, char *str, int radix)
+{
+    char buffer[65], *pos;
+
+    pos = &buffer[64];
+    *pos = '\0';
+
+    do {
+	int digit = value % radix;
+	value /= radix;
+
+	if (digit < 10)
+	    *--pos = '0' + digit;
+        else
+	    *--pos = 'a' + digit - 10;
+    } while (value != 0);
+
+    memcpy(str, pos, buffer + 65 - pos);
+    return str;
+}
+
+/*********************************************************************
+ *  _ultow (MSVCRT.@)
+ */
+wchar_t* CDECL _ultow(__msvcrt_ulong value, wchar_t *str, int radix)
+{
+    wchar_t buffer[33], *pos;
+
+    pos = &buffer[32];
+    *pos = '\0';
+
+    do {
+	int digit = value % radix;
+	value /= radix;
+
+	if (digit < 10)
+	    *--pos = '0' + digit;
+        else
+	    *--pos = 'a' + digit - 10;
+    } while (value != 0);
+
+    memcpy(str, pos, (buffer + 33 - pos) * sizeof(wchar_t));
+    return str;
+}
+
+/*********************************************************************
+ *  _ui64tow (MSVCRT.@)
+ */
+wchar_t* CDECL _ui64tow(unsigned __int64 value, wchar_t *str, int radix)
+{
+    wchar_t buffer[65], *pos;
+
+    pos = &buffer[64];
+    *pos = '\0';
+
+    do {
+	int digit = value % radix;
+	value /= radix;
+
+	if (digit < 10)
+	    *--pos = '0' + digit;
+        else
+	    *--pos = 'a' + digit - 10;
+    } while (value != 0);
+
+    memcpy(str, pos, (buffer + 65 - pos) * sizeof(wchar_t));
+    return str;
+}
+
+/*********************************************************************
+ *  _i64toa (MSVCRT.@)
+ */
+char* CDECL _i64toa(__int64 value, char *str, int radix)
+{
+    unsigned __int64 val;
+    BOOL is_negative;
+    char buffer[65], *pos;
+
+    if (value < 0 && radix == 10)
+    {
+        is_negative = TRUE;
+        val = -value;
+    }
+    else
+    {
+        is_negative = FALSE;
+        val = value;
+    }
+
+    pos = buffer + 64;
+    *pos = '\0';
+
+    do
+    {
+        int digit = val % radix;
+        val /= radix;
+
+        if (digit < 10)
+            *--pos = '0' + digit;
+        else
+            *--pos = 'a' + digit - 10;
+    }
+    while (val != 0);
+
+    if (is_negative)
+        *--pos = '-';
+
+    memcpy(str, pos, buffer + 65 - pos);
+    return str;
+}
+
+/*********************************************************************
+ *  _i64tow (MSVCRT.@)
+ */
+wchar_t* CDECL _i64tow(__int64 value, wchar_t *str, int radix)
+{
+    unsigned __int64 val;
+    BOOL is_negative;
+    wchar_t buffer[65], *pos;
+
+    if (value < 0 && radix == 10)
+    {
+        is_negative = TRUE;
+        val = -value;
+    }
+    else
+    {
+        is_negative = FALSE;
+        val = value;
+    }
+
+    pos = buffer + 64;
+    *pos = '\0';
+
+    do
+    {
+        int digit = val % radix;
+        val /= radix;
+
+        if (digit < 10)
+            *--pos = '0' + digit;
+        else
+            *--pos = 'a' + digit - 10;
+    }
+    while (val != 0);
+
+    if (is_negative)
+        *--pos = '-';
+
+    memcpy(str, pos, (buffer + 65 - pos) * sizeof(wchar_t));
+    return str;
+}
+
 /*********************************************************************
  *  _ui64toa_s (MSVCRT.@)
  */
@@ -2855,13 +3064,84 @@ void * __cdecl memcpy(void *dst, const void *src, size_t n)
     return memmove(dst, src, n);
 }
 
+/*********************************************************************
+ *                  _memccpy   (MSVCRT.@)
+ */
+void * __cdecl _memccpy(void *dst, const void *src, int c, size_t n)
+{
+    unsigned char *d = dst;
+    const unsigned char *s = src;
+    while (n--) if ((*d++ = *s++) == (unsigned char)c) return d;
+    return NULL;
+}
+
+
+static inline void memset_aligned_32(unsigned char *d, uint64_t v, size_t n)
+{
+    unsigned char *end = d + n;
+    while (d < end)
+    {
+        *(uint64_t *)(d + 0) = v;
+        *(uint64_t *)(d + 8) = v;
+        *(uint64_t *)(d + 16) = v;
+        *(uint64_t *)(d + 24) = v;
+        d += 32;
+    }
+}
+
 /*********************************************************************
  *		    memset (MSVCRT.@)
  */
-void* __cdecl memset(void *dst, int c, size_t n)
+void *__cdecl memset(void *dst, int c, size_t n)
 {
-    volatile unsigned char *d = dst;  /* avoid gcc optimizations */
-    while (n--) *d++ = c;
+    typedef uint64_t DECLSPEC_ALIGN(1) unaligned_ui64;
+    typedef uint32_t DECLSPEC_ALIGN(1) unaligned_ui32;
+    typedef uint16_t DECLSPEC_ALIGN(1) unaligned_ui16;
+
+    uint64_t v = 0x101010101010101ull * (unsigned char)c;
+    unsigned char *d = (unsigned char *)dst;
+    size_t a = 0x20 - ((uintptr_t)d & 0x1f);
+
+    if (n >= 16)
+    {
+        *(unaligned_ui64 *)(d + 0) = v;
+        *(unaligned_ui64 *)(d + 8) = v;
+        *(unaligned_ui64 *)(d + n - 16) = v;
+        *(unaligned_ui64 *)(d + n - 8) = v;
+        if (n <= 32) return dst;
+        *(unaligned_ui64 *)(d + 16) = v;
+        *(unaligned_ui64 *)(d + 24) = v;
+        *(unaligned_ui64 *)(d + n - 32) = v;
+        *(unaligned_ui64 *)(d + n - 24) = v;
+        if (n <= 64) return dst;
+
+        n = (n - a) & ~0x1f;
+        memset_aligned_32(d + a, v, n);
+        return dst;
+    }
+    if (n >= 8)
+    {
+        *(unaligned_ui64 *)d = v;
+        *(unaligned_ui64 *)(d + n - 8) = v;
+        return dst;
+    }
+    if (n >= 4)
+    {
+        *(unaligned_ui32 *)d = v;
+        *(unaligned_ui32 *)(d + n - 4) = v;
+        return dst;
+    }
+    if (n >= 2)
+    {
+        *(unaligned_ui16 *)d = v;
+        *(unaligned_ui16 *)(d + n - 2) = v;
+        return dst;
+    }
+    if (n >= 1)
+    {
+        *(uint8_t *)d = v;
+        return dst;
+    }
     return dst;
 }
 
@@ -3083,6 +3363,16 @@ size_t __cdecl strcspn(const char *str, const char *reject)
     return p - str;
 }
 
+/*********************************************************************
+ *                  strspn   (MSVCRT.@)
+ */
+size_t __cdecl strspn(const char *str, const char *accept)
+{
+    const char *ptr;
+    for (ptr = str; *ptr; ptr++) if (!strchr( accept, *ptr )) break;
+    return ptr - str;
+}
+
 /*********************************************************************
  *                  strpbrk   (MSVCRT.@)
  */
