@@ -41,7 +41,7 @@ WINE_DEFAULT_DEBUG_CHANNEL(plugplay);
 static inline const char *debugstr_propkey( const DEVPROPKEY *id )
 {
     if (!id) return "(null)";
-    return wine_dbg_sprintf( "{%s,%04x}", wine_dbgstr_guid( &id->fmtid ), id->pid );
+    return wine_dbg_sprintf( "{%s,%04lx}", wine_dbgstr_guid( &id->fmtid ), id->pid );
 }
 
 #define MAX_SERVICE_NAME 260
@@ -125,7 +125,7 @@ static NTSTATUS get_device_instance_id( DEVICE_OBJECT *device, WCHAR *buffer )
 
     if ((status = get_device_id( device, BusQueryDeviceID, &id )))
     {
-        ERR("Failed to get device ID, status %#x.\n", status);
+        ERR("Failed to get device ID, status %#lx.\n", status);
         return status;
     }
 
@@ -134,7 +134,7 @@ static NTSTATUS get_device_instance_id( DEVICE_OBJECT *device, WCHAR *buffer )
 
     if ((status = get_device_id( device, BusQueryInstanceID, &id )))
     {
-        ERR("Failed to get instance ID, status %#x.\n", status);
+        ERR("Failed to get instance ID, status %#lx.\n", status);
         return status;
     }
 
@@ -199,7 +199,7 @@ static void load_function_driver( DEVICE_OBJECT *device, HDEVINFO set, SP_DEVINF
     status = ZwLoadDriver( &string );
     if (status != STATUS_SUCCESS && status != STATUS_IMAGE_ALREADY_LOADED)
     {
-        ERR("Failed to load driver %s, status %#x.\n", debugstr_w(driver), status);
+        ERR("Failed to load driver %s, status %#lx.\n", debugstr_w(driver), status);
         return;
     }
 
@@ -218,12 +218,12 @@ static void load_function_driver( DEVICE_OBJECT *device, HDEVINFO set, SP_DEVINF
         status = driver_obj->DriverExtension->AddDevice( driver_obj, device );
     else
         status = STATUS_NOT_IMPLEMENTED;
-    TRACE("AddDevice routine %p returned %#x.\n", driver_obj->DriverExtension->AddDevice, status);
+    TRACE("AddDevice routine %p returned %#lx.\n", driver_obj->DriverExtension->AddDevice, status);
 
     ObDereferenceObject( driver_obj );
 
     if (status != STATUS_SUCCESS)
-        ERR("AddDevice failed for driver %s, status %#x.\n", debugstr_w(driver), status);
+        ERR("AddDevice failed for driver %s, status %#lx.\n", debugstr_w(driver), status);
 }
 
 /* Return the total number of characters in a REG_MULTI_SZ string, including
@@ -257,7 +257,7 @@ static BOOL install_device_driver( DEVICE_OBJECT *device, HDEVINFO set, SP_DEVIN
 
     if ((status = get_device_id( device, BusQueryHardwareIDs, &ids )) || !ids)
     {
-        ERR("Failed to get hardware IDs, status %#x.\n", status);
+        ERR("Failed to get hardware IDs, status %#lx.\n", status);
         return FALSE;
     }
 
@@ -267,7 +267,7 @@ static BOOL install_device_driver( DEVICE_OBJECT *device, HDEVINFO set, SP_DEVIN
 
     if ((status = get_device_id( device, BusQueryCompatibleIDs, &ids )) || !ids)
     {
-        ERR("Failed to get compatible IDs, status %#x.\n", status);
+        ERR("Failed to get compatible IDs, status %#lx.\n", status);
         return FALSE;
     }
 
@@ -277,7 +277,7 @@ static BOOL install_device_driver( DEVICE_OBJECT *device, HDEVINFO set, SP_DEVIN
 
     if (!SetupDiBuildDriverInfoList( set, sp_device, SPDIT_COMPATDRIVER ))
     {
-        ERR("Failed to build compatible driver list, error %#x.\n", GetLastError());
+        ERR("Failed to build compatible driver list, error %#lx.\n", GetLastError());
         return FALSE;
     }
 
@@ -285,7 +285,7 @@ static BOOL install_device_driver( DEVICE_OBJECT *device, HDEVINFO set, SP_DEVIN
     {
         if (!SetupDiCallClassInstaller(dif_list[i], set, sp_device) && GetLastError() != ERROR_DI_DO_DEFAULT)
         {
-            WARN("Install function %#x failed, error %#x.\n", dif_list[i], GetLastError());
+            WARN("Install function %#lx failed, error %#lx.\n", dif_list[i], GetLastError());
             return FALSE;
         }
     }
@@ -319,7 +319,7 @@ static void enumerate_new_device( DEVICE_OBJECT *device, HDEVINFO set )
     if (!SetupDiCreateDeviceInfoW( set, device_instance_id, &GUID_NULL, NULL, NULL, 0, &sp_device )
             && !SetupDiOpenDeviceInfoW( set, device_instance_id, NULL, 0, &sp_device ))
     {
-        ERR("Failed to create or open device %s, error %#x.\n", debugstr_w(device_instance_id), GetLastError());
+        ERR("Failed to create or open device %s, error %#lx.\n", debugstr_w(device_instance_id), GetLastError());
         return;
     }
 
@@ -337,7 +337,7 @@ static void enumerate_new_device( DEVICE_OBJECT *device, HDEVINFO set )
 
     if ((status = get_device_caps( device, &caps )))
     {
-        ERR("Failed to get caps for device %s, status %#x.\n", debugstr_w(device_instance_id), status);
+        ERR("Failed to get caps for device %s, status %#lx.\n", debugstr_w(device_instance_id), status);
         return;
     }
 
@@ -419,12 +419,12 @@ static void handle_bus_relations( DEVICE_OBJECT *parent )
     relations = (DEVICE_RELATIONS *)irp_status.Information;
     if (irp_status.u.Status)
     {
-        ERR("Failed to enumerate child devices, status %#x.\n", irp_status.u.Status);
+        ERR("Failed to enumerate child devices, status %#lx.\n", irp_status.u.Status);
         SetupDiDestroyDeviceInfoList( set );
         return;
     }
 
-    TRACE("Got %u devices.\n", relations->Count);
+    TRACE("Got %lu devices.\n", relations->Count);
 
     for (i = 0; i < relations->Count; ++i)
     {
@@ -488,7 +488,7 @@ NTSTATUS WINAPI IoGetDeviceProperty( DEVICE_OBJECT *device, DEVICE_REGISTRY_PROP
     NTSTATUS status;
     HDEVINFO set;
 
-    TRACE("device %p, property %u, length %u, buffer %p, needed %p.\n",
+    TRACE("device %p, property %u, length %lu, buffer %p, needed %p.\n",
             device, property, length, buffer, needed);
 
     switch (property)
@@ -500,7 +500,7 @@ NTSTATUS WINAPI IoGetDeviceProperty( DEVICE_OBJECT *device, DEVICE_REGISTRY_PROP
             status = get_device_id( device, BusQueryInstanceID, &id );
             if (status != STATUS_SUCCESS)
             {
-                ERR("Failed to get instance ID, status %#x.\n", status);
+                ERR("Failed to get instance ID, status %#lx.\n", status);
                 break;
             }
 
@@ -607,13 +607,13 @@ NTSTATUS WINAPI IoGetDeviceProperty( DEVICE_OBJECT *device, DEVICE_REGISTRY_PROP
 
     if ((set = SetupDiCreateDeviceInfoList( &GUID_NULL, NULL )) == INVALID_HANDLE_VALUE)
     {
-        ERR("Failed to create device list, error %#x.\n", GetLastError());
+        ERR("Failed to create device list, error %#lx.\n", GetLastError());
         return GetLastError();
     }
 
     if (!SetupDiOpenDeviceInfoW( set, device_instance_id, NULL, 0, &sp_device))
     {
-        ERR("Failed to open device, error %#x.\n", GetLastError());
+        ERR("Failed to open device, error %#lx.\n", GetLastError());
         SetupDiDestroyDeviceInfoList( set );
         return GetLastError();
     }
@@ -676,7 +676,7 @@ static void send_devicechange( DWORD code, void *data, unsigned int size )
     }
     __EXCEPT(rpc_filter)
     {
-        WARN("Failed to send event, exception %#x.\n", GetExceptionCode());
+        WARN("Failed to send event, exception %#lx.\n", GetExceptionCode());
     }
     __ENDTRY
 }
@@ -811,7 +811,7 @@ NTSTATUS WINAPI IoSetDevicePropertyData( DEVICE_OBJECT *device, const DEVPROPKEY
     NTSTATUS status;
     HDEVINFO set;
 
-    TRACE( "device %p, property_key %s, lcid %#x, flags %#x, type %#x, size %u, data %p.\n",
+    TRACE( "device %p, property_key %s, lcid %#lx, flags %#lx, type %#lx, size %lu, data %p.\n",
            device, debugstr_propkey(property_key), lcid, flags, type, size, data );
 
     /* flags is always treated as PLUGPLAY_PROPERTY_PERSISTENT starting with Win 8 / 2012 */
@@ -822,20 +822,20 @@ NTSTATUS WINAPI IoSetDevicePropertyData( DEVICE_OBJECT *device, const DEVPROPKEY
 
     if ((set = SetupDiCreateDeviceInfoList( &GUID_NULL, NULL )) == INVALID_HANDLE_VALUE)
     {
-        ERR( "Failed to create device list, error %#x.\n", GetLastError() );
+        ERR( "Failed to create device list, error %#lx.\n", GetLastError() );
         return GetLastError();
     }
 
     if (!SetupDiOpenDeviceInfoW( set, device_instance_id, NULL, 0, &sp_device ))
     {
-        ERR( "Failed to open device, error %#x.\n", GetLastError() );
+        ERR( "Failed to open device, error %#lx.\n", GetLastError() );
         SetupDiDestroyDeviceInfoList( set );
         return GetLastError();
     }
 
     if (!SetupDiSetDevicePropertyW( set, &sp_device, property_key, type, data, size, 0 ))
     {
-        ERR( "Failed to set property, error %#x.\n", GetLastError() );
+        ERR( "Failed to set property, error %#lx.\n", GetLastError() );
         SetupDiDestroyDeviceInfoList( set );
         return GetLastError();
     }
@@ -874,7 +874,7 @@ NTSTATUS WINAPI IoRegisterDeviceInterface(DEVICE_OBJECT *device, const GUID *cla
     if (!SetupDiCreateDeviceInfoW( set, device_instance_id, class_guid, NULL, NULL, 0, &sp_device )
             && !SetupDiOpenDeviceInfoW( set, device_instance_id, NULL, 0, &sp_device ))
     {
-        ERR("Failed to create device %s, error %#x.\n", debugstr_w(device_instance_id), GetLastError());
+        ERR("Failed to create device %s, error %#lx.\n", debugstr_w(device_instance_id), GetLastError());
         return GetLastError();
     }
 
@@ -935,11 +935,11 @@ NTSTATUS WINAPI IoOpenDeviceRegistryKey( DEVICE_OBJECT *device, ULONG type, ACCE
     NTSTATUS status;
     HDEVINFO set;
 
-    TRACE("device %p, type %#x, access %#x, key %p.\n", device, type, access, key);
+    TRACE("device %p, type %#lx, access %#lx, key %p.\n", device, type, access, key);
 
     if ((status = get_device_instance_id( device, device_instance_id )))
     {
-        ERR("Failed to get device instance ID, error %#x.\n", status);
+        ERR("Failed to get device instance ID, error %#lx.\n", status);
         return status;
     }
 
@@ -1098,17 +1098,17 @@ void pnp_manager_start(void)
 
     RtlInitUnicodeString( &driver_nameU, driver_nameW );
     if ((status = IoCreateDriver( &driver_nameU, pnp_manager_driver_entry )))
-        ERR("Failed to create PnP manager driver, status %#x.\n", status);
+        ERR("Failed to create PnP manager driver, status %#lx.\n", status);
 
     if ((err = RpcStringBindingComposeW( NULL, protseq, NULL, endpoint, NULL, &binding_str )))
     {
-        ERR("RpcStringBindingCompose() failed, error %#x\n", err);
+        ERR("RpcStringBindingCompose() failed, error %#lx\n", err);
         return;
     }
     err = RpcBindingFromStringBindingW( binding_str, &plugplay_binding_handle );
     RpcStringFreeW( &binding_str );
     if (err)
-        ERR("RpcBindingFromStringBinding() failed, error %#x\n", err);
+        ERR("RpcBindingFromStringBinding() failed, error %#lx\n", err);
 }
 
 void pnp_manager_stop_driver( struct wine_driver *driver )
@@ -1146,7 +1146,7 @@ void CDECL wine_enumerate_root_devices( const WCHAR *driver_name )
     set = SetupDiGetClassDevsW( NULL, rootW, NULL, DIGCF_ALLCLASSES );
     if (set == INVALID_HANDLE_VALUE)
     {
-        ERR("Failed to build device set, error %#x.\n", GetLastError());
+        ERR("Failed to build device set, error %#lx.\n", GetLastError());
         return;
     }
 
@@ -1174,7 +1174,7 @@ void CDECL wine_enumerate_root_devices( const WCHAR *driver_name )
         if ((status = IoCreateDevice( pnp_manager, sizeof(struct root_pnp_device), NULL,
                 FILE_DEVICE_CONTROLLER, FILE_AUTOGENERATED_DEVICE_NAME, FALSE, &device )))
         {
-            ERR("Failed to create root-enumerated PnP device %s, status %#x.\n", debugstr_w(id), status);
+            ERR("Failed to create root-enumerated PnP device %s, status %#lx.\n", debugstr_w(id), status);
             continue;
         }
 
