@@ -84,7 +84,7 @@ const struct win_class_data* find_class_data(HWND hwnd, const struct win_class_d
 HRESULT WINAPI CreateStdAccessibleObject( HWND hwnd, LONG idObject,
         REFIID riidInterface, void** ppvObject )
 {
-    TRACE("%p %d %s %p\n", hwnd, idObject,
+    TRACE("%p %ld %s %p\n", hwnd, idObject,
           debugstr_guid( riidInterface ), ppvObject );
 
     switch(idObject) {
@@ -93,7 +93,7 @@ HRESULT WINAPI CreateStdAccessibleObject( HWND hwnd, LONG idObject,
     case OBJID_WINDOW:
         return create_window_object(hwnd, riidInterface, ppvObject);
     default:
-        FIXME("unhandled object id: %d\n", idObject);
+        FIXME("unhandled object id: %ld\n", idObject);
         return E_NOTIMPL;
     }
 }
@@ -109,10 +109,10 @@ HRESULT WINAPI ObjectFromLresult( LRESULT result, REFIID riid, WPARAM wParam, vo
     HRESULT hr;
     WCHAR *p;
 
-    TRACE("%ld %s %ld %p\n", result, debugstr_guid(riid), wParam, ppObject );
+    TRACE("%Id %s %Id %p\n", result, debugstr_guid(riid), wParam, ppObject );
 
     if(wParam)
-        FIXME("unsupported wParam = %lx\n", wParam);
+        FIXME("unsupported wParam = %Ix\n", wParam);
 
     if(!ppObject)
         return E_INVALIDARG;
@@ -182,10 +182,10 @@ LRESULT WINAPI LresultFromObject( REFIID riid, WPARAM wParam, LPUNKNOWN pAcc )
     ATOM atom;
     void *view;
 
-    TRACE("%s %ld %p\n", debugstr_guid(riid), wParam, pAcc);
+    TRACE("%s %Id %p\n", debugstr_guid(riid), wParam, pAcc);
 
     if(wParam)
-        FIXME("unsupported wParam = %lx\n", wParam);
+        FIXME("unsupported wParam = %Ix\n", wParam);
 
     if(!pAcc)
         return E_INVALIDARG;
@@ -263,18 +263,77 @@ LRESULT WINAPI LresultFromObject( REFIID riid, WPARAM wParam, LPUNKNOWN pAcc )
     return atom;
 }
 
-HRESULT WINAPI AccessibleObjectFromPoint( POINT ptScreen, IAccessible** ppacc, VARIANT* pvarChild )
-{
-    FIXME("{%d,%d} %p %p: stub\n", ptScreen.x, ptScreen.y, ppacc, pvarChild );
-    return E_NOTIMPL;
-}
-
 static void variant_init_i4( VARIANT *v, int val )
 {
     V_VT(v) = VT_I4;
     V_I4(v) = val;
 }
 
+HRESULT WINAPI AccessibleObjectFromPoint( POINT point, IAccessible** acc, VARIANT* child_id )
+{
+    IAccessible *cur;
+    HRESULT hr;
+    VARIANT v;
+    HWND hwnd;
+
+    TRACE("{%ld,%ld} %p %p\n", point.x, point.y, acc, child_id);
+
+    if (!acc || !child_id)
+        return E_INVALIDARG;
+
+    *acc = NULL;
+    V_VT(child_id) = VT_EMPTY;
+
+    hwnd = WindowFromPoint(point);
+    if (!hwnd)
+        return E_FAIL;
+    hwnd = GetAncestor(hwnd, GA_ROOT);
+
+    hr = AccessibleObjectFromWindow(hwnd, OBJID_WINDOW, &IID_IAccessible, (void **)&cur);
+    if (FAILED(hr))
+        return hr;
+    if (!cur)
+        return E_FAIL;
+
+    V_VT(&v) = VT_EMPTY;
+    while (1)
+    {
+        hr = IAccessible_accHitTest(cur, point.x, point.y, &v);
+        if (FAILED(hr))
+        {
+            IAccessible_Release(cur);
+            return hr;
+        }
+
+        if (V_VT(&v) == VT_I4)
+        {
+            *acc = cur;
+            variant_init_i4(child_id, V_I4(&v));
+            return S_OK;
+        }
+        else if (V_VT(&v) == VT_DISPATCH)
+        {
+            IAccessible_Release(cur);
+
+            hr = IDispatch_QueryInterface(V_DISPATCH(&v), &IID_IAccessible, (void**)&cur);
+            VariantClear(&v);
+            if (FAILED(hr))
+                return hr;
+            if (!cur)
+                return E_FAIL;
+        }
+        else
+        {
+            VariantClear(&v);
+            IAccessible_Release(cur);
+            FIXME("unhandled variant type: %d\n", V_VT(&v));
+            return E_NOTIMPL;
+        }
+    }
+
+    return S_OK;
+}
+
 HRESULT WINAPI AccessibleObjectFromEvent( HWND hwnd, DWORD object_id, DWORD child_id,
                              IAccessible **acc_out, VARIANT *child_id_out )
 {
@@ -283,7 +342,7 @@ HRESULT WINAPI AccessibleObjectFromEvent( HWND hwnd, DWORD object_id, DWORD chil
     IDispatch *child = NULL;
     HRESULT hr;
 
-    TRACE("%p %d %d %p %p\n", hwnd, object_id, child_id, acc_out, child_id_out);
+    TRACE("%p %ld %ld %p %p\n", hwnd, object_id, child_id, acc_out, child_id_out);
 
     if (!acc_out)
         return E_INVALIDARG;
@@ -297,7 +356,7 @@ HRESULT WINAPI AccessibleObjectFromEvent( HWND hwnd, DWORD object_id, DWORD chil
     variant_init_i4(&child_id_variant, child_id);
     hr = IAccessible_get_accChild(acc, child_id_variant, &child);
     if (FAILED(hr))
-        TRACE("get_accChild failed with %#x!\n", hr);
+        TRACE("get_accChild failed with %#lx!\n", hr);
 
     if (SUCCEEDED(hr) && child)
     {
@@ -319,7 +378,7 @@ HRESULT WINAPI AccessibleObjectFromEvent( HWND hwnd, DWORD object_id, DWORD chil
 HRESULT WINAPI AccessibleObjectFromWindow( HWND hwnd, DWORD dwObjectID,
                              REFIID riid, void** ppvObject )
 {
-    TRACE("%p %d %s %p\n", hwnd, dwObjectID,
+    TRACE("%p %ld %s %p\n", hwnd, dwObjectID,
           debugstr_guid( riid ), ppvObject );
 
     if(!ppvObject)
@@ -376,7 +435,7 @@ HRESULT WINAPI WindowFromAccessibleObject(IAccessible *acc, HWND *phwnd)
 BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fdwReason,
                     LPVOID lpvReserved)
 {
-    TRACE("%p, %d, %p\n", hinstDLL, fdwReason, lpvReserved);
+    TRACE("%p, %ld, %p\n", hinstDLL, fdwReason, lpvReserved);
 
     switch (fdwReason)
     {
@@ -438,7 +497,7 @@ UINT WINAPI GetRoleTextW(DWORD role, LPWSTR lpRole, UINT rolemax)
     INT ret;
     WCHAR *resptr;
 
-    TRACE("%u %p %u\n", role, lpRole, rolemax);
+    TRACE("%lu %p %u\n", role, lpRole, rolemax);
 
     /* return role text length */
     if(!lpRole)
@@ -458,7 +517,7 @@ UINT WINAPI GetRoleTextA(DWORD role, LPSTR lpRole, UINT rolemax)
     UINT length;
     WCHAR *roletextW;
 
-    TRACE("%u %p %u\n", role, lpRole, rolemax);
+    TRACE("%lu %p %u\n", role, lpRole, rolemax);
 
     if(lpRole && !rolemax)
         return 0;
@@ -505,7 +564,7 @@ UINT WINAPI GetStateTextW(DWORD state_bit, WCHAR *state_str, UINT state_str_len)
 {
     DWORD state_id;
 
-    TRACE("%x %p %u\n", state_bit, state_str, state_str_len);
+    TRACE("%lx %p %u\n", state_bit, state_str, state_str_len);
 
     if(state_bit & ~(STATE_SYSTEM_VALID | STATE_SYSTEM_HASPOPUP)) {
         if(state_str && state_str_len)
@@ -535,7 +594,7 @@ UINT WINAPI GetStateTextA(DWORD state_bit, CHAR *state_str, UINT state_str_len)
 {
     DWORD state_id;
 
-    TRACE("%x %p %u\n", state_bit, state_str, state_str_len);
+    TRACE("%lx %p %u\n", state_bit, state_str, state_str_len);
 
     if(state_str && !state_str_len)
         return 0;
@@ -570,7 +629,7 @@ HRESULT WINAPI AccessibleChildren(IAccessible *container,
     LONG i, child_no;
     HRESULT hr;
 
-    TRACE("%p %d %d %p %p\n", container, start, count, children, children_cnt);
+    TRACE("%p %ld %ld %p %p\n", container, start, count, children, children_cnt);
 
     if(!container || !children || !children_cnt)
         return E_INVALIDARG;
