@@ -199,7 +199,7 @@ static ULONG WINAPI opc_part_enum_AddRef(IOpcPartEnumerator *iface)
     struct opc_part_enum *part_enum = impl_from_IOpcPartEnumerator(iface);
     ULONG refcount = InterlockedIncrement(&part_enum->refcount);
 
-    TRACE("%p increasing refcount to %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     return refcount;
 }
@@ -209,7 +209,7 @@ static ULONG WINAPI opc_part_enum_Release(IOpcPartEnumerator *iface)
     struct opc_part_enum *part_enum = impl_from_IOpcPartEnumerator(iface);
     ULONG refcount = InterlockedDecrement(&part_enum->refcount);
 
-    TRACE("%p decreasing refcount to %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     if (!refcount)
     {
@@ -360,7 +360,7 @@ static ULONG WINAPI opc_rel_enum_AddRef(IOpcRelationshipEnumerator *iface)
     struct opc_rel_enum *rel_enum = impl_from_IOpcRelationshipEnumerator(iface);
     ULONG refcount = InterlockedIncrement(&rel_enum->refcount);
 
-    TRACE("%p increasing refcount to %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     return refcount;
 }
@@ -370,7 +370,7 @@ static ULONG WINAPI opc_rel_enum_Release(IOpcRelationshipEnumerator *iface)
     struct opc_rel_enum *rel_enum = impl_from_IOpcRelationshipEnumerator(iface);
     ULONG refcount = InterlockedDecrement(&rel_enum->refcount);
 
-    TRACE("%p decreasing refcount to %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     if (!refcount)
     {
@@ -520,7 +520,7 @@ static ULONG WINAPI opc_content_stream_AddRef(IStream *iface)
     struct opc_content_stream *stream = impl_from_IStream(iface);
     ULONG refcount = InterlockedIncrement(&stream->refcount);
 
-    TRACE("%p increasing refcount to %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     return refcount;
 }
@@ -530,7 +530,7 @@ static ULONG WINAPI opc_content_stream_Release(IStream *iface)
     struct opc_content_stream *stream = impl_from_IStream(iface);
     ULONG refcount = InterlockedDecrement(&stream->refcount);
 
-    TRACE("%p decreasing refcount to %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     if (!refcount)
     {
@@ -546,7 +546,7 @@ static HRESULT WINAPI opc_content_stream_Read(IStream *iface, void *buff, ULONG
     struct opc_content_stream *stream = impl_from_IStream(iface);
     DWORD read = 0;
 
-    TRACE("iface %p, buff %p, size %u, num_read %p.\n", iface, buff, size, num_read);
+    TRACE("%p, %p, %lu, %p.\n", iface, buff, size, num_read);
 
     if (!num_read)
         num_read = &read;
@@ -569,7 +569,7 @@ static HRESULT WINAPI opc_content_stream_Write(IStream *iface, const void *data,
     struct opc_content_stream *stream = impl_from_IStream(iface);
     DWORD written = 0;
 
-    TRACE("iface %p, data %p, size %u, num_written %p.\n", iface, data, size, num_written);
+    TRACE("%p, %p, %lu, %p.\n", iface, data, size, num_written);
 
     if (!num_written)
         num_written = &written;
@@ -597,7 +597,7 @@ static HRESULT WINAPI opc_content_stream_Seek(IStream *iface, LARGE_INTEGER move
     struct opc_content_stream *stream = impl_from_IStream(iface);
     ULARGE_INTEGER pos;
 
-    TRACE("iface %p, move %s, origin %d, newpos %p.\n", iface, wine_dbgstr_longlong(move.QuadPart), origin, newpos);
+    TRACE("%p, %s, %ld, %p.\n", iface, wine_dbgstr_longlong(move.QuadPart), origin, newpos);
 
     switch (origin)
     {
@@ -611,7 +611,7 @@ static HRESULT WINAPI opc_content_stream_Seek(IStream *iface, LARGE_INTEGER move
         pos.QuadPart = stream->content->size.QuadPart + move.QuadPart;
         break;
     default:
-        WARN("Unknown origin mode %d.\n", origin);
+        WARN("Unknown origin mode %ld.\n", origin);
         return E_INVALIDARG;
     }
 
@@ -641,7 +641,7 @@ static HRESULT WINAPI opc_content_stream_CopyTo(IStream *iface, IStream *dest, U
 
 static HRESULT WINAPI opc_content_stream_Commit(IStream *iface, DWORD flags)
 {
-    FIXME("iface %p, flags %#x stub!\n", iface, flags);
+    FIXME("iface %p, flags %#lx stub!\n", iface, flags);
 
     return E_NOTIMPL;
 }
@@ -656,7 +656,7 @@ static HRESULT WINAPI opc_content_stream_Revert(IStream *iface)
 static HRESULT WINAPI opc_content_stream_LockRegion(IStream *iface, ULARGE_INTEGER offset,
         ULARGE_INTEGER size, DWORD lock_type)
 {
-    FIXME("iface %p, offset %s, size %s, lock_type %d stub!\n", iface, wine_dbgstr_longlong(offset.QuadPart),
+    FIXME("iface %p, offset %s, size %s, lock_type %ld stub!\n", iface, wine_dbgstr_longlong(offset.QuadPart),
             wine_dbgstr_longlong(size.QuadPart), lock_type);
 
     return E_NOTIMPL;
@@ -665,7 +665,7 @@ static HRESULT WINAPI opc_content_stream_LockRegion(IStream *iface, ULARGE_INTEG
 static HRESULT WINAPI opc_content_stream_UnlockRegion(IStream *iface, ULARGE_INTEGER offset, ULARGE_INTEGER size,
         DWORD lock_type)
 {
-    FIXME("iface %p, offset %s, size %s, lock_type %d stub!\n", iface, wine_dbgstr_longlong(offset.QuadPart),
+    FIXME("iface %p, offset %s, size %s, lock_type %ld stub!\n", iface, wine_dbgstr_longlong(offset.QuadPart),
             wine_dbgstr_longlong(size.QuadPart), lock_type);
 
     return E_NOTIMPL;
@@ -673,7 +673,7 @@ static HRESULT WINAPI opc_content_stream_UnlockRegion(IStream *iface, ULARGE_INT
 
 static HRESULT WINAPI opc_content_stream_Stat(IStream *iface, STATSTG *statstg, DWORD flag)
 {
-    FIXME("iface %p, statstg %p, flag %d stub!\n", iface, statstg, flag);
+    FIXME("iface %p, statstg %p, flag %ld stub!\n", iface, statstg, flag);
 
     return E_NOTIMPL;
 }
@@ -761,7 +761,7 @@ static ULONG WINAPI opc_part_AddRef(IOpcPart *iface)
     struct opc_part *part = impl_from_IOpcPart(iface);
     ULONG refcount = InterlockedIncrement(&part->refcount);
 
-    TRACE("%p increasing refcount to %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     return refcount;
 }
@@ -771,7 +771,7 @@ static ULONG WINAPI opc_part_Release(IOpcPart *iface)
     struct opc_part *part = impl_from_IOpcPart(iface);
     ULONG refcount = InterlockedDecrement(&part->refcount);
 
-    TRACE("%p decreasing refcount to %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     if (!refcount)
     {
@@ -933,7 +933,7 @@ static ULONG WINAPI opc_part_set_AddRef(IOpcPartSet *iface)
     struct opc_part_set *part_set = impl_from_IOpcPartSet(iface);
     ULONG refcount = InterlockedIncrement(&part_set->refcount);
 
-    TRACE("%p increasing refcount to %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     return refcount;
 }
@@ -943,7 +943,7 @@ static ULONG WINAPI opc_part_set_Release(IOpcPartSet *iface)
     struct opc_part_set *part_set = impl_from_IOpcPartSet(iface);
     ULONG refcount = InterlockedDecrement(&part_set->refcount);
 
-    TRACE("%p decreasing refcount to %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     if (!refcount)
     {
@@ -1070,7 +1070,7 @@ static ULONG WINAPI opc_relationship_AddRef(IOpcRelationship *iface)
     struct opc_relationship *relationship = impl_from_IOpcRelationship(iface);
     ULONG refcount = InterlockedIncrement(&relationship->refcount);
 
-    TRACE("%p increasing refcount to %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     return refcount;
 }
@@ -1080,7 +1080,7 @@ static ULONG WINAPI opc_relationship_Release(IOpcRelationship *iface)
     struct opc_relationship *relationship = impl_from_IOpcRelationship(iface);
     ULONG refcount = InterlockedDecrement(&relationship->refcount);
 
-    TRACE("%p decreasing refcount to %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     if (!refcount)
     {
@@ -1253,7 +1253,7 @@ static ULONG WINAPI opc_relationship_set_AddRef(IOpcRelationshipSet *iface)
     struct opc_relationship_set *relationship_set = impl_from_IOpcRelationshipSet(iface);
     ULONG refcount = InterlockedIncrement(&relationship_set->refcount);
 
-    TRACE("%p increasing refcount to %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     return refcount;
 }
@@ -1263,7 +1263,7 @@ static ULONG WINAPI opc_relationship_set_Release(IOpcRelationshipSet *iface)
     struct opc_relationship_set *relationship_set = impl_from_IOpcRelationshipSet(iface);
     ULONG refcount = InterlockedDecrement(&relationship_set->refcount);
 
-    TRACE("%p decreasing refcount to %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     if (!refcount)
     {
@@ -1432,7 +1432,7 @@ static ULONG WINAPI opc_package_AddRef(IOpcPackage *iface)
     struct opc_package *package = impl_from_IOpcPackage(iface);
     ULONG refcount = InterlockedIncrement(&package->refcount);
 
-    TRACE("%p increasing refcount to %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     return refcount;
 }
@@ -1442,7 +1442,7 @@ static ULONG WINAPI opc_package_Release(IOpcPackage *iface)
     struct opc_package *package = impl_from_IOpcPackage(iface);
     ULONG refcount = InterlockedDecrement(&package->refcount);
 
-    TRACE("%p decreasing refcount to %u.\n", iface, refcount);
+    TRACE("%p, refcount %lu.\n", iface, refcount);
 
     if (!refcount)
     {
