@@ -809,7 +809,7 @@ struct testfilter
     const AM_MEDIA_TYPE *mt;
     HANDLE eos_event;
     unsigned int sample_count, eos_count, new_segment_count;
-    REFERENCE_TIME seek_start, seek_end;
+    REFERENCE_TIME segment_start, segment_end, seek_start, seek_end;
 };
 
 static inline struct testfilter *impl_from_strmbase_filter(struct strmbase_filter *iface)
@@ -836,10 +836,21 @@ static void testfilter_destroy(struct strmbase_filter *iface)
     strmbase_filter_cleanup(&filter->filter);
 }
 
+static HRESULT testfilter_init_stream(struct strmbase_filter *iface)
+{
+    struct testfilter *filter = impl_from_strmbase_filter(iface);
+
+    filter->new_segment_count = 0;
+    filter->eos_count = 0;
+    filter->sample_count = 0;
+    return S_OK;
+}
+
 static const struct strmbase_filter_ops testfilter_ops =
 {
     .filter_get_pin = testfilter_get_pin,
     .filter_destroy = testfilter_destroy,
+    .filter_init_stream = testfilter_init_stream,
 };
 
 static HRESULT testsource_query_interface(struct strmbase_pin *iface, REFIID iid, void **out)
@@ -894,14 +905,6 @@ static HRESULT testsink_query_interface(struct strmbase_pin *iface, REFIID iid,
     return S_OK;
 }
 
-static HRESULT testsink_query_accept(struct strmbase_pin *iface, const AM_MEDIA_TYPE *mt)
-{
-    struct testfilter *filter = impl_from_strmbase_filter(iface->filter);
-    if (filter->mt && !compare_media_types(mt, filter->mt))
-        return S_FALSE;
-    return S_OK;
-}
-
 static HRESULT testsink_get_media_type(struct strmbase_pin *iface, unsigned int index, AM_MEDIA_TYPE *mt)
 {
     struct testfilter *filter = impl_from_strmbase_filter(iface->filter);
@@ -913,6 +916,28 @@ static HRESULT testsink_get_media_type(struct strmbase_pin *iface, unsigned int
     return VFW_S_NO_MORE_ITEMS;
 }
 
+static HRESULT testsink_connect(struct strmbase_sink *iface, IPin *peer, const AM_MEDIA_TYPE *mt)
+{
+    struct testfilter *filter = impl_from_strmbase_filter(iface->pin.filter);
+    AM_MEDIA_TYPE mt2;
+    IPin *peer2;
+    HRESULT hr;
+
+    hr = IPin_ConnectedTo(peer, &peer2);
+    ok(hr == S_OK, "Got hr %#x.\n", hr);
+    ok(peer2 == &iface->pin.IPin_iface, "Peer didn't match.\n");
+    IPin_Release(peer2);
+
+    hr = IPin_ConnectionMediaType(peer, &mt2);
+    ok(hr == S_OK, "Got hr %#x.\n", hr);
+    ok(compare_media_types(mt, &mt2), "Media types didn't match.\n");
+    FreeMediaType(&mt2);
+
+    if (filter->mt && !IsEqualGUID(&mt->majortype, &filter->mt->majortype))
+        return VFW_E_TYPE_NOT_ACCEPTED;
+    return S_OK;
+}
+
 static HRESULT WINAPI testsink_Receive(struct strmbase_sink *iface, IMediaSample *sample)
 {
     struct testfilter *filter = impl_from_strmbase_filter(iface->pin.filter);
@@ -960,22 +985,28 @@ static HRESULT testsink_new_segment(struct strmbase_sink *iface,
     IMediaSeeking *seeking;
     HRESULT hr;
 
+    if (winetest_debug > 1)
+        trace("%04x: Got segment with timestamps %I64d-%I64d.\n", GetCurrentThreadId(), start, end);
+
     ++filter->new_segment_count;
 
     IPin_QueryInterface(iface->pin.peer, &IID_IMediaSeeking, (void **)&seeking);
     hr = IMediaSeeking_GetPositions(seeking, &filter->seek_start, &filter->seek_end);
     ok(hr == S_OK, "Got hr %#x.\n", hr);
-    ok(rate == 1.0, "Got rate %.16e.\n", rate);
     IMediaSeeking_Release(seeking);
 
+    ok(start == filter->segment_start, "Expected start %I64d, got %I64d.\n", filter->segment_start, start);
+    ok(end == filter->segment_end, "Expected end %I64d, got %I64d.\n", filter->segment_end, end);
+    ok(rate == 1.0, "Got rate %.16e.\n", rate);
+
     return S_OK;
 }
 
 static const struct strmbase_sink_ops testsink_ops =
 {
     .base.pin_query_interface = testsink_query_interface,
-    .base.pin_query_accept = testsink_query_accept,
     .base.pin_get_media_type = testsink_get_media_type,
+    .sink_connect = testsink_connect,
     .pfnReceive = testsink_Receive,
     .sink_eos = testsink_eos,
     .sink_new_segment = testsink_new_segment,
@@ -1067,6 +1098,7 @@ static void testfilter_init(struct testfilter *filter)
     strmbase_sink_init(&filter->sink, &filter->filter, L"sink", &testsink_ops, NULL);
     filter->IAsyncReader_iface.lpVtbl = &async_reader_vtbl;
     filter->eos_event = CreateEventW(NULL, FALSE, FALSE, NULL);
+    filter->segment_end = 50000000;
 }
 
 static void test_filter_state(IMediaControl *control)
@@ -1339,6 +1371,8 @@ static void test_connect_pin(void)
     hr = IFilterGraph2_ConnectDirect(graph, source, &testsink.sink.pin.IPin_iface, &req_mt);
     ok(hr == VFW_E_NO_ACCEPTABLE_TYPES, "Got hr %#x.\n", hr);
 
+    /* Test enumeration of sink media types. */
+
     testsink.mt = &req_mt;
     hr = IFilterGraph2_ConnectDirect(graph, source, &testsink.sink.pin.IPin_iface, NULL);
     ok(hr == VFW_E_NO_ACCEPTABLE_TYPES, "Got hr %#x.\n", hr);
@@ -1346,8 +1380,10 @@ static void test_connect_pin(void)
     req_mt.majortype = MEDIATYPE_Video;
     req_mt.subtype = MEDIASUBTYPE_I420;
     req_mt.formattype = FORMAT_VideoInfo;
+    req_mt.lSampleSize = 444;
     hr = IFilterGraph2_ConnectDirect(graph, source, &testsink.sink.pin.IPin_iface, NULL);
     ok(hr == S_OK, "Got hr %#x.\n", hr);
+    ok(compare_media_types(&testsink.sink.pin.mt, &req_mt), "Media types didn't match.\n");
 
     IPin_Release(source);
     hr = IFilterGraph2_Disconnect(graph, sink);
@@ -1537,7 +1573,7 @@ static void test_seeking(void)
     duration = 0;
     hr = IMediaSeeking_GetDuration(seeking, &duration);
     ok(hr == S_OK, "Got hr %#x.\n", hr);
-    ok(duration > 0, "Got duration %s.\n", wine_dbgstr_longlong(duration));
+    ok(duration == 50000000, "Got duration %I64d.\n", duration);
 
     stop = current = 0xdeadbeef;
     hr = IMediaSeeking_GetStopPosition(seeking, &stop);
@@ -1671,7 +1707,6 @@ static void test_streaming(void)
     ok(WaitForSingleObject(testsink.eos_event, 100) == WAIT_TIMEOUT, "Got more than one EOS.\n");
     ok(testsink.sample_count, "Expected at least one sample.\n");
 
-    testsink.sample_count = testsink.eos_count = 0;
     hr = IMediaControl_Stop(control);
     ok(hr == S_OK, "Got hr %#x.\n", hr);
     hr = IMediaControl_Pause(control);
@@ -1681,11 +1716,11 @@ static void test_streaming(void)
     ok(WaitForSingleObject(testsink.eos_event, 100) == WAIT_TIMEOUT, "Got more than one EOS.\n");
     ok(testsink.sample_count, "Expected at least one sample.\n");
 
-    testsink.sample_count = testsink.eos_count = 0;
-    start = 1500 * 10000;
-    end = 3500 * 10000;
-    hr = IMediaSeeking_SetPositions(seeking, &start, AM_SEEKING_AbsolutePositioning,
-            &end, AM_SEEKING_AbsolutePositioning);
+    testsink.new_segment_count = testsink.sample_count = testsink.eos_count = 0;
+    testsink.segment_start = 1500 * 10000;
+    testsink.segment_end = 3500 * 10000;
+    hr = IMediaSeeking_SetPositions(seeking, &testsink.segment_start, AM_SEEKING_AbsolutePositioning,
+            &testsink.segment_end, AM_SEEKING_AbsolutePositioning);
     ok(hr == S_OK, "Got hr %#x.\n", hr);
 
     ok(!WaitForSingleObject(testsink.eos_event, 1000), "Did not receive EOS.\n");
@@ -1698,7 +1733,6 @@ static void test_streaming(void)
     ok(start == testsink.seek_start, "Expected start position %I64u, got %I64u.\n", testsink.seek_start, start);
     ok(end == testsink.seek_end, "Expected end position %I64u, got %I64u.\n", testsink.seek_end, end);
 
-    testsink.sample_count = testsink.eos_count = 0;
     hr = IMediaControl_Stop(control);
     ok(hr == S_OK, "Got hr %#x.\n", hr);
     hr = IMediaControl_Pause(control);
