@@ -39,14 +39,14 @@ static void ME_SetCursorToEnd(ME_TextEditor *editor, ME_Cursor *cursor, BOOL fin
 }
 
 
-int ME_GetSelectionOfs(ME_TextEditor *editor, int *from, int *to)
+int ME_GetSelectionOfs(ME_TextEditor *editor, LONG *from, LONG *to)
 {
   *from = ME_GetCursorOfs(&editor->pCursors[0]);
   *to =   ME_GetCursorOfs(&editor->pCursors[1]);
 
   if (*from > *to)
   {
-    int tmp = *from;
+    LONG tmp = *from;
     *from = *to;
     *to = tmp;
     return 1;
@@ -160,7 +160,7 @@ int set_selection_cursors(ME_TextEditor *editor, int from, int to)
     /* deselected and caret moved to end of the current selection */
     if (from < 0)
     {
-      int start, end;
+      LONG start, end;
       ME_GetSelectionOfs(editor, &start, &end);
       if (start != end)
       {
@@ -993,32 +993,17 @@ static BOOL cursor_from_virtual_coords( ME_TextEditor *editor, int x, int y,
  *
  * x & y are pixel positions in client coordinates.
  *
- * isExact will be set to TRUE if the run is directly under the pixel
- * position, FALSE if it not, unless isExact is set to NULL.
- *
- * return FALSE if outside client area and the cursor is not set,
- * otherwise TRUE is returned.
+ * return TRUE if the run is directly under the pixel
+ * position, FALSE if it not.
  */
-BOOL ME_CharFromPos(ME_TextEditor *editor, int x, int y,
-                    ME_Cursor *cursor, BOOL *isExact)
+BOOL cursor_from_coords( ME_TextEditor *editor, int x, int y, ME_Cursor *cursor )
 {
-  RECT rc;
-  BOOL bResult;
-
-  ITextHost_TxGetClientRect(editor->texthost, &rc);
-  if (x < 0 || y < 0 || x >= rc.right || y >= rc.bottom) {
-    if (isExact) *isExact = FALSE;
-    return FALSE;
-  }
-  x += editor->horz_si.nPos;
-  y += editor->vert_si.nPos;
-  bResult = cursor_from_virtual_coords( editor, x, y, cursor, FALSE );
-  if (isExact) *isExact = bResult;
-  return TRUE;
+    x += editor->horz_si.nPos;
+    y += editor->vert_si.nPos;
+    return cursor_from_virtual_coords( editor, x, y, cursor, FALSE );
 }
 
 
-
 /* Extends the selection with a word, line, or paragraph selection type.
  *
  * The selection is anchored by editor->pCursors[2-3] such that the text
@@ -1368,7 +1353,7 @@ BOOL ME_IsSelection(ME_TextEditor *editor)
 
 void ME_DeleteSelection(ME_TextEditor *editor)
 {
-  int from, to;
+  LONG from, to;
   int nStartCursor = ME_GetSelectionOfs(editor, &from, &to);
   int nEndCursor = nStartCursor ^ 1;
   ME_DeleteTextAtCursor(editor, nStartCursor, to - from);
@@ -1402,7 +1387,7 @@ void ME_SendSelChange(ME_TextEditor *editor)
 
     if (editor->nEventMask & ENM_SELCHANGE)
     {
-      TRACE("cpMin=%d cpMax=%d seltyp=%d (%s %s)\n",
+      TRACE("cpMin=%ld cpMax=%ld seltyp=%d (%s %s)\n",
             sc.chrg.cpMin, sc.chrg.cpMax, sc.seltyp,
             (sc.seltyp & SEL_TEXT) ? "SEL_TEXT" : "",
             (sc.seltyp & SEL_MULTICHAR) ? "SEL_MULTICHAR" : "");
