@@ -73,7 +73,7 @@ static ULONG WINAPI data_key_AddRef( ISpRegDataKey *iface )
     struct data_key *This = impl_from_ISpRegDataKey( iface );
     ULONG ref = InterlockedIncrement( &This->ref );
 
-    TRACE( "(%p) ref = %u\n", This, ref );
+    TRACE( "(%p) ref = %lu\n", This, ref );
     return ref;
 }
 
@@ -82,7 +82,7 @@ static ULONG WINAPI data_key_Release( ISpRegDataKey *iface )
     struct data_key *This = impl_from_ISpRegDataKey( iface );
     ULONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE( "(%p) ref = %u\n", This, ref );
+    TRACE( "(%p) ref = %lu\n", This, ref );
 
     if (!ref)
     {
@@ -265,7 +265,7 @@ static ULONG WINAPI token_category_AddRef( ISpObjectTokenCategory *iface )
     struct token_category *This = impl_from_ISpObjectTokenCategory( iface );
     ULONG ref = InterlockedIncrement( &This->ref );
 
-    TRACE( "(%p) ref = %u\n", This, ref );
+    TRACE( "(%p) ref = %lu\n", This, ref );
     return ref;
 }
 
@@ -274,7 +274,7 @@ static ULONG WINAPI token_category_Release( ISpObjectTokenCategory *iface )
     struct token_category *This = impl_from_ISpObjectTokenCategory( iface );
     ULONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE( "(%p) ref = %u\n", This, ref );
+    TRACE( "(%p) ref = %lu\n", This, ref );
 
     if (!ref)
     {
@@ -514,7 +514,7 @@ static HRESULT WINAPI token_category_GetDefaultTokenId( ISpObjectTokenCategory *
         return SPERR_NOT_FOUND;
     } else if (res != ERROR_SUCCESS) {
         /* probably not the correct return value */
-        FIXME( "returning %08x\n", res );
+        FIXME( "returning %08lx\n", res );
         return res;
     }
 
@@ -606,7 +606,7 @@ static ULONG WINAPI token_enum_AddRef( ISpObjectTokenEnumBuilder *iface )
     struct token_enum *This = impl_from_ISpObjectTokenEnumBuilder( iface );
     ULONG ref = InterlockedIncrement( &This->ref );
 
-    TRACE( "(%p) ref = %u\n", This, ref );
+    TRACE( "(%p) ref = %lu\n", This, ref );
     return ref;
 }
 
@@ -615,7 +615,7 @@ static ULONG WINAPI token_enum_Release( ISpObjectTokenEnumBuilder *iface )
     struct token_enum *This = impl_from_ISpObjectTokenEnumBuilder( iface );
     ULONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE( "(%p) ref = %u\n", This, ref );
+    TRACE( "(%p) ref = %lu\n", This, ref );
 
     if (!ref)
     {
@@ -633,7 +633,7 @@ static HRESULT WINAPI token_enum_Next( ISpObjectTokenEnumBuilder *iface,
 {
     struct token_enum *This = impl_from_ISpObjectTokenEnumBuilder( iface );
 
-    TRACE( "(%p)->(%u %p %p)\n", This, num, tokens, fetched );
+    TRACE( "(%p)->(%lu %p %p)\n", This, num, tokens, fetched );
 
     if (!This->init) return SPERR_UNINITIALIZED;
 
@@ -817,7 +817,7 @@ static ULONG WINAPI token_AddRef( ISpObjectToken *iface )
     struct object_token *This = impl_from_ISpObjectToken( iface );
     ULONG ref = InterlockedIncrement( &This->ref );
 
-    TRACE( "(%p) ref = %u\n", This, ref );
+    TRACE( "(%p) ref = %lu\n", This, ref );
     return ref;
 }
 
@@ -826,7 +826,7 @@ static ULONG WINAPI token_Release( ISpObjectToken *iface )
     struct object_token *This = impl_from_ISpObjectToken( iface );
     ULONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE( "(%p) ref = %u\n", This, ref );
+    TRACE( "(%p) ref = %lu\n", This, ref );
 
     if (!ref)
     {
