@@ -493,15 +493,15 @@ START_TEST(rpcapi)
     ok(state == TASK_STATE_DISABLED, "expected TASK_STATE_DISABLED, got %u\n", state);
 
     hr = SchRpcEnableTask(L"\\Wine\\Task1", 0xdeadbeef);
-todo_wine
+    todo_wine
     ok(hr == S_OK, "expected S_OK, got %#x\n", hr);
 
     enabled = state = 0xdeadbeef;
     hr = SchRpcGetTaskInfo(L"\\Wine\\Task1", SCH_FLAG_STATE, &enabled, &state);
     ok(hr == S_OK, "expected S_OK, got %#x\n", hr);
-todo_wine
+    todo_wine
     ok(enabled == 1, "expected 1, got %u\n", enabled);
-todo_wine
+    todo_wine
     ok(state == TASK_STATE_READY, "expected TASK_STATE_READY, got %u\n", state);
 
     hr = SchRpcDelete(L"Wine\\Task1", 0);
@@ -520,7 +520,10 @@ todo_wine
     if (hr != E_ACCESSDENIED)
     {
         ok(!info, "expected NULL, info %p\n", info);
-        hr = IIDFromString(path, &iid);
+        if (path[0] == '\\')
+            hr = IIDFromString(path + 1, &iid);
+        else
+            hr = IIDFromString(path, &iid);
         ok(hr == S_OK, "IIDFromString(%s) error %#x\n", wine_dbgstr_w(path), hr);
         hr = SchRpcDelete(path, 0);
         ok(hr == S_OK, "expected S_OK, got %#x\n", hr);
