@@ -18,15 +18,15 @@
  */
 
 #include <stdarg.h>
+#include <stdlib.h>
 #include "windef.h"
 #include "winbase.h"
 #include "sspi.h"
 #include "rpc.h"
 #include "wincred.h"
-#include "secur32_priv.h"
 
 #include "wine/debug.h"
-#include "wine/unicode.h"
+#include "secur32_priv.h"
 
 WINE_DEFAULT_DEBUG_CHANNEL(secur32);
 
@@ -36,7 +36,7 @@ WINE_DEFAULT_DEBUG_CHANNEL(secur32);
 static SECURITY_STATUS SEC_ENTRY nego_QueryCredentialsAttributesA(
     PCredHandle phCredential, ULONG ulAttribute, PVOID pBuffer)
 {
-    FIXME("%p, %u, %p\n", phCredential, ulAttribute, pBuffer);
+    FIXME("%p, %lu, %p\n", phCredential, ulAttribute, pBuffer);
     return SEC_E_UNSUPPORTED_FUNCTION;
 }
 
@@ -46,7 +46,7 @@ static SECURITY_STATUS SEC_ENTRY nego_QueryCredentialsAttributesA(
 static SECURITY_STATUS SEC_ENTRY nego_QueryCredentialsAttributesW(
     PCredHandle phCredential, ULONG ulAttribute, PVOID pBuffer)
 {
-    FIXME("%p, %u, %p\n", phCredential, ulAttribute, pBuffer);
+    FIXME("%p, %lu, %p\n", phCredential, ulAttribute, pBuffer);
     return SEC_E_UNSUPPORTED_FUNCTION;
 }
 
@@ -58,6 +58,8 @@ struct sec_handle
     SecHandle       handle_ntlm;
 };
 
+#define WINE_NO_CACHED_CREDENTIALS 0x10000000
+
 /***********************************************************************
  *              AcquireCredentialsHandleW
  */
@@ -72,12 +74,12 @@ static SECURITY_STATUS SEC_ENTRY nego_AcquireCredentialsHandleW(
     struct sec_handle *cred;
     SecurePackage *package;
 
-    TRACE("%s, %s, 0x%08x, %p, %p, %p, %p, %p, %p\n",
+    TRACE("%s, %s, 0x%08lx, %p, %p, %p, %p, %p, %p\n",
           debugstr_w(pszPrincipal), debugstr_w(pszPackage), fCredentialUse,
           pLogonID, pAuthData, pGetKeyFn, pGetKeyArgument, phCredential, ptsExpiry);
 
     if (!pszPackage) return SEC_E_SECPKG_NOT_FOUND;
-    if (!(cred = heap_alloc_zero( sizeof(*cred) ))) return SEC_E_INSUFFICIENT_MEMORY;
+    if (!(cred = calloc( 1, sizeof(*cred) ))) return SEC_E_INSUFFICIENT_MEMORY;
 
     if ((package = SECUR32_findPackageW( kerberosW )))
     {
@@ -88,14 +90,11 @@ static SECURITY_STATUS SEC_ENTRY nego_AcquireCredentialsHandleW(
 
     if ((package = SECUR32_findPackageW( ntlmW )))
     {
+        ULONG cred_use = pAuthData ? fCredentialUse : fCredentialUse | WINE_NO_CACHED_CREDENTIALS;
+
         ret = package->provider->fnTableW.AcquireCredentialsHandleW( pszPrincipal, ntlmW,
-                fCredentialUse, pLogonID, pAuthData, pGetKeyFn, pGetKeyArgument, &cred->handle_ntlm, ptsExpiry );
-        if (ret == SEC_E_OK)
-        {
-            NtlmCredentials *ntlm_cred = (NtlmCredentials *)cred->handle_ntlm.dwLower;
-            ntlm_cred->no_cached_credentials = (pAuthData == NULL);
-            cred->ntlm = package->provider;
-        }
+                cred_use, pLogonID, pAuthData, pGetKeyFn, pGetKeyArgument, &cred->handle_ntlm, ptsExpiry );
+        if (ret == SEC_E_OK) cred->ntlm = package->provider;
     }
 
     if (cred->krb || cred->ntlm)
@@ -105,7 +104,7 @@ static SECURITY_STATUS SEC_ENTRY nego_AcquireCredentialsHandleW(
         return SEC_E_OK;
     }
 
-    heap_free( cred );
+    free( cred );
     return ret;
 }
 
@@ -121,14 +120,14 @@ static SECURITY_STATUS SEC_ENTRY nego_AcquireCredentialsHandleA(
     SEC_WCHAR *user = NULL, *domain = NULL, *passwd = NULL, *package = NULL;
     SEC_WINNT_AUTH_IDENTITY_W *identityW = NULL;
 
-    TRACE("%s, %s, 0x%08x, %p, %p, %p, %p, %p, %p\n",
+    TRACE("%s, %s, 0x%08lx, %p, %p, %p, %p, %p, %p\n",
           debugstr_a(pszPrincipal), debugstr_a(pszPackage), fCredentialUse,
           pLogonID, pAuthData, pGetKeyFn, pGetKeyArgument, phCredential, ptsExpiry);
 
     if (pszPackage)
     {
         int package_len = MultiByteToWideChar( CP_ACP, 0, pszPackage, -1, NULL, 0 );
-        if (!(package = heap_alloc( package_len * sizeof(SEC_WCHAR) ))) return SEC_E_INSUFFICIENT_MEMORY;
+        if (!(package = malloc( package_len * sizeof(SEC_WCHAR) ))) return SEC_E_INSUFFICIENT_MEMORY;
         MultiByteToWideChar( CP_ACP, 0, pszPackage, -1, package, package_len );
     }
     if (pAuthData)
@@ -138,14 +137,14 @@ static SECURITY_STATUS SEC_ENTRY nego_AcquireCredentialsHandleA(
 
         if (identity->Flags == SEC_WINNT_AUTH_IDENTITY_ANSI)
         {
-            if (!(identityW = heap_alloc( sizeof(*identityW) ))) goto done;
+            if (!(identityW = malloc( sizeof(*identityW) ))) goto done;
 
             if (!identity->UserLength) user_len = 0;
             else
             {
                 user_len = MultiByteToWideChar( CP_ACP, 0, (LPCSTR)identity->User,
                                                 identity->UserLength, NULL, 0 );
-                if (!(user = heap_alloc( user_len * sizeof(SEC_WCHAR) ))) goto done;
+                if (!(user = malloc( user_len * sizeof(SEC_WCHAR) ))) goto done;
                 MultiByteToWideChar( CP_ACP, 0, (LPCSTR)identity->User, identity->UserLength,
                                      user, user_len );
             }
@@ -154,7 +153,7 @@ static SECURITY_STATUS SEC_ENTRY nego_AcquireCredentialsHandleA(
             {
                 domain_len = MultiByteToWideChar( CP_ACP, 0, (LPCSTR)identity->Domain,
                                                   identity->DomainLength, NULL, 0 );
-                if (!(domain = heap_alloc( domain_len * sizeof(SEC_WCHAR) ))) goto done;
+                if (!(domain = malloc( domain_len * sizeof(SEC_WCHAR) ))) goto done;
                 MultiByteToWideChar( CP_ACP, 0, (LPCSTR)identity->Domain, identity->DomainLength,
                                      domain, domain_len );
             }
@@ -163,7 +162,7 @@ static SECURITY_STATUS SEC_ENTRY nego_AcquireCredentialsHandleA(
             {
                 passwd_len = MultiByteToWideChar( CP_ACP, 0, (LPCSTR)identity->Password,
                                                   identity->PasswordLength, NULL, 0 );
-                if (!(passwd = heap_alloc( passwd_len * sizeof(SEC_WCHAR) ))) goto done;
+                if (!(passwd = malloc( passwd_len * sizeof(SEC_WCHAR) ))) goto done;
                 MultiByteToWideChar( CP_ACP, 0, (LPCSTR)identity->Password, identity->PasswordLength,
                                      passwd, passwd_len );
             }
@@ -180,11 +179,11 @@ static SECURITY_STATUS SEC_ENTRY nego_AcquireCredentialsHandleA(
     ret = nego_AcquireCredentialsHandleW( NULL, package, fCredentialUse, pLogonID, identityW,
                                           pGetKeyFn, pGetKeyArgument, phCredential, ptsExpiry );
 done:
-    heap_free( package );
-    heap_free( user );
-    heap_free( domain );
-    heap_free( passwd );
-    heap_free( identityW );
+    free( package );
+    free( user );
+    free( domain );
+    free( passwd );
+    free( identityW );
     return ret;
 }
 
@@ -200,7 +199,7 @@ static SECURITY_STATUS SEC_ENTRY nego_InitializeSecurityContextW(
     SECURITY_STATUS ret = SEC_E_INVALID_HANDLE;
     struct sec_handle *handle = NULL, *ctxt, *new_ctxt = NULL, *cred = NULL;
 
-    TRACE("%p, %p, %s, 0x%08x, %u, %u, %p, %u, %p, %p, %p, %p\n",
+    TRACE("%p, %p, %s, 0x%08lx, %lu, %lu, %p, %lu, %p, %p, %p, %p\n",
           phCredential, phContext, debugstr_w(pszTargetName), fContextReq,
           Reserved1, TargetDataRep, pInput, Reserved1, phNewContext, pOutput,
           pfContextAttr, ptsExpiry);
@@ -212,7 +211,7 @@ static SECURITY_STATUS SEC_ENTRY nego_InitializeSecurityContextW(
     else if (phCredential)
     {
         handle = cred = (struct sec_handle *)phCredential->dwLower;
-        if (!(new_ctxt = ctxt = heap_alloc_zero( sizeof(*ctxt) ))) return SEC_E_INSUFFICIENT_MEMORY;
+        if (!(new_ctxt = ctxt = calloc( 1, sizeof(*ctxt) ))) return SEC_E_INSUFFICIENT_MEMORY;
         ctxt->krb  = cred->krb;
         ctxt->ntlm = cred->ntlm;
     }
@@ -246,7 +245,7 @@ static SECURITY_STATUS SEC_ENTRY nego_InitializeSecurityContextW(
         }
     }
 
-    heap_free( new_ctxt );
+    free( new_ctxt );
     return ret;
 }
 
@@ -262,7 +261,7 @@ static SECURITY_STATUS SEC_ENTRY nego_InitializeSecurityContextA(
     SECURITY_STATUS ret;
     SEC_WCHAR *target = NULL;
 
-    TRACE("%p, %p, %s, 0x%08x, %u, %u, %p, %u, %p, %p, %p, %p\n",
+    TRACE("%p, %p, %s, 0x%08lx, %lu, %lu, %p, %lu, %p, %p, %p, %p\n",
           phCredential, phContext, debugstr_a(pszTargetName), fContextReq,
           Reserved1, TargetDataRep, pInput, Reserved1, phNewContext, pOutput,
           pfContextAttr, ptsExpiry);
@@ -270,13 +269,13 @@ static SECURITY_STATUS SEC_ENTRY nego_InitializeSecurityContextA(
     if (pszTargetName)
     {
         int target_len = MultiByteToWideChar( CP_ACP, 0, pszTargetName, -1, NULL, 0 );
-        if (!(target = heap_alloc( target_len * sizeof(SEC_WCHAR) ))) return SEC_E_INSUFFICIENT_MEMORY;
+        if (!(target = malloc( target_len * sizeof(SEC_WCHAR) ))) return SEC_E_INSUFFICIENT_MEMORY;
         MultiByteToWideChar( CP_ACP, 0, pszTargetName, -1, target, target_len );
     }
     ret = nego_InitializeSecurityContextW( phCredential, phContext, target, fContextReq,
                                            Reserved1, TargetDataRep, pInput, Reserved2,
                                            phNewContext, pOutput, pfContextAttr, ptsExpiry );
-    heap_free( target );
+    free( target );
     return ret;
 }
 
@@ -291,7 +290,7 @@ static SECURITY_STATUS SEC_ENTRY nego_AcceptSecurityContext(
     SECURITY_STATUS ret = SEC_E_INVALID_HANDLE;
     struct sec_handle *handle = NULL, *ctxt, *new_ctxt = NULL, *cred = NULL;
 
-    TRACE("%p, %p, %p, 0x%08x, %u, %p, %p, %p, %p\n", phCredential, phContext,
+    TRACE("%p, %p, %p, 0x%08lx, %lu, %p, %p, %p, %p\n", phCredential, phContext,
           pInput, fContextReq, TargetDataRep, phNewContext, pOutput, pfContextAttr,
           ptsExpiry);
 
@@ -302,7 +301,7 @@ static SECURITY_STATUS SEC_ENTRY nego_AcceptSecurityContext(
     else if (phCredential)
     {
         handle = cred = (struct sec_handle *)phCredential->dwLower;
-        if (!(new_ctxt = ctxt = heap_alloc_zero( sizeof(*ctxt) ))) return SEC_E_INSUFFICIENT_MEMORY;
+        if (!(new_ctxt = ctxt = calloc( 1, sizeof(*ctxt) ))) return SEC_E_INSUFFICIENT_MEMORY;
         ctxt->krb  = cred->krb;
         ctxt->ntlm = cred->ntlm;
     }
@@ -336,7 +335,7 @@ static SECURITY_STATUS SEC_ENTRY nego_AcceptSecurityContext(
         }
     }
 
-    heap_free( new_ctxt );
+    free( new_ctxt );
     return ret;
 }
 
@@ -376,7 +375,7 @@ static SECURITY_STATUS SEC_ENTRY nego_DeleteSecurityContext(PCtxtHandle phContex
         ret = ctxt->ntlm->fnTableW.DeleteSecurityContext( &ctxt->handle_ntlm );
     }
     TRACE( "freeing %p\n", ctxt );
-    heap_free( ctxt );
+    free( ctxt );
     return ret;
 }
 
@@ -403,7 +402,7 @@ static SECURITY_STATUS SEC_ENTRY nego_QueryContextAttributesW(
     SECURITY_STATUS ret = SEC_E_INVALID_HANDLE;
     struct sec_handle *ctxt;
 
-    TRACE("%p, %u, %p\n", phContext, ulAttribute, pBuffer);
+    TRACE("%p, %lu, %p\n", phContext, ulAttribute, pBuffer);
 
     if (!phContext) return SEC_E_INVALID_HANDLE;
 
@@ -428,7 +427,7 @@ static SECURITY_STATUS SEC_ENTRY nego_QueryContextAttributesA(PCtxtHandle phCont
     SECURITY_STATUS ret = SEC_E_INVALID_HANDLE;
     struct sec_handle *ctxt;
 
-    TRACE("%p, %u, %p\n", phContext, ulAttribute, pBuffer);
+    TRACE("%p, %lu, %p\n", phContext, ulAttribute, pBuffer);
 
     if (!phContext) return SEC_E_INVALID_HANDLE;
 
@@ -479,7 +478,7 @@ static SECURITY_STATUS SEC_ENTRY nego_MakeSignature(PCtxtHandle phContext,
     SECURITY_STATUS ret = SEC_E_INVALID_HANDLE;
     struct sec_handle *ctxt;
 
-    TRACE("%p, 0x%08x, %p, %u\n", phContext, fQOP, pMessage, MessageSeqNo);
+    TRACE("%p, 0x%08lx, %p, %lu\n", phContext, fQOP, pMessage, MessageSeqNo);
 
     if (!phContext) return SEC_E_INVALID_HANDLE;
 
@@ -504,7 +503,7 @@ static SECURITY_STATUS SEC_ENTRY nego_VerifySignature(PCtxtHandle phContext,
     SECURITY_STATUS ret = SEC_E_INVALID_HANDLE;
     struct sec_handle *ctxt;
 
-    TRACE("%p, %p, %u, %p\n", phContext, pMessage, MessageSeqNo, pfQOP);
+    TRACE("%p, %p, %lu, %p\n", phContext, pMessage, MessageSeqNo, pfQOP);
 
     if (!phContext) return SEC_E_INVALID_HANDLE;
 
@@ -535,7 +534,7 @@ static SECURITY_STATUS SEC_ENTRY nego_FreeCredentialsHandle(PCredHandle phCreden
     if (cred->krb) cred->krb->fnTableW.FreeCredentialsHandle( &cred->handle_krb );
     if (cred->ntlm) cred->ntlm->fnTableW.FreeCredentialsHandle( &cred->handle_ntlm );
 
-    heap_free( cred );
+    free( cred );
     return SEC_E_OK;
 }
 
@@ -548,7 +547,7 @@ static SECURITY_STATUS SEC_ENTRY nego_EncryptMessage(PCtxtHandle phContext,
     SECURITY_STATUS ret = SEC_E_INVALID_HANDLE;
     struct sec_handle *ctxt;
 
-    TRACE("%p, 0x%08x, %p, %u\n", phContext, fQOP, pMessage, MessageSeqNo);
+    TRACE("%p, 0x%08lx, %p, %lu\n", phContext, fQOP, pMessage, MessageSeqNo);
 
     if (!phContext) return SEC_E_INVALID_HANDLE;
 
@@ -573,7 +572,7 @@ static SECURITY_STATUS SEC_ENTRY nego_DecryptMessage(PCtxtHandle phContext,
     SECURITY_STATUS ret = SEC_E_INVALID_HANDLE;
     struct sec_handle *ctxt;
 
-    TRACE("%p, %p, %u, %p\n", phContext, pMessage, MessageSeqNo, pfQOP);
+    TRACE("%p, %p, %lu, %p\n", phContext, pMessage, MessageSeqNo, pfQOP);
 
     if (!phContext) return SEC_E_INVALID_HANDLE;
 
