@@ -395,7 +395,7 @@ static void create_directories( const WCHAR *name )
     {
         *p = 0;
         if (!CreateDirectoryW(path, NULL))
-            TRACE("Couldn't create directory %s - error: %d\n", wine_dbgstr_w(path), GetLastError());
+            TRACE("Couldn't create directory %s - error: %ld\n", wine_dbgstr_w(path), GetLastError());
         *p = '\\';
         p = wcschr(p+1, '\\');
     }
@@ -431,11 +431,11 @@ static void *load_fake_dll( const WCHAR *name, SIZE_T *size )
     len = lstrlenW( name );
     if (build_dir) maxlen = lstrlenW(build_dir) + ARRAY_SIZE(L"\\programs") + len + 1;
     while ((path = enum_load_path( i++ ))) maxlen = max( maxlen, lstrlenW(path) );
-    maxlen += ARRAY_SIZE(pe_dir) + len + ARRAY_SIZE(L".fake");
+    maxlen += ARRAY_SIZE(pe_dir) + len + 1;
 
     if (!(file = HeapAlloc( GetProcessHeap(), 0, maxlen * sizeof(WCHAR) ))) return NULL;
 
-    pos = maxlen - len - ARRAY_SIZE(L".fake");
+    pos = maxlen - len - 1;
     lstrcpyW( file + pos, name );
     file[--pos] = '\\';
 
@@ -450,8 +450,6 @@ static void *load_fake_dll( const WCHAR *name, SIZE_T *size )
         ptr = prepend( ptr, L"\\dlls", 5 );
         ptr = prepend( ptr, build_dir, lstrlenW(build_dir) );
         if ((res = read_file( ptr, &data, size ))) goto done;
-        lstrcpyW( file + pos + len + 1, L".fake" );
-        if ((res = read_file( ptr, &data, size ))) goto done;
 
         /* now as a program */
         ptr = file + pos;
@@ -462,8 +460,6 @@ static void *load_fake_dll( const WCHAR *name, SIZE_T *size )
         ptr = prepend( ptr, L"\\programs", 9 );
         ptr = prepend( ptr, build_dir, lstrlenW(build_dir) );
         if ((res = read_file( ptr, &data, size ))) goto done;
-        lstrcpyW( file + pos + len + 1, L".fake" );
-        if ((res = read_file( ptr, &data, size ))) goto done;
     }
 
     file[pos + len + 1] = 0;
@@ -511,7 +507,7 @@ static HANDLE create_dest_file( const WCHAR *name, BOOL delete )
 
         h = CreateFileW( name, GENERIC_WRITE, 0, NULL, CREATE_NEW, 0, NULL );
         if (h == INVALID_HANDLE_VALUE)
-            ERR( "failed to create %s (error=%u)\n", debugstr_w(name), GetLastError() );
+            ERR( "failed to create %s (error=%lu)\n", debugstr_w(name), GetLastError() );
     }
     return h;
 }
@@ -701,7 +697,7 @@ static BOOL create_manifest( const xmlstr_t *arch, const xmlstr_t *name, const x
     {
         TRACE( "creating %s\n", debugstr_w(path) );
         ret = (WriteFile( handle, data, len, &written, NULL ) && written == len);
-        if (!ret) ERR( "failed to write to %s (error=%u)\n", debugstr_w(path), GetLastError() );
+        if (!ret) ERR( "failed to write to %s (error=%lu)\n", debugstr_w(path), GetLastError() );
         CloseHandle( handle );
         if (!ret) DeleteFileW( path );
     }
@@ -872,7 +868,7 @@ static void register_fake_dll( const WCHAR *name, const void *data, size_t size,
 
         if (!registrar)
         {
-            ERR( "failed to create IRegistrar: %x\n", hr );
+            ERR( "failed to create IRegistrar: %lx\n", hr );
             return;
         }
     }
@@ -883,11 +879,11 @@ static void register_fake_dll( const WCHAR *name, const void *data, size_t size,
     GetEnvironmentVariableW( L"SystemRoot", buffer, ARRAY_SIZE(buffer) );
     IRegistrar_AddReplacement( registrar, L"SystemRoot", buffer );
     EnumResourceNamesW( module, L"WINE_REGISTRY", register_resource, (LONG_PTR)&hr );
-    if (FAILED(hr)) ERR( "failed to register %s: %x\n", debugstr_w(name), hr );
+    if (FAILED(hr)) ERR( "failed to register %s: %lx\n", debugstr_w(name), hr );
 }
 
 /* copy a fake dll file to the dest directory */
-static int install_fake_dll( WCHAR *dest, WCHAR *file, const WCHAR *ext, BOOL delete, struct list *delay_copy )
+static int install_fake_dll( WCHAR *dest, WCHAR *file, BOOL delete, struct list *delay_copy )
 {
     int ret;
     SIZE_T size;
@@ -898,7 +894,6 @@ static int install_fake_dll( WCHAR *dest, WCHAR *file, const WCHAR *ext, BOOL de
     WCHAR *end = name + lstrlenW(name);
     SIZE_T len = end - name;
 
-    if (ext) lstrcpyW( end, ext );
     if (!(ret = read_file( file, &data, &size )))
     {
         *end = 0;
@@ -919,7 +914,7 @@ static int install_fake_dll( WCHAR *dest, WCHAR *file, const WCHAR *ext, BOOL de
             TRACE( "%s -> %s\n", debugstr_w(file), debugstr_w(dest) );
 
             ret = (WriteFile( h, data, size, &written, NULL ) && written == size);
-            if (!ret) ERR( "failed to write to %s (error=%u)\n", debugstr_w(dest), GetLastError() );
+            if (!ret) ERR( "failed to write to %s (error=%lu)\n", debugstr_w(dest), GetLastError() );
             CloseHandle( h );
             if (ret) register_fake_dll( dest, data, size, delay_copy );
             else DeleteFileW( dest );
@@ -953,7 +948,7 @@ static void delay_copy_files( struct list *delay_copy )
         if (h && h != INVALID_HANDLE_VALUE)
         {
             ret = (WriteFile( h, data, size, &written, NULL ) && written == size);
-            if (!ret) ERR( "failed to write to %s (error=%u)\n", debugstr_w(copy->dest), GetLastError() );
+            if (!ret) ERR( "failed to write to %s (error=%lu)\n", debugstr_w(copy->dest), GetLastError() );
             CloseHandle( h );
             if (!ret) DeleteFileW( copy->dest );
         }
@@ -986,16 +981,11 @@ static void install_lib_dir( WCHAR *dest, WCHAR *file, const WCHAR *wildcard,
         {
             lstrcatW( name, L"\\" );
             lstrcatW( name, data.name );
-            if (wcschr( data.name, '.' )) /* module possibly already has an extension */
-            {
-                if (install_fake_dll( dest, file, NULL, delete, &delay_copy )) continue;
-                if (install_fake_dll( dest, file, L".fake", delete, &delay_copy )) continue;
-            }
+            if (wcschr( data.name, '.' ) && install_fake_dll( dest, file, delete, &delay_copy ))
+                continue;
             lstrcatW( name, default_ext );
-            if (install_fake_dll( dest, file, NULL, delete, &delay_copy )) continue;
-            if (install_fake_dll( dest, file, L".fake", delete, &delay_copy )) continue;
         }
-        else install_fake_dll( dest, file, NULL, delete, &delay_copy );
+        install_fake_dll( dest, file, delete, &delay_copy );
     }
     while (!_wfindnext( handle, &data ));
     _findclose( handle );
@@ -1013,7 +1003,7 @@ static BOOL create_wildcard_dlls( const WCHAR *dirname, const WCHAR *wildcard, B
 
     if (build_dir) maxlen = lstrlenW(build_dir) + ARRAY_SIZE(L"\\programs") + 1;
     for (i = 0; (path = enum_load_path(i)); i++) maxlen = max( maxlen, lstrlenW(path) );
-    maxlen += 2 * max_dll_name_len + 2 + ARRAY_SIZE(pe_dir) + 10; /* ".dll.fake" */
+    maxlen += 2 * max_dll_name_len + 2 + ARRAY_SIZE(pe_dir) + 10; /* ".dll" */
     if (!(file = HeapAlloc( GetProcessHeap(), 0, maxlen * sizeof(WCHAR) ))) return FALSE;
 
     if (!(dest = HeapAlloc( GetProcessHeap(), 0, (lstrlenW(dirname) + max_dll_name_len) * sizeof(WCHAR) )))
@@ -1080,7 +1070,7 @@ BOOL create_fake_dll( const WCHAR *name, const WCHAR *source )
 
         ret = (WriteFile( h, buffer, size, &written, NULL ) && written == size);
         if (ret) register_fake_dll( name, buffer, size, &delay_copy );
-        else ERR( "failed to write to %s (error=%u)\n", debugstr_w(name), GetLastError() );
+        else ERR( "failed to write to %s (error=%lu)\n", debugstr_w(name), GetLastError() );
     }
     else
     {
