@@ -1,6 +1,6 @@
 /*
  * The parameters of many functions changes between different OS versions
- * (NT uses Unicode strings, 95 uses ASCII strings)
+ * (NT uses Unicode strings, 95 uses ANSI strings)
  *
  * Copyright 1997 Marcus Meissner
  *           1998 Jürgen Schmied
@@ -19,7 +19,6 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
-#include "config.h"
 
 #include <string.h>
 #include <stdarg.h>
@@ -42,7 +41,6 @@
 #include "winuser.h"
 #include "shlobj.h"
 #include "shell32_main.h"
-#include "undocshell.h"
 #include "pidl.h"
 #include "shlwapi.h"
 #include "commdlg.h"
@@ -51,6 +49,17 @@
 WINE_DEFAULT_DEBUG_CHANNEL(shell);
 WINE_DECLARE_DEBUG_CHANNEL(pidl);
 
+/* SHWaitForFileToOpen flags */
+#define SHWFF_ADD       0x01
+#define SHWFF_REMOVE    0x02
+#define SHWFF_WAIT      0x04
+
+/* RegisterShellHook types */
+#define RSH_DEREGISTER          0
+#define RSH_REGISTER            1
+#define RSH_REGISTER_PROGMAN    2
+#define RSH_REGISTER_TASKMAN    3
+
 /* FIXME: !!! move CREATEMRULIST and flags to header file !!! */
 /*        !!! it is in both here and comctl32undoc.c      !!! */
 typedef struct tagCREATEMRULIST
@@ -106,7 +115,7 @@ DWORD WINAPI ParseFieldA(
 	LPSTR dst,
 	DWORD len)
 {
-	WARN("(%s,0x%08x,%p,%d) semi-stub.\n",debugstr_a(src),nField,dst,len);
+	WARN("(%s,0x%08lx,%p,%ld) semi-stub.\n",debugstr_a(src),nField,dst,len);
 
 	if (!src || !src[0] || !dst || !len)
 	  return 0;
@@ -136,7 +145,7 @@ DWORD WINAPI ParseFieldA(
  */
 DWORD WINAPI ParseFieldW(LPCWSTR src, DWORD nField, LPWSTR dst, DWORD len)
 {
-	WARN("(%s,0x%08x,%p,%d) semi-stub.\n", debugstr_w(src), nField, dst, len);
+	WARN("(%s,0x%08lx,%p,%ld) semi-stub.\n", debugstr_w(src), nField, dst, len);
 
 	if (!src || !src[0] || !dst || !len)
 	  return 0;
@@ -184,7 +193,7 @@ static BOOL GetFileNameFromBrowseA(
     OPENFILENAMEA ofn;
     BOOL ret;
 
-    TRACE("%p, %s, %d, %s, %s, %s, %s)\n",
+    TRACE("%p, %s, %ld, %s, %s, %s, %s)\n",
 	  hwndOwner, lpstrFile, nMaxFile, lpstrInitialDir, lpstrDefExt,
 	  lpstrFilter, lpstrTitle);
 
@@ -231,7 +240,7 @@ static BOOL GetFileNameFromBrowseW(
     OPENFILENAMEW ofn;
     BOOL ret;
 
-    TRACE("%p, %s, %d, %s, %s, %s, %s)\n",
+    TRACE("%p, %s, %ld, %s, %s, %s, %s)\n",
 	  hwndOwner, debugstr_w(lpstrFile), nMaxFile, debugstr_w(lpstrInitialDir), debugstr_w(lpstrDefExt),
 	  debugstr_w(lpstrFilter), debugstr_w(lpstrTitle));
 
@@ -287,7 +296,7 @@ VOID WINAPI SHGetSetSettings(LPSHELLSTATE lpss, DWORD dwMask, BOOL bSet)
 {
   if(bSet)
   {
-    FIXME("%p 0x%08x TRUE\n", lpss, dwMask);
+    FIXME("%p 0x%08lx TRUE\n", lpss, dwMask);
   }
   else
   {
@@ -309,7 +318,7 @@ VOID WINAPI SHGetSettings(LPSHELLFLAGSTATE lpsfs, DWORD dwMask)
 	DWORD	dwData;
 	DWORD	dwDataSize = sizeof (DWORD);
 
-	TRACE("(%p 0x%08x)\n",lpsfs,dwMask);
+	TRACE("(%p 0x%08lx)\n",lpsfs,dwMask);
 
 	if (RegCreateKeyExA(HKEY_CURRENT_USER, "Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Advanced",
 				 0, 0, 0, KEY_ALL_ACCESS, 0, &hKey, 0))
@@ -377,7 +386,7 @@ LRESULT WINAPI SHShellFolderView_Message(
 	UINT uMessage,
 	LPARAM lParam)
 {
-	FIXME("%p %08x %08lx stub\n",hwndCabinet, uMessage, lParam);
+	FIXME("%p %08x %08Ix stub\n",hwndCabinet, uMessage, lParam);
 	return 0;
 }
 
@@ -397,7 +406,7 @@ BOOL WINAPI RegisterShellHook(
 	HWND hWnd,
 	DWORD dwType)
 {
-	FIXME("(%p,0x%08x):stub.\n",hWnd, dwType);
+	FIXME("(%p,0x%08lx):stub.\n",hWnd, dwType);
 	return TRUE;
 }
 
@@ -423,10 +432,10 @@ int WINAPIV ShellMessageBoxW(
 	WCHAR	szText[100],szTitle[100];
 	LPCWSTR pszText = szText, pszTitle = szTitle;
 	LPWSTR  pszTemp;
-	__ms_va_list args;
+	va_list args;
 	int	ret;
 
-	__ms_va_start(args, uType);
+	va_start(args, uType);
 	/* wvsprintfA(buf,fmt, args); */
 
 	TRACE("(%p,%p,%p,%p,%08x)\n",
@@ -445,7 +454,7 @@ int WINAPIV ShellMessageBoxW(
 	FormatMessageW(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_STRING,
 		       pszText, 0, 0, (LPWSTR)&pszTemp, 0, &args);
 
-	__ms_va_end(args);
+	va_end(args);
 
 	ret = MessageBoxW(hWnd,pszTemp,pszTitle,uType);
         LocalFree(pszTemp);
@@ -481,10 +490,10 @@ int WINAPIV ShellMessageBoxA(
 	char	szText[100],szTitle[100];
 	LPCSTR  pszText = szText, pszTitle = szTitle;
 	LPSTR   pszTemp;
-	__ms_va_list args;
+	va_list args;
 	int	ret;
 
-	__ms_va_start(args, uType);
+	va_start(args, uType);
 	/* wvsprintfA(buf,fmt, args); */
 
 	TRACE("(%p,%p,%p,%p,%08x)\n",
@@ -503,7 +512,7 @@ int WINAPIV ShellMessageBoxA(
 	FormatMessageA(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_STRING,
 		       pszText, 0, 0, (LPSTR)&pszTemp, 0, &args);
 
-	__ms_va_end(args);
+	va_end(args);
 
 	ret = MessageBoxA(hWnd,pszTemp,pszTitle,uType);
         LocalFree(pszTemp);
@@ -587,7 +596,7 @@ HRESULT WINAPI SHDoDragDrop(
 	DWORD dwOKEffect,
 	LPDWORD pdwEffect)
 {
-    FIXME("(%p %p %p 0x%08x %p):stub.\n",
+    FIXME("(%p %p %p 0x%08lx %p):stub.\n",
     hWnd, lpDataObject, lpDropSource, dwOKEffect, pdwEffect);
 	return DoDragDrop(lpDataObject, lpDropSource, dwOKEffect, pdwEffect);
 }
@@ -599,7 +608,7 @@ HRESULT WINAPI SHDoDragDrop(
 WORD WINAPI ArrangeWindows(HWND hwndParent, DWORD dwReserved, const RECT *lpRect,
         WORD cKids, const HWND *lpKids)
 {
-    FIXME("(%p 0x%08x %p 0x%04x %p):stub.\n",
+    FIXME("(%p 0x%08lx %p 0x%04x %p):stub.\n",
 	   hwndParent, dwReserved, lpRect, cKids, lpKids);
     return 0;
 }
@@ -788,12 +797,12 @@ void WINAPI SHAddToRecentDocs (UINT uFlags,LPCVOID pv)
     if (ret == ERROR_SUCCESS) {
 	if (!( (type == REG_DWORD) ||
 	       ((type == REG_BINARY) && (datalen == 4)) )) {
-	    ERR("Error policy data for \"NoRecentDocsHistory\" not formatted correctly, type=%d, len=%d\n",
+	    ERR("Error policy data for \"NoRecentDocsHistory\" not formatted correctly, type=%ld, len=%ld\n",
 		type, datalen);
 	    return;
 	}
 
-	TRACE("policy value for NoRecentDocsHistory = %08x\n", data[0]);
+	TRACE("policy value for NoRecentDocsHistory = %08lx\n", data[0]);
 	/* now test the actual policy value */
 	if ( data[0] != 0)
 	    return;
@@ -951,7 +960,7 @@ void WINAPI SHAddToRecentDocs (UINT uFlags,LPCVOID pv)
 		    if (!DeleteFileA(old_lnk_name)) {
 			if ((attr = GetFileAttributesA(old_lnk_name)) == INVALID_FILE_ATTRIBUTES) {
 			    if ((err = GetLastError()) != ERROR_FILE_NOT_FOUND) {
-				ERR("Delete for %s failed, err=%d, attr=%08x\n",
+				ERR("Delete for %s failed, err=%d, attr=%08lx\n",
 				    old_lnk_name, err, attr);
 			    }
 			    else {
@@ -960,7 +969,7 @@ void WINAPI SHAddToRecentDocs (UINT uFlags,LPCVOID pv)
 			    }
 			}
 			else {
-			    ERR("Delete for %s failed, attr=%08x\n",
+			    ERR("Delete for %s failed, attr=%08lx\n",
 				old_lnk_name, attr);
 			}
 		    }
@@ -1023,7 +1032,7 @@ void WINAPI SHAddToRecentDocs (UINT uFlags,LPCVOID pv)
 					     (LPVOID *)&pPf);
 	    if(FAILED(hres)) {
 		/* bombed */
-		ERR("failed QueryInterface for IPersistFile %08x\n", hres);
+		ERR("failed QueryInterface for IPersistFile %08lx\n", hres);
 		goto fail;
 	    }
 
@@ -1035,7 +1044,7 @@ void WINAPI SHAddToRecentDocs (UINT uFlags,LPCVOID pv)
 	    }
 	    if(FAILED(hres)) {
 		/* bombed */
-		ERR("failed Set{IDList|Path} %08x\n", hres);
+		ERR("failed Set{IDList|Path} %08lx\n", hres);
 		goto fail;
 	    }
 
@@ -1044,7 +1053,7 @@ void WINAPI SHAddToRecentDocs (UINT uFlags,LPCVOID pv)
 	    hres = IShellLinkA_SetDescription(psl, desc);
 	    if(FAILED(hres)) {
 		/* bombed */
-		ERR("failed SetDescription %08x\n", hres);
+		ERR("failed SetDescription %08lx\n", hres);
 		goto fail;
 	    }
 
@@ -1054,7 +1063,7 @@ void WINAPI SHAddToRecentDocs (UINT uFlags,LPCVOID pv)
 	    hres = IPersistFile_Save(pPf, widelink, TRUE);
 	    if(FAILED(hres)) {
 		/* bombed */
-		ERR("failed IPersistFile::Save %08x\n", hres);
+		ERR("failed IPersistFile::Save %08lx\n", hres);
 		IPersistFile_Release(pPf);
 		IShellLinkA_Release(psl);
 		goto fail;
@@ -1062,11 +1071,11 @@ void WINAPI SHAddToRecentDocs (UINT uFlags,LPCVOID pv)
 	    hres = IPersistFile_SaveCompleted(pPf, widelink);
 	    IPersistFile_Release(pPf);
 	    IShellLinkA_Release(psl);
-	    TRACE("shortcut %s has been created, result=%08x\n",
+	    TRACE("shortcut %s has been created, result=%08lx\n",
 		  new_lnk_filepath, hres);
 	}
 	else {
-	    ERR("CoCreateInstance failed, hres=%08x\n", hres);
+	    ERR("CoCreateInstance failed, hres=%08lx\n", hres);
 	}
     }
 
@@ -1083,7 +1092,7 @@ void WINAPI SHAddToRecentDocs (UINT uFlags,LPCVOID pv)
  *
  */
 HRESULT WINAPI SHWinHelp (DWORD v, DWORD w, DWORD x, DWORD z)
-{	FIXME("0x%08x 0x%08x 0x%08x 0x%08x stub\n",v,w,x,z);
+{	FIXME("0x%08lx 0x%08lx 0x%08lx 0x%08lx stub\n",v,w,x,z);
 	return 0;
 }
 /*************************************************************************
@@ -1138,7 +1147,7 @@ BOOL WINAPI DAD_DragEnter(HWND hwnd)
  */
 BOOL WINAPI DAD_DragEnterEx(HWND hwnd, POINT p)
 {
-    FIXME("hwnd = %p (%d,%d)\n",hwnd,p.x,p.y);
+    FIXME("hwnd = %p (%ld,%ld)\n",hwnd,p.x,p.y);
     return FALSE;
 }
 /*************************************************************************
@@ -1147,7 +1156,7 @@ BOOL WINAPI DAD_DragEnterEx(HWND hwnd, POINT p)
  */
 BOOL WINAPI DAD_DragMove(POINT p)
 {
-    FIXME("(%d,%d)\n",p.x,p.y);
+    FIXME("(%ld,%ld)\n",p.x,p.y);
     return FALSE;
 }
 /*************************************************************************
@@ -1184,17 +1193,6 @@ BOOL WINAPI DAD_ShowDragImage(BOOL bShow)
     return FALSE;
 }
 
-static const WCHAR szwCabLocation[] = {
-  'S','o','f','t','w','a','r','e','\\',
-  'M','i','c','r','o','s','o','f','t','\\',
-  'W','i','n','d','o','w','s','\\',
-  'C','u','r','r','e','n','t','V','e','r','s','i','o','n','\\',
-  'E','x','p','l','o','r','e','r','\\',
-  'C','a','b','i','n','e','t','S','t','a','t','e',0
-};
-
-static const WCHAR szwSettings[] = { 'S','e','t','t','i','n','g','s',0 };
-
 /*************************************************************************
  * ReadCabinetState				[SHELL32.651] NT 4.0
  *
@@ -1209,12 +1207,11 @@ BOOL WINAPI ReadCabinetState(CABINETSTATE *cs, int length)
 	if( (cs == NULL) || (length < (int)sizeof(*cs))  )
 		return FALSE;
 
-	r = RegOpenKeyW( HKEY_CURRENT_USER, szwCabLocation, &hkey );
+	r = RegOpenKeyW( HKEY_CURRENT_USER, L"Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\CabinetState", &hkey );
 	if( r == ERROR_SUCCESS )
 	{
 		type = REG_BINARY;
-		r = RegQueryValueExW( hkey, szwSettings, 
-			NULL, &type, (LPBYTE)cs, (LPDWORD)&length );
+		r = RegQueryValueExW( hkey, L"Settings", NULL, &type, (LPBYTE)cs, (LPDWORD)&length );
 		RegCloseKey( hkey );
 			
 	}
@@ -1256,13 +1253,11 @@ BOOL WINAPI WriteCabinetState(CABINETSTATE *cs)
 	if( cs == NULL )
 		return FALSE;
 
-	r = RegCreateKeyExW( HKEY_CURRENT_USER, szwCabLocation, 0,
+	r = RegCreateKeyExW( HKEY_CURRENT_USER, L"Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\CabinetState", 0,
 		 NULL, 0, KEY_ALL_ACCESS, NULL, &hkey, NULL);
 	if( r == ERROR_SUCCESS )
 	{
-		r = RegSetValueExW( hkey, szwSettings, 0, 
-			REG_BINARY, (LPBYTE) cs, cs->cLength);
-
+		r = RegSetValueExW( hkey, L"Settings", 0, REG_BINARY, (LPBYTE) cs, cs->cLength);
 		RegCloseKey( hkey );
 	}
 
@@ -1357,7 +1352,7 @@ BOOL WINAPI IsUserAnAdmin(VOID)
  *
  * See shlwapi.SHAllocShared
  */
-HANDLE WINAPI SHAllocShared(LPVOID lpvData, DWORD dwSize, DWORD dwProcId)
+HANDLE WINAPI SHAllocShared(const void *lpvData, DWORD dwSize, DWORD dwProcId)
 {
     GET_FUNC(pSHAllocShared, shlwapi, (char*)7, NULL);
     return pSHAllocShared(lpvData, dwSize, dwProcId);
@@ -1400,7 +1395,7 @@ BOOL WINAPI SHFreeShared(HANDLE hShared, DWORD dwProcId)
  * SetAppStartingCursor				[SHELL32.99]
  */
 HRESULT WINAPI SetAppStartingCursor(HWND u, DWORD v)
-{	FIXME("hwnd=%p 0x%04x stub\n",u,v );
+{	FIXME("hwnd=%p 0x%04lx stub\n",u,v );
 	return 0;
 }
 
@@ -1424,7 +1419,7 @@ HRESULT WINAPI SetAppStartingCursor(HWND u, DWORD v)
  * hack in SHCoCreateInstance)
  */
 HRESULT WINAPI SHLoadOLE(LPARAM lParam)
-{	FIXME("0x%08lx stub\n",lParam);
+{	FIXME("0x%08Ix stub\n",lParam);
 	return S_OK;
 }
 /*************************************************************************
@@ -1481,7 +1476,7 @@ BOOL WINAPI SHWaitForFileToOpen(
 	DWORD dwFlags,
 	DWORD dwTimeout)
 {
-	FIXME("%p 0x%08x 0x%08x stub\n", pidl, dwFlags, dwTimeout);
+	FIXME("%p 0x%08lx 0x%08lx stub\n", pidl, dwFlags, dwTimeout);
 	return FALSE;
 }
 
@@ -1667,7 +1662,7 @@ UINT WINAPI SHAddFromPropSheetExtArray(HPSXA hpsxa, LPFNADDPROPSHEETPAGE lpfnAdd
     UINT i;
     PPSXA psxa = (PPSXA)hpsxa;
 
-    TRACE("(%p,%p,%08lx)\n", hpsxa, lpfnAddPage, lParam);
+    TRACE("(%p,%p,%08Ix)\n", hpsxa, lpfnAddPage, lParam);
 
     if (psxa)
     {
@@ -1701,7 +1696,6 @@ HPSXA WINAPI SHCreatePropSheetExtArray(HKEY hKey, LPCWSTR pszSubKey, UINT max_if
  */
 HPSXA WINAPI SHCreatePropSheetExtArrayEx(HKEY hKey, LPCWSTR pszSubKey, UINT max_iface, LPDATAOBJECT pDataObj)
 {
-    static const WCHAR szPropSheetSubKey[] = {'s','h','e','l','l','e','x','\\','P','r','o','p','e','r','t','y','S','h','e','e','t','H','a','n','d','l','e','r','s',0};
     WCHAR szHandler[64];
     DWORD dwHandlerLen;
     WCHAR szClsidHandler[39];
@@ -1724,7 +1718,7 @@ HPSXA WINAPI SHCreatePropSheetExtArrayEx(HKEY hKey, LPCWSTR pszSubKey, UINT max_
     if (lRet != ERROR_SUCCESS)
         return NULL;
 
-    lRet = RegOpenKeyExW(hkBase, szPropSheetSubKey, 0, KEY_ENUMERATE_SUB_KEYS, &hkPropSheetHandlers);
+    lRet = RegOpenKeyExW(hkBase, L"shellex\\PropertySheetHandlers", 0, KEY_ENUMERATE_SUB_KEYS, &hkPropSheetHandlers);
     RegCloseKey(hkBase);
     if (lRet == ERROR_SUCCESS)
     {
@@ -1814,7 +1808,7 @@ UINT WINAPI SHReplaceFromPropSheetExtArray(HPSXA hpsxa, UINT uPageID, LPFNADDPRO
     UINT i;
     PPSXA psxa = (PPSXA)hpsxa;
 
-    TRACE("(%p,%u,%p,%08lx)\n", hpsxa, uPageID, lpfnReplaceWith, lParam);
+    TRACE("(%p,%u,%p,%08Ix)\n", hpsxa, uPageID, lpfnReplaceWith, lParam);
 
     if (psxa)
     {
@@ -1871,7 +1865,7 @@ HRESULT WINAPI CIDLData_CreateFromIDArray(
     UINT i;
     HWND hwnd = 0;   /*FIXME: who should be hwnd of owner? set to desktop */
 
-    TRACE("(%p, %d, %p, %p)\n", pidlFolder, cpidlFiles, lppidlFiles, ppdataObject);
+    TRACE("(%p, %ld, %p, %p)\n", pidlFolder, cpidlFiles, lppidlFiles, ppdataObject);
     if (TRACE_ON(pidl))
     {
 	pdump (pidlFolder);
@@ -1896,7 +1890,7 @@ HRESULT WINAPI SHCreateStdEnumFmtEtc(
 {
 	IEnumFORMATETC *pef;
 	HRESULT hRes;
-	TRACE("cf=%d fe=%p pef=%p\n", cFormats, lpFormats, ppenumFormatetc);
+	TRACE("cf=%ld fe=%p pef=%p\n", cFormats, lpFormats, ppenumFormatetc);
 
 	pef = IEnumFORMATETC_Constructor(cFormats, lpFormats);
 	if (!pef)
@@ -1961,7 +1955,7 @@ INT WINAPI SHHandleUpdateImage(LPCITEMIDLIST pidlExtra)
 
 BOOL WINAPI SHObjectProperties(HWND hwnd, DWORD dwType, LPCWSTR szObject, LPCWSTR szPage)
 {
-    FIXME("%p, 0x%08x, %s, %s - stub\n", hwnd, dwType, debugstr_w(szObject), debugstr_w(szPage));
+    FIXME("%p, 0x%08lx, %s, %s - stub\n", hwnd, dwType, debugstr_w(szObject), debugstr_w(szPage));
 
     return TRUE;
 }
@@ -1991,8 +1985,6 @@ BOOL WINAPI SHGetNewLinkInfoW(LPCWSTR pszLinkTo, LPCWSTR pszDir, LPWSTR pszName,
     const WCHAR *basename;
     WCHAR *dst_basename;
     int i=2;
-    static const WCHAR lnkformat[] = {'%','s','.','l','n','k',0};
-    static const WCHAR lnkformatnum[] = {'%','s',' ','(','%','d',')','.','l','n','k',0};
 
     TRACE("(%s, %s, %p, %p, 0x%08x)\n", debugstr_w(pszLinkTo), debugstr_w(pszDir),
           pszName, pfMustCopy, uFlags);
@@ -2012,7 +2004,7 @@ BOOL WINAPI SHGetNewLinkInfoW(LPCWSTR pszLinkTo, LPCWSTR pszDir, LPWSTR pszName,
     if (GetFileAttributesW(pszLinkTo) == INVALID_FILE_ATTRIBUTES)
         return FALSE;
 
-    basename = strrchrW(pszLinkTo, '\\');
+    basename = wcsrchr(pszLinkTo, '\\');
     if (basename)
         basename = basename+1;
     else
@@ -2022,13 +2014,13 @@ BOOL WINAPI SHGetNewLinkInfoW(LPCWSTR pszLinkTo, LPCWSTR pszDir, LPWSTR pszName,
     if (!PathAddBackslashW(pszName))
         return FALSE;
 
-    dst_basename = pszName + strlenW(pszName);
+    dst_basename = pszName + lstrlenW(pszName);
 
-    snprintfW(dst_basename, pszName + MAX_PATH - dst_basename, lnkformat, basename);
+    swprintf(dst_basename, pszName + MAX_PATH - dst_basename, L"%s.lnk", basename);
 
     while (GetFileAttributesW(pszName) != INVALID_FILE_ATTRIBUTES)
     {
-        snprintfW(dst_basename, pszName + MAX_PATH - dst_basename, lnkformatnum, basename, i);
+        swprintf(dst_basename, pszName + MAX_PATH - dst_basename, L"%s (%d).lnk", basename, i);
         i++;
     }
 
@@ -2037,7 +2029,7 @@ BOOL WINAPI SHGetNewLinkInfoW(LPCWSTR pszLinkTo, LPCWSTR pszDir, LPWSTR pszName,
 
 HRESULT WINAPI SHStartNetConnectionDialog(HWND hwnd, LPCSTR pszRemoteName, DWORD dwType)
 {
-    FIXME("%p, %s, 0x%08x - stub\n", hwnd, debugstr_a(pszRemoteName), dwType);
+    FIXME("%p, %s, 0x%08lx - stub\n", hwnd, debugstr_a(pszRemoteName), dwType);
 
     return S_OK;
 }
