@@ -266,7 +266,7 @@ static BOOL SHELL_ArgifyW(WCHAR* out, int len, const WCHAR* fmt, const WCHAR* lp
     else
         out[len-1] = '\0';
 
-    TRACE("used %i of %i space\n",used,len);
+    TRACE("used %li of %i space\n",used,len);
     if (out_len)
         *out_len = used;
 
@@ -333,7 +333,7 @@ static UINT_PTR SHELL_ExecuteW(const WCHAR *lpCmd, WCHAR *env, BOOL shWait,
            when starting app immediately before making a DDE connection. */
         if (shWait)
             if (WaitForInputIdle( info.hProcess, 30000 ) == WAIT_FAILED)
-                WARN("WaitForInputIdle failed: Error %d\n", GetLastError() );
+                WARN("WaitForInputIdle failed: Error %ld\n", GetLastError() );
         retval = 33;
         if (psei->fMask & SEE_MASK_NOCLOSEPROCESS)
             psei_out->hProcess = info.hProcess;
@@ -343,11 +343,11 @@ static UINT_PTR SHELL_ExecuteW(const WCHAR *lpCmd, WCHAR *env, BOOL shWait,
     }
     else if ((retval = GetLastError()) >= 32)
     {
-        TRACE("CreateProcess returned error %ld\n", retval);
+        TRACE("CreateProcess returned error %Id\n", retval);
         retval = ERROR_BAD_FORMAT;
     }
 
-    TRACE("returning %lu\n", retval);
+    TRACE("returning %Iu\n", retval);
 
     psei_out->hInstApp = (HINSTANCE)retval;
     if( gcdret )
@@ -739,7 +739,7 @@ static HDDEDATA CALLBACK dde_cb(UINT uType, UINT uFmt, HCONV hConv,
                                 HSZ hsz1, HSZ hsz2, HDDEDATA hData,
                                 ULONG_PTR dwData1, ULONG_PTR dwData2)
 {
-    TRACE("dde_cb: %04x, %04x, %p, %p, %p, %p, %08lx, %08lx\n",
+    TRACE("dde_cb: %04x, %04x, %p, %p, %p, %p, %08Ix, %08Ix\n",
            uType, uFmt, hConv, hsz1, hsz2, hData, dwData1, dwData2);
     return NULL;
 }
@@ -1199,7 +1199,7 @@ static HRESULT shellex_run_context_menu_default( IShellExtInit *obj,
         string[0] = 0;
         GetMenuItemInfoW( hmenu, i, TRUE, &info );
 
-        TRACE("menu %d %s %08x %08lx %08x %08x\n", i, debugstr_w(string),
+        TRACE("menu %d %s %08x %08Ix %08x %08x\n", i, debugstr_w(string),
             info.fState, info.dwItemData, info.fType, info.wID );
         if ( ( !sei->lpVerb && (info.fState & MFS_DEFAULT) ) ||
              ( sei->lpVerb && !lstrcmpiW( sei->lpVerb, string ) ) )
@@ -1223,7 +1223,7 @@ static HRESULT shellex_run_context_menu_default( IShellExtInit *obj,
     
     r = IContextMenu_InvokeCommand( cm, (LPCMINVOKECOMMANDINFO) &ici );
 
-    TRACE("invoke command returned %08x\n", r );
+    TRACE("invoke command returned %08lx\n", r );
 
 end:
     if ( hmenu )
@@ -1250,7 +1250,7 @@ static HRESULT shellex_load_object_and_run( HKEY hkey, LPCGUID guid, LPSHELLEXEC
                            &IID_IShellExtInit, (LPVOID*)&obj );
     if ( FAILED( r ) )
     {
-        ERR("failed %08x\n", r );
+        ERR("failed %08lx\n", r );
         goto end;
     }
 
@@ -1395,11 +1395,11 @@ static void SHELL_translate_idlist( LPSHELLEXECUTEINFOW sei, LPWSTR wszParameter
         if (buffer[0]==':' && buffer[1]==':') {
             /* open shell folder for the specified class GUID */
             if (lstrlenW(buffer) + 1 > parametersLen)
-                ERR("parameters len exceeds buffer size (%i > %i), truncating\n",
+                ERR("parameters len exceeds buffer size (%i > %li), truncating\n",
                     lstrlenW(buffer) + 1, parametersLen);
             lstrcpynW(wszParameters, buffer, parametersLen);
             if (lstrlenW(L"explorer.exe") > dwApplicationNameLen)
-                ERR("application len exceeds buffer size (%i), truncating\n",
+                ERR("application len exceeds buffer size (%li), truncating\n",
                     dwApplicationNameLen);
             lstrcpynW(wszApplicationName, L"explorer.exe", dwApplicationNameLen);
 
@@ -1552,7 +1552,7 @@ static BOOL SHELL_execute( LPSHELLEXECUTEINFOW sei, SHELL_ExecuteW32 execfunc )
     /* make a local copy of the LPSHELLEXECUTEINFO structure and work with this from now on */
     sei_tmp = *sei;
 
-    TRACE("mask=0x%08x hwnd=%p verb=%s file=%s parm=%s dir=%s show=0x%08x class=%s\n",
+    TRACE("mask=0x%08lx hwnd=%p verb=%s file=%s parm=%s dir=%s show=0x%08x class=%s\n",
             sei_tmp.fMask, sei_tmp.hwnd, debugstr_w(sei_tmp.lpVerb),
             debugstr_w(sei_tmp.lpFile), debugstr_w(sei_tmp.lpParameters),
             debugstr_w(sei_tmp.lpDirectory), sei_tmp.nShow,
@@ -1614,7 +1614,7 @@ static BOOL SHELL_execute( LPSHELLEXECUTEINFOW sei, SHELL_ExecuteW32 execfunc )
 
     if (sei_tmp.fMask & unsupportedFlags)
     {
-        FIXME("flags ignored: 0x%08x\n", sei_tmp.fMask & unsupportedFlags);
+        FIXME("flags ignored: 0x%08lx\n", sei_tmp.fMask & unsupportedFlags);
     }
 
     /* process the IDList */
@@ -1830,7 +1830,7 @@ static BOOL SHELL_execute( LPSHELLEXECUTEINFOW sei, SHELL_ExecuteW32 execfunc )
     }
 
 end:
-    TRACE("retval %lu\n", retval);
+    TRACE("retval %Iu\n", retval);
 
     heap_free(wszApplicationName);
     if (wszParameters != parametersBuffer)
