@@ -40,7 +40,6 @@
 #include "shlguid.h"
 
 #include "pidl.h"
-#include "undocshell.h"
 #include "shell32_main.h"
 #include "shlwapi.h"
 #include "wine/debug.h"
@@ -48,6 +47,10 @@
 
 WINE_DEFAULT_DEBUG_CHANNEL (shell);
 
+/* SHCreateLinks flags */
+#define SHCLF_PREFIXNAME        0x01
+#define SHCLF_CREATEONDESKTOP   0x02
+
 /***************************************************************************
  *  SHELL32_GetCustomFolderAttribute (internal function)
  *
@@ -115,7 +118,7 @@ LPCWSTR GetNextElementW (LPCWSTR pszNext, LPWSTR pszOut, DWORD dwOut)
     LPCWSTR pszTail = pszNext;
     DWORD dwCopy;
 
-    TRACE ("(%s %p 0x%08x)\n", debugstr_w(pszNext), pszOut, dwOut);
+    TRACE ("(%s %p 0x%08lx)\n", debugstr_w(pszNext), pszOut, dwOut);
 
     *pszOut = 0;
 
@@ -133,7 +136,7 @@ LPCWSTR GetNextElementW (LPCWSTR pszNext, LPWSTR pszOut, DWORD dwOut)
     else
 	pszTail = NULL;
 
-    TRACE ("--(%s %s 0x%08x %p)\n", debugstr_w (pszNext), debugstr_w (pszOut), dwOut, pszTail);
+    TRACE ("--(%s %s 0x%08lx %p)\n", debugstr_w (pszNext), debugstr_w (pszOut), dwOut, pszTail);
     return pszTail;
 }
 
@@ -167,7 +170,7 @@ HRESULT SHELL32_ParseNextElement (IShellFolder2 * psf, HWND hwndOwner, LPBC pbc,
     ILFree (*pidlInOut);
     *pidlInOut = pidlTemp;
 
-    TRACE ("-- pidl=%p ret=0x%08x\n", pidlInOut ? *pidlInOut : NULL, hr);
+    TRACE ("-- pidl=%p ret=0x%08lx\n", pidlInOut ? *pidlInOut : NULL, hr);
     return hr;
 }
 
@@ -228,7 +231,7 @@ static HRESULT SHELL32_CoCreateInitSF (LPCITEMIDLIST pidlRoot, LPCWSTR pathRoot,
 	}
 	ILFree (pidlAbsolute);
     }
-    TRACE ("-- (%p) ret=0x%08x\n", *ppvOut, hr);
+    TRACE ("-- (%p) ret=0x%08lx\n", *ppvOut, hr);
     return hr;
 }
 
@@ -305,7 +308,7 @@ HRESULT SHELL32_BindToChild (LPCITEMIDLIST pidlRoot, const CLSID *clsidChild,
         IShellFolder_Release (pSF);
     }
 
-    TRACE ("-- returning (%p) 0x%08x\n", *ppvOut, hr);
+    TRACE ("-- returning (%p) 0x%08lx\n", *ppvOut, hr);
 
     return hr;
 }
@@ -330,7 +333,7 @@ HRESULT SHELL32_GetDisplayNameOfChild (IShellFolder2 * psf,
     LPITEMIDLIST pidlFirst;
     HRESULT hr;
 
-    TRACE ("(%p)->(pidl=%p 0x%08x %p 0x%08x)\n", psf, pidl, dwFlags, szOut, dwOutLen);
+    TRACE ("(%p)->(pidl=%p 0x%08lx %p 0x%08lx)\n", psf, pidl, dwFlags, szOut, dwOutLen);
     pdump (pidl);
 
     pidlFirst = ILCloneFirst (pidl);
@@ -353,7 +356,7 @@ HRESULT SHELL32_GetDisplayNameOfChild (IShellFolder2 * psf,
     } else
 	hr = E_OUTOFMEMORY;
 
-    TRACE ("-- ret=0x%08x %s\n", hr, debugstr_w(szOut));
+    TRACE ("-- ret=0x%08lx %s\n", hr, debugstr_w(szOut));
 
     return hr;
 }
@@ -397,11 +400,11 @@ HRESULT SHELL32_GetItemAttributes (IShellFolder2 *psf, LPCITEMIDLIST pidl, LPDWO
                           SFGAO_FILESYSTEM |        /*0x40000000 */
                           SFGAO_HASSUBFOLDER;       /*0x80000000 */
     
-    TRACE ("0x%08x\n", *pdwAttributes);
+    TRACE ("0x%08lx\n", *pdwAttributes);
 
     if (*pdwAttributes & ~dwSupportedAttr)
     {
-        WARN ("attributes 0x%08x not implemented\n", (*pdwAttributes & ~dwSupportedAttr));
+        WARN ("attributes 0x%08lx not implemented\n", (*pdwAttributes & ~dwSupportedAttr));
         *pdwAttributes &= dwSupportedAttr;
     }
 
@@ -417,7 +420,7 @@ HRESULT SHELL32_GetItemAttributes (IShellFolder2 *psf, LPCITEMIDLIST pidl, LPDWO
     } else if (_ILGetDataPointer (pidl)) {
 	DWORD file_attr = _ILGetFileAttributes (pidl, NULL, 0);
 
-        if (!file_attr && has_guid) {
+        if (!file_attr) {
 	    WCHAR path[MAX_PATH];
 	    STRRET strret;
 
@@ -464,7 +467,7 @@ HRESULT SHELL32_GetItemAttributes (IShellFolder2 *psf, LPCITEMIDLIST pidl, LPDWO
     } else {
 	*pdwAttributes &= SFGAO_HASSUBFOLDER|SFGAO_FOLDER|SFGAO_FILESYSANCESTOR|SFGAO_DROPTARGET|SFGAO_HASPROPSHEET|SFGAO_CANRENAME|SFGAO_CANLINK;
     }
-    TRACE ("-- 0x%08x\n", *pdwAttributes);
+    TRACE ("-- 0x%08lx\n", *pdwAttributes);
     return S_OK;
 }
 
@@ -615,7 +618,7 @@ HRESULT WINAPI SHCreateLinks( HWND hWnd, LPCSTR lpszDir, LPDATAOBJECT lpDataObje
 HRESULT WINAPI SHOpenFolderAndSelectItems( PCIDLIST_ABSOLUTE pidlFolder, UINT cidl,
                               PCUITEMID_CHILD_ARRAY *apidl, DWORD flags )
 {
-    FIXME("%p %u %p 0x%x: stub\n", pidlFolder, cidl, apidl, flags);
+    FIXME("%p %u %p 0x%lx: stub\n", pidlFolder, cidl, apidl, flags);
     return E_NOTIMPL;
 }
 
@@ -653,7 +656,7 @@ HRESULT WINAPI SHGetSetFolderCustomSettings( LPSHFOLDERCUSTOMSETTINGS fcs, PCWST
         }
     }
     else
-        FIXME("%p %s 0x%x: stub\n", fcs, debugstr_w(path), flag);
+        FIXME("%p %s 0x%lx: stub\n", fcs, debugstr_w(path), flag);
 
     return hr;
 }
