@@ -388,7 +388,7 @@ static void test_get_set(void)
 
 void create_lnk_(int line, const WCHAR* path, lnk_desc_t* desc)
 {
-    HRESULT r;
+    HRESULT r, init_dirty;
     IShellLinkA *sl;
     IPersistFile *pf;
 
@@ -451,6 +451,17 @@ void create_lnk_(int line, const WCHAR* path, lnk_desc_t* desc)
         IPersistFile_GetCurFile(pf, NULL);
     }
 
+        init_dirty = IPersistFile_IsDirty(pf); /* empty links start off as clean */
+        r = IPersistFile_Save(pf, NULL, FALSE);
+        lok(r == S_OK || r == E_INVALIDARG /* before Windows 7 */, "save failed (0x%08x)\n", r);
+        r = IPersistFile_IsDirty(pf);
+        lok(r == init_dirty, "dirty (0x%08x)\n", r);
+
+        r = IPersistFile_Save(pf, NULL, TRUE);
+        lok(r == S_OK || r == E_INVALIDARG /* before Windows 7 */, "save failed (0x%08x)\n", r);
+        r = IPersistFile_IsDirty(pf);
+        lok(r == init_dirty, "dirty (0x%08x)\n", r);
+
         /* test GetCurFile before ::Save */
         str = (LPWSTR)0xdeadbeef;
         r = IPersistFile_GetCurFile(pf, &str);
@@ -459,6 +470,18 @@ void create_lnk_(int line, const WCHAR* path, lnk_desc_t* desc)
 
         r = IPersistFile_Save(pf, path, TRUE);
         lok(r == S_OK, "save failed (0x%08x)\n", r);
+        r = IPersistFile_IsDirty(pf);
+        lok(r == S_FALSE, "dirty (0x%08x)\n", r);
+
+        /* test GetCurFile after ::Save */
+        r = IPersistFile_GetCurFile(pf, &str);
+        lok(r == S_OK, "got 0x%08x\n", r);
+        lok(str != NULL, "Didn't expect NULL\n");
+        lok(!wcscmp(path, str), "Expected %s, got %s\n", wine_dbgstr_w(path), wine_dbgstr_w(str));
+        CoTaskMemFree(str);
+
+        r = IPersistFile_Save(pf, NULL, TRUE);
+        lok(r == S_OK, "save failed (0x%08x)\n", r);
 
         /* test GetCurFile after ::Save */
         r = IPersistFile_GetCurFile(pf, &str);
@@ -1158,7 +1181,7 @@ static void test_ExtractIcon(void)
 
     /* specified instance handle */
     hicon = ExtractIconA(GetModuleHandleA("shell32.dll"), NULL, 0);
-todo_wine
+    todo_wine
     ok(hicon == NULL, "Got icon %p\n", hicon);
     hicon2 = ExtractIconA(GetModuleHandleA("shell32.dll"), "shell32.dll", -1);
     ok(hicon2 != NULL, "Got icon %p\n", hicon2);
@@ -1184,14 +1207,14 @@ todo_wine
     CloseHandle(file);
 
     hicon = ExtractIconA(NULL, path, 0);
-todo_wine
+    todo_wine
     ok(hicon == NULL, "Got icon %p\n", hicon);
 
     hicon = ExtractIconA(NULL, path, -1);
     ok(hicon == NULL, "Got icon %p\n", hicon);
 
     hicon = ExtractIconA(NULL, path, 1);
-todo_wine
+    todo_wine
     ok(hicon == NULL, "Got icon %p\n", hicon);
 
     r = DeleteFileA(path);
@@ -1232,14 +1255,14 @@ if (0)
     CloseHandle(file);
 
     hicon = ExtractIconW(NULL, pathW, 0);
-todo_wine
+    todo_wine
     ok(hicon == NULL, "Got icon %p\n", hicon);
 
     hicon = ExtractIconW(NULL, pathW, -1);
     ok(hicon == NULL, "Got icon %p\n", hicon);
 
     hicon = ExtractIconW(NULL, pathW, 1);
-todo_wine
+    todo_wine
     ok(hicon == NULL, "Got icon %p\n", hicon);
 
     r = DeleteFileW(pathW);
