@@ -74,7 +74,7 @@ static void __cdecl test_invalid_parameter_handler(const wchar_t *expression,
     ok(function == NULL, "function is not NULL\n");
     ok(file == NULL, "file is not NULL\n");
     ok(line == 0, "line = %u\n", line);
-    ok(arg == 0, "arg = %lx\n", (UINT_PTR)arg);
+    ok(arg == 0, "arg = %Ix\n", arg);
 }
 
 static int WINAPIV vsprintf_wrapper(unsigned __int64 options, char *str,
@@ -838,13 +838,31 @@ static void test_printf_fp(void)
 
             r = vsprintf_wrapper(flags[j], buf, sizeof(buf), tests[i].fmt, tests[i].d);
             ok(r == strlen(res) || broken(broken_res && r == strlen(broken_res)),
-                    "%d,%d) r = %d, expected %d\n", i, j, r, strlen(res));
+                    "%d,%d) r = %d, expected %Id\n", i, j, r, strlen(res));
             ok(!strcmp(buf, res) || broken(broken_res && !strcmp(buf, broken_res)),
                     "%d,%d) buf = %s, expected %s\n", i, j, buf, res);
         }
     }
 }
 
+static void test_printf_width_specification(void)
+{
+    int r;
+    char buffer[20];
+
+    r = vsprintf_wrapper(0, buffer, sizeof(buffer), "%0*2d", 1, 3);
+    ok(r == 2, "r = %d\n", r);
+    ok(!strcmp(buffer, "03"), "buffer wrong, got=%s\n", buffer);
+
+    r = vsprintf_wrapper(0, buffer, sizeof(buffer), "%*0d", 1, 2);
+    ok(r == 1, "r = %d\n", r);
+    ok(!strcmp(buffer, "2"), "buffer wrong, got=%s\n", buffer);
+
+    r = vsprintf_wrapper(0, buffer, sizeof(buffer), "% *2d", 0, 7);
+    ok(r == 2, "r = %d\n", r);
+    ok(!strcmp(buffer, " 7"), "buffer wrong, got=%s\n", buffer);
+}
+
 START_TEST(printf)
 {
     ok(_set_invalid_parameter_handler(test_invalid_parameter_handler) == NULL,
@@ -862,4 +880,5 @@ START_TEST(printf)
     test_printf_c99();
     test_printf_natural_string();
     test_printf_fp();
+    test_printf_width_specification();
 }
