@@ -52,7 +52,7 @@ static ULONG WINAPI uia_object_wrapper_AddRef(IUnknown *iface)
     struct uia_object_wrapper *wrapper = impl_uia_object_wrapper_from_IUnknown(iface);
     ULONG refcount = InterlockedIncrement(&wrapper->refcount);
 
-    TRACE("%p, refcount %d\n", iface, refcount);
+    TRACE("%p, refcount %ld\n", iface, refcount);
 
     return refcount;
 }
@@ -62,7 +62,7 @@ static ULONG WINAPI uia_object_wrapper_Release(IUnknown *iface)
     struct uia_object_wrapper *wrapper = impl_uia_object_wrapper_from_IUnknown(iface);
     ULONG refcount = InterlockedDecrement(&wrapper->refcount);
 
-    TRACE("%p, refcount %d\n", iface, refcount);
+    TRACE("%p, refcount %ld\n", iface, refcount);
     if (!refcount)
     {
         IUnknown_Release(wrapper->marshaler);
@@ -178,7 +178,7 @@ ULONG WINAPI hwnd_host_provider_AddRef(IRawElementProviderSimple *iface)
     struct hwnd_host_provider *host_prov = impl_from_hwnd_host_provider(iface);
     ULONG refcount = InterlockedIncrement(&host_prov->refcount);
 
-    TRACE("%p, refcount %d\n", iface, refcount);
+    TRACE("%p, refcount %ld\n", iface, refcount);
 
     return refcount;
 }
@@ -188,7 +188,7 @@ ULONG WINAPI hwnd_host_provider_Release(IRawElementProviderSimple *iface)
     struct hwnd_host_provider *host_prov = impl_from_hwnd_host_provider(iface);
     ULONG refcount = InterlockedDecrement(&host_prov->refcount);
 
-    TRACE("%p, refcount %d\n", iface, refcount);
+    TRACE("%p, refcount %ld\n", iface, refcount);
 
     if (!refcount)
         heap_free(host_prov);
@@ -311,7 +311,7 @@ int WINAPI UiaLookupId(enum AutomationIdentifierType type, const GUID *guid)
 LRESULT WINAPI UiaReturnRawElementProvider(HWND hwnd, WPARAM wParam,
         LPARAM lParam, IRawElementProviderSimple *elprov)
 {
-    FIXME("(%p, %lx, %lx, %p) stub!\n", hwnd, wParam, lParam, elprov);
+    FIXME("(%p, %Ix, %Ix, %p) stub!\n", hwnd, wParam, lParam, elprov);
     return 0;
 }
 
@@ -324,6 +324,15 @@ HRESULT WINAPI UiaRaiseAutomationEvent(IRawElementProviderSimple *provider, EVEN
     return S_OK;
 }
 
+/***********************************************************************
+ *          UiaRaiseAutomationPropertyChangedEvent (uiautomationcore.@)
+ */
+HRESULT WINAPI UiaRaiseAutomationPropertyChangedEvent(IRawElementProviderSimple *provider, PROPERTYID id, VARIANT old, VARIANT new)
+{
+    FIXME("(%p, %d, %s, %s): stub\n", provider, id, debugstr_variant(&old), debugstr_variant(&new));
+    return S_OK;
+}
+
 void WINAPI UiaRegisterProviderCallback(UiaProviderCallback *callback)
 {
     FIXME("(%p): stub\n", callback);
