@@ -25,15 +25,10 @@
 
 #include "ntstatus.h"
 #define WIN32_NO_STATUS
-#include "windef.h"
-#include "winbase.h"
-#include "wingdi.h"
-#include "winuser.h"
-#include "wine/server.h"
-#include "win.h"
 #include "user_private.h"
+#include "win.h"
 #include "controls.h"
-#include "wine/gdi_driver.h"
+#include "wine/server.h"
 #include "wine/list.h"
 #include "wine/debug.h"
 
@@ -644,6 +639,7 @@ static HRGN send_ncpaint( HWND hwnd, HWND *child, UINT *flags )
 {
     HRGN whole_rgn = get_update_region( hwnd, flags, child );
     HRGN client_rgn = 0;
+    DWORD style;
 
     if (child) hwnd = *child;
 
@@ -683,7 +679,17 @@ static HRGN send_ncpaint( HWND hwnd, HWND *child, UINT *flags )
 
         if (whole_rgn) /* NOTE: WM_NCPAINT allows wParam to be 1 */
         {
-            if (*flags & UPDATE_NONCLIENT) SendMessageW( hwnd, WM_NCPAINT, (WPARAM)whole_rgn, 0 );
+            if (*flags & UPDATE_NONCLIENT)
+            {
+                /* Mark standard scroll bars as not painted before sending WM_NCPAINT */
+                style = GetWindowLongW( hwnd, GWL_STYLE );
+                if (style & WS_HSCROLL)
+                    SCROLL_SetStandardScrollPainted( hwnd, SB_HORZ, FALSE );
+                if (style & WS_VSCROLL)
+                    SCROLL_SetStandardScrollPainted( hwnd, SB_VERT, FALSE );
+
+                SendMessageW( hwnd, WM_NCPAINT, (WPARAM)whole_rgn, 0 );
+            }
             if (whole_rgn > (HRGN)1) DeleteObject( whole_rgn );
         }
         SetThreadDpiAwarenessContext( context );
@@ -892,7 +898,7 @@ static HWND fix_caret(HWND hWnd, const RECT *scroll_rect, INT dx, INT dy,
     RECT rect, mapped_rcCaret;
 
     info.cbSize = sizeof(info);
-    if (!GetGUIThreadInfo( GetCurrentThreadId(), &info )) return 0;
+    if (!NtUserGetGUIThreadInfo( GetCurrentThreadId(), &info )) return 0;
     if (!info.hwndCaret) return 0;
     
     mapped_rcCaret = info.rcCaret;
@@ -1511,7 +1517,7 @@ static INT scroll_window( HWND hwnd, INT dx, INT dy, const RECT *rect, const REC
         hDC = GetDCEx( hwnd, 0, dcxflags);
         if (hDC)
         {
-            ScrollDC( hDC, dx, dy, &rc, &cliprc, hrgnUpdate, rcUpdate );
+            NtUserScrollDC( hDC, dx, dy, &rc, &cliprc, hrgnUpdate, rcUpdate );
 
             ReleaseDC( hwnd, hDC );
 
@@ -1637,119 +1643,6 @@ BOOL WINAPI ScrollWindow( HWND hwnd, INT dx, INT dy,
                           SW_INVALIDATE | SW_ERASE | (rect ? 0 : SW_SCROLLCHILDREN), FALSE ) != ERROR;
 }
 
-
-/*************************************************************************
- *		ScrollDC (USER32.@)
- *
- * dx, dy, lprcScroll and lprcClip are all in logical coordinates (msdn is
- * wrong) hrgnUpdate is returned in device coordinates with rcUpdate in
- * logical coordinates.
- */
-BOOL WINAPI ScrollDC( HDC hdc, INT dx, INT dy, const RECT *scroll, const RECT *clip,
-                      HRGN ret_update_rgn, LPRECT update_rect )
-
-{
-    HRGN update_rgn = ret_update_rgn;
-    RECT src_rect, clip_rect, offset;
-    INT dxdev, dydev;
-    HRGN dstrgn, cliprgn, visrgn;
-    BOOL ret;
-
-    TRACE( "dx,dy %d,%d scroll %s clip %s update %p rect %p\n",
-           dx, dy, wine_dbgstr_rect(scroll), wine_dbgstr_rect(clip), ret_update_rgn, update_rect );
-
-    /* get the visible region */
-    visrgn = CreateRectRgn( 0, 0, 0, 0 );
-    GetRandomRgn( hdc, visrgn, SYSRGN );
-    if (!(GetVersion() & 0x80000000))
-    {
-        POINT org;
-        GetDCOrgEx( hdc, &org );
-        OffsetRgn( visrgn, -org.x, -org.y );
-    }
-
-    /* intersect with the clipping region if the DC has one */
-    cliprgn = CreateRectRgn( 0, 0, 0, 0);
-    if (GetClipRgn( hdc, cliprgn ) != 1)
-    {
-        DeleteObject( cliprgn );
-        cliprgn = 0;
-    }
-    else CombineRgn( visrgn, visrgn, cliprgn, RGN_AND );
-
-    /* only those pixels in the scroll rectangle that remain in the clipping
-     * rect are scrolled. */
-    if (clip)
-        clip_rect = *clip;
-    else
-        GetClipBox( hdc, &clip_rect );
-    src_rect = clip_rect;
-    OffsetRect( &clip_rect, -dx, -dy );
-    IntersectRect( &src_rect, &src_rect, &clip_rect );
-
-    /* if an scroll rectangle is specified, only the pixels within that
-     * rectangle are scrolled */
-    if (scroll) IntersectRect( &src_rect, &src_rect, scroll );
-
-    /* now convert to device coordinates */
-    LPtoDP( hdc, (LPPOINT)&src_rect, 2 );
-    TRACE( "source rect: %s\n", wine_dbgstr_rect(&src_rect) );
-    /* also dx and dy */
-    SetRect( &offset, 0, 0, dx, dy );
-    LPtoDP( hdc, (LPPOINT)&offset, 2 );
-    dxdev = offset.right - offset.left;
-    dydev = offset.bottom - offset.top;
-
-    /* now intersect with the visible region to get the pixels that will actually scroll */
-    dstrgn = CreateRectRgnIndirect( &src_rect );
-    CombineRgn( dstrgn, dstrgn, visrgn, RGN_AND );
-    OffsetRgn( dstrgn, dxdev, dydev );
-    ExtSelectClipRgn( hdc, dstrgn, RGN_AND );
-
-    /* compute the update areas.  This is the combined clip rectangle
-     * minus the scrolled region, and intersected with the visible region. */
-    if (ret_update_rgn || update_rect)
-    {
-        /* intersect clip and scroll rectangles, allowing NULL values */
-        if (scroll)
-        {
-            if (clip)
-                IntersectRect( &clip_rect, clip, scroll );
-            else
-                clip_rect = *scroll;
-        }
-        else if (clip)
-            clip_rect = *clip;
-        else
-            GetClipBox( hdc, &clip_rect );
-
-        /* Convert the combined clip rectangle to device coordinates */
-        LPtoDP( hdc, (LPPOINT)&clip_rect, 2 );
-        if (update_rgn)
-            SetRectRgn( update_rgn, clip_rect.left, clip_rect.top, clip_rect.right, clip_rect.bottom );
-        else
-            update_rgn = CreateRectRgnIndirect( &clip_rect );
-
-        CombineRgn( update_rgn, update_rgn, visrgn, RGN_AND );
-        CombineRgn( update_rgn, update_rgn, dstrgn, RGN_DIFF );
-    }
-
-    ret = USER_Driver->pScrollDC( hdc, dx, dy, update_rgn );
-
-    if (ret && update_rect)
-    {
-        GetRgnBox( update_rgn, update_rect );
-        DPtoLP( hdc, (LPPOINT)update_rect, 2 );
-        TRACE( "returning update_rect %s\n", wine_dbgstr_rect(update_rect) );
-    }
-    if (!ret_update_rgn) DeleteObject( update_rgn );
-    SelectClipRgn( hdc, cliprgn );
-    if (cliprgn) DeleteObject( cliprgn );
-    DeleteObject( visrgn );
-    DeleteObject( dstrgn );
-    return ret;
-}
-
 /************************************************************************
  *		PrintWindow (USER32.@)
  *
