@@ -35,34 +35,16 @@ WINE_DEFAULT_DEBUG_CHANNEL(graphics);
 
 HMODULE user32_module = 0;
 
-static CRITICAL_SECTION user_section;
-static CRITICAL_SECTION_DEBUG critsect_debug =
-{
-    0, 0, &user_section,
-    { &critsect_debug.ProcessLocksList, &critsect_debug.ProcessLocksList },
-      0, 0, { (DWORD_PTR)(__FILE__ ": user_section") }
-};
-static CRITICAL_SECTION user_section = { &critsect_debug, -1, 0, 0, 0, 0 };
-
-static HPALETTE (WINAPI *pfnGDISelectPalette)( HDC hdc, HPALETTE hpal, WORD bkgnd );
-static UINT (WINAPI *pfnGDIRealizePalette)( HDC hdc );
-static HPALETTE hPrimaryPalette;
-
 static DWORD exiting_thread_id;
 
 extern void WDML_NotifyThreadDetach(void);
 
-#ifdef __MINGW32__
-/* work around a Mingw build issue where _wassert causes a duplicate reference to MessageBoxW */
-void __cdecl _wassert( const WCHAR *msg, const WCHAR *file, unsigned line) { abort(); }
-#endif
-
 /***********************************************************************
  *           USER_Lock
  */
 void USER_Lock(void)
 {
-    EnterCriticalSection( &user_section );
+    NtUserCallOneParam( 0, NtUserLock );
 }
 
 
@@ -71,7 +53,7 @@ void USER_Lock(void)
  */
 void USER_Unlock(void)
 {
-    LeaveCriticalSection( &user_section );
+    NtUserCallOneParam( 1, NtUserLock );
 }
 
 
@@ -82,78 +64,16 @@ void USER_Unlock(void)
  */
 void USER_CheckNotLock(void)
 {
-    if (RtlIsCriticalSectionLockedByThread(&user_section))
-    {
-        ERR( "BUG: holding USER lock\n" );
-        DebugBreak();
-    }
+    NtUserCallOneParam( 2, NtUserLock );
 }
 
 
 /***********************************************************************
- *		UserSelectPalette (Not a Windows API)
+ *             UserRealizePalette (USER32.@)
  */
-static HPALETTE WINAPI UserSelectPalette( HDC hDC, HPALETTE hPal, BOOL bForceBackground )
+UINT WINAPI UserRealizePalette( HDC hdc )
 {
-    WORD wBkgPalette = 1;
-
-    if (!bForceBackground && (hPal != GetStockObject(DEFAULT_PALETTE)))
-    {
-        HWND hwnd = WindowFromDC( hDC );
-        if (hwnd)
-        {
-            HWND hForeground = GetForegroundWindow();
-            /* set primary palette if it's related to current active */
-            if (hForeground == hwnd || IsChild(hForeground,hwnd))
-            {
-                wBkgPalette = 0;
-                hPrimaryPalette = hPal;
-            }
-        }
-    }
-    return pfnGDISelectPalette( hDC, hPal, wBkgPalette);
-}
-
-
-/***********************************************************************
- *		UserRealizePalette (USER32.@)
- */
-UINT WINAPI UserRealizePalette( HDC hDC )
-{
-    UINT realized = pfnGDIRealizePalette( hDC );
-
-    /* do not send anything if no colors were changed */
-    if (realized && GetCurrentObject( hDC, OBJ_PAL ) == hPrimaryPalette)
-    {
-        /* send palette change notification */
-        HWND hWnd = WindowFromDC( hDC );
-        if (hWnd) SendMessageTimeoutW( HWND_BROADCAST, WM_PALETTECHANGED, (WPARAM)hWnd, 0,
-                                       SMTO_ABORTIFHUNG, 2000, NULL );
-    }
-    return realized;
-}
-
-
-/***********************************************************************
- *           palette_init
- *
- * Patch the function pointers in GDI for SelectPalette and RealizePalette
- */
-static void palette_init(void)
-{
-    void **ptr;
-    HMODULE module = GetModuleHandleA( "gdi32" );
-    if (!module)
-    {
-        ERR( "cannot get GDI32 handle\n" );
-        return;
-    }
-    if ((ptr = (void**)GetProcAddress( module, "pfnSelectPalette" )))
-        pfnGDISelectPalette = InterlockedExchangePointer( ptr, UserSelectPalette );
-    else ERR( "cannot find pfnSelectPalette in GDI32\n" );
-    if ((ptr = (void**)GetProcAddress( module, "pfnRealizePalette" )))
-        pfnGDIRealizePalette = InterlockedExchangePointer( ptr, UserRealizePalette );
-    else ERR( "cannot find pfnRealizePalette in GDI32\n" );
+    return NtUserCallOneParam( HandleToUlong(hdc), NtUserRealizePalette );
 }
 
 
@@ -213,10 +133,28 @@ static void dpiaware_init(void)
     }
 }
 
+static const struct user_callbacks user_funcs =
+{
+    GetDesktopWindow,
+    GetWindowRect,
+    IsChild,
+    RedrawWindow,
+    SendMessageTimeoutW,
+    WindowFromDC,
+    MSG_SendInternalMessageTimeout,
+};
 
-static const void *kernel_callback_table[] =
+static void WINAPI User32CallFreeIcon( ULONG *param, ULONG size )
+{
+    wow_handlers.free_icon_param( *param );
+}
+
+static const void *kernel_callback_table[NtUserCallCount] =
 {
     User32CallEnumDisplayMonitor,
+    User32CallWinEventHook,
+    User32CallWindowsHook,
+    User32CallFreeIcon,
 };
 
 
@@ -227,15 +165,15 @@ static BOOL process_attach(void)
 {
     NtCurrentTeb()->Peb->KernelCallbackTable = kernel_callback_table;
 
+    /* FIXME: should not be needed */
+    NtUserCallOneParam( (UINT_PTR)&user_funcs, NtUserSetCallbacks );
+
     dpiaware_init();
     register_desktop_class();
 
     /* Initialize system colors and metrics */
     SYSPARAMS_Init();
 
-    /* Setup palette function pointers */
-    palette_init();
-
     return TRUE;
 }
 
@@ -259,12 +197,11 @@ static void thread_detach(void)
     exiting_thread_id = GetCurrentThreadId();
 
     WDML_NotifyThreadDetach();
-    USER_Driver->pThreadDetach();
 
+    NtUserCallNoParam( NtUserThreadDetach );
     destroy_thread_windows();
     CloseHandle( thread_info->server_queue );
     HeapFree( GetProcessHeap(), 0, thread_info->wmchar_data );
-    HeapFree( GetProcessHeap(), 0, thread_info->key_state );
     HeapFree( GetProcessHeap(), 0, thread_info->rawinput );
 
     exiting_thread_id = 0;
@@ -295,7 +232,6 @@ BOOL WINAPI DllMain( HINSTANCE inst, DWORD reason, LPVOID reserved )
     case DLL_PROCESS_DETACH:
         USER_unload_driver();
         FreeLibrary(imm32_module);
-        DeleteCriticalSection(&user_section);
         break;
     }
     return ret;
