@@ -2,6 +2,7 @@
  * Win32 5.1 Theme drawing
  *
  * Copyright (C) 2003 Kevin Koltzau
+ * Copyright 2021 Zhiyi Zhang for CodeWeavers
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,6 +19,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
+#define COBJMACROS
+
 #include <stdlib.h>
 #include <stdarg.h>
 
@@ -25,9 +28,11 @@
 #include "winbase.h"
 #include "winuser.h"
 #include "wingdi.h"
+#include "commctrl.h"
+#include "commoncontrols.h"
 #include "vfwmsgs.h"
 #include "uxtheme.h"
-#include "tmschema.h"
+#include "vssym32.h"
 
 #include "msstyles.h"
 #include "uxthemedll.h"
@@ -47,20 +52,33 @@ extern ATOM atDialogThemeEnabled;
 /***********************************************************************
  *      EnableThemeDialogTexture                            (UXTHEME.@)
  */
-HRESULT WINAPI EnableThemeDialogTexture(HWND hwnd, DWORD dwFlags)
+HRESULT WINAPI EnableThemeDialogTexture(HWND hwnd, DWORD new_flag)
 {
+    DWORD old_flag = 0;
     BOOL res;
 
-    TRACE("(%p,0x%08x\n", hwnd, dwFlags);
-    res = SetPropW (hwnd, (LPCWSTR)MAKEINTATOM(atDialogThemeEnabled), 
-                    UlongToHandle(dwFlags|0x80000000));
-        /* 0x80000000 serves as a "flags set" flag */
-    if (!res)
-          return HRESULT_FROM_WIN32(GetLastError());
-    if (dwFlags & ETDT_USETABTEXTURE)
-        return SetWindowTheme (hwnd, NULL, L"Tab");
-    else
-        return SetWindowTheme (hwnd, NULL, NULL);
+    TRACE("(%p,%#lx\n", hwnd, new_flag);
+
+    new_flag &= ETDT_VALIDBITS;
+
+    if (new_flag == 0)
+        return S_OK;
+
+    if (new_flag & ETDT_DISABLE)
+    {
+        new_flag = ETDT_DISABLE;
+        old_flag = 0;
+    }
+
+    if (new_flag & ~ETDT_DISABLE)
+    {
+        old_flag = HandleToUlong(GetPropW(hwnd, (LPCWSTR)MAKEINTATOM(atDialogThemeEnabled)));
+        old_flag &= ~ETDT_DISABLE;
+    }
+
+    new_flag = new_flag | old_flag;
+    res = SetPropW(hwnd, (LPCWSTR)MAKEINTATOM(atDialogThemeEnabled), UlongToHandle(new_flag));
+    return res ? S_OK : HRESULT_FROM_WIN32(GetLastError());
  }
 
 /***********************************************************************
@@ -69,14 +87,11 @@ HRESULT WINAPI EnableThemeDialogTexture(HWND hwnd, DWORD dwFlags)
 BOOL WINAPI IsThemeDialogTextureEnabled(HWND hwnd)
 {
     DWORD dwDialogTextureFlags;
+
     TRACE("(%p)\n", hwnd);
 
     dwDialogTextureFlags = HandleToUlong( GetPropW( hwnd, (LPCWSTR)MAKEINTATOM(atDialogThemeEnabled) ));
-    if (dwDialogTextureFlags == 0) 
-        /* Means EnableThemeDialogTexture wasn't called for this dialog */
-        return TRUE;
-
-    return (dwDialogTextureFlags & ETDT_ENABLE) && !(dwDialogTextureFlags & ETDT_DISABLE);
+    return dwDialogTextureFlags && !(dwDialogTextureFlags & ETDT_DISABLE);
 }
 
 /***********************************************************************
@@ -144,49 +159,88 @@ HRESULT WINAPI DrawThemeBackground(HTHEME hTheme, HDC hdc, int iPartId,
     return DrawThemeBackgroundEx(hTheme, hdc, iPartId, iStateId, pRect, &opts);
 }
 
+/* Map integer 1..7 to TMT_MINDPI1..TMT_MINDPI7 */
+static int mindpi_index_to_property(int index)
+{
+    return index <= 5 ? TMT_MINDPI1 + index - 1 : TMT_MINDPI6 + index - 6;
+}
+
+/* Map integer 1..7 to TMT_MINSIZE1..TMT_MINSIZE7 */
+static int minsize_index_to_property(int index)
+{
+    return index <= 5 ? TMT_MINSIZE1 + index - 1 : TMT_MINSIZE6 + index - 6;
+}
+
+/* Map integer 1..7 to TMT_IMAGEFILE1..TMT_IMAGEFILE7 */
+static int imagefile_index_to_property(int index)
+{
+    return index <= 5 ? TMT_IMAGEFILE1 + index - 1 : TMT_IMAGEFILE6 + index - 6;
+}
+
 /***********************************************************************
  *      UXTHEME_SelectImage
  *
  * Select the image to use
  */
-static PTHEME_PROPERTY UXTHEME_SelectImage(HTHEME hTheme, HDC hdc, int iPartId, int iStateId, const RECT *pRect, BOOL glyph)
+static PTHEME_PROPERTY UXTHEME_SelectImage(HTHEME hTheme, int iPartId, int iStateId,
+                                           const RECT *pRect, BOOL glyph, int *imageDpi)
 {
-    PTHEME_PROPERTY tp;
-    int imageselecttype = IST_NONE;
+    int imageselecttype = IST_NONE, glyphtype = GT_NONE;
+    PTHEME_PROPERTY tp = NULL;
     int i;
-    int image;
-    if(glyph)
-        image = TMT_GLYPHIMAGEFILE;
-    else
-        image = TMT_IMAGEFILE;
 
-    if((tp=MSSTYLES_FindProperty(hTheme, iPartId, iStateId, TMT_FILENAME, image)))
-        return tp;
+    if (imageDpi)
+        *imageDpi = 96;
+
+    /* Try TMT_IMAGEFILE first when drawing part background and the part contains glyph images.
+     * Otherwise, search TMT_IMAGEFILE1~7 and then TMT_IMAGEFILE or TMT_GLYPHIMAGEFILE */
+    if (!glyph)
+    {
+        GetThemeEnumValue(hTheme, iPartId, iStateId, TMT_GLYPHTYPE, &glyphtype);
+        if (glyphtype == GT_IMAGEGLYPH &&
+            (tp = MSSTYLES_FindProperty(hTheme, iPartId, iStateId, TMT_FILENAME, TMT_IMAGEFILE)))
+                return tp;
+    }
+
     GetThemeEnumValue(hTheme, iPartId, iStateId, TMT_IMAGESELECTTYPE, &imageselecttype);
 
     if(imageselecttype == IST_DPI) {
         int reqdpi = 0;
-        int screendpi = GetDeviceCaps(hdc, LOGPIXELSX);
-        for(i=4; i>=0; i--) {
+        int dpi = MSSTYLES_GetThemeDPI(hTheme);
+        for (i = 7; i >= 1; i--)
+        {
             reqdpi = 0;
-            if(SUCCEEDED(GetThemeInt(hTheme, iPartId, iStateId, i + TMT_MINDPI1, &reqdpi))) {
-                if(reqdpi != 0 && screendpi >= reqdpi) {
-                    TRACE("Using %d DPI, image %d\n", reqdpi, i + TMT_IMAGEFILE1);
-                    return MSSTYLES_FindProperty(hTheme, iPartId, iStateId, TMT_FILENAME, i + TMT_IMAGEFILE1);
+            if (SUCCEEDED(GetThemeInt(hTheme, iPartId, iStateId, mindpi_index_to_property(i),
+                                      &reqdpi)))
+            {
+                if (reqdpi != 0 && dpi >= reqdpi)
+                {
+                    TRACE("Using %d DPI, image %d\n", reqdpi, imagefile_index_to_property(i));
+
+                    if (imageDpi)
+                        *imageDpi = reqdpi;
+
+                    return MSSTYLES_FindProperty(hTheme, iPartId, iStateId, TMT_FILENAME,
+                                                 imagefile_index_to_property(i));
                 }
             }
         }
         /* If an image couldn't be selected, choose the first one */
-        return MSSTYLES_FindProperty(hTheme, iPartId, iStateId, TMT_FILENAME, TMT_IMAGEFILE1);
+        tp = MSSTYLES_FindProperty(hTheme, iPartId, iStateId, TMT_FILENAME, TMT_IMAGEFILE1);
     }
     else if(imageselecttype == IST_SIZE) {
         POINT size = {pRect->right-pRect->left, pRect->bottom-pRect->top};
         POINT reqsize;
-        for(i=4; i>=0; i--) {
-            PTHEME_PROPERTY fileProp = 
-                MSSTYLES_FindProperty(hTheme, iPartId, iStateId, TMT_FILENAME, i + TMT_IMAGEFILE1);
+        for (i = 7; i >= 1; i--)
+        {
+            PTHEME_PROPERTY fileProp;
+
+            fileProp = MSSTYLES_FindProperty(hTheme, iPartId, iStateId, TMT_FILENAME,
+                                             imagefile_index_to_property(i));
             if (!fileProp) continue;
-            if(FAILED(GetThemePosition(hTheme, iPartId, iStateId, i + TMT_MINSIZE1, &reqsize))) {
+            if (FAILED(GetThemePosition(hTheme, iPartId, iStateId, minsize_index_to_property(i),
+                                        &reqsize)))
+            {
                 /* fall back to size of Nth image */
                 WCHAR szPath[MAX_PATH];
                 int imagelayout = IL_HORIZONTAL;
@@ -213,14 +267,19 @@ static PTHEME_PROPERTY UXTHEME_SelectImage(HTHEME hTheme, HDC hdc, int iPartId,
                 }
             }
             if(reqsize.x <= size.x && reqsize.y <= size.y) {
-                TRACE("Using image size %dx%d, image %d\n", reqsize.x, reqsize.y, i + TMT_IMAGEFILE1);
+                TRACE("Using image size %ldx%ld, image %d\n", reqsize.x, reqsize.y,
+                      imagefile_index_to_property(i));
                 return fileProp;
             }
         }
         /* If an image couldn't be selected, choose the smallest one */
-        return MSSTYLES_FindProperty(hTheme, iPartId, iStateId, TMT_FILENAME, TMT_IMAGEFILE1);
+        tp = MSSTYLES_FindProperty(hTheme, iPartId, iStateId, TMT_FILENAME, TMT_IMAGEFILE1);
     }
-    return NULL;
+
+    if (!tp)
+        tp = MSSTYLES_FindProperty(hTheme, iPartId, iStateId, TMT_FILENAME,
+                                   glyph ? TMT_GLYPHIMAGEFILE : TMT_IMAGEFILE);
+    return tp;
 }
 
 /***********************************************************************
@@ -228,15 +287,18 @@ static PTHEME_PROPERTY UXTHEME_SelectImage(HTHEME hTheme, HDC hdc, int iPartId,
  *
  * Load image for part/state
  */
-static HRESULT UXTHEME_LoadImage(HTHEME hTheme, HDC hdc, int iPartId, int iStateId, const RECT *pRect, BOOL glyph,
-                          HBITMAP *hBmp, RECT *bmpRect, BOOL* hasImageAlpha)
+static HRESULT UXTHEME_LoadImage(HTHEME hTheme, int iPartId, int iStateId, const RECT *pRect,
+                                 BOOL glyph, HBITMAP *hBmp, RECT *bmpRect, BOOL *hasImageAlpha,
+                                 int *imageDpi)
 {
     int imagelayout = IL_HORIZONTAL;
     int imagecount = 1;
     int imagenum;
     BITMAP bmp;
     WCHAR szPath[MAX_PATH];
-    PTHEME_PROPERTY tp = UXTHEME_SelectImage(hTheme, hdc, iPartId, iStateId, pRect, glyph);
+    PTHEME_PROPERTY tp;
+
+    tp = UXTHEME_SelectImage(hTheme, iPartId, iStateId, pRect, glyph, imageDpi);
     if(!tp) {
         FIXME("Couldn't determine image for part/state %d/%d, invalid theme?\n", iPartId, iStateId);
         return E_PROP_ID_UNSUPPORTED;
@@ -484,8 +546,8 @@ static HRESULT UXTHEME_DrawImageGlyph(HTHEME hTheme, HDC hdc, int iPartId,
     POINT topleft;
     BOOL hasAlpha;
 
-    hr = UXTHEME_LoadImage(hTheme, hdc, iPartId, iStateId, pRect, TRUE, 
-        &bmpSrc, &rcSrc, &hasAlpha);
+    hr = UXTHEME_LoadImage(hTheme, iPartId, iStateId, pRect, TRUE, &bmpSrc, &rcSrc, &hasAlpha,
+                           NULL);
     if(FAILED(hr)) return hr;
     hdcSrc = CreateCompatibleDC(hdc);
     if(!hdcSrc) {
@@ -523,7 +585,7 @@ static HRESULT UXTHEME_DrawImageGlyph(HTHEME hTheme, HDC hdc, int iPartId,
 }
 
 /***********************************************************************
- *      UXTHEME_DrawImageGlyph
+ *      UXTHEME_DrawGlyph
  *
  * Draw glyph on top of background, if appropriate
  */
@@ -550,85 +612,74 @@ static HRESULT UXTHEME_DrawGlyph(HTHEME hTheme, HDC hdc, int iPartId,
  *
  * Used by GetThemePartSize and UXTHEME_DrawImageBackground
  */
-static HRESULT get_image_part_size (HTHEME hTheme, HDC hdc, int iPartId,
-                                    int iStateId, RECT *prc, THEMESIZE eSize,
-                                    POINT *psz)
+static HRESULT get_image_part_size(HTHEME hTheme, int iPartId, int iStateId, RECT *prc,
+                                   THEMESIZE eSize, POINT *psz)
 {
+    int imageDpi, dstDpi;
     HRESULT hr = S_OK;
     HBITMAP bmpSrc;
     RECT rcSrc;
     BOOL hasAlpha;
 
-    hr = UXTHEME_LoadImage(hTheme, hdc, iPartId, iStateId, prc, FALSE, 
-        &bmpSrc, &rcSrc, &hasAlpha);
+    hr = UXTHEME_LoadImage(hTheme, iPartId, iStateId, prc, FALSE, &bmpSrc, &rcSrc, &hasAlpha,
+                           &imageDpi);
     if (FAILED(hr)) return hr;
 
     switch (eSize)
     {
         case TS_DRAW:
+        {
+            int sizingType = ST_STRETCH, scalingType = TSST_NONE, stretchMark = 0;
+            POINT srcSize;
+
+            srcSize.x = rcSrc.right - rcSrc.left;
+            srcSize.y = rcSrc.bottom - rcSrc.top;
+
+            GetThemeEnumValue(hTheme, iPartId, iStateId, TMT_SIZINGTYPE, &sizingType);
+            if (sizingType == ST_TRUESIZE)
+            {
+                GetThemeEnumValue(hTheme, iPartId, iStateId, TMT_TRUESIZESCALINGTYPE, &scalingType);
+                GetThemeInt(hTheme, iPartId, iStateId, TMT_TRUESIZESTRETCHMARK, &stretchMark);
+                if (scalingType == TSST_DPI)
+                {
+                    /* Scale to DPI only if the destination DPI exceeds the source DPI by
+                     * stretchMark percent */
+                    dstDpi = MSSTYLES_GetThemeDPI(hTheme);
+                    if (dstDpi != imageDpi && MulDiv(100, dstDpi, imageDpi) >= stretchMark + 100)
+                    {
+                        srcSize.x = MulDiv(srcSize.x, dstDpi, imageDpi);
+                        srcSize.y = MulDiv(srcSize.y, dstDpi, imageDpi);
+                    }
+                }
+            }
+            *psz = srcSize;
+
             if (prc != NULL)
             {
-                RECT rcDst;
                 POINT dstSize;
-                POINT srcSize;
-                int sizingtype = ST_STRETCH;
                 BOOL uniformsizing = FALSE;
 
-                rcDst = *prc;
+                dstSize.x = prc->right - prc->left;
+                dstSize.y = prc->bottom - prc->top;
 
-                dstSize.x = rcDst.right-rcDst.left;
-                dstSize.y = rcDst.bottom-rcDst.top;
-                srcSize.x = rcSrc.right-rcSrc.left;
-                srcSize.y = rcSrc.bottom-rcSrc.top;
-            
                 GetThemeBool(hTheme, iPartId, iStateId, TMT_UNIFORMSIZING, &uniformsizing);
                 if(uniformsizing) {
                     /* Scale height and width equally */
                     if (dstSize.x*srcSize.y < dstSize.y*srcSize.x)
-                    {
                         dstSize.y = MulDiv (srcSize.y, dstSize.x, srcSize.x);
-                        rcDst.bottom = rcDst.top + dstSize.y;
-                    }
                     else
-                    {
                         dstSize.x = MulDiv (srcSize.x, dstSize.y, srcSize.y);
-                        rcDst.right = rcDst.left + dstSize.x;
-                    }
                 }
-            
-                GetThemeEnumValue(hTheme, iPartId, iStateId, TMT_SIZINGTYPE, &sizingtype);
-                if(sizingtype == ST_TRUESIZE) {
-                    int truesizestretchmark = 100;
-            
-                    if(dstSize.x < 0 || dstSize.y < 0) {
-                        BOOL mirrorimage = TRUE;
-                        GetThemeBool(hTheme, iPartId, iStateId, TMT_MIRRORIMAGE, &mirrorimage);
-                        if(mirrorimage) {
-                            if(dstSize.x < 0) {
-                                rcDst.left += dstSize.x;
-                                rcDst.right += dstSize.x;
-                            }
-                            if(dstSize.y < 0) {
-                                rcDst.top += dstSize.y;
-                                rcDst.bottom += dstSize.y;
-                            }
-                        }
-                    }
-                    /* Whatever TrueSizeStretchMark does - it does not seem to
-                     * be what's outlined below. It appears as if native 
-                     * uxtheme always stretches if dest is smaller than source
-                     * (ie as if TrueSizeStretchMark==100 with the code below) */
-#if 0
-                    /* Only stretch when target exceeds source by truesizestretchmark percent */
-                    GetThemeInt(hTheme, iPartId, iStateId, TMT_TRUESIZESTRETCHMARK, &truesizestretchmark);
-#endif
-                    if(dstSize.x < 0 || dstSize.y < 0 ||
-                      (MulDiv(srcSize.x, 100, dstSize.x) > truesizestretchmark &&
-                      MulDiv(srcSize.y, 100, dstSize.y) > truesizestretchmark)) {
-                        memcpy (psz, &dstSize, sizeof (SIZE));
-                    }
-                    else {
-                        memcpy (psz, &srcSize, sizeof (SIZE));
+
+                if (sizingType == ST_TRUESIZE)
+                {
+                    if ((dstSize.x < 0 || dstSize.y < 0)
+                        || (dstSize.x < srcSize.x && dstSize.y < srcSize.y)
+                        || (scalingType == TSST_SIZE
+                            && MulDiv(100, dstSize.x, srcSize.x) >= stretchMark + 100
+                            && MulDiv(100, dstSize.y, srcSize.y) >= stretchMark + 100))
+                    {
+                        *psz = dstSize;
                     }
                 }
                 else
@@ -636,9 +687,10 @@ static HRESULT get_image_part_size (HTHEME hTheme, HDC hdc, int iPartId,
                     psz->x = abs(dstSize.x);
                     psz->y = abs(dstSize.y);
                 }
-                break;
             }
-            /* else fall through */
+
+            break;
+        }
         case TS_MIN:
             /* FIXME: couldn't figure how native uxtheme computes min size */
         case TS_TRUE:
@@ -659,9 +711,9 @@ static HRESULT UXTHEME_DrawImageBackground(HTHEME hTheme, HDC hdc, int iPartId,
                                     const DTBGOPTS *pOptions)
 {
     HRESULT hr = S_OK;
-    HBITMAP bmpSrc, bmpSrcResized = NULL;
+    HBITMAP bmpSrc;
     HGDIOBJ oldSrc;
-    HDC hdcSrc, hdcOrigSrc = NULL;
+    HDC hdcSrc;
     RECT rcSrc;
     RECT rcDst;
     POINT dstSize;
@@ -672,8 +724,8 @@ static HRESULT UXTHEME_DrawImageBackground(HTHEME hTheme, HDC hdc, int iPartId,
     COLORREF transparentcolor = 0;
     BOOL hasAlpha;
 
-    hr = UXTHEME_LoadImage(hTheme, hdc, iPartId, iStateId, pRect, FALSE, 
-        &bmpSrc, &rcSrc, &hasAlpha);
+    hr = UXTHEME_LoadImage(hTheme, iPartId, iStateId, pRect, FALSE, &bmpSrc, &rcSrc, &hasAlpha,
+                           NULL);
     if(FAILED(hr)) return hr;
     hdcSrc = CreateCompatibleDC(hdc);
     if(!hdcSrc) {
@@ -696,7 +748,7 @@ static HRESULT UXTHEME_DrawImageBackground(HTHEME hTheme, HDC hdc, int iPartId,
     if(sizingtype == ST_TRUESIZE) {
         int valign = VA_CENTER, halign = HA_CENTER;
 
-        get_image_part_size (hTheme, hdc, iPartId, iStateId, pRect, TS_DRAW, &drawSize);
+        get_image_part_size(hTheme, iPartId, iStateId, pRect, TS_DRAW, &drawSize);
         GetThemeEnumValue(hTheme, iPartId, iStateId, TMT_VALIGN, &valign);
         GetThemeEnumValue(hTheme, iPartId, iStateId, TMT_HALIGN, &halign);
 
@@ -725,32 +777,17 @@ static HRESULT UXTHEME_DrawImageBackground(HTHEME hTheme, HDC hdc, int iPartId,
 
         GetThemeMargins(hTheme, hdc, iPartId, iStateId, TMT_SIZINGMARGINS, NULL, &sm);
 
-        /* Resize source image if destination smaller than margins */
+        /* Resize sizing margins if destination is smaller */
         if (sm.cyTopHeight + sm.cyBottomHeight > dstSize.y || sm.cxLeftWidth + sm.cxRightWidth > dstSize.x) {
             if (sm.cyTopHeight + sm.cyBottomHeight > dstSize.y) {
                 sm.cyTopHeight = MulDiv(sm.cyTopHeight, dstSize.y, srcSize.y);
                 sm.cyBottomHeight = dstSize.y - sm.cyTopHeight;
-                srcSize.y = dstSize.y;
             }
 
             if (sm.cxLeftWidth + sm.cxRightWidth > dstSize.x) {
                 sm.cxLeftWidth = MulDiv(sm.cxLeftWidth, dstSize.x, srcSize.x);
                 sm.cxRightWidth = dstSize.x - sm.cxLeftWidth;
-                srcSize.x = dstSize.x;
             }
-
-            hdcOrigSrc = hdcSrc;
-            hdcSrc = CreateCompatibleDC(NULL);
-            bmpSrcResized = CreateBitmap(srcSize.x, srcSize.y, 1, 32, NULL);
-            SelectObject(hdcSrc, bmpSrcResized);
-
-            UXTHEME_StretchBlt(hdcSrc, 0, 0, srcSize.x, srcSize.y, hdcOrigSrc, rcSrc.left, rcSrc.top,
-                               rcSrc.right - rcSrc.left, rcSrc.bottom - rcSrc.top, transparent, transparentcolor);
-
-            rcSrc.left = 0;
-            rcSrc.top = 0;
-            rcSrc.right = srcSize.x;
-            rcSrc.bottom = srcSize.y;
         }
 
         hdcDst = hdc;
@@ -857,8 +894,6 @@ draw_error:
     }
     SelectObject(hdcSrc, oldSrc);
     DeleteDC(hdcSrc);
-    if (bmpSrcResized) DeleteObject(bmpSrcResized);
-    if (hdcOrigSrc) DeleteDC(hdcOrigSrc);
     *pRect = rcDst;
     return hr;
 }
@@ -922,7 +957,7 @@ static HRESULT UXTHEME_DrawBackgroundFill(HTHEME hTheme, HDC hdc, int iPartId,
     HRESULT hr = S_OK;
     int filltype = FT_SOLID;
 
-    TRACE("(%d,%d,%d)\n", iPartId, iStateId, pOptions->dwFlags);
+    TRACE("(%d,%d,%ld)\n", iPartId, iStateId, pOptions->dwFlags);
 
     if(pOptions->dwFlags & DTBG_OMITCONTENT)
         return S_OK;
@@ -1020,7 +1055,7 @@ HRESULT WINAPI DrawThemeBackgroundEx(HTHEME hTheme, HDC hdc, int iPartId,
     int bgtype = BT_BORDERFILL;
     RECT rt;
 
-    TRACE("(%p,%p,%d,%d,%d,%d)\n", hTheme, hdc, iPartId, iStateId,pRect->left,pRect->top);
+    TRACE("(%p,%p,%d,%d,%ld,%ld)\n", hTheme, hdc, iPartId, iStateId,pRect->left,pRect->top);
     if(!hTheme)
         return E_HANDLE;
 
@@ -1619,10 +1654,57 @@ HRESULT WINAPI DrawThemeEdge(HTHEME hTheme, HDC hdc, int iPartId,
 HRESULT WINAPI DrawThemeIcon(HTHEME hTheme, HDC hdc, int iPartId, int iStateId,
                              const RECT *pRect, HIMAGELIST himl, int iImageIndex)
 {
-    FIXME("%d %d: stub\n", iPartId, iStateId);
-    if(!hTheme)
+    INT effect = ICE_NONE, saturation = 0, alpha = 128;
+    IImageList *image_list = (IImageList *)himl;
+    IMAGELISTDRAWPARAMS params = {0};
+    COLORREF color = 0;
+
+    TRACE("%p %p %d %d %s %p %d\n", hTheme, hdc, iPartId, iStateId, wine_dbgstr_rect(pRect), himl,
+          iImageIndex);
+
+    if (!hTheme)
         return E_HANDLE;
-    return E_NOTIMPL;
+
+    GetThemeEnumValue(hTheme, iPartId, iStateId, TMT_ICONEFFECT, &effect);
+    switch (effect)
+    {
+    case ICE_NONE:
+        params.fState = ILS_NORMAL;
+        break;
+    case ICE_GLOW:
+        GetThemeColor(hTheme, iPartId, iStateId, TMT_GLOWCOLOR, &color);
+        params.fState = ILS_GLOW;
+        params.crEffect = color;
+        break;
+    case ICE_SHADOW:
+        GetThemeColor(hTheme, iPartId, iStateId, TMT_SHADOWCOLOR, &color);
+        params.fState = ILS_SHADOW;
+        params.crEffect = color;
+        break;
+    case ICE_PULSE:
+        GetThemeInt(hTheme, iPartId, iStateId, TMT_SATURATION, &saturation);
+        params.fState = ILS_SATURATE;
+        params.Frame = saturation;
+        break;
+    case ICE_ALPHA:
+        GetThemeInt(hTheme, iPartId, iStateId, TMT_ALPHALEVEL, &alpha);
+        params.fState = ILS_ALPHA;
+        params.Frame = alpha;
+        break;
+    }
+
+    params.cbSize = sizeof(params);
+    params.himl = himl;
+    params.i = iImageIndex;
+    params.hdcDst = hdc;
+    params.x = pRect->left;
+    params.y = pRect->top;
+    params.cx = pRect->right - pRect->left;
+    params.cy = pRect->bottom - pRect->top;
+    params.rgbBk = CLR_NONE;
+    params.rgbFg = CLR_NONE;
+    params.fStyle = ILD_TRANSPARENT;
+    return IImageList_Draw(image_list, &params);
 }
 
 /***********************************************************************
@@ -1662,14 +1744,14 @@ HRESULT WINAPI DrawThemeTextEx(HTHEME hTheme, HDC hdc, int iPartId, int iStateId
     int oldBkMode;
     int fontProp;
 
-    TRACE("%p %p %d %d %s:%d 0x%08x %p %p\n", hTheme, hdc, iPartId, iStateId,
+    TRACE("%p %p %d %d %s:%d 0x%08lx %p %p\n", hTheme, hdc, iPartId, iStateId,
         debugstr_wn(pszText, iCharCount), iCharCount, flags, rect, options);
 
     if(!hTheme)
         return E_HANDLE;
 
     if (options->dwFlags & ~(DTT_TEXTCOLOR | DTT_FONTPROP))
-        FIXME("unsupported flags 0x%08x\n", options->dwFlags);
+        FIXME("unsupported flags 0x%08lx\n", options->dwFlags);
 
     if (options->dwFlags & DTT_FONTPROP)
         fontProp = options->iFontPropId;
@@ -1990,7 +2072,7 @@ HRESULT WINAPI GetThemePartSize(HTHEME hTheme, HDC hdc, int iPartId,
     if (bgtype == BT_NONE)
         /* do nothing */;
     else if(bgtype == BT_IMAGEFILE)
-        hr = get_image_part_size (hTheme, hdc, iPartId, iStateId, prc, eSize, &size);
+        hr = get_image_part_size(hTheme, iPartId, iStateId, prc, eSize, &size);
     else if(bgtype == BT_BORDERFILL)
         hr = get_border_background_size (hTheme, iPartId, iStateId, eSize, &size);
     else {
@@ -2101,8 +2183,8 @@ BOOL WINAPI IsThemeBackgroundPartiallyTransparent(HTHEME hTheme, int iPartId,
 
     if (bgtype != BT_IMAGEFILE) return FALSE;
 
-    if(FAILED (UXTHEME_LoadImage (hTheme, 0, iPartId, iStateId, &rect, FALSE, 
-                                  &bmpSrc, &rcSrc, &hasAlpha))) 
+    if (FAILED(UXTHEME_LoadImage(hTheme, iPartId, iStateId, &rect, FALSE, &bmpSrc, &rcSrc,
+                                 &hasAlpha, NULL)))
         return FALSE;
 
     get_transparency (hTheme, iPartId, iStateId, hasAlpha, &transparent,
