@@ -28,7 +28,7 @@
 #include "winreg.h"
 #include "vfwmsgs.h"
 #include "uxtheme.h"
-#include "tmschema.h"
+#include "vssym32.h"
 
 #include "uxthemedll.h"
 #include "msstyles.h"
@@ -153,7 +153,7 @@ static void UXTHEME_LoadTheme(void)
         }
         else {
             bThemeActive = FALSE;
-            TRACE("Failed to get ThemeActive: %d\n", GetLastError());
+            TRACE("Failed to get ThemeActive: %ld\n", GetLastError());
         }
         buffsize = sizeof(szCurrentColor);
         if (RegQueryValueExW(hKey, L"ColorName", NULL, NULL, (BYTE*)szCurrentColor, &buffsize))
@@ -421,7 +421,7 @@ static void UXTHEME_SaveSystemMetrics(struct system_metrics *metrics, BOOL send_
  */
 HRESULT UXTHEME_SetActiveTheme(PTHEME_FILE tf)
 {
-    BOOL ret, loaded_before = FALSE;
+    BOOL ret, loaded_before = FALSE, same_theme = FALSE;
     struct system_metrics metrics;
     DWORD size;
     HKEY hKey;
@@ -430,6 +430,9 @@ HRESULT UXTHEME_SetActiveTheme(PTHEME_FILE tf)
 
     if(tf) {
         bThemeActive = TRUE;
+        same_theme = !lstrcmpW(szCurrentTheme, tf->szThemeFile)
+                     && !lstrcmpW(szCurrentColor, tf->pszSelectedColor)
+                     && !lstrcmpW(szCurrentSize, tf->pszSelectedSize);
         lstrcpynW(szCurrentTheme, tf->szThemeFile, ARRAY_SIZE(szCurrentTheme));
         lstrcpynW(szCurrentColor, tf->pszSelectedColor, ARRAY_SIZE(szCurrentColor));
         lstrcpynW(szCurrentSize, tf->pszSelectedSize, ARRAY_SIZE(szCurrentSize));
@@ -443,13 +446,13 @@ HRESULT UXTHEME_SetActiveTheme(PTHEME_FILE tf)
             if (!RegQueryValueExW(hKey, L"LoadedBefore", NULL, NULL, (BYTE *)tmp, &size))
                 loaded_before = (tmp[0] != '0');
             else
-                WARN("Failed to get LoadedBefore: %d\n", GetLastError());
+                WARN("Failed to get LoadedBefore: %ld\n", GetLastError());
             RegCloseKey(hKey);
         }
-        if (loaded_before)
+        if (loaded_before && same_theme)
             return MSSTYLES_SetActiveTheme(tf, FALSE);
 
-        if (ret)
+        if (!loaded_before && ret)
             UXTHEME_SaveUnthemedSystemMetrics(&metrics);
     }
     else {
@@ -618,7 +621,7 @@ static HTHEME open_theme_data(HWND hwnd, LPCWSTR pszClassList, DWORD flags, UINT
     LPCWSTR pszAppName;
     LPCWSTR pszUseClassList;
     HTHEME hTheme = NULL;
-    TRACE("(%p,%s, %x)\n", hwnd, debugstr_w(pszClassList), flags);
+    TRACE("(%p,%s, %lx)\n", hwnd, debugstr_w(pszClassList), flags);
 
     if(!pszClassList)
     {
@@ -627,7 +630,7 @@ static HTHEME open_theme_data(HWND hwnd, LPCWSTR pszClassList, DWORD flags, UINT
     }
 
     if(flags)
-        FIXME("unhandled flags: %x\n", flags);
+        FIXME("unhandled flags: %lx\n", flags);
 
     if(bThemeActive)
     {
@@ -735,7 +738,7 @@ HRESULT WINAPI SetWindowTheme(HWND hwnd, LPCWSTR pszSubAppName,
 HRESULT WINAPI SetWindowThemeAttribute(HWND hwnd, enum WINDOWTHEMEATTRIBUTETYPE type,
                                        PVOID attribute, DWORD size)
 {
-   FIXME("(%p,%d,%p,%d): stub\n", hwnd, type, attribute, size);
+   FIXME("(%p,%d,%p,%ld): stub\n", hwnd, type, attribute, size);
    return E_NOTIMPL;
 }
 
@@ -767,7 +770,7 @@ DWORD WINAPI GetThemeAppProperties(void)
  */
 void WINAPI SetThemeAppProperties(DWORD dwFlags)
 {
-    TRACE("(0x%08x)\n", dwFlags);
+    TRACE("(0x%08lx)\n", dwFlags);
     dwThemeAppProperties = dwFlags;
 }
 
@@ -790,7 +793,7 @@ HRESULT WINAPI HitTestThemeBackground(HTHEME hTheme, HDC hdc, int iPartId,
                                      const RECT *pRect, HRGN hrgn,
                                      POINT ptTest, WORD *pwHitTestCode)
 {
-    FIXME("%d %d 0x%08x: stub\n", iPartId, iStateId, dwOptions);
+    FIXME("%d %d 0x%08lx: stub\n", iPartId, iStateId, dwOptions);
     if(!hTheme)
         return E_HANDLE;
     return E_NOTIMPL;
@@ -909,7 +912,7 @@ HRESULT WINAPI OpenThemeFile(LPCWSTR pszThemeFileName, LPCWSTR pszColorName,
                              LPCWSTR pszSizeName, HTHEMEFILE *hThemeFile,
                              DWORD unknown)
 {
-    TRACE("(%s,%s,%s,%p,%d)\n", debugstr_w(pszThemeFileName),
+    TRACE("(%s,%s,%s,%p,%ld)\n", debugstr_w(pszThemeFileName),
           debugstr_w(pszColorName), debugstr_w(pszSizeName),
           hThemeFile, unknown);
     return MSSTYLES_OpenThemeFile(pszThemeFileName, pszColorName, pszSizeName, (PTHEME_FILE*)hThemeFile);
@@ -989,7 +992,7 @@ HRESULT WINAPI GetThemeDefaults(LPCWSTR pszThemeFileName, LPWSTR pszColorName,
 {
     PTHEME_FILE pt;
     HRESULT hr;
-    TRACE("(%s,%p,%d,%p,%d)\n", debugstr_w(pszThemeFileName),
+    TRACE("(%s,%p,%ld,%p,%ld)\n", debugstr_w(pszThemeFileName),
           pszColorName, dwColorNameLen,
           pszSizeName, dwSizeNameLen);
 
@@ -1104,7 +1107,7 @@ HRESULT WINAPI EnumThemeColors(LPWSTR pszThemeFileName, LPWSTR pszSizeName,
     HRESULT hr;
     LPWSTR tmp;
     UINT resourceId = dwColorNum + 1000;
-    TRACE("(%s,%s,%d)\n", debugstr_w(pszThemeFileName),
+    TRACE("(%s,%s,%ld)\n", debugstr_w(pszThemeFileName),
           debugstr_w(pszSizeName), dwColorNum);
 
     hr = MSSTYLES_OpenThemeFile(pszThemeFileName, NULL, pszSizeName, &pt);
@@ -1162,7 +1165,7 @@ HRESULT WINAPI EnumThemeSizes(LPWSTR pszThemeFileName, LPWSTR pszColorName,
     HRESULT hr;
     LPWSTR tmp;
     UINT resourceId = dwSizeNum + 3000;
-    TRACE("(%s,%s,%d)\n", debugstr_w(pszThemeFileName),
+    TRACE("(%s,%s,%ld)\n", debugstr_w(pszThemeFileName),
           debugstr_w(pszColorName), dwSizeNum);
 
     hr = MSSTYLES_OpenThemeFile(pszThemeFileName, pszColorName, NULL, &pt);
