@@ -32,16 +32,16 @@ WINE_DEFAULT_DEBUG_CHANNEL(wbemprox);
 static HRESULT append_table( struct view *view, struct table *table )
 {
     struct table **tmp;
-    if (!(tmp = heap_realloc( view->table, (view->table_count + 1) * sizeof(*tmp) ))) return E_OUTOFMEMORY;
+    if (!(tmp = realloc( view->table, (view->table_count + 1) * sizeof(*tmp) ))) return E_OUTOFMEMORY;
     view->table = tmp;
     view->table[view->table_count++] = table;
     return S_OK;
 }
 
-HRESULT create_view( enum view_type type, const WCHAR *path, const struct keyword *keywordlist, const WCHAR *class,
-                     const struct property *proplist, const struct expr *cond, struct view **ret )
+HRESULT create_view( enum view_type type, enum wbm_namespace ns, const WCHAR *path, const struct keyword *keywordlist,
+                     const WCHAR *class, const struct property *proplist, const struct expr *cond, struct view **ret )
 {
-    struct view *view = heap_alloc_zero( sizeof(*view) );
+    struct view *view = calloc( 1, sizeof(*view) );
 
     if (!view) return E_OUTOFMEMORY;
 
@@ -54,25 +54,27 @@ HRESULT create_view( enum view_type type, const WCHAR *path, const struct keywor
 
     case VIEW_TYPE_SELECT:
     {
-        struct table *table = grab_table( class );
+        struct table *table = grab_table( ns, class );
         HRESULT hr;
 
         if (table && (hr = append_table( view, table )) != S_OK)
         {
-            heap_free( view );
+            free( view );
             return hr;
         }
+        else if (!table && ns == WBEMPROX_NAMESPACE_LAST) return WBEM_E_INVALID_CLASS;
         view->proplist = proplist;
         view->cond     = cond;
         break;
     }
     default:
         ERR( "unhandled type %u\n", type );
-        heap_free( view );
+        free( view );
         return E_INVALIDARG;
     }
 
     view->type = type;
+    view->ns = ns;
     *ret = view;
     return S_OK;
 }
@@ -82,9 +84,9 @@ void destroy_view( struct view *view )
     ULONG i;
     if (!view) return;
     for (i = 0; i < view->table_count; i++) release_table( view->table[i] );
-    heap_free( view->table );
-    heap_free( view->result );
-    heap_free( view );
+    free( view->table );
+    free( view->result );
+    free( view );
 }
 
 static BOOL eval_like( const WCHAR *lstr, const WCHAR *rstr )
@@ -93,6 +95,7 @@ static BOOL eval_like( const WCHAR *lstr, const WCHAR *rstr )
 
     while (*p && *q)
     {
+        if (q[0] == '\\' && q[1] == '\\') q++;
         if (*q == '%')
         {
             while (*q == '%') q++;
@@ -297,7 +300,7 @@ static const WCHAR *format_int( WCHAR *buf, UINT len, CIMTYPE type, LONGLONG val
         return buf;
 
     default:
-        ERR( "unhandled type %u\n", type );
+        ERR( "unhandled type %lu\n", type );
         return NULL;
     }
 }
@@ -474,19 +477,20 @@ static WCHAR *build_assoc_query( const WCHAR *class, UINT class_len )
     UINT len = class_len + ARRAY_SIZE(fmtW);
     WCHAR *ret;
 
-    if (!(ret = heap_alloc( len * sizeof(WCHAR) ))) return NULL;
+    if (!(ret = malloc( len * sizeof(WCHAR) ))) return NULL;
     swprintf( ret, len, fmtW, class );
     return ret;
 }
 
-static HRESULT create_assoc_enum( const WCHAR *class, UINT class_len, IEnumWbemClassObject **iter )
+static HRESULT create_assoc_enum( enum wbm_namespace ns, const WCHAR *class, UINT class_len,
+                                  IEnumWbemClassObject **iter )
 {
     WCHAR *query;
     HRESULT hr;
 
     if (!(query = build_assoc_query( class, class_len ))) return E_OUTOFMEMORY;
-    hr = exec_query( query, iter );
-    heap_free( query );
+    hr = exec_query( ns, query, iter );
+    free( query );
     return hr;
 }
 
@@ -496,7 +500,7 @@ static WCHAR *build_antecedent_query( const WCHAR *assocclass, const WCHAR *depe
     UINT len = lstrlenW(assocclass) + lstrlenW(dependent) + ARRAY_SIZE(fmtW);
     WCHAR *ret;
 
-    if (!(ret = heap_alloc( len * sizeof(WCHAR) ))) return NULL;
+    if (!(ret = malloc( len * sizeof(WCHAR) ))) return NULL;
     swprintf( ret, len, fmtW, assocclass, dependent );
     return ret;
 }
@@ -530,7 +534,7 @@ static WCHAR *build_canonical_path( const WCHAR *relpath )
     }
 
     len = ARRAY_SIZE( L"\\\\%s\\%s:" ) + SysStringLen( server ) + SysStringLen( namespace ) + lstrlenW( relpath );
-    if ((ret = heap_alloc( len * sizeof(WCHAR ) )))
+    if ((ret = malloc( len * sizeof(WCHAR ) )))
     {
         len = swprintf( ret, len, L"\\\\%s\\%s:", server, namespace );
         for (i = 0; i < lstrlenW( relpath ); i ++)
@@ -546,7 +550,7 @@ static WCHAR *build_canonical_path( const WCHAR *relpath )
     return ret;
 }
 
-static HRESULT get_antecedent( const WCHAR *assocclass, const WCHAR *dependent, BSTR *ret )
+static HRESULT get_antecedent( enum wbm_namespace ns, const WCHAR *assocclass, const WCHAR *dependent, BSTR *ret )
 {
     WCHAR *fullpath, *str;
     IEnumWbemClassObject *iter = NULL;
@@ -557,7 +561,7 @@ static HRESULT get_antecedent( const WCHAR *assocclass, const WCHAR *dependent,
 
     if (!(fullpath = build_canonical_path( dependent ))) return E_OUTOFMEMORY;
     if (!(str = build_antecedent_query( assocclass, fullpath ))) goto done;
-    if ((hr = exec_query( str, &iter )) != S_OK) goto done;
+    if ((hr = exec_query( ns, str, &iter )) != S_OK) goto done;
 
     IEnumWbemClassObject_Next( iter, WBEM_INFINITE, 1, &obj, &count );
     if (!count)
@@ -573,18 +577,18 @@ static HRESULT get_antecedent( const WCHAR *assocclass, const WCHAR *dependent,
 
 done:
     if (iter) IEnumWbemClassObject_Release( iter );
-    heap_free( str );
-    heap_free( fullpath );
+    free( str );
+    free( fullpath );
     return hr;
 }
 
-static HRESULT do_query( const WCHAR *str, struct query **ret_query )
+static HRESULT do_query( enum wbm_namespace ns, const WCHAR *str, struct query **ret_query )
 {
     struct query *query;
     HRESULT hr;
 
-    if (!(query = create_query())) return E_OUTOFMEMORY;
-    if ((hr = parse_query( str, &query->view, &query->mem )) != S_OK || (hr = execute_view( query->view )) != S_OK)
+    if (!(query = create_query( ns ))) return E_OUTOFMEMORY;
+    if ((hr = parse_query( ns, str, &query->view, &query->mem )) != S_OK || (hr = execute_view( query->view )) != S_OK)
     {
         release_query( query );
         return hr;
@@ -593,7 +597,8 @@ static HRESULT do_query( const WCHAR *str, struct query **ret_query )
     return S_OK;
 }
 
-static HRESULT get_antecedent_table( const WCHAR *assocclass, const WCHAR *dependent, struct table **table )
+static HRESULT get_antecedent_table( enum wbm_namespace ns, const WCHAR *assocclass, const WCHAR *dependent,
+                                     struct table **table )
 {
     BSTR antecedent = NULL;
     struct path *path = NULL;
@@ -601,7 +606,7 @@ static HRESULT get_antecedent_table( const WCHAR *assocclass, const WCHAR *depen
     struct query *query = NULL;
     HRESULT hr;
 
-    if ((hr = get_antecedent( assocclass, dependent, &antecedent )) != S_OK) return hr;
+    if ((hr = get_antecedent( ns, assocclass, dependent, &antecedent )) != S_OK) return hr;
     if (!antecedent)
     {
         *table = NULL;
@@ -614,7 +619,7 @@ static HRESULT get_antecedent_table( const WCHAR *assocclass, const WCHAR *depen
         goto done;
     }
 
-    if ((hr = do_query( str, &query )) != S_OK) goto done;
+    if ((hr = do_query( ns, str, &query )) != S_OK) goto done;
     if (query->view->table_count) *table = addref_table( query->view->table[0] );
     else *table = NULL;
 
@@ -622,7 +627,7 @@ done:
     if (query) release_query( query );
     free_path( path );
     SysFreeString( antecedent );
-    heap_free( str );
+    free( str );
     return hr;
 }
 
@@ -635,7 +640,7 @@ static HRESULT exec_assoc_view( struct view *view )
     if (view->keywordlist) FIXME( "ignoring keywords\n" );
     if ((hr = parse_path( view->path, &path )) != S_OK) return hr;
 
-    if ((hr = create_assoc_enum( path->class, path->class_len, &iter )) != S_OK) goto done;
+    if ((hr = create_assoc_enum( view->ns, path->class, path->class_len, &iter )) != S_OK) goto done;
     for (;;)
     {
         ULONG count;
@@ -653,7 +658,7 @@ static HRESULT exec_assoc_view( struct view *view )
         }
         IWbemClassObject_Release( obj );
 
-        hr = get_antecedent_table( V_BSTR(&var), view->path, &table );
+        hr = get_antecedent_table( view->ns, V_BSTR(&var), view->path, &table );
         VariantClear( &var );
         if (hr != S_OK) goto done;
 
@@ -666,7 +671,7 @@ static HRESULT exec_assoc_view( struct view *view )
 
     if (view->table_count)
     {
-        if (!(view->result = heap_alloc_zero( view->table_count * sizeof(UINT) ))) hr = E_OUTOFMEMORY;
+        if (!(view->result = calloc( view->table_count, sizeof(UINT) ))) hr = E_OUTOFMEMORY;
         else view->result_count = view->table_count;
     }
 
@@ -694,7 +699,7 @@ static HRESULT exec_select_view( struct view *view )
     if (!table->num_rows) return S_OK;
 
     len = min( table->num_rows, 16 );
-    if (!(view->result = heap_alloc( len * sizeof(UINT) ))) return E_OUTOFMEMORY;
+    if (!(view->result = malloc( len * sizeof(UINT) ))) return E_OUTOFMEMORY;
 
     for (i = 0; i < table->num_rows; i++)
     {
@@ -706,7 +711,7 @@ static HRESULT exec_select_view( struct view *view )
         {
             UINT *tmp;
             len *= 2;
-            if (!(tmp = heap_realloc( view->result, len * sizeof(UINT) ))) return E_OUTOFMEMORY;
+            if (!(tmp = realloc( view->result, len * sizeof(UINT) ))) return E_OUTOFMEMORY;
             view->result = tmp;
         }
         if (status == FILL_STATUS_FILTERED) val = 1;
@@ -734,12 +739,13 @@ HRESULT execute_view( struct view *view )
     }
 }
 
-struct query *create_query(void)
+struct query *create_query( enum wbm_namespace ns )
 {
     struct query *query;
 
-    if (!(query = heap_alloc( sizeof(*query) ))) return NULL;
+    if (!(query = malloc( sizeof(*query) ))) return NULL;
     list_init( &query->mem );
+    query->ns = ns;
     query->refs = 1;
     return query;
 }
@@ -750,8 +756,8 @@ void free_query( struct query *query )
 
     if (!query) return;
     destroy_view( query->view );
-    LIST_FOR_EACH_SAFE( mem, next, &query->mem ) { heap_free( mem ); }
-    heap_free( query );
+    LIST_FOR_EACH_SAFE( mem, next, &query->mem ) { free( mem ); }
+    free( query );
 }
 
 struct query *addref_query( struct query *query )
@@ -765,14 +771,14 @@ void release_query( struct query *query )
     if (!InterlockedDecrement( &query->refs )) free_query( query );
 }
 
-HRESULT exec_query( const WCHAR *str, IEnumWbemClassObject **result )
+HRESULT exec_query( enum wbm_namespace ns, const WCHAR *str, IEnumWbemClassObject **result )
 {
     HRESULT hr;
     struct query *query;
 
     *result = NULL;
-    if (!(query = create_query())) return E_OUTOFMEMORY;
-    hr = parse_query( str, &query->view, &query->mem );
+    if (!(query = create_query( ns ))) return E_OUTOFMEMORY;
+    hr = parse_query( ns, str, &query->view, &query->mem );
     if (hr != S_OK) goto done;
     hr = execute_view( query->view );
     if (hr != S_OK) goto done;
@@ -805,7 +811,7 @@ static BSTR build_proplist( const struct table *table, UINT row, UINT count, UIN
     UINT i, j, offset;
     BSTR *values, ret = NULL;
 
-    if (!(values = heap_alloc( count * sizeof(BSTR) ))) return NULL;
+    if (!(values = malloc( count * sizeof(BSTR) ))) return NULL;
 
     *len = j = 0;
     for (i = 0; i < table->num_cols; i++)
@@ -833,7 +839,7 @@ static BSTR build_proplist( const struct table *table, UINT row, UINT count, UIN
         }
     }
     for (i = 0; i < count; i++) SysFreeString( values[i] );
-    heap_free( values );
+    free( values );
     return ret;
 }
 
@@ -1000,6 +1006,19 @@ static HRESULT get_system_propval( const struct view *view, UINT table_index, UI
         if (type) *type = CIM_STRING;
         return S_OK;
     }
+    if (!wcsicmp( name, L"__DERIVATION" ))
+    {
+        if (ret)
+        {
+            SAFEARRAY *sa;
+            FIXME( "returning empty array for __DERIVATION\n" );
+            if (!(sa = SafeArrayCreateVector( VT_BSTR, 0, 0 ))) return E_OUTOFMEMORY;
+            V_VT( ret ) = VT_BSTR | VT_ARRAY;
+            V_ARRAY( ret ) = sa;
+        }
+        if (type) *type = CIM_STRING | CIM_FLAG_ARRAY;
+        return S_OK;
+    }
     FIXME("system property %s not implemented\n", debugstr_w(name));
     return WBEM_E_NOT_FOUND;
 }
@@ -1028,7 +1047,7 @@ VARTYPE to_vartype( CIMTYPE type )
     case CIM_REAL32:    return VT_R4;
 
     default:
-        ERR("unhandled type %u\n", type);
+        ERR( "unhandled type %lu\n", type );
         break;
     }
     return 0;
@@ -1259,13 +1278,13 @@ static struct array *to_array( VARIANT *var, CIMTYPE *type )
     if (SafeArrayGetVartype( V_ARRAY( var ), &vartype ) != S_OK) return NULL;
     if (!(basetype = to_cimtype( vartype ))) return NULL;
     if (SafeArrayGetUBound( V_ARRAY( var ), 1, &bound ) != S_OK) return NULL;
-    if (!(ret = heap_alloc( sizeof(struct array) ))) return NULL;
+    if (!(ret = malloc( sizeof(struct array) ))) return NULL;
 
     ret->count     = bound + 1;
     ret->elem_size = get_type_size( basetype );
-    if (!(ret->ptr = heap_alloc_zero( ret->count * ret->elem_size )))
+    if (!(ret->ptr = calloc( ret->count, ret->elem_size )))
     {
-        heap_free( ret );
+        free( ret );
         return NULL;
     }
     for (i = 0; i < ret->count; i++)
@@ -1376,7 +1395,8 @@ HRESULT put_propval( const struct view *view, UINT index, const WCHAR *name, VAR
 HRESULT get_properties( const struct view *view, UINT index, LONG flags, SAFEARRAY **props )
 {
     static const WCHAR * const system_props[] =
-        { L"__GENUS", L"__CLASS", L"__RELPATH", L"__PROPERTY_COUNT", L"__SERVER", L"__NAMESPACE", L"__PATH" };
+        { L"__GENUS", L"__CLASS", L"__RELPATH", L"__PROPERTY_COUNT", L"__DERIVATION", L"__SERVER", L"__NAMESPACE",
+          L"__PATH" };
     SAFEARRAY *sa;
     BSTR str;
     UINT i, table_index, result_index, count = 0;
