@@ -24,21 +24,13 @@
 #endif
 
 #include <assert.h>
-#include <stdarg.h>
-#include <string.h>
-#include <stdio.h>
 #include <pthread.h>
 
 #include "ntstatus.h"
 #define WIN32_NO_STATUS
-#include "windef.h"
-#include "winbase.h"
-#include "wingdi.h"
-#include "winreg.h"
-#include "wine/winbase16.h"
-#include "winuser.h"
-
 #include "ntgdi_private.h"
+#include "ntuser_private.h"
+#include "wine/winbase16.h"
 #include "wine/list.h"
 #include "wine/debug.h"
 
@@ -83,28 +75,6 @@ const struct gdi_dc_funcs *get_display_driver(void)
     return &user_driver->dc_funcs;
 }
 
-struct monitor_info
-{
-    const WCHAR *name;
-    RECT rect;
-};
-
-static BOOL CALLBACK monitor_enum_proc( HMONITOR monitor, HDC hdc, LPRECT rect, LPARAM lparam )
-{
-    struct monitor_info *info = (struct monitor_info *)lparam;
-    MONITORINFOEXW mi;
-
-    mi.cbSize = sizeof(mi);
-    user_callbacks->pGetMonitorInfoW( monitor, (MONITORINFO *)&mi );
-    if (!wcsicmp( info->name, mi.szDevice ))
-    {
-        info->rect = mi.rcMonitor;
-        return FALSE;
-    }
-
-    return TRUE;
-}
-
 static INT CDECL nulldrv_AbortDoc( PHYSDEV dev )
 {
     return 0;
@@ -224,41 +194,31 @@ static INT CDECL nulldrv_GetDeviceCaps( PHYSDEV dev, INT cap )
     case HORZRES:
     {
         DC *dc = get_nulldrv_dc( dev );
-        struct monitor_info info;
+        RECT rect;
         int ret;
 
-        if (!user_callbacks) return 640;
-
         if (dc->display[0])
         {
-            info.name = dc->display;
-            SetRectEmpty( &info.rect );
-            user_callbacks->pEnumDisplayMonitors( NULL, NULL, monitor_enum_proc, (LPARAM)&info );
-            if (!IsRectEmpty( &info.rect ))
-                return info.rect.right - info.rect.left;
+            rect = get_display_rect( dc->display );
+            if (!IsRectEmpty( &rect )) return rect.right - rect.left;
         }
 
-        ret = user_callbacks->pGetSystemMetrics( SM_CXSCREEN );
+        ret = get_system_metrics( SM_CXSCREEN );
         return ret ? ret : 640;
     }
     case VERTRES:
     {
         DC *dc = get_nulldrv_dc( dev );
-        struct monitor_info info;
+        RECT rect;
         int ret;
 
-        if (!user_callbacks) return 480;
-
-        if (dc->display[0] && user_callbacks)
+        if (dc->display[0])
         {
-            info.name = dc->display;
-            SetRectEmpty( &info.rect );
-            user_callbacks->pEnumDisplayMonitors( NULL, NULL, monitor_enum_proc, (LPARAM)&info );
-            if (!IsRectEmpty( &info.rect ))
-                return info.rect.bottom - info.rect.top;
+            rect = get_display_rect( dc->display );
+            if (!IsRectEmpty( &rect )) return rect.bottom - rect.top;
         }
 
-        ret = user_callbacks->pGetSystemMetrics( SM_CYSCREEN );
+        ret = get_system_metrics( SM_CYSCREEN );
         return ret ? ret : 480;
     }
     case BITSPIXEL:
@@ -333,14 +293,14 @@ static INT CDECL nulldrv_GetDeviceCaps( PHYSDEV dev, INT cap )
     case DESKTOPHORZRES:
         if (NtGdiGetDeviceCaps( dev->hdc, TECHNOLOGY ) == DT_RASDISPLAY)
         {
-            RECT rect = get_virtual_screen_rect();
+            RECT rect = get_virtual_screen_rect( 0 );
             return rect.right - rect.left;
         }
         return NtGdiGetDeviceCaps( dev->hdc, HORZRES );
     case DESKTOPVERTRES:
         if (NtGdiGetDeviceCaps( dev->hdc, TECHNOLOGY ) == DT_RASDISPLAY)
         {
-            RECT rect = get_virtual_screen_rect();
+            RECT rect = get_virtual_screen_rect( 0 );
             return rect.bottom - rect.top;
         }
         return NtGdiGetDeviceCaps( dev->hdc, VERTRES );
@@ -616,11 +576,6 @@ static struct opengl_funcs * CDECL nulldrv_wine_get_wgl_driver( PHYSDEV dev, UIN
     return (void *)-1;
 }
 
-static const struct vulkan_funcs * CDECL nulldrv_wine_get_vulkan_driver( PHYSDEV dev, UINT version )
-{
-    return NULL;
-}
-
 const struct gdi_dc_funcs null_driver =
 {
     nulldrv_AbortDoc,                   /* pAbortDoc */
@@ -715,7 +670,6 @@ const struct gdi_dc_funcs null_driver =
     nulldrv_D3DKMTCheckVidPnExclusiveOwnership, /* pD3DKMTCheckVidPnExclusiveOwnership */
     nulldrv_D3DKMTSetVidPnSourceOwner,  /* pD3DKMTSetVidPnSourceOwner */
     nulldrv_wine_get_wgl_driver,        /* wine_get_wgl_driver */
-    nulldrv_wine_get_vulkan_driver,     /* wine_get_vulkan_driver */
 
     GDI_PRIORITY_NULL_DRV               /* priority */
 };
@@ -812,6 +766,7 @@ static BOOL CDECL nulldrv_EnumDisplaySettingsEx( LPCWSTR name, DWORD num, LPDEVM
 static void CDECL nulldrv_UpdateDisplayDevices( const struct gdi_device_manager *manager,
                                                 BOOL force, void *param )
 {
+    manager->add_monitor( NULL, param ); /* use virtual monitor */
 }
 
 static BOOL CDECL nulldrv_CreateDesktopWindow( HWND hwnd )
@@ -968,6 +923,11 @@ static BOOL CDECL nulldrv_SystemParametersInfo( UINT action, UINT int_param, voi
     return FALSE;
 }
 
+static const struct vulkan_funcs * CDECL nulldrv_wine_get_vulkan_driver( UINT version )
+{
+    return NULL;
+}
+
 static void CDECL nulldrv_ThreadDetach( void )
 {
 }
@@ -990,6 +950,11 @@ static BOOL CDECL loaderdrv_ActivateKeyboardLayout( HKL layout, UINT flags )
     return load_driver()->pActivateKeyboardLayout( layout, flags );
 }
 
+static void CDECL loaderdrv_Beep(void)
+{
+    load_driver()->pBeep();
+}
+
 static INT CDECL loaderdrv_GetKeyNameText( LONG lparam, LPWSTR buffer, INT size )
 {
     return load_driver()->pGetKeyNameText( lparam, buffer, size );
@@ -1011,6 +976,11 @@ static INT CDECL loaderdrv_ToUnicodeEx( UINT virt, UINT scan, const BYTE *state,
     return load_driver()->pToUnicodeEx( virt, scan, state, str, size, flags, layout );
 }
 
+static BOOL CDECL loaderdrv_RegisterHotKey( HWND hwnd, UINT modifiers, UINT vk )
+{
+    return load_driver()->pRegisterHotKey( hwnd, modifiers, vk );
+}
+
 static void CDECL loaderdrv_UnregisterHotKey( HWND hwnd, UINT modifiers, UINT vk )
 {
     load_driver()->pUnregisterHotKey( hwnd, modifiers, vk );
@@ -1037,6 +1007,21 @@ static void CDECL loaderdrv_SetCursor( HCURSOR cursor )
     load_driver()->pSetCursor( cursor );
 }
 
+static BOOL CDECL loaderdrv_GetCursorPos( POINT *pt )
+{
+    return load_driver()->pGetCursorPos( pt );
+}
+
+static BOOL CDECL loaderdrv_SetCursorPos( INT x, INT y )
+{
+    return load_driver()->pSetCursorPos( x, y );
+}
+
+static BOOL CDECL loaderdrv_ClipCursor( const RECT *clip )
+{
+    return load_driver()->pClipCursor( clip );
+}
+
 static void CDECL loaderdrv_UpdateClipboard(void)
 {
     load_driver()->pUpdateClipboard();
@@ -1048,21 +1033,45 @@ static void CDECL loaderdrv_UpdateDisplayDevices( const struct gdi_device_manage
     load_driver()->pUpdateDisplayDevices( manager, force, param );
 }
 
+static const struct vulkan_funcs * CDECL loaderdrv_wine_get_vulkan_driver( UINT version )
+{
+    return load_driver()->pwine_get_vulkan_driver( version );
+}
+
 static const struct user_driver_funcs lazy_load_driver =
 {
+    /* keyboard functions */
     .pActivateKeyboardLayout = loaderdrv_ActivateKeyboardLayout,
+    .pBeep = loaderdrv_Beep,
     .pGetKeyNameText = loaderdrv_GetKeyNameText,
     .pGetKeyboardLayoutList = loaderdrv_GetKeyboardLayoutList,
     .pMapVirtualKeyEx = loaderdrv_MapVirtualKeyEx,
     .pToUnicodeEx = loaderdrv_ToUnicodeEx,
+    .pRegisterHotKey = loaderdrv_RegisterHotKey,
     .pUnregisterHotKey = loaderdrv_UnregisterHotKey,
     .pVkKeyScanEx = loaderdrv_VkKeyScanEx,
+    /* cursor/icon functions */
+    .pDestroyCursorIcon = nulldrv_DestroyCursorIcon,
+    .pSetCursor = loaderdrv_SetCursor,
+    .pGetCursorPos = loaderdrv_GetCursorPos,
+    .pSetCursorPos = loaderdrv_SetCursorPos,
+    .pClipCursor = loaderdrv_ClipCursor,
+    /* clipboard functions */
+    .pUpdateClipboard = loaderdrv_UpdateClipboard,
+    /* display modes */
     .pChangeDisplaySettingsEx = loaderdrv_ChangeDisplaySettingsEx,
     .pEnumDisplaySettingsEx = loaderdrv_EnumDisplaySettingsEx,
     .pUpdateDisplayDevices = loaderdrv_UpdateDisplayDevices,
-    .pSetCursor = loaderdrv_SetCursor,
-    .pUpdateClipboard = loaderdrv_UpdateClipboard,
+    /* windowing functions */
+    .pMsgWaitForMultipleObjectsEx = nulldrv_MsgWaitForMultipleObjectsEx,
     .pScrollDC = nulldrv_ScrollDC,
+    .pWindowMessage = nulldrv_WindowMessage,
+    /* system parameters */
+    .pSystemParametersInfo = nulldrv_SystemParametersInfo,
+    /* vulkan support */
+    .pwine_get_vulkan_driver = loaderdrv_wine_get_vulkan_driver,
+    /* thread management */
+    .pThreadDetach = nulldrv_ThreadDetach,
 };
 
 const struct user_driver_funcs *user_driver = &lazy_load_driver;
@@ -1123,6 +1132,7 @@ void CDECL __wine_set_display_driver( struct user_driver_funcs *driver, UINT ver
     SET_USER_FUNC(WindowPosChanging);
     SET_USER_FUNC(WindowPosChanged);
     SET_USER_FUNC(SystemParametersInfo);
+    SET_USER_FUNC(wine_get_vulkan_driver);
     SET_USER_FUNC(ThreadDetach);
 #undef SET_USER_FUNC
 
