@@ -452,15 +452,7 @@ static const struct DefaultFontInfo default_fonts[] =
     },
 };
 
-
-/*************************************************************************
- * __wine_make_gdi_object_system    (win32u.@)
- *
- * USER has to tell GDI that its system brushes and pens are non-deletable.
- * For a description of the GDI object magics and their flags,
- * see "Undocumented Windows" (wrong about the OBJECT_NOSYSTEM flag, though).
- */
-void CDECL __wine_make_gdi_object_system( HGDIOBJ handle, BOOL set)
+void make_gdi_object_system( HGDIOBJ handle, BOOL set)
 {
     GDI_HANDLE_ENTRY *entry;
 
@@ -572,16 +564,6 @@ BOOL GDI_dec_ref_count( HGDIOBJ handle )
 }
 
 
-/******************************************************************************
- *              get_system_dpi
- *
- * Get the system DPI, based on the DPI awareness mode.
- */
-DWORD get_system_dpi(void)
-{
-    return user_callbacks ? user_callbacks->pGetDpiForSystem() : 96;
-}
-
 static HFONT create_font( const LOGFONTW *deffont )
 {
     ENUMLOGFONTEXDVW lf;
@@ -1168,29 +1150,46 @@ static struct unix_funcs unix_funcs =
     NtGdiUpdateColors,
     NtGdiWidenPath,
     NtUserActivateKeyboardLayout,
+    NtUserCallHwnd,
+    NtUserCallHwndParam,
+    NtUserCallNextHookEx,
+    NtUserCallNoParam,
     NtUserCallOneParam,
     NtUserCallTwoParam,
     NtUserChangeDisplaySettings,
+    NtUserClipCursor,
     NtUserCountClipboardFormats,
+    NtUserDestroyCursor,
+    NtUserDrawIconEx,
     NtUserEnumDisplayDevices,
     NtUserEnumDisplayMonitors,
     NtUserEnumDisplaySettings,
+    NtUserGetAsyncKeyState,
+    NtUserGetCursorInfo,
     NtUserGetDisplayConfigBufferSizes,
+    NtUserGetIconInfo,
     NtUserGetKeyNameText,
     NtUserGetKeyboardLayoutList,
     NtUserGetPriorityClipboardFormat,
+    NtUserGetQueueStatus,
     NtUserGetUpdatedClipboardFormats,
     NtUserIsClipboardFormatAvailable,
     NtUserMapVirtualKeyEx,
+    NtUserRegisterHotKey,
     NtUserScrollDC,
     NtUserSelectPalette,
+    NtUserSetCursor,
+    NtUserSetCursorIconData,
+    NtUserSetCursorPos,
+    NtUserSetSysColors,
     NtUserShowCursor,
+    NtUserSystemParametersInfo,
+    NtUserSystemParametersInfoForDpi,
     NtUserToUnicodeEx,
     NtUserUnregisterHotKey,
     NtUserVkKeyScanEx,
 
     GetDCHook,
-    MirrorRgn,
     SetDCHook,
     SetDIBits,
     SetHookFlags,
@@ -1199,7 +1198,6 @@ static struct unix_funcs unix_funcs =
     __wine_get_icm_profile,
     __wine_get_vulkan_driver,
     __wine_get_wgl_driver,
-    __wine_make_gdi_object_system,
     __wine_set_display_driver,
     __wine_set_visible_region,
 };
