@@ -99,13 +99,8 @@ SOFTWARE.
 #endif
 
 #include <assert.h>
-#include <stdarg.h>
-#include <stdlib.h>
-#include <string.h>
-#include "windef.h"
-#include "winbase.h"
-#include "wingdi.h"
 #include "ntgdi_private.h"
+#include "ntuser_private.h"
 #include "wine/debug.h"
 
 WINE_DEFAULT_DEBUG_CHANNEL(region);
@@ -1375,9 +1370,9 @@ INT mirror_region( HRGN dst, HRGN src, INT width )
 }
 
 /***********************************************************************
- *           MirrorRgn    (GDI32.@)
+ *           mirror_window_region
  */
-BOOL WINAPI MirrorRgn( HWND hwnd, HRGN hrgn )
+BOOL mirror_window_region( HWND hwnd, HRGN hrgn )
 {
     RECT rect;
 
