@@ -103,15 +103,23 @@ static void * const syscalls[] =
     NtGdiTransformPoints,
     NtUserAddClipboardFormatListener,
     NtUserAttachThreadInput,
+    NtUserBuildHwndList,
     NtUserCloseDesktop,
     NtUserCloseWindowStation,
     NtUserCreateDesktopEx,
     NtUserCreateWindowStation,
+    NtUserFindExistingCursorIcon,
     NtUserGetClipboardFormatName,
     NtUserGetClipboardOwner,
     NtUserGetClipboardSequenceNumber,
     NtUserGetClipboardViewer,
     NtUserGetCursor,
+    NtUserGetCursorFrameInfo,
+    NtUserGetDoubleClickTime,
+    NtUserGetDpiForMonitor,
+    NtUserGetForegroundWindow,
+    NtUserGetGUIThreadInfo,
+    NtUserGetIconSize,
     NtUserGetKeyState,
     NtUserGetKeyboardLayout,
     NtUserGetKeyboardLayoutName,
@@ -120,9 +128,12 @@ static void * const syscalls[] =
     NtUserGetMouseMovePointsEx,
     NtUserGetObjectInformation,
     NtUserGetOpenClipboardWindow,
+    NtUserGetProcessDpiAwarenessContext,
     NtUserGetProcessWindowStation,
     NtUserGetProp,
+    NtUserGetSystemDpiForProcess,
     NtUserGetThreadDesktop,
+    NtUserNotifyWinEvent,
     NtUserOpenDesktop,
     NtUserOpenInputDesktop,
     NtUserOpenWindowStation,
@@ -130,9 +141,14 @@ static void * const syscalls[] =
     NtUserRemoveProp,
     NtUserSetKeyboardState,
     NtUserSetObjectInformation,
+    NtUserSetProcessDpiAwarenessContext,
     NtUserSetProcessWindowStation,
     NtUserSetProp,
     NtUserSetThreadDesktop,
+    NtUserSetWinEventHook,
+    NtUserSetWindowsHookEx,
+    NtUserUnhookWinEvent,
+    NtUserUnhookWindowsHookEx,
 };
 
 static BYTE arguments[ARRAY_SIZE(syscalls)];
@@ -160,3 +176,21 @@ unixlib_entry_t __wine_unix_call_funcs[] =
     init,
     callbacks_init,
 };
+
+#ifdef _WIN64
+
+WINE_DEFAULT_DEBUG_CHANNEL(win32u);
+
+static NTSTATUS wow64_init( void *args )
+{
+    FIXME( "\n" );
+    return STATUS_NOT_SUPPORTED;
+}
+
+const unixlib_entry_t __wine_unix_call_wow64_funcs[] =
+{
+    init,
+    wow64_init,
+};
+
+#endif /* _WIN64 */
