@@ -83,7 +83,7 @@ static ULONG WINAPI ImagingFactory_AddRef(IWICImagingFactory2 *iface)
     ImagingFactory *This = impl_from_IWICImagingFactory2(iface);
     ULONG ref = InterlockedIncrement(&This->ref);
 
-    TRACE("(%p) refcount=%u\n", iface, ref);
+    TRACE("(%p) refcount=%lu\n", iface, ref);
 
     return ref;
 }
@@ -93,7 +93,7 @@ static ULONG WINAPI ImagingFactory_Release(IWICImagingFactory2 *iface)
     ImagingFactory *This = impl_from_IWICImagingFactory2(iface);
     ULONG ref = InterlockedDecrement(&This->ref);
 
-    TRACE("(%p) refcount=%u\n", iface, ref);
+    TRACE("(%p) refcount=%lu\n", iface, ref);
 
     if (ref == 0)
         HeapFree(GetProcessHeap(), 0, This);
@@ -109,7 +109,7 @@ static HRESULT WINAPI ImagingFactory_CreateDecoderFromFilename(
     IWICStream *stream;
     HRESULT hr;
 
-    TRACE("(%p,%s,%s,%u,%u,%p)\n", iface, debugstr_w(wzFilename),
+    TRACE("(%p,%s,%s,%lu,%u,%p)\n", iface, debugstr_w(wzFilename),
         debugstr_guid(pguidVendor), dwDesiredAccess, metadataOptions, ppIDecoder);
 
     hr = StreamImpl_Create(&stream);
@@ -230,13 +230,13 @@ static HRESULT WINAPI ImagingFactory_CreateDecoderFromStream(
             BYTE data[4];
             ULONG bytesread;
 
-            WARN("failed to load from a stream %#x\n", res);
+            WARN("failed to load from a stream %#lx\n", res);
 
             seek.QuadPart = 0;
             if (IStream_Seek(pIStream, seek, STREAM_SEEK_SET, NULL) == S_OK)
             {
                 if (IStream_Read(pIStream, data, 4, &bytesread) == S_OK)
-                    WARN("first %i bytes of stream=%x %x %x %x\n", bytesread, data[0], data[1], data[2], data[3]);
+                    WARN("first %li bytes of stream=%x %x %x %x\n", bytesread, data[0], data[1], data[2], data[3]);
             }
         }
         *ppIDecoder = NULL;
@@ -251,7 +251,7 @@ static HRESULT WINAPI ImagingFactory_CreateDecoderFromFileHandle(
     IWICStream *stream;
     HRESULT hr;
 
-    TRACE("(%p,%lx,%s,%u,%p)\n", iface, hFile, debugstr_guid(pguidVendor),
+    TRACE("(%p,%Ix,%s,%u,%p)\n", iface, hFile, debugstr_guid(pguidVendor),
         metadataOptions, ppIDecoder);
 
     hr = StreamImpl_Create(&stream);
@@ -709,7 +709,7 @@ static BOOL get_16bpp_format(HBITMAP hbm, WICPixelFormatGUID *format)
     }
     else
     {
-        FIXME("unrecognized bitfields %x,%x,%x\n", bmh.bV4RedMask,
+        FIXME("unrecognized bitfields %lx,%lx,%lx\n", bmh.bV4RedMask,
             bmh.bV4GreenMask, bmh.bV4BlueMask);
         ret = FALSE;
     }
@@ -981,7 +981,7 @@ failed:
 static HRESULT WINAPI ImagingFactory_CreateComponentEnumerator(IWICImagingFactory2 *iface,
     DWORD componentTypes, DWORD options, IEnumUnknown **ppIEnumUnknown)
 {
-    TRACE("(%p,%u,%u,%p)\n", iface, componentTypes, options, ppIEnumUnknown);
+    TRACE("(%p,%lu,%lu,%p)\n", iface, componentTypes, options, ppIEnumUnknown);
     return CreateComponentEnumerator(componentTypes, options, ppIEnumUnknown);
 }
 
@@ -1249,7 +1249,7 @@ static HRESULT WINAPI ComponentFactory_CreateQueryWriterFromReader(IWICComponent
 static HRESULT WINAPI ComponentFactory_CreateMetadataReader(IWICComponentFactory *iface,
         REFGUID format, const GUID *vendor, DWORD options, IStream *stream, IWICMetadataReader **reader)
 {
-    FIXME("%p,%s,%s,%x,%p,%p: stub\n", iface, debugstr_guid(format), debugstr_guid(vendor),
+    FIXME("%p,%s,%s,%lx,%p,%p: stub\n", iface, debugstr_guid(format), debugstr_guid(vendor),
         options, stream, reader);
     return E_NOTIMPL;
 }
@@ -1267,7 +1267,7 @@ static HRESULT WINAPI ComponentFactory_CreateMetadataReaderFromContainer(IWICCom
     BOOL matches;
     LARGE_INTEGER zero;
 
-    TRACE("%p,%s,%s,%x,%p,%p\n", iface, debugstr_guid(format), debugstr_guid(vendor),
+    TRACE("%p,%s,%s,%lx,%p,%p\n", iface, debugstr_guid(format), debugstr_guid(vendor),
         options, stream, reader);
 
     if (!format || !stream || !reader)
@@ -1385,7 +1385,7 @@ start:
 static HRESULT WINAPI ComponentFactory_CreateMetadataWriter(IWICComponentFactory *iface,
         REFGUID format, const GUID *vendor, DWORD options, IWICMetadataWriter **writer)
 {
-    FIXME("%p,%s,%s,%x,%p: stub\n", iface, debugstr_guid(format), debugstr_guid(vendor), options, writer);
+    FIXME("%p,%s,%s,%lx,%p: stub\n", iface, debugstr_guid(format), debugstr_guid(vendor), options, writer);
     return E_NOTIMPL;
 }
 
@@ -1410,8 +1410,12 @@ static HRESULT WINAPI ComponentFactory_CreateQueryReaderFromBlockReader(IWICComp
 static HRESULT WINAPI ComponentFactory_CreateQueryWriterFromBlockWriter(IWICComponentFactory *iface,
         IWICMetadataBlockWriter *block_writer, IWICMetadataQueryWriter **query_writer)
 {
-    FIXME("%p,%p,%p: stub\n", iface, block_writer, query_writer);
-    return E_NOTIMPL;
+    TRACE("%p,%p,%p\n", iface, block_writer, query_writer);
+
+    if (!block_writer || !query_writer)
+        return E_INVALIDARG;
+
+    return MetadataQueryWriter_CreateInstance(block_writer, NULL, query_writer);
 }
 
 static HRESULT WINAPI ComponentFactory_CreateEncoderPropertyBag(IWICComponentFactory *iface,
