@@ -26,12 +26,8 @@
 
 DEFINE_GUID(CLSID_WineTgaDecoder, 0xb11fc79a,0x67cc,0x43e6,0xa9,0xce,0xe3,0xd5,0x49,0x45,0xd3,0x04);
 
-DEFINE_GUID(CLSID_WICIcnsEncoder, 0x312fb6f1,0xb767,0x409d,0x8a,0x6d,0x0f,0xc1,0x54,0xd4,0xf0,0x5c);
-
 DEFINE_GUID(GUID_WineContainerFormatTga, 0x0c44fda1,0xa5c5,0x4298,0x96,0x85,0x47,0x3f,0xc1,0x7c,0xd3,0x22);
 
-DEFINE_GUID(GUID_WineContainerFormatIcns, 0xe4cd3e69,0x4436,0x4363,0x98,0x1d,0xcc,0xf0,0x5a,0x87,0x4c,0x73);
-
 DEFINE_GUID(GUID_VendorWine, 0xddf46da1,0x7dc1,0x404e,0x98,0xf2,0xef,0xa4,0x8d,0xfc,0x95,0x0a);
 
 extern IID IID_IMILBitmap;
@@ -150,9 +146,9 @@ extern HRESULT JpegDecoder_CreateInstance(REFIID iid, void** ppv) DECLSPEC_HIDDE
 extern HRESULT JpegEncoder_CreateInstance(REFIID iid, void** ppv) DECLSPEC_HIDDEN;
 extern HRESULT TiffDecoder_CreateInstance(REFIID iid, void** ppv) DECLSPEC_HIDDEN;
 extern HRESULT TiffEncoder_CreateInstance(REFIID iid, void** ppv) DECLSPEC_HIDDEN;
-extern HRESULT IcnsEncoder_CreateInstance(REFIID iid, void** ppv) DECLSPEC_HIDDEN;
 extern HRESULT TgaDecoder_CreateInstance(REFIID iid, void** ppv) DECLSPEC_HIDDEN;
 extern HRESULT DdsDecoder_CreateInstance(REFIID iid, void** ppv) DECLSPEC_HIDDEN;
+extern HRESULT DdsEncoder_CreateInstance(REFIID iid, void** ppv) DECLSPEC_HIDDEN;
 
 extern HRESULT BitmapImpl_Create(UINT uiWidth, UINT uiHeight,
     UINT stride, UINT datasize, void *view, UINT offset,
@@ -269,7 +265,7 @@ struct decoder_info
 struct decoder_stat
 {
     DWORD flags;
-    DWORD frame_count;
+    UINT frame_count;
 };
 
 struct decoder_frame
@@ -317,14 +313,6 @@ HRESULT CDECL stream_read(IStream *stream, void *buffer, ULONG read, ULONG *byte
 HRESULT CDECL stream_seek(IStream *stream, LONGLONG ofs, DWORD origin, ULONGLONG *new_position);
 HRESULT CDECL stream_write(IStream *stream, const void *buffer, ULONG write, ULONG *bytes_written);
 
-struct win32_funcs
-{
-    HRESULT (CDECL *stream_getsize)(IStream *stream, ULONGLONG *size);
-    HRESULT (CDECL *stream_read)(IStream *stream, void *buffer, ULONG read, ULONG *bytes_read);
-    HRESULT (CDECL *stream_seek)(IStream *stream, LONGLONG ofs, DWORD origin, ULONGLONG *new_position);
-    HRESULT (CDECL *stream_write)(IStream *stream, const void *buffer, ULONG write, ULONG *bytes_written);
-};
-
 HRESULT CDECL decoder_create(const CLSID *decoder_clsid, struct decoder_info *info, struct decoder **result);
 HRESULT CDECL decoder_initialize(struct decoder *This, IStream *stream, struct decoder_stat *st);
 HRESULT CDECL decoder_get_frame_info(struct decoder* This, UINT frame, struct decoder_frame *info);
@@ -373,7 +361,7 @@ struct encoder_frame
     UINT bpp;
     BOOL indexed;
     DOUBLE dpix, dpiy;
-    DWORD num_colors;
+    UINT num_colors;
     WICColor palette[256];
     /* encoder options */
     BOOL interlace;
@@ -413,31 +401,6 @@ HRESULT CDECL tiff_encoder_create(struct encoder_info *info, struct encoder **re
 HRESULT CDECL jpeg_encoder_create(struct encoder_info *info, struct encoder **result);
 HRESULT CDECL icns_encoder_create(struct encoder_info *info, struct encoder **result);
 
-struct unix_funcs
-{
-    HRESULT (CDECL *decoder_create)(const CLSID *decoder_clsid, struct decoder_info *info, struct decoder **result);
-    HRESULT (CDECL *decoder_initialize)(struct decoder *This, IStream *stream, struct decoder_stat *st);
-    HRESULT (CDECL *decoder_get_frame_info)(struct decoder* This, UINT frame, struct decoder_frame *info);
-    HRESULT (CDECL *decoder_copy_pixels)(struct decoder* This, UINT frame, const WICRect *prc,
-        UINT stride, UINT buffersize, BYTE *buffer);
-    HRESULT (CDECL *decoder_get_metadata_blocks)(struct decoder* This, UINT frame, UINT *count,
-        struct decoder_block **blocks);
-    HRESULT (CDECL *decoder_get_color_context)(struct decoder* This, UINT frame, UINT num,
-        BYTE **data, DWORD *datasize);
-    void (CDECL *decoder_destroy)(struct decoder* This);
-    HRESULT (CDECL *encoder_create)(const CLSID *encoder_clsid, struct encoder_info *info, struct encoder **result);
-    HRESULT (CDECL *encoder_initialize)(struct encoder* This, IStream *stream);
-    HRESULT (CDECL *encoder_get_supported_format)(struct encoder* This, GUID *pixel_format, DWORD *bpp, BOOL *indexed);
-    HRESULT (CDECL *encoder_create_frame)(struct encoder* This, const struct encoder_frame *frame);
-    HRESULT (CDECL *encoder_write_lines)(struct encoder* This, BYTE *data, DWORD line_count, DWORD stride);
-    HRESULT (CDECL *encoder_commit_frame)(struct encoder* This);
-    HRESULT (CDECL *encoder_commit_file)(struct encoder* This);
-    void (CDECL *encoder_destroy)(struct encoder* This);
-};
-
-HRESULT get_unix_decoder(const CLSID *decoder_clsid, struct decoder_info *info, struct decoder **result);
-HRESULT get_unix_encoder(const CLSID *encoder_clsid, struct encoder_info *info, struct encoder **result);
-
 extern HRESULT CommonDecoder_CreateInstance(struct decoder *decoder,
     const struct decoder_info *decoder_info, REFIID iid, void** ppv) DECLSPEC_HIDDEN;
 
