@@ -24,6 +24,7 @@
 #include <windef.h>
 #include <winbase.h>
 #include <winternl.h>
+#include <ddk/hidsdi.h>
 
 #include "unixlib.h"
 
@@ -94,7 +95,7 @@ struct raw_device_vtbl
     void (*destroy)(struct unix_device *iface);
     NTSTATUS (*start)(struct unix_device *iface);
     void (*stop)(struct unix_device *iface);
-    NTSTATUS (*get_report_descriptor)(struct unix_device *iface, BYTE *buffer, DWORD length, DWORD *out_length);
+    NTSTATUS (*get_report_descriptor)(struct unix_device *iface, BYTE *buffer, UINT length, UINT *out_length);
     void (*set_output_report)(struct unix_device *iface, HID_XFER_PACKET *packet, IO_STATUS_BLOCK *io);
     void (*get_feature_report)(struct unix_device *iface, HID_XFER_PACKET *packet, IO_STATUS_BLOCK *io);
     void (*set_feature_report)(struct unix_device *iface, HID_XFER_PACKET *packet, IO_STATUS_BLOCK *io);
@@ -105,8 +106,9 @@ struct hid_device_vtbl
     void (*destroy)(struct unix_device *iface);
     NTSTATUS (*start)(struct unix_device *iface);
     void (*stop)(struct unix_device *iface);
-    NTSTATUS (*haptics_start)(struct unix_device *iface, DWORD duration_ms,
+    NTSTATUS (*haptics_start)(struct unix_device *iface, UINT duration_ms,
                               USHORT rumble_intensity, USHORT buzz_intensity);
+    NTSTATUS (*haptics_stop)(struct unix_device *iface);
     NTSTATUS (*physical_device_control)(struct unix_device *iface, USAGE control);
     NTSTATUS (*physical_device_set_gain)(struct unix_device *iface, BYTE percent);
     NTSTATUS (*physical_effect_control)(struct unix_device *iface, BYTE index, USAGE control, BYTE iterations);
@@ -121,32 +123,32 @@ struct hid_report_descriptor
     BYTE next_report_id[3];
 };
 
-enum haptics_waveform_index
+/* HID spec uses None / Stop names for the first two implicit waveforms,
+ * where Windows SDK headers use STOP / NULL for the corresponding HID
+ * usage constants. We're not actually using the usages anyway are we
+ * stick to the HID spec here.
+ */
+enum haptics_waveform_ordinal
 {
-    HAPTICS_WAVEFORM_STOP_INDEX = 1,
-    HAPTICS_WAVEFORM_NULL_INDEX = 2,
-    HAPTICS_WAVEFORM_RUMBLE_INDEX = 3,
-    HAPTICS_WAVEFORM_BUZZ_INDEX = 4,
-    HAPTICS_WAVEFORM_LAST_INDEX = HAPTICS_WAVEFORM_BUZZ_INDEX,
+    HAPTICS_WAVEFORM_NONE_ORDINAL = 1, /* implicit, not included in waveform_list / duration_list */
+    HAPTICS_WAVEFORM_STOP_ORDINAL = 2, /* implicit, not included in waveform_list / duration_list */
+    HAPTICS_WAVEFORM_RUMBLE_ORDINAL = 3,
+    HAPTICS_WAVEFORM_BUZZ_ORDINAL = 4,
+    HAPTICS_WAVEFORM_FIRST_ORDINAL = HAPTICS_WAVEFORM_RUMBLE_ORDINAL,
+    HAPTICS_WAVEFORM_LAST_ORDINAL = HAPTICS_WAVEFORM_BUZZ_ORDINAL,
 };
 
 struct hid_haptics_features
 {
-    WORD  waveform_list[HAPTICS_WAVEFORM_LAST_INDEX - HAPTICS_WAVEFORM_NULL_INDEX];
-    WORD  duration_list[HAPTICS_WAVEFORM_LAST_INDEX - HAPTICS_WAVEFORM_NULL_INDEX];
-    DWORD waveform_cutoff_time_ms;
-};
-
-struct hid_haptics_waveform
-{
-    WORD manual_trigger;
-    WORD intensity;
+    WORD waveform_list[HAPTICS_WAVEFORM_LAST_ORDINAL - HAPTICS_WAVEFORM_FIRST_ORDINAL + 1];
+    WORD duration_list[HAPTICS_WAVEFORM_LAST_ORDINAL - HAPTICS_WAVEFORM_FIRST_ORDINAL + 1];
+    UINT waveform_cutoff_time_ms;
 };
 
 struct hid_haptics
 {
     struct hid_haptics_features features;
-    struct hid_haptics_waveform waveforms[HAPTICS_WAVEFORM_LAST_INDEX + 1];
+    UINT16 waveform_intensity[HAPTICS_WAVEFORM_LAST_ORDINAL + 1];
     BYTE features_report;
     BYTE waveform_report;
 };
@@ -188,6 +190,7 @@ struct hid_physical
 struct hid_device_state
 {
     ULONG bit_size;
+    USAGE_AND_PAGE abs_axis_usages[32];
     USHORT abs_axis_start;
     USHORT abs_axis_count;
     USHORT rel_axis_start;
