@@ -1320,6 +1320,9 @@ static void *shader_sm4_init(const DWORD *byte_code, size_t byte_code_size,
     {
         struct wined3d_shader_signature_element *e = &output_signature->elements[i];
 
+        if (priv->shader_version.type == WINED3D_SHADER_TYPE_PIXEL
+                && _strnicmp(e->semantic_name, "SV_TARGET", -1))
+            continue;
         if (e->register_idx >= ARRAY_SIZE(priv->output_map))
         {
             WARN("Invalid output index %u.\n", e->register_idx);
@@ -1460,6 +1463,7 @@ static BOOL shader_sm4_read_param(struct wined3d_sm4_data *priv, const DWORD **p
 
             default:
                 FIXME("Skipping modifier 0x%08x.\n", m);
+            case 0x01:
                 *modifier = WINED3DSPSM_NONE;
                 break;
         }
