@@ -20,9 +20,16 @@
 #ifndef __WINE_VULKAN_LOADER_H
 #define __WINE_VULKAN_LOADER_H
 
+#include "ntstatus.h"
+#define WIN32_NO_STATUS
+#include <stdarg.h>
+#include "windef.h"
+#include "winbase.h"
+#include "winternl.h"
 #include "wine/debug.h"
 #include "wine/vulkan.h"
 #include "wine/vulkan_driver.h"
+#include "wine/unixlib.h"
 
 #include "loader_thunks.h"
 
@@ -62,6 +69,45 @@ void *wine_vk_get_device_proc_addr(const char *name) DECLSPEC_HIDDEN;
 void *wine_vk_get_phys_dev_proc_addr(const char *name) DECLSPEC_HIDDEN;
 void *wine_vk_get_instance_proc_addr(const char *name) DECLSPEC_HIDDEN;
 
+/* debug callbacks params */
+
+struct wine_vk_debug_utils_params
+{
+    PFN_vkDebugUtilsMessengerCallbackEXT user_callback;
+    void *user_data;
+
+    VkDebugUtilsMessageSeverityFlagBitsEXT severity;
+    VkDebugUtilsMessageTypeFlagsEXT message_types;
+    VkDebugUtilsMessengerCallbackDataEXT data;
+};
+
+struct wine_vk_debug_report_params
+{
+    PFN_vkDebugReportCallbackEXT user_callback;
+    void *user_data;
+
+    VkDebugReportFlagsEXT flags;
+    VkDebugReportObjectTypeEXT object_type;
+    uint64_t object_handle;
+    size_t location;
+    int32_t code;
+    const char *layer_prefix;
+    const char *message;
+};
+
 extern const struct unix_funcs *unix_funcs;
+extern unixlib_handle_t unix_handle DECLSPEC_HIDDEN;
+
+static inline NTSTATUS vk_unix_call(enum unix_call code, void *params)
+{
+    return __wine_unix_call(unix_handle, code, params);
+}
+
+struct unix_funcs
+{
+    NTSTATUS (WINAPI *p_vk_call)(enum unix_call, void *);
+    BOOL (WINAPI *p_is_available_instance_function)(VkInstance, const char *);
+    BOOL (WINAPI *p_is_available_device_function)(VkDevice, const char *);
+};
 
 #endif /* __WINE_VULKAN_LOADER_H */
