@@ -213,6 +213,10 @@ static PS_ATTRIBUTE_LIST *ps_attributes_32to64( PS_ATTRIBUTE_LIST **attr, const
                         LongToHandle( ((LONG *)ULongToPtr(attr32->Attributes[i].Value))[j] );
             }
             break;
+        case PS_ATTRIBUTE_PARENT_PROCESS:
+            ret->Attributes[i].Size     = sizeof(HANDLE);
+            ret->Attributes[i].ValuePtr = LongToHandle( attr32->Attributes[i].Value );
+            break;
         case PS_ATTRIBUTE_CLIENT_ID:
             ret->Attributes[i].Size     = sizeof(CLIENT_ID);
             ret->Attributes[i].ValuePtr = Wow64AllocateTemp( ret->Attributes[i].Size );
@@ -361,7 +365,7 @@ static void call_user_exception_dispatcher( EXCEPTION_RECORD32 *rec, void *ctx32
             ctx.EFlags &= ~(0x100|0x400|0x40000);
             NtSetInformationThread( GetCurrentThread(), ThreadWow64Context, &ctx, sizeof(ctx) );
 
-            TRACE( "exception %08x dispatcher %08x stack %08x eip %08x\n",
+            TRACE( "exception %08lx dispatcher %08lx stack %08lx eip %08lx\n",
                    rec->ExceptionCode, ctx.Eip, ctx.Esp, stack->context.Eip );
         }
         break;
@@ -388,7 +392,7 @@ static void call_user_exception_dispatcher( EXCEPTION_RECORD32 *rec, void *ctx32
             else ctx.Cpsr &= ~0x20;
             NtSetInformationThread( GetCurrentThread(), ThreadWow64Context, &ctx, sizeof(ctx) );
 
-            TRACE( "exception %08x dispatcher %08x stack %08x pc %08x\n",
+            TRACE( "exception %08lx dispatcher %08lx stack %08lx pc %08lx\n",
                    rec->ExceptionCode, ctx.Pc, ctx.Sp, stack->context.Sp );
         }
         break;
@@ -512,7 +516,7 @@ NTSTATUS WINAPI wow64_NtCreateThread( UINT *args )
     void *initial_teb = get_ptr( &args );
     BOOLEAN suspended = get_ulong( &args );
 
-    FIXME( "%p %x %p %p %p %p %p %u: stub\n", handle_ptr, access, attr32, process,
+    FIXME( "%p %lx %p %p %p %p %p %u: stub\n", handle_ptr, access, attr32, process,
            id32, context, initial_teb, suspended );
     return STATUS_NOT_IMPLEMENTED;
 }
@@ -930,10 +934,10 @@ NTSTATUS WINAPI wow64_NtQueryInformationThread( UINT *args )
         return status;
     }
 
-    case ThreadDescription:  /* THREAD_DESCRIPTION_INFORMATION */
+    case ThreadNameInformation:  /* THREAD_NAME_INFORMATION */
     {
-        THREAD_DESCRIPTION_INFORMATION *info;
-        THREAD_DESCRIPTION_INFORMATION32 *info32 = ptr;
+        THREAD_NAME_INFORMATION *info;
+        THREAD_NAME_INFORMATION32 *info32 = ptr;
         ULONG size, ret_size;
 
         if (len >= sizeof(*info32))
@@ -943,10 +947,10 @@ NTSTATUS WINAPI wow64_NtQueryInformationThread( UINT *args )
             status = NtQueryInformationThread( handle, class, info, size, &ret_size );
             if (!status)
             {
-                info32->Description.Length = info->Description.Length;
-                info32->Description.MaximumLength = info->Description.MaximumLength;
-                info32->Description.Buffer = PtrToUlong( info32 + 1 );
-                memcpy( info32 + 1, info + 1, min( len, info->Description.MaximumLength ));
+                info32->ThreadName.Length = info->ThreadName.Length;
+                info32->ThreadName.MaximumLength = info->ThreadName.MaximumLength;
+                info32->ThreadName.Buffer = PtrToUlong( info32 + 1 );
+                memcpy( info32 + 1, info + 1, min( len, info->ThreadName.MaximumLength ));
             }
         }
         else status = NtQueryInformationThread( handle, class, NULL, 0, &ret_size );
@@ -1186,13 +1190,13 @@ NTSTATUS WINAPI wow64_NtSetInformationThread( UINT *args )
         }
         else return STATUS_INVALID_PARAMETER;
 
-    case ThreadDescription:   /* THREAD_DESCRIPTION_INFORMATION */
-        if (len == sizeof(THREAD_DESCRIPTION_INFORMATION32))
+    case ThreadNameInformation:   /* THREAD_NAME_INFORMATION */
+        if (len == sizeof(THREAD_NAME_INFORMATION32))
         {
-            THREAD_DESCRIPTION_INFORMATION32 *info32 = ptr;
-            THREAD_DESCRIPTION_INFORMATION info;
+            THREAD_NAME_INFORMATION32 *info32 = ptr;
+            THREAD_NAME_INFORMATION info;
 
-            if (!unicode_str_32to64( &info.Description, &info32->Description ))
+            if (!unicode_str_32to64( &info.ThreadName, &info32->ThreadName ))
                 return STATUS_ACCESS_VIOLATION;
             return NtSetInformationThread( handle, class, &info, sizeof(info) );
         }
