@@ -141,7 +141,7 @@ NTSTATUS WINAPI wow64_NtAcceptConnectPort( UINT *args )
     LPC_SECTION_WRITE *write = get_ptr( &args );
     LPC_SECTION_READ *read = get_ptr( &args );
 
-    FIXME( "%p %u %p %u %p %p: stub\n", handle_ptr, id, msg, accept, write, read );
+    FIXME( "%p %lu %p %u %p %p: stub\n", handle_ptr, id, msg, accept, write, read );
     return STATUS_NOT_IMPLEMENTED;
 }
 
@@ -169,6 +169,18 @@ NTSTATUS WINAPI wow64_NtClearEvent( UINT *args )
 }
 
 
+/**********************************************************************
+ *           wow64_NtCompareObjects
+ */
+NTSTATUS WINAPI wow64_NtCompareObjects( UINT *args )
+{
+    HANDLE first = get_handle( &args );
+    HANDLE second = get_handle( &args );
+
+    return NtCompareObjects( first, second );
+}
+
+
 /**********************************************************************
  *           wow64_NtCompleteConnectPort
  */
