@@ -110,8 +110,8 @@ static const char *debugstr_config( const struct console_config *config )
 
 static const char *debugstr_logfont( const LOGFONTW *lf, unsigned int ft )
 {
-    return wine_dbg_sprintf( "%s%s%s%s  lfHeight=%d lfWidth=%d lfEscapement=%d "
-                             "lfOrientation=%d lfWeight=%d lfItalic=%u lfUnderline=%u "
+    return wine_dbg_sprintf( "%s%s%s%s  lfHeight=%ld lfWidth=%ld lfEscapement=%ld "
+                             "lfOrientation=%ld lfWeight=%ld lfItalic=%u lfUnderline=%u "
                              "lfStrikeOut=%u lfCharSet=%u lfPitchAndFamily=%u lfFaceName=%s",
                              (ft & RASTER_FONTTYPE) ? "raster" : "",
                              (ft & TRUETYPE_FONTTYPE) ? "truetype" : "",
@@ -124,8 +124,8 @@ static const char *debugstr_logfont( const LOGFONTW *lf, unsigned int ft )
 
 static const char *debugstr_textmetric( const TEXTMETRICW *tm, unsigned int ft )
 {
-        return wine_dbg_sprintf( "%s%s%s%s tmHeight=%d tmAscent=%d tmDescent=%d "
-                                 "tmAveCharWidth=%d tmMaxCharWidth=%d tmWeight=%d "
+        return wine_dbg_sprintf( "%s%s%s%s tmHeight=%ld tmAscent=%ld tmDescent=%ld "
+                                 "tmAveCharWidth=%ld tmMaxCharWidth=%ld tmWeight=%ld "
                                  "tmPitchAndFamily=%u tmCharSet=%u",
                                  (ft & RASTER_FONTTYPE) ? "raster" : "",
                                  (ft & TRUETYPE_FONTTYPE) ? "truetype" : "",
@@ -256,7 +256,7 @@ static void load_config( const WCHAR *key_name, struct console_config *config )
     config->menu_mask    = 0;
     config->popup_attr   = 0xF5;
     config->quick_edit   = 0;
-    config->sb_height    = 25;
+    config->sb_height    = 150;
     config->sb_width     = 80;
     config->attr         = 0x000F;
     config->win_height   = 25;
@@ -285,7 +285,7 @@ static void save_registry_key( HKEY key, const struct console_config *config )
     DWORD val, width, height, i;
     WCHAR color_name[13];
 
-    TRACE( "%s", debugstr_config( config ));
+    TRACE( "%s\n", debugstr_config( config ));
 
     for (i = 0; i < ARRAY_SIZE(config->color_map); i++)
     {
@@ -303,7 +303,8 @@ static void save_registry_key( HKEY key, const struct console_config *config )
     val = config->edition_mode;
     RegSetValueExW( key, L"EditionMode", 0, REG_DWORD, (BYTE *)&val, sizeof(val) );
 
-    RegSetValueExW( key, L"FaceName", 0, REG_SZ, (BYTE *)&config->face_name, sizeof(config->face_name) );
+    RegSetValueExW( key, L"FaceName", 0, REG_SZ, (BYTE *)&config->face_name,
+                    (lstrlenW(config->face_name) + 1) * sizeof(WCHAR) );
 
     val = config->font_pitch_family;
     RegSetValueExW( key, L"FontPitchFamily", 0, REG_DWORD, (BYTE *)&val, sizeof(val) );
@@ -428,9 +429,9 @@ static void fill_mem_dc( struct console *console, const RECT *update )
 /* set a new position for the cursor */
 static void update_window_cursor( struct console *console )
 {
-    if (console->win != GetFocus() || !console->active->cursor_visible) return;
+    if (!console->active->cursor_visible || console->win != GetFocus()) return;
 
-    SetCaretPos( (console->active->cursor_x - console->active->win.left) * console->active->font.width,
+    SetCaretPos( (get_bounded_cursor_x( console->active ) - console->active->win.left) * console->active->font.width,
                  (console->active->cursor_y - console->active->win.top)  * console->active->font.height );
     ShowCaret( console->win );
 }
@@ -607,10 +608,10 @@ static void update_window( struct console *console )
         }
     }
 
-    if (update_all || console->active->cursor_x != console->window->cursor_pos.X ||
+    if (update_all || get_bounded_cursor_x( console->active ) != console->window->cursor_pos.X ||
         console->active->cursor_y != console->window->cursor_pos.Y)
     {
-        console->window->cursor_pos.X = console->active->cursor_x;
+        console->window->cursor_pos.X = get_bounded_cursor_x( console->active );
         console->window->cursor_pos.Y = console->active->cursor_y;
         update_window_cursor( console );
     }
@@ -645,13 +646,14 @@ static HFONT select_font_config( struct console_config *config, unsigned int cp,
     lstrcpyW( config->face_name, lf->lfFaceName );
 
     /* FIXME: use maximum width for DBCS codepages since some chars take two cells */
-    if (GetCPInfo( cp, &cpinfo ) && cpinfo.MaxCharSize > 1)
+    if (GetCPInfo( cp, &cpinfo ) && cpinfo.MaxCharSize == 2)
         config->cell_width  = tm.tmMaxCharWidth;
 
     return font;
 }
 
-static void fill_logfont( LOGFONTW *lf, const WCHAR *name, unsigned int height, unsigned int weight )
+static void fill_logfont( LOGFONTW *lf, const WCHAR *face_name, size_t face_name_size,
+                          unsigned int height, unsigned int weight )
 {
     lf->lfHeight         = height;
     lf->lfWidth          = 0;
@@ -666,7 +668,9 @@ static void fill_logfont( LOGFONTW *lf, const WCHAR *name, unsigned int height,
     lf->lfClipPrecision  = CLIP_DEFAULT_PRECIS;
     lf->lfQuality        = DEFAULT_QUALITY;
     lf->lfPitchAndFamily = FIXED_PITCH | FF_DONTCARE;
-    lstrcpyW( lf->lfFaceName, name );
+    face_name_size = min( face_name_size, sizeof(lf->lfFaceName) - sizeof(WCHAR) );
+    memcpy( lf->lfFaceName, face_name, face_name_size );
+    lf->lfFaceName[face_name_size / sizeof(WCHAR)] = 0;
 }
 
 static BOOL set_console_font( struct console *console, const LOGFONTW *logfont )
@@ -682,9 +686,9 @@ static BOOL set_console_font( struct console *console, const LOGFONTW *logfont )
     if (console->window->font && logfont->lfHeight == console->active->font.height &&
         logfont->lfWeight == console->active->font.weight &&
         !logfont->lfItalic && !logfont->lfUnderline && !logfont->lfStrikeOut &&
-        console->active->font.face_len == wcslen( logfont->lfFaceName ) * sizeof(WCHAR) &&
+        console->active->font.face_len == wcslen( logfont->lfFaceName ) &&
         !memcmp( logfont->lfFaceName, console->active->font.face_name,
-                 console->active->font.face_len ))
+                 console->active->font.face_len * sizeof(WCHAR) ))
     {
         TRACE( "equal to current\n" );
         return TRUE;
@@ -704,15 +708,16 @@ static BOOL set_console_font( struct console *console, const LOGFONTW *logfont )
 
     font_info->width  = tm.tmAveCharWidth;
     font_info->height = tm.tmHeight + tm.tmExternalLeading;
+    font_info->pitch_family = tm.tmPitchAndFamily;
     font_info->weight = tm.tmWeight;
 
     free( font_info->face_name );
-    font_info->face_len = wcslen( logfont->lfFaceName ) * sizeof(WCHAR);
-    font_info->face_name = malloc( font_info->face_len );
-    memcpy( font_info->face_name, logfont->lfFaceName, font_info->face_len );
+    font_info->face_len = wcslen( logfont->lfFaceName );
+    font_info->face_name = malloc( font_info->face_len * sizeof(WCHAR) );
+    memcpy( font_info->face_name, logfont->lfFaceName, font_info->face_len * sizeof(WCHAR) );
 
     /* FIXME: use maximum width for DBCS codepages since some chars take two cells */
-    if (GetCPInfo( console->output_cp, &cpinfo ) && cpinfo.MaxCharSize > 1)
+    if (GetCPInfo( console->output_cp, &cpinfo ) && cpinfo.MaxCharSize == 2)
         font_info->width  = tm.tmMaxCharWidth;
 
     if (console->window->font) DeleteObject( console->window->font );
@@ -818,9 +823,10 @@ static int WINAPI get_first_font_sub_enum( const LOGFONTW *lf, const TEXTMETRICW
             load_config( fc->console->window->config_key, &config );
             config.cell_width  = fc->console->active->font.width;
             config.cell_height = fc->console->active->font.height;
-            fc->console->active->font.face_len = wcslen( config.face_name ) * sizeof(WCHAR);
-            memcpy( fc->console->active->font.face_name, config.face_name,
-                    fc->console->active->font.face_len );
+            memcpy( config.face_name, fc->console->active->font.face_name,
+                    fc->console->active->font.face_len * sizeof(WCHAR) );
+            config.face_name[fc->console->active->font.face_len] = 0;
+
             /* Force also its writing back to the registry so that we can get it
              * the next time.
              */
@@ -849,15 +855,15 @@ static int WINAPI get_first_font_enum( const LOGFONTW *lf, const TEXTMETRICW *tm
 
 
 /* sets logfont as the new font for the console */
-static void update_console_font( struct console *console, const WCHAR *font,
-                                 unsigned int height, unsigned int weight )
+void update_console_font( struct console *console, const WCHAR *face_name, size_t face_name_size,
+                          unsigned int height, unsigned int weight )
 {
     struct font_chooser fc;
     LOGFONTW lf;
 
-    if (font[0] && height && weight)
+    if (face_name[0] && height && weight)
     {
-        fill_logfont( &lf, font, height, weight );
+        fill_logfont( &lf, face_name, face_name_size, height, weight );
         if (set_console_font( console, &lf )) return;
     }
 
@@ -870,7 +876,7 @@ static void update_console_font( struct console *console, const WCHAR *font,
         EnumFontFamiliesW( console->window->mem_dc, NULL, get_first_font_enum, (LPARAM)&fc );
         if (fc.done) return;
     }
-    ERR( "Couldn't find a decent font" );
+    ERR( "Couldn't find a decent font\n" );
 }
 
 /* get a cell from a relative coordinate in window (takes into account the scrolling) */
@@ -1579,8 +1585,9 @@ static BOOL select_font( struct dialog_info *di )
     if (font_idx < 0 || size_idx < 0 || size_idx >= di->font_count)
         return FALSE;
 
-    fill_logfont( &lf, di->font[size_idx].faceName, di->font[size_idx].height,
-                  di->font[size_idx].weight );
+    fill_logfont( &lf, di->font[size_idx].faceName,
+                  wcslen(di->font[size_idx].faceName) * sizeof(WCHAR),
+                  di->font[size_idx].height, di->font[size_idx].weight );
     font = select_font_config( &config, di->console->output_cp, di->console->win, &lf );
     if (!font) return FALSE;
 
@@ -1700,7 +1707,9 @@ static INT_PTR WINAPI font_dialog_proc( HWND dialog, UINT msg, WPARAM wparam, LP
                 {
                     LOGFONTW lf;
 
-                    fill_logfont( &lf, di->font[val].faceName, di->font[val].height, di->font[val].weight );
+                    fill_logfont( &lf, di->font[val].faceName,
+                                  wcslen(di->font[val].faceName) * sizeof(WCHAR),
+                                  di->font[val].height, di->font[val].weight );
                     DeleteObject( select_font_config( &di->config, di->console->output_cp,
                                                       di->console->win, &lf ));
                 }
@@ -1816,8 +1825,9 @@ static INT_PTR WINAPI save_dialog_proc( HWND dialog, UINT msg, WPARAM wparam, LP
     switch (msg)
     {
     case WM_INITDIALOG:
+        SendMessageW( dialog, WM_NEXTDLGCTL, (WPARAM)GetDlgItem( dialog, IDC_SAV_SESSION ), TRUE );
         SendDlgItemMessageW( dialog, IDC_SAV_SESSION, BM_SETCHECK, BST_CHECKED, 0 );
-        break;
+        return FALSE;
 
     case WM_COMMAND:
         switch (LOWORD(wparam))
@@ -1885,7 +1895,7 @@ static void apply_config( struct console *console, const struct console_config *
     console->active->attr = config->attr;
     console->active->popup_attr = config->popup_attr;
     console->active->win.left   = config->win_pos.X;
-    console->active->win.right  = config->win_pos.Y;
+    console->active->win.top    = config->win_pos.Y;
     console->active->win.right  = config->win_pos.X + config->win_width - 1;
     console->active->win.bottom = config->win_pos.Y + config->win_height - 1;
     memcpy( console->active->color_map, config->color_map, sizeof(config->color_map) );
@@ -1894,13 +1904,17 @@ static void apply_config( struct console *console, const struct console_config *
         console->active->font.height != config->cell_height ||
         console->active->font.weight != config->font_weight ||
         console->active->font.pitch_family != config->font_pitch_family ||
-        console->active->font.face_len != wcslen( config->face_name ) * sizeof(WCHAR) ||
-        memcmp( console->active->font.face_name, config->face_name, console->active->font.face_len ))
+        console->active->font.face_len != wcslen( config->face_name ) ||
+        memcmp( console->active->font.face_name, config->face_name,
+                console->active->font.face_len * sizeof(WCHAR) ))
     {
-        update_console_font( console, config->face_name, config->cell_height, config->font_weight );
+        update_console_font( console, config->face_name, wcslen(config->face_name) * sizeof(WCHAR),
+                             config->cell_height, config->font_weight );
     }
 
     update_window( console );
+
+    notify_screen_buffer_size( console->active );
 }
 
 static void current_config( struct console *console, struct console_config *config )
@@ -1923,13 +1937,11 @@ static void current_config( struct console *console, struct console_config *conf
     config->popup_attr = console->active->popup_attr;
     memcpy( config->color_map, console->active->color_map, sizeof(config->color_map) );
 
-    config->win_height  = console->active->win.bottom - console->active->win.top + 1;
-    config->win_width   = console->active->win.right - console->active->win.left + 1;
     config->cell_width  = console->active->font.width;
     config->cell_height = console->active->font.height;
     config->font_weight = console->active->font.weight;
     config->font_pitch_family = console->active->font.pitch_family;
-    len = min( ARRAY_SIZE(config->face_name) - 1, console->active->font.face_len / sizeof(WCHAR) );
+    len = min( ARRAY_SIZE(config->face_name) - 1, console->active->font.face_len );
     if (len) memcpy( config->face_name, console->active->font.face_name, len * sizeof(WCHAR) );
     config->face_name[len] = 0;
 
@@ -2142,15 +2154,18 @@ static LRESULT window_create( HWND hwnd, const CREATESTRUCTW *create )
     SetWindowLongPtrW( hwnd, 0, (DWORD_PTR)console );
     console->win = hwnd;
 
-    sys_menu = GetSystemMenu( hwnd, FALSE );
-    if (!sys_menu) return 0;
-    console->window->popup_menu = CreatePopupMenu();
-    if (!console->window->popup_menu) return 0;
+    if (console->window)
+    {
+        sys_menu = GetSystemMenu( hwnd, FALSE );
+        if (!sys_menu) return 0;
+        console->window->popup_menu = CreatePopupMenu();
+        if (!console->window->popup_menu) return 0;
 
-    fill_menu( sys_menu, TRUE );
-    fill_menu( console->window->popup_menu, FALSE );
+        fill_menu( sys_menu, TRUE );
+        fill_menu( console->window->popup_menu, FALSE );
 
-    console->window->mem_dc = CreateCompatibleDC( 0 );
+        console->window->mem_dc = CreateCompatibleDC( 0 );
+    }
     return 0;
 }
 
@@ -2168,14 +2183,18 @@ static LRESULT WINAPI window_proc( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lp
         PostQuitMessage( 0 );
         break;
 
+    case WM_TIMER:
     case WM_UPDATE_CONFIG:
-        update_window( console );
+        if (console->window && console->window->update_state == UPDATE_PENDING)
+            update_window( console );
         break;
 
     case WM_PAINT:
         {
             PAINTSTRUCT ps;
 
+            if (!console->window) break;
+
             BeginPaint( console->win, &ps );
             BitBlt( ps.hdc, 0, 0,
                     (console->active->win.right - console->active->win.left + 1) * console->active->font.width,
@@ -2190,6 +2209,7 @@ static LRESULT WINAPI window_proc( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lp
         }
 
     case WM_SHOWWINDOW:
+        if (!console->window) break;
         if (wparam)
             update_window( console );
         else
@@ -2201,7 +2221,7 @@ static LRESULT WINAPI window_proc( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lp
 
     case WM_KEYDOWN:
     case WM_KEYUP:
-        if (console->window->in_selection)
+        if (console->window && console->window->in_selection)
             handle_selection_key( console, msg == WM_KEYDOWN, wparam, lparam );
         else
             record_key_input( console, msg == WM_KEYDOWN, wparam, lparam );
@@ -2213,7 +2233,7 @@ static LRESULT WINAPI window_proc( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lp
         break;
 
     case WM_LBUTTONDOWN:
-        if (console->window->quick_edit || console->window->in_selection)
+        if (console->window && (console->window->quick_edit || console->window->in_selection))
         {
             if (console->window->in_selection)
                 update_selection( console, 0 );
@@ -2238,7 +2258,7 @@ static LRESULT WINAPI window_proc( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lp
         break;
 
     case WM_MOUSEMOVE:
-        if (console->window->quick_edit || console->window->in_selection)
+        if (console->window && (console->window->quick_edit || console->window->in_selection))
         {
             if (GetCapture() == console->win && console->window->in_selection &&
                 (wparam & MK_LBUTTON))
@@ -2254,7 +2274,7 @@ static LRESULT WINAPI window_proc( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lp
         break;
 
     case WM_LBUTTONUP:
-        if (console->window->quick_edit || console->window->in_selection)
+        if (console->window && (console->window->quick_edit || console->window->in_selection))
         {
             if (GetCapture() == console->win && console->window->in_selection)
             {
@@ -2270,7 +2290,7 @@ static LRESULT WINAPI window_proc( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lp
         break;
 
     case WM_RBUTTONDOWN:
-        if ((wparam & (MK_CONTROL|MK_SHIFT)) == console->window->menu_mask)
+        if (console->window && (wparam & (MK_CONTROL|MK_SHIFT)) == console->window->menu_mask)
         {
             POINT       pt;
             pt.x = (short)LOWORD(lparam);
@@ -2301,7 +2321,7 @@ static LRESULT WINAPI window_proc( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lp
         break;
 
     case WM_SETFOCUS:
-        if (console->active->cursor_visible)
+        if (console->window && console->active->cursor_visible)
         {
             CreateCaret( console->win, console->window->cursor_bitmap,
                          console->active->font.width, console->active->font.height );
@@ -2310,12 +2330,12 @@ static LRESULT WINAPI window_proc( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lp
         break;
 
     case WM_KILLFOCUS:
-        if (console->active->cursor_visible)
+        if (console->window && console->active->cursor_visible)
             DestroyCaret();
         break;
 
     case WM_SIZE:
-        if (console->window->update_state != UPDATE_BUSY)
+        if (console->window && console->window->update_state != UPDATE_BUSY)
             resize_window( console,
                            max( LOWORD(lparam) / console->active->font.width, 20 ),
                            max( HIWORD(lparam) / console->active->font.height, 20 ));
@@ -2326,6 +2346,7 @@ static LRESULT WINAPI window_proc( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lp
             int win_width = console->active->win.right - console->active->win.left + 1;
             int x = console->active->win.left;
 
+            if (!console->window) break;
             switch (LOWORD(wparam))
             {
             case SB_PAGEUP:     x -= 8;              break;
@@ -2357,6 +2378,8 @@ static LRESULT WINAPI window_proc( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lp
             int win_height = console->active->win.bottom - console->active->win.top + 1;
             int y = console->active->win.top;
 
+            if (!console->window) break;
+
             if (msg == WM_MOUSEWHEEL)
             {
                 UINT scroll_lines = 3;
@@ -2388,6 +2411,7 @@ static LRESULT WINAPI window_proc( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lp
         }
 
     case WM_SYSCOMMAND:
+        if (!console->window) break;
         switch (wparam)
         {
         case IDS_DEFAULT:
@@ -2402,6 +2426,7 @@ static LRESULT WINAPI window_proc( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lp
         break;
 
     case WM_COMMAND:
+        if (!console->window) break;
         switch (wparam)
         {
         case IDS_DEFAULT:
@@ -2436,7 +2461,7 @@ static LRESULT WINAPI window_proc( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lp
             break;
         case IDS_SCROLL:
         case IDS_SEARCH:
-            FIXME( "Unhandled yet command: %lx\n", wparam );
+            FIXME( "Unhandled yet command: %Ix\n", wparam );
             break;
         default:
             return DefWindowProcW( hwnd, msg, wparam, lparam );
@@ -2444,7 +2469,7 @@ static LRESULT WINAPI window_proc( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lp
         break;
 
     case WM_INITMENUPOPUP:
-        if (!HIWORD(lparam)) return DefWindowProcW( hwnd, msg, wparam, lparam );
+        if (!console->window || !HIWORD(lparam)) return DefWindowProcW( hwnd, msg, wparam, lparam );
         set_menu_details( console, GetSystemMenu(console->win, FALSE) );
         break;
 
@@ -2455,11 +2480,16 @@ static LRESULT WINAPI window_proc( HWND hwnd, UINT msg, WPARAM wparam, LPARAM lp
     return 0;
 }
 
-void update_window_config( struct console *console )
+void update_window_config( struct console *console, BOOL delay )
 {
-    if (!console->win || console->window->update_state != UPDATE_NONE) return;
+    const int delay_timeout = 50;
+
+    if (!console->window || console->window->update_state != UPDATE_NONE) return;
     console->window->update_state = UPDATE_PENDING;
-    PostMessageW( console->win, WM_UPDATE_CONFIG, 0, 0 );
+    if (delay)
+        SetTimer( console->win, 1, delay_timeout, NULL );
+    else
+        PostMessageW( console->win, WM_UPDATE_CONFIG, 0, 0 );
 }
 
 void update_window_region( struct console *console, const RECT *update )
@@ -2469,7 +2499,7 @@ void update_window_region( struct console *console, const RECT *update )
     window_rect->top    = min( window_rect->top,    update->top );
     window_rect->right  = max( window_rect->right,  update->right );
     window_rect->bottom = max( window_rect->bottom, update->bottom );
-    update_window_config( console );
+    update_window_config( console, TRUE );
 }
 
 BOOL init_window( struct console *console )
@@ -2528,3 +2558,25 @@ BOOL init_window( struct console *console )
     apply_config( console, &config );
     return TRUE;
 }
+
+void init_message_window( struct console *console )
+{
+    WNDCLASSW wndclass;
+
+    wndclass.style         = CS_DBLCLKS;
+    wndclass.lpfnWndProc   = window_proc;
+    wndclass.cbClsExtra    = 0;
+    wndclass.cbWndExtra    = sizeof(DWORD_PTR);
+    wndclass.hInstance     = GetModuleHandleW( NULL );
+    wndclass.hIcon         = 0;
+    wndclass.hCursor       = 0;
+    wndclass.hbrBackground = GetStockObject( BLACK_BRUSH );
+    wndclass.lpszMenuName  = NULL;
+    wndclass.lpszClassName = L"WineConsoleClass";
+    RegisterClassW(&wndclass);
+
+    CreateWindowW( wndclass.lpszClassName, NULL,
+                   WS_OVERLAPPED|WS_CAPTION|WS_SYSMENU|WS_THICKFRAME|WS_MINIMIZEBOX|
+                   WS_MAXIMIZEBOX|WS_HSCROLL|WS_VSCROLL, CW_USEDEFAULT, CW_USEDEFAULT,
+                   0, 0, HWND_MESSAGE, 0, wndclass.hInstance, console );
+}
