@@ -84,7 +84,7 @@ static HRESULT load_typelib(void)
     hres = LoadRegTypeLib(&LIBID_SHDocVw, 1, 0, LOCALE_SYSTEM_DEFAULT, &tl);
     if (FAILED(hres))
     {
-        ERR("LoadRegTypeLib failed: %08x\n", hres);
+        ERR("LoadRegTypeLib failed: %08lx\n", hres);
         return hres;
     }
 
@@ -107,7 +107,7 @@ static HRESULT get_typeinfo(tid_t tid, ITypeInfo **typeinfo)
 
         hres = ITypeLib_GetTypeInfoOfGuid(typelib, tid_ids[tid], &ti);
         if (FAILED(hres)) {
-            ERR("GetTypeInfoOfGuid(%s) failed: %08x\n", debugstr_guid(tid_ids[tid]), hres);
+            ERR("GetTypeInfoOfGuid(%s) failed: %08lx\n", debugstr_guid(tid_ids[tid]), hres);
             return hres;
         }
 
@@ -467,7 +467,7 @@ static BOOL process_changes( const WCHAR *folder, char *buf )
             break;
 
         default:
-            WARN( "unexpected action %u\n", info->Action );
+            WARN( "unexpected action %lu\n", info->Action );
             break;
         }
         if (!info->NextEntryOffset) break;
@@ -623,7 +623,7 @@ static WNDPROC desktop_orig_wndproc;
 /* window procedure for the desktop window */
 static LRESULT WINAPI desktop_wnd_proc( HWND hwnd, UINT message, WPARAM wp, LPARAM lp )
 {
-    WINE_TRACE( "got msg %04x wp %lx lp %lx\n", message, wp, lp );
+    WINE_TRACE( "got msg %04x wp %Ix lp %Ix\n", message, wp, lp );
 
     switch(message)
     {
@@ -836,6 +836,7 @@ static HMODULE load_graphics_driver( const WCHAR *driver, const GUID *guid )
         if (!wcscmp( name, L"null" ))
         {
             TRACE( "display %s using null driver\n", debugstr_guid(guid) );
+            wcscpy( libname, L"null" );
             null_driver = TRUE;
             break;
         }
@@ -851,17 +852,13 @@ static HMODULE load_graphics_driver( const WCHAR *driver, const GUID *guid )
             strcpy( error, "Make sure that your X server is running and that $DISPLAY is set correctly." );
             break;
         default:
-            sprintf( error, "Unknown error (%u).", GetLastError() );
+            sprintf( error, "Unknown error (%lu).", GetLastError() );
             break;
         }
         name = next;
     }
 
-    if (module)
-    {
-        GetModuleFileNameW( module, buffer, MAX_PATH );
-        TRACE( "display %s driver %s\n", debugstr_guid(guid), debugstr_w(buffer) );
-    }
+    TRACE( "display %s driver %s\n", debugstr_guid(guid), debugstr_w(libname) );
 
     swprintf( key, ARRAY_SIZE(key), device_keyW, guid->Data1, guid->Data2, guid->Data3,
               guid->Data4[0], guid->Data4[1], guid->Data4[2], guid->Data4[3],
@@ -872,7 +869,7 @@ static HMODULE load_graphics_driver( const WCHAR *driver, const GUID *guid )
     {
         if (module || null_driver)
             RegSetValueExW( hkey, graphics_driverW, 0, REG_SZ,
-                            (BYTE *)buffer, (lstrlenW(buffer) + 1) * sizeof(WCHAR) );
+                            (BYTE *)libname, (lstrlenW(libname) + 1) * sizeof(WCHAR) );
         else
             RegSetValueExA( hkey, "DriverError", 0, REG_SZ, (BYTE *)error, strlen(error) + 1 );
         RegCloseKey( hkey );
@@ -900,7 +897,7 @@ static void initialize_display_settings(void)
             continue;
         }
 
-        WINE_TRACE( "Device %s current display mode %ux%u %uBits %uHz at %d,%d.\n",
+        WINE_TRACE( "Device %s current display mode %lux%lu %luBits %luHz at %ld,%ld.\n",
                     wine_dbgstr_w( ddW.DeviceName ), dmW.dmPelsWidth, dmW.dmPelsHeight,
                     dmW.dmBitsPerPel, dmW.dmDisplayFrequency, dmW.u1.s2.dmPosition.x,
                     dmW.u1.s2.dmPosition.y );
@@ -963,6 +960,7 @@ void manage_desktop( WCHAR *arg )
     const WCHAR *name = NULL;
     BOOL enable_shell = FALSE;
     void (WINAPI *pShellDDEInit)( BOOL ) = NULL;
+    HMODULE shell32;
 
     /* get the rest of the command line (if any) */
     while (*p && !is_whitespace(*p)) p++;
@@ -999,7 +997,7 @@ void manage_desktop( WCHAR *arg )
     {
         if (!(desktop = CreateDesktopW( name, NULL, NULL, 0, DESKTOP_ALL_ACCESS, NULL )))
         {
-            WINE_ERR( "failed to create desktop %s error %d\n", wine_dbgstr_w(name), GetLastError() );
+            WINE_ERR( "failed to create desktop %s error %ld\n", wine_dbgstr_w(name), GetLastError() );
             ExitProcess( 1 );
         }
         SetThreadDesktop( desktop );
@@ -1032,20 +1030,15 @@ void manage_desktop( WCHAR *arg )
         initialize_display_settings();
         initialize_appbar();
 
-        if (graphics_driver)
+        if (using_root) enable_shell = FALSE;
+
+        initialize_systray( graphics_driver, using_root, enable_shell );
+        if (!using_root) initialize_launchers( hwnd );
+
+        if ((shell32 = LoadLibraryW( L"shell32.dll" )) &&
+            (pShellDDEInit = (void *)GetProcAddress( shell32, (LPCSTR)188)))
         {
-            HMODULE shell32;
-
-            if (using_root) enable_shell = FALSE;
-
-            initialize_systray( graphics_driver, using_root, enable_shell );
-            if (!using_root) initialize_launchers( hwnd );
-
-            if ((shell32 = LoadLibraryW( L"shell32.dll" )) &&
-                (pShellDDEInit = (void *)GetProcAddress( shell32, (LPCSTR)188)))
-            {
-                pShellDDEInit( TRUE );
-            }
+            pShellDDEInit( TRUE );
         }
     }
 
@@ -1129,7 +1122,7 @@ static HRESULT WINAPI shellwindows_GetTypeInfoCount(IShellWindows *iface, UINT *
 static HRESULT WINAPI shellwindows_GetTypeInfo(IShellWindows *iface,
         UINT iTInfo, LCID lcid, ITypeInfo **ppTInfo)
 {
-    TRACE("%d %d %p\n", iTInfo, lcid, ppTInfo);
+    TRACE("%d %ld %p\n", iTInfo, lcid, ppTInfo);
     return get_typeinfo(IShellWindows_tid, ppTInfo);
 }
 
@@ -1140,7 +1133,7 @@ static HRESULT WINAPI shellwindows_GetIDsOfNames(IShellWindows *iface,
     ITypeInfo *typeinfo;
     HRESULT hr;
 
-    TRACE("%s %p %d %d %p\n", debugstr_guid(riid), rgszNames, cNames,
+    TRACE("%s %p %d %ld %p\n", debugstr_guid(riid), rgszNames, cNames,
           lcid, rgDispId);
 
     if (!rgszNames || cNames == 0 || !rgDispId)
@@ -1164,7 +1157,7 @@ static HRESULT WINAPI shellwindows_Invoke(IShellWindows *iface,
     ITypeInfo *typeinfo;
     HRESULT hr;
 
-    TRACE("%d %s %d %08x %p %p %p %p\n", dispIdMember, debugstr_guid(riid),
+    TRACE("%ld %s %ld %08x %p %p %p %p\n", dispIdMember, debugstr_guid(riid),
             lcid, wFlags, pDispParams, pVarResult, pExcepInfo, puArgErr);
 
     hr = get_typeinfo(IShellWindows_tid, &typeinfo);
@@ -1203,7 +1196,7 @@ static HRESULT WINAPI shellwindows_Register(IShellWindows *iface,
     struct shellwindows *sw = impl_from_IShellWindows(iface);
     struct window *window;
 
-    TRACE("iface %p, disp %p, hwnd %#x, class %u, cookie %p.\n", iface, disp, hwnd, class, cookie);
+    TRACE("iface %p, disp %p, hwnd %#lx, class %u, cookie %p.\n", iface, disp, hwnd, class, cookie);
 
     if (!hwnd)
         return E_POINTER;
@@ -1223,6 +1216,7 @@ static HRESULT WINAPI shellwindows_Register(IShellWindows *iface,
     window->hwnd = hwnd;
     window->class = class;
     *cookie = window->cookie = ++cookie_counter;
+    window->pidl = NULL;
 
     LeaveCriticalSection(&sw->cs);
     return S_OK;
@@ -1231,7 +1225,7 @@ static HRESULT WINAPI shellwindows_Register(IShellWindows *iface,
 static HRESULT WINAPI shellwindows_RegisterPending(IShellWindows *iface,
     LONG threadid, VARIANT *loc, VARIANT *root, int class, LONG *cookie)
 {
-    FIXME("0x%x %s %s 0x%x %p\n", threadid, debugstr_variant(loc), debugstr_variant(root),
+    FIXME("0x%lx %s %s 0x%x %p\n", threadid, debugstr_variant(loc), debugstr_variant(root),
             class, cookie);
     return E_NOTIMPL;
 }
@@ -1241,7 +1235,7 @@ static HRESULT WINAPI shellwindows_Revoke(IShellWindows *iface, LONG cookie)
     struct shellwindows *sw = impl_from_IShellWindows(iface);
     unsigned int i;
 
-    TRACE("iface %p, cookie %u.\n", iface, cookie);
+    TRACE("iface %p, cookie %lu.\n", iface, cookie);
 
     EnterCriticalSection(&sw->cs);
 
@@ -1265,7 +1259,7 @@ static HRESULT WINAPI shellwindows_OnNavigate(IShellWindows *iface, LONG cookie,
     struct shellwindows *sw = impl_from_IShellWindows(iface);
     unsigned int i;
 
-    TRACE("iface %p, cookie %u, location %s.\n", iface, cookie, debugstr_variant(location));
+    TRACE("iface %p, cookie %lu, location %s.\n", iface, cookie, debugstr_variant(location));
 
     if (V_VT(location) != (VT_ARRAY | VT_UI1))
     {
@@ -1298,7 +1292,7 @@ static HRESULT WINAPI shellwindows_OnNavigate(IShellWindows *iface, LONG cookie,
 
 static HRESULT WINAPI shellwindows_OnActivated(IShellWindows *iface, LONG cookie, VARIANT_BOOL active)
 {
-    FIXME("0x%x 0x%x\n", cookie, active);
+    FIXME("0x%lx 0x%x\n", cookie, active);
     return E_NOTIMPL;
 }
 
@@ -1349,7 +1343,7 @@ static HRESULT WINAPI shellwindows_FindWindowSW(IShellWindows *iface, VARIANT *l
 
 static HRESULT WINAPI shellwindows_OnCreated(IShellWindows *iface, LONG cookie, IUnknown *punk)
 {
-    FIXME("0x%x %p\n", cookie, punk);
+    FIXME("0x%lx %p\n", cookie, punk);
     return E_NOTIMPL;
 }
 
@@ -1503,7 +1497,7 @@ static HRESULT WINAPI webbrowser_GetTypeInfo(IWebBrowser2 *iface, UINT iTInfo, L
                                      LPTYPEINFO *ppTInfo)
 {
     struct shellbrowserwindow *This = impl_from_IWebBrowser2(iface);
-    TRACE("(%p)->(%d %d %p)\n", This, iTInfo, lcid, ppTInfo);
+    TRACE("(%p)->(%d %ld %p)\n", This, iTInfo, lcid, ppTInfo);
     return get_typeinfo(IWebBrowser2_tid, ppTInfo);
 }
 
@@ -1515,7 +1509,7 @@ static HRESULT WINAPI webbrowser_GetIDsOfNames(IWebBrowser2 *iface, REFIID riid,
     ITypeInfo *typeinfo;
     HRESULT hr;
 
-    TRACE("(%p)->(%s %p %d %d %p)\n", This, debugstr_guid(riid), rgszNames, cNames,
+    TRACE("(%p)->(%s %p %d %ld %p)\n", This, debugstr_guid(riid), rgszNames, cNames,
           lcid, rgDispId);
 
     if(!rgszNames || cNames == 0 || !rgDispId)
@@ -1540,7 +1534,7 @@ static HRESULT WINAPI webbrowser_Invoke(IWebBrowser2 *iface, DISPID dispIdMember
     ITypeInfo *typeinfo;
     HRESULT hr;
 
-    TRACE("(%p)->(%d %s %d %08x %p %p %p %p)\n", This, dispIdMember, debugstr_guid(riid),
+    TRACE("(%p)->(%ld %s %ld %08x %p %p %p %p)\n", This, dispIdMember, debugstr_guid(riid),
             lcid, wFlags, pDispParams, pVarResult, pExcepInfo, puArgErr);
 
     hr = get_typeinfo(IWebBrowser2_tid, &typeinfo);
@@ -1672,7 +1666,7 @@ static HRESULT WINAPI webbrowser_get_Left(IWebBrowser2 *iface, LONG *pl)
 static HRESULT WINAPI webbrowser_put_Left(IWebBrowser2 *iface, LONG Left)
 {
     struct shellbrowserwindow *This = impl_from_IWebBrowser2(iface);
-    FIXME("(%p)->(%d)\n", This, Left);
+    FIXME("(%p)->(%ld)\n", This, Left);
     return E_NOTIMPL;
 }
 
@@ -1686,7 +1680,7 @@ static HRESULT WINAPI webbrowser_get_Top(IWebBrowser2 *iface, LONG *pl)
 static HRESULT WINAPI webbrowser_put_Top(IWebBrowser2 *iface, LONG Top)
 {
     struct shellbrowserwindow *This = impl_from_IWebBrowser2(iface);
-    FIXME("(%p)->(%d)\n", This, Top);
+    FIXME("(%p)->(%ld)\n", This, Top);
     return E_NOTIMPL;
 }
 
@@ -1700,7 +1694,7 @@ static HRESULT WINAPI webbrowser_get_Width(IWebBrowser2 *iface, LONG *pl)
 static HRESULT WINAPI webbrowser_put_Width(IWebBrowser2 *iface, LONG Width)
 {
     struct shellbrowserwindow *This = impl_from_IWebBrowser2(iface);
-    FIXME("(%p)->(%d)\n", This, Width);
+    FIXME("(%p)->(%ld)\n", This, Width);
     return E_NOTIMPL;
 }
 
@@ -1714,7 +1708,7 @@ static HRESULT WINAPI webbrowser_get_Height(IWebBrowser2 *iface, LONG *pl)
 static HRESULT WINAPI webbrowser_put_Height(IWebBrowser2 *iface, LONG Height)
 {
     struct shellbrowserwindow *This = impl_from_IWebBrowser2(iface);
-    FIXME("(%p)->(%d)\n", This, Height);
+    FIXME("(%p)->(%ld)\n", This, Height);
     return E_NOTIMPL;
 }
 
@@ -2229,7 +2223,7 @@ static HRESULT WINAPI shellbrowser_BrowseObject(IShellBrowser *iface, LPCITEMIDL
 
 static HRESULT WINAPI shellbrowser_GetViewStateStream(IShellBrowser *iface, DWORD mode, IStream **stream)
 {
-    FIXME("0x%x %p\n", mode, stream);
+    FIXME("0x%lx %p\n", mode, stream);
     return E_NOTIMPL;
 }
 
@@ -2242,7 +2236,7 @@ static HRESULT WINAPI shellbrowser_GetControlWindow(IShellBrowser *iface, UINT i
 static HRESULT WINAPI shellbrowser_SendControlMsg(IShellBrowser *iface, UINT id, UINT uMsg,
     WPARAM wParam, LPARAM lParam, LRESULT *pret)
 {
-    FIXME("%d %d %lx %lx %p\n", id, uMsg, wParam, lParam, pret);
+    FIXME("%d %d %Ix %Ix %p\n", id, uMsg, wParam, lParam, pret);
     return E_NOTIMPL;
 }
 
@@ -2320,5 +2314,5 @@ static void shellwindows_init(void)
         &shellwindows_classfactory.classreg);
 
     if (FAILED(hr))
-        WARN("Failed to register ShellWindows object: %08x\n", hr);
+        WARN("Failed to register ShellWindows object: %08lx\n", hr);
 }
