@@ -23,6 +23,7 @@
 
 #include <string.h>
 #include <windows.h>
+#include <commctrl.h>
 #include <shlwapi.h>
 #include "resource.h"
 #include "regstr.h"
@@ -69,7 +70,7 @@ static void output_writeconsole(const WCHAR *str, DWORD len)
     }
 }
 
-static void output_formatstring(const WCHAR *fmt, __ms_va_list va_args)
+static void output_formatstring(const WCHAR *fmt, va_list va_args)
 {
     WCHAR *str;
     DWORD len;
@@ -78,7 +79,7 @@ static void output_formatstring(const WCHAR *fmt, __ms_va_list va_args)
                          fmt, 0, 0, (LPWSTR)&str, 0, &va_args);
     if (len == 0 && GetLastError() != ERROR_NO_WORK_DONE)
     {
-        WINE_FIXME("Could not format string: le=%u, fmt=%s\n", GetLastError(), wine_dbgstr_w(fmt));
+        WINE_FIXME("Could not format string: le=%lu, fmt=%s\n", GetLastError(), wine_dbgstr_w(fmt));
         return;
     }
     output_writeconsole(str, len);
@@ -88,25 +89,25 @@ static void output_formatstring(const WCHAR *fmt, __ms_va_list va_args)
 static void WINAPIV output_message(unsigned int id, ...)
 {
     WCHAR fmt[1024];
-    __ms_va_list va_args;
+    va_list va_args;
 
     if (!LoadStringW(GetModuleHandleW(NULL), id, fmt, ARRAY_SIZE(fmt)))
     {
-        WINE_FIXME("LoadString failed with %d\n", GetLastError());
+        WINE_FIXME("LoadString failed with %ld\n", GetLastError());
         return;
     }
-    __ms_va_start(va_args, id);
+    va_start(va_args, id);
     output_formatstring(fmt, va_args);
-    __ms_va_end(va_args);
+    va_end(va_args);
 }
 
 static void WINAPIV output_array(const WCHAR *fmt, ...)
 {
-    __ms_va_list va_args;
+    va_list va_args;
 
-    __ms_va_start(va_args, fmt);
+    va_start(va_args, fmt);
     output_formatstring(fmt, va_args);
-    __ms_va_end(va_args);
+    va_end(va_args);
 }
 
 /**
@@ -172,10 +173,12 @@ int __cdecl wmain(int argc, WCHAR *argv[])
             GetExitCodeProcess( pi.hProcess, &exit_code );
             ExitProcess( exit_code );
         }
-        else WINE_ERR( "failed to restart 64-bit %s, err %d\n", wine_dbgstr_w(filename), GetLastError() );
+        else WINE_ERR( "failed to restart 64-bit %s, err %ld\n", wine_dbgstr_w(filename), GetLastError() );
         Wow64RevertWow64FsRedirection( redir );
     }
 
+    InitCommonControls();
+
     while( i<argc )
     {
         token = argv[i++];
@@ -344,7 +347,7 @@ static void UninstallProgram(void)
         {   /* wait for the process to exit */
             WaitForSingleObject(info.hProcess, INFINITE);
             res = GetExitCodeProcess(info.hProcess, &exit_code);
-            WINE_TRACE("%d: %08x\n", res, exit_code);
+            WINE_TRACE("%d: %08lx\n", res, exit_code);
         }
         else
         {
