@@ -20,60 +20,62 @@
  *
  */
 
-#include "config.h"
-#include "wine/port.h"
-
 #define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 #include <commdlg.h>
-#include <wine/debug.h>
 #include <stdio.h>
-#include <dirent.h>
 #include <assert.h>
 #include <stdlib.h>
-#ifdef HAVE_SYS_STAT_H
-#include <sys/stat.h>
-#endif
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
 
 #include "winecfg.h"
 #include "resource.h"
+#include "wine/debug.h"
 
 WINE_DEFAULT_DEBUG_CHANNEL(winecfg);
 
+#ifdef __i386__
+static const WCHAR pe_dir[] = L"\\i386-windows";
+#elif defined __x86_64__
+static const WCHAR pe_dir[] = L"\\x86_64-windows";
+#elif defined __arm__
+static const WCHAR pe_dir[] = L"\\arm-windows";
+#elif defined __aarch64__
+static const WCHAR pe_dir[] = L"\\aarch64-windows";
+#else
+static const WCHAR pe_dir[] = L"";
+#endif
+
 /* dlls that shouldn't be configured anything other than builtin; list must be sorted*/
-static const char * const builtin_only[] =
+static const WCHAR * const builtin_only[] =
 {
-    "advapi32",
-    "capi2032",
-    "dbghelp",
-    "ddraw",
-    "gdi32",
-    "gphoto2.ds",
-    "icmp",
-    "iphlpapi",
-    "kernel32",
-    "l3codeca.acm",
-    "mountmgr.sys",
-    "mswsock",
-    "ntdll",
-    "ntoskrnl.exe",
-    "opengl32",
-    "sane.ds",
-    "secur32",
-    "twain_32",
-    "unicows",
-    "user32",
-    "vdmdbg",
-    "w32skrnl",
-    "winmm",
-    "wintab32",
-    "wnaspi32",
-    "wow32",
-    "ws2_32",
-    "wsock32",
+    L"advapi32",
+    L"capi2032",
+    L"dbghelp",
+    L"ddraw",
+    L"gdi32",
+    L"gphoto2.ds",
+    L"icmp",
+    L"iphlpapi",
+    L"kernel32",
+    L"l3codeca.acm",
+    L"mountmgr.sys",
+    L"mswsock",
+    L"ntdll",
+    L"ntoskrnl.exe",
+    L"opengl32",
+    L"sane.ds",
+    L"secur32",
+    L"twain_32",
+    L"unicows",
+    L"user32",
+    L"vdmdbg",
+    L"w32skrnl",
+    L"winmm",
+    L"wintab32",
+    L"wnaspi32",
+    L"wow32",
+    L"ws2_32",
+    L"wsock32",
 };
 
 enum dllmode
@@ -88,21 +90,21 @@ enum dllmode
 
 struct dll
 {
-        char *name;
+        WCHAR *name;
         enum dllmode mode;
 };
 
 static const WCHAR emptyW[1];
 
 /* Convert a registry string to a dllmode */
-static enum dllmode string_to_mode(char *in)
+static enum dllmode string_to_mode(const WCHAR *in)
 {
     int i, j, len;
-    char *out;
+    WCHAR *out;
     enum dllmode res;
 
-    len = strlen(in);
-    out = HeapAlloc(GetProcessHeap(), 0, len + 1);
+    len = wcslen(in);
+    out = HeapAlloc(GetProcessHeap(), 0, (len + 1) * sizeof(WCHAR));
 
     /* remove the spaces */
     for (i = j = 0; i <= len; ++i) {
@@ -113,34 +115,34 @@ static enum dllmode string_to_mode(char *in)
 
     /* parse the string */
     res = UNKNOWN;
-    if (strcmp(out, "builtin,native") == 0) res = BUILTIN_NATIVE;
-    if (strcmp(out, "native,builtin") == 0) res = NATIVE_BUILTIN;
-    if (strcmp(out, "builtin") == 0) res = BUILTIN;
-    if (strcmp(out, "native") == 0) res = NATIVE;
-    if (strcmp(out, "") == 0) res = DISABLE;
+    if (wcscmp(out, L"builtin,native") == 0) res = BUILTIN_NATIVE;
+    if (wcscmp(out, L"native,builtin") == 0) res = NATIVE_BUILTIN;
+    if (wcscmp(out, L"builtin") == 0) res = BUILTIN;
+    if (wcscmp(out, L"native") == 0) res = NATIVE;
+    if (wcscmp(out, L"") == 0) res = DISABLE;
 
     HeapFree(GetProcessHeap(), 0, out);
     return res;
 }
 
 /* Convert a dllmode to a registry string. */
-static const char* mode_to_string(enum dllmode mode)
+static const WCHAR* mode_to_string(enum dllmode mode)
 {
     switch( mode )
     {
-        case NATIVE: return "native";
-        case BUILTIN: return "builtin";
-        case NATIVE_BUILTIN: return "native,builtin";
-        case BUILTIN_NATIVE: return "builtin,native";
-        case DISABLE: return "";
-        default: return "";
+        case NATIVE: return L"native";
+        case BUILTIN: return L"builtin";
+        case NATIVE_BUILTIN: return L"native,builtin";
+        case BUILTIN_NATIVE: return L"builtin,native";
+        case DISABLE: return L"";
+        default: return L"";
     }
 }
 
 /* Convert a dllmode to a pretty string for display. TODO: use translations. */
-static const char* mode_to_label(enum dllmode mode)
+static const WCHAR* mode_to_label(enum dllmode mode)
 {
-    static char buffer[256];
+    static WCHAR buffer[256];
     UINT id = 0;
 
     switch( mode )
@@ -150,9 +152,9 @@ static const char* mode_to_label(enum dllmode mode)
     case NATIVE_BUILTIN: id = IDS_DLL_NATIVE_BUILTIN; break;
     case BUILTIN_NATIVE: id = IDS_DLL_BUILTIN_NATIVE; break;
     case DISABLE: id = IDS_DLL_DISABLED; break;
-    default: return "??";
+    default: return L"??";
     }
-    if (!LoadStringA( GetModuleHandleA(NULL), id, buffer, sizeof(buffer) )) buffer[0] = 0;
+    if (!LoadStringW( GetModuleHandleW(NULL), id, buffer, ARRAY_SIZE(buffer) )) buffer[0] = 0;
     return buffer;
 }
 
@@ -185,44 +187,42 @@ static DWORD mode_to_id(enum dllmode mode)
 }
 
 /* helper for is_builtin_only */
-static int compare_dll( const void *ptr1, const void *ptr2 )
+static int __cdecl compare_dll( const void *ptr1, const void *ptr2 )
 {
-    const char * const *name1 = ptr1;
-    const char * const *name2 = ptr2;
-    return strcmp( *name1, *name2 );
+    const WCHAR * const *name1 = ptr1;
+    const WCHAR * const *name2 = ptr2;
+    return wcscmp( *name1, *name2 );
 }
 
 /* check if dll is recommended as builtin only */
-static inline BOOL is_builtin_only( const char *name )
+static inline BOOL is_builtin_only( const WCHAR *name )
 {
-    const char *ext = strrchr( name, '.' );
+    const WCHAR *ext = wcsrchr( name, '.' );
 
     if (ext)
     {
-        if (!strcmp( ext, ".vxd" ) ||
-            !strcmp( ext, ".drv" ) ||
-            !strcmp( ext, ".tlb" ))
+        if (!wcscmp( ext, L".vxd" ) ||
+            !wcscmp( ext, L".drv" ) ||
+            !wcscmp( ext, L".tlb" ))
             return TRUE;
     }
-    if (!strncmp( name, "wine", 4 )) return TRUE;
+    if (!wcsncmp( name, L"wine", 4 )) return TRUE;
     return bsearch( &name, builtin_only, ARRAY_SIZE(builtin_only),
                     sizeof(builtin_only[0]), compare_dll ) != NULL;
 }
 
 /* check if dll should be offered in the drop-down list */
-static BOOL show_dll_in_list( const char *name )
+static BOOL show_dll_in_list( const WCHAR *name )
 {
-    const char *ext = strrchr( name, '.' );
+    const WCHAR *ext = wcsrchr( name, '.' );
 
     if (ext)
     {
         /* skip 16-bit dlls */
-        if (strlen(ext) > 2 && !strcmp( ext + strlen(ext) - 2, "16" )) return FALSE;
+        if (wcslen(ext) > 2 && !wcscmp( ext + wcslen(ext) - 2, L"16" )) return FALSE;
         /* skip exes */
-        if (!strcmp( ext, ".exe" )) return FALSE;
+        if (!wcscmp( ext, L".exe" )) return FALSE;
     }
-    /* skip api set placeholders */
-    if (!strncmp( name, "api-ms-", 7 ) || !strncmp( name, "ext-ms-", 7 )) return FALSE;
     /* skip dlls that should always be builtin */
     return !is_builtin_only( name );
 }
@@ -250,22 +250,22 @@ static void clear_settings(HWND dialog)
 }
 
 /* load the list of available libraries from a given dir */
-static void load_library_list_from_dir( HWND dialog, const char *dir_path, int check_subdirs )
+static void load_library_list_from_dir( HWND dialog, const WCHAR *dir_path, int check_subdirs )
 {
-    static const char * const ext[] = { ".dll", ".dll.so", ".so", "" };
-    char *buffer, *p, name[256];
+    static const WCHAR * const ext[] = { L".dll", L".dll.so", L".so", L"" };
+    WCHAR *buffer, *p, name[256];
     unsigned int i;
     HANDLE handle;
-    WIN32_FIND_DATAA data;
+    WIN32_FIND_DATAW data;
 
-    buffer = HeapAlloc( GetProcessHeap(), 0, strlen(dir_path) + 2 * sizeof(name) + 10 );
+    buffer = HeapAlloc( GetProcessHeap(), 0, (wcslen(dir_path) + 10) * sizeof(WCHAR) + 2 * sizeof(name) );
 
-    strcpy( buffer, dir_path );
-    strcat( buffer, "\\*" );
+    wcscpy( buffer, dir_path );
+    wcscat( buffer, L"\\*" );
     buffer[1] = '\\';  /* change \??\ to \\?\ */
-    p = buffer + strlen(buffer) - 1;
+    p = buffer + wcslen(buffer) - 1;
 
-    if ((handle = FindFirstFileA( buffer, &data )) == INVALID_HANDLE_VALUE)
+    if ((handle = FindFirstFileW( buffer, &data )) == INVALID_HANDLE_VALUE)
     {
         HeapFree( GetProcessHeap(), 0, buffer );
         return;
@@ -273,19 +273,19 @@ static void load_library_list_from_dir( HWND dialog, const char *dir_path, int c
 
     do
     {
-        size_t len = strlen(data.cFileName);
-        if (len > sizeof(name)) continue;
+        size_t len = wcslen(data.cFileName);
+        if (len > ARRAY_SIZE(name)) continue;
         if (check_subdirs)
         {
-            if (!strcmp( data.cFileName, "." )) continue;
-            if (!strcmp( data.cFileName, ".." )) continue;
+            if (!wcscmp( data.cFileName, L"." )) continue;
+            if (!wcscmp( data.cFileName, L".." )) continue;
             if (!show_dll_in_list( data.cFileName )) continue;
             for (i = 0; i < ARRAY_SIZE( ext ); i++)
             {
-                sprintf( p, "%s\\%s%s", data.cFileName, data.cFileName, ext[i] );
-                if (GetFileAttributesA( buffer ) != INVALID_FILE_ATTRIBUTES)
+                swprintf( p, 2 * ARRAY_SIZE(name) + 10, L"%s\\%s%s", data.cFileName, data.cFileName, ext[i] );
+                if (GetFileAttributesW( buffer ) != INVALID_FILE_ATTRIBUTES)
                 {
-                    SendDlgItemMessageA( dialog, IDC_DLLCOMBO, CB_ADDSTRING, 0, (LPARAM)data.cFileName );
+                    SendDlgItemMessageW( dialog, IDC_DLLCOMBO, CB_ADDSTRING, 0, (LPARAM)data.cFileName );
                     break;
                 }
             }
@@ -295,17 +295,17 @@ static void load_library_list_from_dir( HWND dialog, const char *dir_path, int c
             for (i = 0; i < ARRAY_SIZE( ext ); i++)
             {
                 if (!ext[i][0]) continue;
-                if (len > strlen(ext[i]) && !strcmp( data.cFileName + len - strlen(ext[i]), ext[i]))
+                if (len > wcslen(ext[i]) && !wcscmp( data.cFileName + len - wcslen(ext[i]), ext[i]))
                 {
-                    len -= strlen( ext[i] );
-                    memcpy( name, data.cFileName, len );
+                    len -= wcslen( ext[i] );
+                    memcpy( name, data.cFileName, len * sizeof(WCHAR) );
                     name[len] = 0;
                     if (!show_dll_in_list( name )) continue;
-                    SendDlgItemMessageA( dialog, IDC_DLLCOMBO, CB_ADDSTRING, 0, (LPARAM)name );
+                    SendDlgItemMessageW( dialog, IDC_DLLCOMBO, CB_ADDSTRING, 0, (LPARAM)name );
                 }
             }
         }
-    } while (FindNextFileA( handle, &data ));
+    } while (FindNextFileW( handle, &data ));
 
     FindClose( handle );
     HeapFree( GetProcessHeap(), 0, buffer );
@@ -315,38 +315,40 @@ static void load_library_list_from_dir( HWND dialog, const char *dir_path, int c
 static void load_library_list( HWND dialog )
 {
     unsigned int i = 0;
-    char item1[256], item2[256], var[32], path[MAX_PATH];
+    WCHAR item1[256], item2[256], var[32], path[MAX_PATH];
     HCURSOR old_cursor = SetCursor( LoadCursorW(0, (LPWSTR)IDC_WAIT) );
 
-    if (GetEnvironmentVariableA( "WINEBUILDDIR", path, MAX_PATH ))
+    if (GetEnvironmentVariableW( L"WINEBUILDDIR", path, MAX_PATH ))
     {
-        char *dir = HeapAlloc( GetProcessHeap(), 0, strlen(path) + sizeof("\\dlls") );
-        strcpy( dir, path );
-        strcat( dir, "\\dlls" );
+        WCHAR *dir = HeapAlloc( GetProcessHeap(), 0, wcslen(path) * sizeof(WCHAR) + sizeof(L"\\dlls") );
+        wcscpy( dir, path );
+        wcscat( dir, L"\\dlls" );
         load_library_list_from_dir( dialog, dir, TRUE );
         HeapFree( GetProcessHeap(), 0, dir );
     }
 
     for (;;)
     {
-        sprintf( var, "WINEDLLDIR%u", i++ );
-        if (!GetEnvironmentVariableA( var, path, MAX_PATH )) break;
+        swprintf( var, ARRAY_SIZE(var), L"WINEDLLDIR%u", i++ );
+        if (!GetEnvironmentVariableW( var, path, MAX_PATH )) break;
+        load_library_list_from_dir( dialog, path, FALSE );
+        wcscat( path, pe_dir );
         load_library_list_from_dir( dialog, path, FALSE );
     }
 
     /* get rid of duplicate entries */
 
-    SendDlgItemMessageA( dialog, IDC_DLLCOMBO, CB_GETLBTEXT, 0, (LPARAM)item1 );
+    SendDlgItemMessageW( dialog, IDC_DLLCOMBO, CB_GETLBTEXT, 0, (LPARAM)item1 );
     i = 1;
-    while (SendDlgItemMessageA( dialog, IDC_DLLCOMBO, CB_GETLBTEXT, i, (LPARAM)item2 ) >= 0)
+    while (SendDlgItemMessageW( dialog, IDC_DLLCOMBO, CB_GETLBTEXT, i, (LPARAM)item2 ) >= 0)
     {
-        if (!strcmp( item1, item2 ))
+        if (!wcscmp( item1, item2 ))
         {
-            SendDlgItemMessageA( dialog, IDC_DLLCOMBO, CB_DELETESTRING, i, 0 );
+            SendDlgItemMessageW( dialog, IDC_DLLCOMBO, CB_DELETESTRING, i, 0 );
         }
         else
         {
-            strcpy( item1, item2 );
+            wcscpy( item1, item2 );
             i++;
         }
     }
@@ -355,8 +357,8 @@ static void load_library_list( HWND dialog )
 
 static void load_library_settings(HWND dialog)
 {
-    char **overrides = enumerate_values(config_key, keypath("DllOverrides"));
-    char **p;
+    WCHAR **overrides = enumerate_values(config_key, keypath(L"DllOverrides"));
+    WCHAR **p;
     int sel, count = 0;
 
     sel = SendDlgItemMessageW(dialog, IDC_DLLS_LIST, LB_GETCURSEL, 0, 0);
@@ -379,26 +381,24 @@ static void load_library_settings(HWND dialog)
     
     for (p = overrides; *p != NULL; p++)
     {
-        int index;
-        char *str, *value;
-        const char *label;
+        int index, len;
+        WCHAR *str, *value;
+        const WCHAR *label;
         struct dll *dll;
 
-        value = get_reg_key(config_key, keypath("DllOverrides"), *p, NULL);
+        value = get_reg_key(config_key, keypath(L"DllOverrides"), *p, NULL);
 
         label = mode_to_label(string_to_mode(value));
-        
-        str = HeapAlloc(GetProcessHeap(), 0, strlen(*p) + 2 + strlen(label) + 2);
-        strcpy(str, *p);
-        strcat(str, " (");
-        strcat(str, label);
-        strcat(str, ")");
+
+        len = wcslen(*p) + 2 + wcslen(label) + 2;
+        str = HeapAlloc(GetProcessHeap(), 0, len * sizeof(WCHAR) );
+        swprintf( str, len, L"%s (%s)", *p, label );
 
         dll = HeapAlloc(GetProcessHeap(), 0, sizeof(struct dll));
         dll->name = *p;
         dll->mode = string_to_mode(value);
 
-        index = SendDlgItemMessageA(dialog, IDC_DLLS_LIST, LB_ADDSTRING, (WPARAM) -1, (LPARAM) str);
+        index = SendDlgItemMessageW(dialog, IDC_DLLS_LIST, LB_ADDSTRING, (WPARAM) -1, (LPARAM) str);
         SendDlgItemMessageW(dialog, IDC_DLLS_LIST, LB_SETITEMDATA, index, (LPARAM) dll);
 
         HeapFree(GetProcessHeap(), 0, str);
@@ -453,7 +453,7 @@ static void set_dllmode(HWND dialog, DWORD id)
     enum dllmode mode;
     struct dll *dll;
     int sel;
-    const char *str;
+    const WCHAR *str;
 
     mode = id_to_mode(id);
 
@@ -463,26 +463,24 @@ static void set_dllmode(HWND dialog, DWORD id)
     dll = (struct dll *) SendDlgItemMessageW(dialog, IDC_DLLS_LIST, LB_GETITEMDATA, sel, 0);
 
     str = mode_to_string(mode);
-    WINE_TRACE("Setting %s to %s\n", dll->name, str);
+    WINE_TRACE("Setting %s to %s\n", debugstr_w(dll->name), debugstr_w(str));
 
     SendMessageW(GetParent(dialog), PSM_CHANGED, 0, 0);
-    set_reg_key(config_key, keypath("DllOverrides"), dll->name, str);
+    set_reg_key(config_key, keypath(L"DllOverrides"), dll->name, str);
 
     load_library_settings(dialog);  /* ... and refresh  */
 }
 
 static void on_add_click(HWND dialog)
 {
-    static const char dotDll[] = ".dll";
-    char buffer[1024], *ptr;
+    WCHAR buffer[1024], *ptr;
 
-    ZeroMemory(buffer, sizeof(buffer));
-
-    SendDlgItemMessageA(dialog, IDC_DLLCOMBO, WM_GETTEXT, sizeof(buffer), (LPARAM) buffer);
-    if (lstrlenA(buffer) >= sizeof(dotDll))
+    buffer[0] = 0;
+    SendDlgItemMessageW(dialog, IDC_DLLCOMBO, WM_GETTEXT, ARRAY_SIZE(buffer), (LPARAM) buffer);
+    if (wcslen(buffer) > 4)
     {
-        ptr = buffer + lstrlenA(buffer) - sizeof(dotDll) + 1;
-        if (!lstrcmpiA(ptr, dotDll))
+        ptr = buffer + wcslen(buffer) - 4;
+        if (!wcsicmp(ptr, L".dll"))
         {
             WINE_TRACE("Stripping dll extension\n");
             *ptr = '\0';
@@ -490,7 +488,7 @@ static void on_add_click(HWND dialog)
     }
 
     /* check if dll is in the builtin-only list */
-    if (!(ptr = strrchr( buffer, '\\' )))
+    if (!(ptr = wcsrchr( buffer, '\\' )))
     {
         ptr = buffer;
         if (*ptr == '*') ptr++;
@@ -498,32 +496,32 @@ static void on_add_click(HWND dialog)
     else ptr++;
     if (is_builtin_only( ptr ))
     {
-        MSGBOXPARAMSA params;
+        MSGBOXPARAMSW params;
         params.cbSize = sizeof(params);
         params.hwndOwner = dialog;
-        params.hInstance = GetModuleHandleA( NULL );
-        params.lpszText = MAKEINTRESOURCEA( IDS_DLL_WARNING );
-        params.lpszCaption = MAKEINTRESOURCEA( IDS_DLL_WARNING_CAPTION );
+        params.hInstance = GetModuleHandleW( NULL );
+        params.lpszText = MAKEINTRESOURCEW( IDS_DLL_WARNING );
+        params.lpszCaption = MAKEINTRESOURCEW( IDS_DLL_WARNING_CAPTION );
         params.dwStyle = MB_ICONWARNING | MB_YESNO;
         params.lpszIcon = NULL;
         params.dwContextHelpId = 0;
         params.lpfnMsgBoxCallback = NULL;
         params.dwLanguageId = 0;
-        if (MessageBoxIndirectA( &params ) != IDYES) return;
+        if (MessageBoxIndirectW( &params ) != IDYES) return;
     }
 
     SendDlgItemMessageW(dialog, IDC_DLLCOMBO, WM_SETTEXT, 0, (LPARAM)emptyW);
     disable(IDC_DLLS_ADDDLL);
     SendMessageW(GetParent(dialog), DM_SETDEFID, IDOK, 0);
 
-    WINE_TRACE("Adding %s as native, builtin\n", buffer);
+    WINE_TRACE("Adding %s as native, builtin\n", debugstr_w(buffer));
 
     SendMessageW(GetParent(dialog), PSM_CHANGED, 0, 0);
-    set_reg_key(config_key, keypath("DllOverrides"), buffer, "native,builtin");
+    set_reg_key(config_key, keypath(L"DllOverrides"), buffer, L"native,builtin");
 
     load_library_settings(dialog);
 
-    SendDlgItemMessageA(dialog, IDC_DLLS_LIST, LB_SELECTSTRING, 0, (LPARAM) buffer);
+    SendDlgItemMessageW(dialog, IDC_DLLS_LIST, LB_SELECTSTRING, 0, (LPARAM) buffer);
 
     set_controls_from_selection(dialog);
 }
@@ -592,7 +590,7 @@ static void on_remove_click(HWND dialog)
     SendDlgItemMessageW(dialog, IDC_DLLS_LIST, LB_DELETESTRING, sel, 0);
 
     SendMessageW(GetParent(dialog), PSM_CHANGED, 0, 0);
-    set_reg_key(config_key, keypath("DllOverrides"), dll->name, NULL);
+    set_reg_key(config_key, keypath(L"DllOverrides"), dll->name, NULL);
 
     HeapFree(GetProcessHeap(), 0, dll->name);
     HeapFree(GetProcessHeap(), 0, dll);
