@@ -19,8 +19,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
-#include "config.h"
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -31,7 +29,6 @@
 #include "winuser.h"
 #include "tlhelp32.h"
 #include "wine/debug.h"
-#include "wine/exception.h"
 
 WINE_DEFAULT_DEBUG_CHANNEL(winedbg);
 
@@ -171,13 +168,13 @@ struct info_modules
 
 static void module_print_info(const struct info_module *module, BOOL is_embedded)
 {
-    dbg_printf("%*.*s-%*.*s\t%-16s%s\n",
-               ADDRWIDTH, ADDRWIDTH, wine_dbgstr_longlong(module->mi.BaseOfImage),
-               ADDRWIDTH, ADDRWIDTH, wine_dbgstr_longlong(module->mi.BaseOfImage + module->mi.ImageSize),
+    dbg_printf("%*.*I64x-%*.*I64x\t%-16s%s\n",
+               ADDRWIDTH, ADDRWIDTH, module->mi.BaseOfImage,
+               ADDRWIDTH, ADDRWIDTH, module->mi.BaseOfImage + module->mi.ImageSize,
                is_embedded ? "\\" : get_symtype_str(&module->mi), module->name);
 }
 
-static int      module_compare(const void* p1, const void* p2)
+static int __cdecl module_compare(const void* p1, const void* p2)
 {
     struct info_module *left = (struct info_module *)p1;
     struct info_module *right = (struct info_module *)p2;
@@ -287,7 +284,7 @@ void info_win32_module(DWORD64 base)
     HeapFree(GetProcessHeap(), 0, im.modules);
 
     if (base && !num_printed)
-        dbg_printf("'0x%x%08x' is not a valid module address\n", (DWORD)(base >> 32), (DWORD)base);
+        dbg_printf("'0x%0*I64x' is not a valid module address\n", ADDRWIDTH, base);
 }
 
 struct class_walker
@@ -395,7 +392,7 @@ static void info_window(HWND hWnd, int indent)
         if (!GetWindowTextA(hWnd, wndName, sizeof(wndName)))
             strcpy(wndName, "-- Empty --");
 
-        dbg_printf("%*s%08lx%*s %-17.17s %08x %0*lx %08x %.14s\n",
+        dbg_printf("%*s%08Ix%*s %-17.17s %08lx %0*Ix %08lx %.14s\n",
                    indent, "", (DWORD_PTR)hWnd, 12 - indent, "",
                    clsName, GetWindowLongW(hWnd, GWL_STYLE),
                    ADDRWIDTH, (ULONG_PTR)GetWindowLongPtrW(hWnd, GWLP_WNDPROC),
@@ -437,9 +434,9 @@ void info_win32_window(HWND hWnd, BOOL detailed)
 
     /* FIXME missing fields: hmemTaskQ, hrgnUpdate, dce, flags, pProp, scroll */
     dbg_printf("next=%p  child=%p  parent=%p  owner=%p  class='%s'\n"
-               "inst=%p  active=%p  idmenu=%08lx\n"
-               "style=0x%08x  exstyle=0x%08x  wndproc=%p  text='%s'\n"
-               "client=%d,%d-%d,%d  window=%d,%d-%d,%d sysmenu=%p\n",
+               "inst=%p  active=%p  idmenu=%08Ix\n"
+               "style=0x%08lx  exstyle=0x%08lx  wndproc=%p  text='%s'\n"
+               "client=%ld,%ld-%ld,%ld  window=%ld,%ld-%ld,%ld sysmenu=%p\n",
                GetWindow(hWnd, GW_HWNDNEXT),
                GetWindow(hWnd, GW_CHILD),
                GetParent(hWnd),
@@ -505,7 +502,7 @@ static void dump_proc_info(const struct dump_proc* dp, unsigned idx, unsigned de
     {
         assert(idx < dp->count);
         dpe = &dp->entries[idx];
-        dbg_printf("%c%08x %-8d ",
+        dbg_printf("%c%08lx %-8ld ",
                    (dpe->proc.th32ProcessID == (dbg_curr_process ?
                                                 dbg_curr_process->pid : 0)) ? '>' : ' ',
                    dpe->proc.th32ProcessID, dpe->proc.cntThreads);
@@ -619,11 +616,11 @@ void info_win32_threads(void)
                     else
                         exename = "";
 
-		    dbg_printf("%08x%s %s\n",
+		    dbg_printf("%08lx%s %s\n",
                                entry.th32OwnerProcessID, p ? " (D)" : "", exename);
                     lastProcessId = entry.th32OwnerProcessID;
 		}
-                dbg_printf("\t%08x %4d%s\n",
+                dbg_printf("\t%08lx %4ld%s\n",
                            entry.th32ThreadID, entry.tpBasePri,
                            (entry.th32ThreadID == dbg_curr_tid) ? " <==" : "");
 
@@ -660,12 +657,12 @@ void info_win32_frame_exceptions(DWORD tid)
 
         if (!thread)
         {
-            dbg_printf("Unknown thread id (%04x) in current process\n", tid);
+            dbg_printf("Unknown thread id (%04lx) in current process\n", tid);
             return;
         }
         if (SuspendThread(thread->handle) == -1)
         {
-            dbg_printf("Can't suspend thread id (%04x)\n", tid);
+            dbg_printf("Can't suspend thread id (%04lx)\n", tid);
             return;
         }
     }
@@ -718,7 +715,7 @@ void info_win32_segments(DWORD start, int length)
             flags[1] = (le.HighWord.Bits.Type & 0x2) ? 'w' : '-';
             flags[2] = '-';
         }
-        dbg_printf("%04x: sel=%04x base=%08x limit=%08x %d-bit %c%c%c\n",
+        dbg_printf("%04lx: sel=%04lx base=%08x limit=%08x %d-bit %c%c%c\n",
                    i, (i << 3) | 7,
                    (le.HighWord.Bits.BaseHi << 24) +
                    (le.HighWord.Bits.BaseMid << 16) + le.BaseLow,
@@ -752,7 +749,7 @@ void info_win32_virtual(DWORD pid)
         hProc = OpenProcess(PROCESS_QUERY_INFORMATION | PROCESS_VM_READ, FALSE, pid);
         if (hProc == NULL)
         {
-            dbg_printf("Cannot open process <%04x>\n", pid);
+            dbg_printf("Cannot open process <%04lx>\n", pid);
             return;
         }
     }
@@ -794,8 +791,8 @@ void info_win32_virtual(DWORD pid)
             type = "";
             prot[0] = '\0';
         }
-        dbg_printf("%08lx %08lx %s %s %s\n",
-                   (DWORD_PTR)addr, (DWORD_PTR)addr + mbi.RegionSize - 1, state, type, prot);
+        dbg_printf("%0*Ix %0*Ix %s %s %s\n",
+                   ADDRWIDTH, (DWORD_PTR)addr, ADDRWIDTH, (DWORD_PTR)addr + mbi.RegionSize - 1, state, type, prot);
         if (addr + mbi.RegionSize < addr) /* wrap around ? */
             break;
         addr += mbi.RegionSize;
@@ -896,10 +893,10 @@ void info_win32_exception(void)
         break;
     case EXCEPTION_ACCESS_VIOLATION:
         if (rec->NumberParameters == 2)
-            dbg_printf("page fault on %s access to 0x%08lx",
+            dbg_printf("page fault on %s access to 0x%0*Ix",
                        rec->ExceptionInformation[0] == EXCEPTION_WRITE_FAULT ? "write" :
                        rec->ExceptionInformation[0] == EXCEPTION_EXECUTE_FAULT ? "execute" : "read",
-                       rec->ExceptionInformation[1]);
+                       ADDRWIDTH, rec->ExceptionInformation[1]);
         else
             dbg_printf("page fault");
         break;
@@ -934,7 +931,7 @@ void info_win32_exception(void)
                                   (void*)rec->ExceptionInformation[1], TRUE, FALSE,
                                   name, sizeof(name));
             else
-                sprintf( name, "%ld", rec->ExceptionInformation[1] );
+                sprintf( name, "%Id", rec->ExceptionInformation[1] );
             dbg_printf("unimplemented function %s.%s called", dll, name);
         }
         break;
@@ -964,18 +961,18 @@ void info_win32_exception(void)
         break;
     case EXCEPTION_WINE_CXX_EXCEPTION:
         if(rec->NumberParameters == 3 && rec->ExceptionInformation[0] == EXCEPTION_WINE_CXX_FRAME_MAGIC)
-            dbg_printf("C++ exception(object = 0x%08lx, type = 0x%08lx)",
-                       rec->ExceptionInformation[1], rec->ExceptionInformation[2]);
+            dbg_printf("C++ exception(object = 0x%0*Ix, type = 0x%0*Ix)",
+                       ADDRWIDTH, rec->ExceptionInformation[1], ADDRWIDTH, rec->ExceptionInformation[2]);
         else if(rec->NumberParameters == 4 && rec->ExceptionInformation[0] == EXCEPTION_WINE_CXX_FRAME_MAGIC)
             dbg_printf("C++ exception(object = %p, type = %p, base = %p)",
                        (void*)rec->ExceptionInformation[1], (void*)rec->ExceptionInformation[2],
                        (void*)rec->ExceptionInformation[3]);
         else
-            dbg_printf("C++ exception with strange parameter count %d or magic 0x%08lx",
-                       rec->NumberParameters, rec->ExceptionInformation[0]);
+            dbg_printf("C++ exception with strange parameter count %ld or magic 0x%0*Ix",
+                       rec->NumberParameters, ADDRWIDTH, rec->ExceptionInformation[0]);
         break;
     default:
-        dbg_printf("0x%08x", rec->ExceptionCode);
+        dbg_printf("0x%08lx", rec->ExceptionCode);
         break;
     }
     if (rec->ExceptionFlags & EH_STACK_INVALID)
@@ -984,7 +981,7 @@ void info_win32_exception(void)
     switch (addr.Mode)
     {
     case AddrModeFlat:
-        dbg_printf(" in %d-bit code (%s)",
+        dbg_printf(" in %ld-bit code (%s)",
                    dbg_curr_process->be_cpu->pointer_size * 8,
                    memory_offset_to_string(hexbuf, addr.Offset, 0));
         break;
