@@ -74,7 +74,7 @@ BOOL dbg_attach_debuggee(DWORD pid)
 
     if (!DebugActiveProcess(pid)) 
     {
-        dbg_printf("Can't attach process %04x: error %u\n", pid, GetLastError());
+        dbg_printf("Can't attach process %04lx: error %lu\n", pid, GetLastError());
         dbg_del_process(dbg_curr_process);
 	return FALSE;
     }
@@ -196,7 +196,7 @@ static BOOL dbg_exception_prolog(BOOL is_debug, const EXCEPTION_RECORD* rec)
                 HeapFree(GetProcessHeap(), 0, last_file);
                 last_name = strcpy(HeapAlloc(GetProcessHeap(), 0, strlen(si->Name) + 1), si->Name);
                 last_file = strcpy(HeapAlloc(GetProcessHeap(), 0, strlen(il.FileName) + 1), il.FileName);
-                dbg_printf("%s () at %s:%u\n", last_name, last_file, il.LineNumber);
+                dbg_printf("%s () at %s:%lu\n", last_name, last_file, il.LineNumber);
             }
         }
     }
@@ -234,7 +234,7 @@ static DWORD dbg_handle_exception(const EXCEPTION_RECORD* rec, BOOL first_chance
 
     assert(dbg_curr_thread);
 
-    WINE_TRACE("exception=%x first_chance=%c\n",
+    WINE_TRACE("exception=%lx first_chance=%c\n",
                rec->ExceptionCode, first_chance ? 'Y' : 'N');
 
     switch (rec->ExceptionCode)
@@ -251,11 +251,11 @@ static DWORD dbg_handle_exception(const EXCEPTION_RECORD* rec, BOOL first_chance
             pThread = dbg_get_thread(dbg_curr_process, pThreadName->dwThreadID);
         if(!pThread)
         {
-            dbg_printf("Thread ID=%04x not in our list of threads -> can't rename\n", pThreadName->dwThreadID);
+            dbg_printf("Thread ID=%04lx not in our list of threads -> can't rename\n", pThreadName->dwThreadID);
             return DBG_CONTINUE;
         }
         if (dbg_read_memory(pThreadName->szName, pThread->name, 9))
-            dbg_printf("Thread ID=%04x renamed using MS VC6 extension (name==\"%.9s\")\n",
+            dbg_printf("Thread ID=%04lx renamed using MS VC6 extension (name==\"%.9s\")\n",
                        pThread->tid, pThread->name);
         return DBG_CONTINUE;
     case EXCEPTION_INVALID_HANDLE:
@@ -332,12 +332,12 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
     case EXCEPTION_DEBUG_EVENT:
         if (!dbg_curr_thread)
         {
-            WINE_ERR("%04x:%04x: not a registered process or thread (perhaps a 16 bit one ?)\n",
+            WINE_ERR("%04lx:%04lx: not a registered process or thread (perhaps a 16 bit one ?)\n",
                      de->dwProcessId, de->dwThreadId);
             break;
         }
 
-        WINE_TRACE("%04x:%04x: exception code=%08x\n",
+        WINE_TRACE("%04lx:%04lx: exception code=%08lx\n",
                    de->dwProcessId, de->dwThreadId,
                    de->u.Exception.ExceptionRecord.ExceptionCode);
 
@@ -370,10 +370,10 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
         size = ARRAY_SIZE(u.buffer);
         if (!QueryFullProcessImageNameW( dbg_curr_process->handle, 0, u.buffer, &size ))
         {
-            swprintf( u.buffer, ARRAY_SIZE(u.buffer), L"Process_%08x", dbg_curr_pid);
+            swprintf(u.buffer, ARRAY_SIZE(u.buffer), L"Process_%08x", dbg_curr_pid);
         }
 
-        WINE_TRACE("%04x:%04x: create process '%s'/%p @%p (%u<%u>)\n",
+        WINE_TRACE("%04lx:%04lx: create process '%s'/%p @%p (%lu<%lu>)\n",
                    de->dwProcessId, de->dwThreadId,
                    wine_dbgstr_w(u.buffer),
                    de->u.CreateProcessInfo.lpImageName,
@@ -386,9 +386,9 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
             dbg_printf("Couldn't initiate DbgHelp\n");
         if (!dbg_load_module(dbg_curr_process->handle, de->u.CreateProcessInfo.hFile, u.buffer,
                              (DWORD_PTR)de->u.CreateProcessInfo.lpBaseOfImage, 0))
-            dbg_printf("couldn't load main module (%u)\n", GetLastError());
+            dbg_printf("couldn't load main module (%lu)\n", GetLastError());
 
-        WINE_TRACE("%04x:%04x: create thread I @%p\n",
+        WINE_TRACE("%04lx:%04lx: create thread I @%p\n",
                    de->dwProcessId, de->dwThreadId, de->u.CreateProcessInfo.lpStartAddress);
 
         dbg_curr_thread = dbg_add_thread(dbg_curr_process,
@@ -405,7 +405,7 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
         break;
 
     case EXIT_PROCESS_DEBUG_EVENT:
-        WINE_TRACE("%04x:%04x: exit process (%d)\n",
+        WINE_TRACE("%04lx:%04lx: exit process (%ld)\n",
                    de->dwProcessId, de->dwThreadId, de->u.ExitProcess.dwExitCode);
 
         if (dbg_curr_process == NULL)
@@ -414,11 +414,11 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
             break;
         }
         tgt_process_active_close_process(dbg_curr_process, FALSE);
-        dbg_printf("Process of pid=%04x has terminated\n", de->dwProcessId);
+        dbg_printf("Process of pid=%04lx has terminated\n", de->dwProcessId);
         break;
 
     case CREATE_THREAD_DEBUG_EVENT:
-        WINE_TRACE("%04x:%04x: create thread D @%p\n",
+        WINE_TRACE("%04lx:%04lx: create thread D @%p\n",
                    de->dwProcessId, de->dwThreadId, de->u.CreateThread.lpStartAddress);
 
         if (dbg_curr_process == NULL)
@@ -445,7 +445,7 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
         break;
 
     case EXIT_THREAD_DEBUG_EVENT:
-        WINE_TRACE("%04x:%04x: exit thread (%d)\n",
+        WINE_TRACE("%04lx:%04lx: exit thread (%ld)\n",
                    de->dwProcessId, de->dwThreadId, de->u.ExitThread.dwExitCode);
 
         if (dbg_curr_thread == NULL)
@@ -466,7 +466,7 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
         fetch_module_name(de->u.LoadDll.lpImageName, de->u.LoadDll.lpBaseOfDll,
                           u.buffer, ARRAY_SIZE(u.buffer));
 
-        WINE_TRACE("%04x:%04x: loads DLL %s @%p (%u<%u>)\n",
+        WINE_TRACE("%04lx:%04lx: loads DLL %s @%p (%lu<%lu>)\n",
                    de->dwProcessId, de->dwThreadId,
                    wine_dbgstr_w(u.buffer), de->u.LoadDll.lpBaseOfDll,
                    de->u.LoadDll.dwDebugInfoFileOffset,
@@ -485,7 +485,7 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
         break;
 
     case UNLOAD_DLL_DEBUG_EVENT:
-        WINE_TRACE("%04x:%04x: unload DLL @%p\n",
+        WINE_TRACE("%04lx:%04lx: unload DLL @%p\n",
                    de->dwProcessId, de->dwThreadId,
                    de->u.UnloadDll.lpBaseOfDll);
         break_delete_xpoints_from_module((DWORD_PTR)de->u.UnloadDll.lpBaseOfDll);
@@ -502,18 +502,18 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
         memory_get_string(dbg_curr_process,
                           de->u.DebugString.lpDebugStringData, TRUE,
                           de->u.DebugString.fUnicode, u.bufferA, sizeof(u.bufferA));
-        WINE_TRACE("%04x:%04x: output debug string (%s)\n",
+        WINE_TRACE("%04lx:%04lx: output debug string (%s)\n",
                    de->dwProcessId, de->dwThreadId, u.bufferA);
         break;
 
     case RIP_EVENT:
-        WINE_TRACE("%04x:%04x: rip error=%u type=%u\n",
+        WINE_TRACE("%04lx:%04lx: rip error=%lu type=%lu\n",
                    de->dwProcessId, de->dwThreadId, de->u.RipInfo.dwError,
                    de->u.RipInfo.dwType);
         break;
 
     default:
-        WINE_TRACE("%04x:%04x: unknown event (%x)\n",
+        WINE_TRACE("%04lx:%04lx: unknown event (%lx)\n",
                    de->dwProcessId, de->dwThreadId, de->dwDebugEventCode);
     }
     if (!cont) return TRUE;  /* stop execution */
@@ -537,12 +537,12 @@ static void dbg_resume_debuggee(DWORD cont)
         if (dbg_curr_thread)
         {
             if (!dbg_curr_process->be_cpu->set_context(dbg_curr_thread->handle, &dbg_context))
-                dbg_printf("Cannot set ctx on %04Ix\n", dbg_curr_tid);
+                dbg_printf("Cannot set ctx on %04lx\n", dbg_curr_tid);
         }
     }
     dbg_interactiveP = FALSE;
     if (!ContinueDebugEvent(dbg_curr_pid, dbg_curr_tid, cont))
-        dbg_printf("Cannot continue on %04Ix (%08x)\n", dbg_curr_tid, cont);
+        dbg_printf("Cannot continue on %04lx (%08lx)\n", dbg_curr_tid, cont);
 }
 
 static void wait_exception(void)
@@ -836,7 +836,7 @@ static const char *get_windows_version(void)
         }
     }
 
-    snprintf( str, sizeof(str), "%d.%d (%d)", info.dwMajorVersion,
+    snprintf( str, sizeof(str), "%ld.%ld (%d)", info.dwMajorVersion,
               info.dwMinorVersion, info.wProductType );
     return str;
 }
