@@ -480,10 +480,10 @@ static WCHAR *lookup_expression(struct assembly_entry *assembly, const WCHAR *ke
 {
     WCHAR path[MAX_PATH];
 
-    if (!wcscmp(key, L"runtime.system32"))
+    if (!wcsicmp(key, L"runtime.system32"))
     {
 #ifdef __x86_64__
-        if (!wcscmp(assembly->identity.architecture, L"x86"))
+        if (!wcsicmp(assembly->identity.architecture, L"x86"))
         {
             GetSystemWow64DirectoryW(path, ARRAY_SIZE(path));
             return strdupW(path);
@@ -492,7 +492,7 @@ static WCHAR *lookup_expression(struct assembly_entry *assembly, const WCHAR *ke
         GetSystemDirectoryW(path, ARRAY_SIZE(path));
         return strdupW(path);
     }
-    if (!wcscmp(key, L"runtime.windows"))
+    if (!wcsicmp(key, L"runtime.windows"))
     {
         GetWindowsDirectoryW(path, ARRAY_SIZE(path));
         return strdupW(path);
@@ -1023,7 +1023,8 @@ static void restart_as_x86_64(void)
 
     memset(&si, 0, sizeof(si));
     si.cb = sizeof(si);
-    GetModuleFileNameW(0, filename, MAX_PATH);
+    GetSystemDirectoryW( filename, MAX_PATH );
+    wcscat( filename, L"\\wusa.exe" );
 
     Wow64DisableWow64FsRedirection(&redir);
     if (CreateProcessW(filename, GetCommandLineW(), NULL, NULL, FALSE, 0, NULL, NULL, &si, &pi))
@@ -1034,7 +1035,7 @@ static void restart_as_x86_64(void)
         CloseHandle(pi.hProcess);
         CloseHandle(pi.hThread);
     }
-    else ERR("Failed to restart 64-bit %s, err %u\n", wine_dbgstr_w(filename), GetLastError());
+    else ERR("Failed to restart 64-bit %s, err %lu\n", wine_dbgstr_w(filename), GetLastError());
     Wow64RevertWow64FsRedirection(redir);
 
     ExitProcess(exit_code);
