@@ -20,7 +20,6 @@
 
 
 #include "config.h"
-#include "wine/port.h"
 
 #include <assert.h>
 #include <dirent.h>
@@ -32,12 +31,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#ifdef HAVE_POLL_H
 #include <poll.h>
-#endif
-#ifdef HAVE_SYS_POLL_H
-#include <sys/poll.h>
-#endif
 #ifdef HAVE_LINUX_MAJOR_H
 #include <linux/major.h>
 #endif
@@ -1873,7 +1867,7 @@ static WCHAR *dup_nt_name( struct fd *root, struct unicode_str name, data_size_t
         name.str++;
         name.len -= sizeof(WCHAR);
     }
-    if ((ret = malloc( retlen + name.len + 1 )))
+    if ((ret = malloc( retlen + name.len + sizeof(WCHAR) )))
     {
         memcpy( ret, root->nt_name, root->nt_namelen );
         if (name.len && name.str[0] != '\\' &&
