@@ -31,9 +31,7 @@
 #include <stdlib.h>
 #include <sys/types.h>
 #include <sys/time.h>
-#ifdef HAVE_SYS_SOCKET_H
-# include <sys/socket.h>
-#endif
+#include <sys/socket.h>
 #include <unistd.h>
 #include <poll.h>
 #ifdef HAVE_SYS_PARAM_H
@@ -682,6 +680,7 @@ struct process *create_process( int fd, struct process *parent, unsigned int fla
     process->trace_data      = 0;
     process->rawinput_mouse  = NULL;
     process->rawinput_kbd    = NULL;
+    memset( &process->image_info, 0, sizeof(process->image_info) );
     list_init( &process->kernel_object );
     list_init( &process->thread_list );
     list_init( &process->locks );
@@ -736,7 +735,7 @@ struct process *create_process( int fd, struct process *parent, unsigned int fla
     /* Assign a high security label to the token. The default would be medium
      * but Wine provides admin access to all applications right now so high
      * makes more sense for the time being. */
-    if (!token_assign_label( process->token, security_high_label_sid ))
+    if (!token_assign_label( process->token, &high_label_sid ))
         goto error;
 
     set_fd_events( process->msg_fd, POLLIN );  /* start listening to events */
@@ -824,12 +823,12 @@ static struct security_descriptor *process_get_sd( struct object *obj )
 
     if (!process_default_sd)
     {
-        size_t users_sid_len = security_sid_len( security_domain_users_sid );
-        size_t admins_sid_len = security_sid_len( security_builtin_admins_sid );
-        size_t dacl_len = sizeof(ACL) + 2 * offsetof( ACCESS_ALLOWED_ACE, SidStart )
-                          + users_sid_len + admins_sid_len;
-        ACCESS_ALLOWED_ACE *aaa;
-        ACL *dacl;
+        struct ace *ace;
+        struct acl *dacl;
+        struct sid *sid;
+        size_t users_sid_len = sid_len( &domain_users_sid );
+        size_t admins_sid_len = sid_len( &builtin_admins_sid );
+        size_t dacl_len = sizeof(*dacl) + 2 * sizeof(*ace) + users_sid_len + admins_sid_len;
 
         process_default_sd = mem_alloc( sizeof(*process_default_sd) + admins_sid_len + users_sid_len
                                     + dacl_len );
@@ -838,27 +837,19 @@ static struct security_descriptor *process_get_sd( struct object *obj )
         process_default_sd->group_len = users_sid_len;
         process_default_sd->sacl_len  = 0;
         process_default_sd->dacl_len  = dacl_len;
-        memcpy( process_default_sd + 1, security_builtin_admins_sid, admins_sid_len );
-        memcpy( (char *)(process_default_sd + 1) + admins_sid_len, security_domain_users_sid, users_sid_len );
+        sid = (struct sid *)(process_default_sd + 1);
+        sid = copy_sid( sid, &builtin_admins_sid );
+        sid = copy_sid( sid, &domain_users_sid );
 
-        dacl = (ACL *)((char *)(process_default_sd + 1) + admins_sid_len + users_sid_len);
-        dacl->AclRevision = ACL_REVISION;
-        dacl->Sbz1 = 0;
-        dacl->AclSize = dacl_len;
-        dacl->AceCount = 2;
-        dacl->Sbz2 = 0;
-        aaa = (ACCESS_ALLOWED_ACE *)(dacl + 1);
-        aaa->Header.AceType = ACCESS_ALLOWED_ACE_TYPE;
-        aaa->Header.AceFlags = INHERIT_ONLY_ACE | CONTAINER_INHERIT_ACE;
-        aaa->Header.AceSize = offsetof( ACCESS_ALLOWED_ACE, SidStart ) + users_sid_len;
-        aaa->Mask = GENERIC_READ;
-        memcpy( &aaa->SidStart, security_domain_users_sid, users_sid_len );
-        aaa = (ACCESS_ALLOWED_ACE *)((char *)aaa + aaa->Header.AceSize);
-        aaa->Header.AceType = ACCESS_ALLOWED_ACE_TYPE;
-        aaa->Header.AceFlags = 0;
-        aaa->Header.AceSize = offsetof( ACCESS_ALLOWED_ACE, SidStart ) + admins_sid_len;
-        aaa->Mask = PROCESS_ALL_ACCESS;
-        memcpy( &aaa->SidStart, security_builtin_admins_sid, admins_sid_len );
+        dacl = (struct acl *)((char *)(process_default_sd + 1) + admins_sid_len + users_sid_len);
+        dacl->revision = ACL_REVISION;
+        dacl->pad1     = 0;
+        dacl->size     = dacl_len;
+        dacl->count    = 2;
+        dacl->pad2     = 0;
+        ace = set_ace( ace_first( dacl ), &domain_users_sid, ACCESS_ALLOWED_ACE_TYPE,
+                       INHERIT_ONLY_ACE | CONTAINER_INHERIT_ACE, GENERIC_READ );
+        set_ace( ace_next( ace ), &builtin_admins_sid, ACCESS_ALLOWED_ACE_TYPE, 0, PROCESS_ALL_ACCESS );
     }
     return process_default_sd;
 }
@@ -1505,15 +1496,8 @@ DECL_HANDLER(get_process_info)
         reply->machine          = process->machine;
         if (get_reply_max_size())
         {
-            client_ptr_t base;
-            const pe_image_info_t *info;
-            struct memory_view *view = get_exe_view( process );
-            if (view)
-            {
-                if ((info = get_view_image_info( view, &base )))
-                    set_reply_data( info, min( sizeof(*info), get_reply_max_size() ));
-            }
-            else set_error( STATUS_PROCESS_IS_TERMINATING );
+            if (!process->running_threads) set_error( STATUS_PROCESS_IS_TERMINATING );
+            else set_reply_data( &process->image_info, min( sizeof(process->image_info), get_reply_max_size() ));
         }
         release_object( process );
     }
@@ -1528,7 +1512,7 @@ DECL_HANDLER(get_process_debug_info)
 
     reply->debug_children = process->debug_children;
     if (!process->debug_obj) set_error( STATUS_PORT_NOT_SET );
-    else reply->debug = alloc_handle( current->process, process->debug_obj, DEBUG_ALL_ACCESS, 0 );
+    else reply->debug = alloc_handle( current->process, process->debug_obj, MAXIMUM_ALLOWED, 0 );
     release_object( process );
 }
 
