@@ -46,34 +46,9 @@ int use_msvcrt = 0;
 int unix_lib = 0;
 int safe_seh = 0;
 int prefer_native = 0;
+int data_only = 0;
 
-#ifdef __i386__
-enum target_cpu target_cpu = CPU_x86;
-#elif defined(__x86_64__)
-enum target_cpu target_cpu = CPU_x86_64;
-#elif defined(__powerpc__)
-enum target_cpu target_cpu = CPU_POWERPC;
-#elif defined(__arm__)
-enum target_cpu target_cpu = CPU_ARM;
-#elif defined(__aarch64__)
-enum target_cpu target_cpu = CPU_ARM64;
-#else
-#error Unsupported CPU
-#endif
-
-#ifdef __APPLE__
-enum target_platform target_platform = PLATFORM_APPLE;
-#elif defined(__linux__)
-enum target_platform target_platform = PLATFORM_LINUX;
-#elif defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
-enum target_platform target_platform = PLATFORM_FREEBSD;
-#elif defined(__sun)
-enum target_platform target_platform = PLATFORM_SOLARIS;
-#elif defined(_WIN32)
-enum target_platform target_platform = PLATFORM_MINGW;
-#else
-enum target_platform target_platform = PLATFORM_UNSPECIFIED;
-#endif
+struct target target = { 0 };
 
 char *target_alias = NULL;
 
@@ -125,22 +100,6 @@ enum exec_mode_values
 
 static enum exec_mode_values exec_mode = MODE_NONE;
 
-static const struct
-{
-    const char *name;
-    enum target_platform platform;
-} platform_names[] =
-{
-    { "macos",       PLATFORM_APPLE },
-    { "darwin",      PLATFORM_APPLE },
-    { "linux",       PLATFORM_LINUX },
-    { "freebsd",     PLATFORM_FREEBSD },
-    { "solaris",     PLATFORM_SOLARIS },
-    { "mingw32",     PLATFORM_MINGW },
-    { "windows-gnu", PLATFORM_MINGW },
-    { "windows",     PLATFORM_WINDOWS },
-    { "winnt",       PLATFORM_MINGW }
-};
 
 /* set the dll file name from the input file name */
 static void set_dll_file_name( const char *name, DLLSPEC *spec )
@@ -210,54 +169,12 @@ static void set_syscall_table( const char *id, DLLSPEC *spec )
 }
 
 /* set the target CPU and platform */
-static void set_target( const char *target )
+static void set_target( const char *name )
 {
-    unsigned int i;
-    char *p, *spec = xstrdup( target );
+    target_alias = xstrdup( name );
 
-    /* target specification is in the form CPU-MANUFACTURER-OS or CPU-MANUFACTURER-KERNEL-OS */
-
-    target_alias = xstrdup( target );
-
-    /* get the CPU part */
-
-    if ((p = strchr( spec, '-' )))
-    {
-        int cpu;
-
-        *p++ = 0;
-        cpu = get_cpu_from_name( spec );
-        if (cpu == -1) fatal_error( "Unrecognized CPU '%s'\n", spec );
-        target_cpu = cpu;
-    }
-    else if (!strcmp( spec, "mingw32" ))
-    {
-        target_cpu = CPU_x86;
-        p = spec;
-    }
-    else
-        fatal_error( "Invalid target specification '%s'\n", target );
-
-    /* get the OS part */
-
-    target_platform = PLATFORM_UNSPECIFIED;  /* default value */
-    for (;;)
-    {
-        for (i = 0; i < ARRAY_SIZE(platform_names); i++)
-        {
-            if (!strncmp( platform_names[i].name, p, strlen(platform_names[i].name) ))
-            {
-                target_platform = platform_names[i].platform;
-                break;
-            }
-        }
-        if (target_platform != PLATFORM_UNSPECIFIED || !(p = strchr( p, '-' ))) break;
-        p++;
-    }
-
-    free( spec );
-
-    if (target_cpu == CPU_ARM && is_pe()) thumb_mode = 1;
+    if (!parse_target( name, &target )) fatal_error( "Unrecognized target '%s'\n", name );
+    if (target.cpu == CPU_ARM && is_pe()) thumb_mode = 1;
 }
 
 /* cleanup on program exit */
@@ -282,6 +199,7 @@ static const char usage_str[] =
 "   -b, --target=TARGET       Specify target CPU and platform for cross-compiling\n"
 "   -B PREFIX                 Look for build tools in the PREFIX directory\n"
 "       --cc-cmd=CC           C compiler to use for assembling (default: fall back to --as-cmd)\n"
+"       --data-only           Generate a data-only dll (i.e. without any executable code)\n"
 "   -d, --delay-lib=LIB       Import the specified library in delayed mode\n"
 "   -D SYM                    Ignored for C flags compatibility\n"
 "   -e, --entry=FUNC          Set the DLL entry point function (default: DllMain)\n"
@@ -335,6 +253,7 @@ enum long_options_values
     LONG_OPT_BUILTIN,
     LONG_OPT_ASCMD,
     LONG_OPT_CCCMD,
+    LONG_OPT_DATA_ONLY,
     LONG_OPT_EXTERNAL_SYMS,
     LONG_OPT_FAKE_MODULE,
     LONG_OPT_FIXUP_CTORS,
@@ -368,6 +287,7 @@ static const struct long_option long_options[] =
     /* other long options */
     { "as-cmd",              1, LONG_OPT_ASCMD },
     { "cc-cmd",              1, LONG_OPT_CCCMD },
+    { "data-only",           0, LONG_OPT_DATA_ONLY },
     { "external-symbols",    0, LONG_OPT_EXTERNAL_SYMS },
     { "fake-module",         0, LONG_OPT_FAKE_MODULE },
     { "large-address-aware", 0, LONG_OPT_LARGE_ADDRESS_AWARE },
@@ -567,6 +487,9 @@ static void option_callback( int optc, char *optarg )
     case LONG_OPT_CCCMD:
         cc_command = strarray_fromstring( optarg, " " );
         break;
+    case LONG_OPT_DATA_ONLY:
+        data_only = 1;
+        break;
     case LONG_OPT_FAKE_MODULE:
         fake_module = 1;
         break;
@@ -691,6 +614,9 @@ int main(int argc, char **argv)
     signal( SIGTERM, exit_on_signal );
     signal( SIGINT, exit_on_signal );
 
+    target = init_argv0_target( argv[0] );
+    if (target.platform == PLATFORM_CYGWIN) target.platform = PLATFORM_MINGW;
+
     files = parse_options( argc, argv, short_options, long_options, 0, option_callback );
 
     atexit( cleanup );  /* make sure we remove the output file on exit */
@@ -700,19 +626,7 @@ int main(int argc, char **argv)
         strcat( spec->file_name, exec_mode == MODE_EXE ? ".exe" : ".dll" );
     init_dll_name( spec );
 
-    switch (target_cpu)
-    {
-    case CPU_x86:
-        if (force_pointer_size == 8) target_cpu = CPU_x86_64;
-        break;
-    case CPU_x86_64:
-        if (force_pointer_size == 4) target_cpu = CPU_x86;
-        break;
-    default:
-        if (force_pointer_size == 8)
-            fatal_error( "Cannot build 64-bit code for this CPU\n" );
-        break;
-    }
+    if (force_pointer_size) set_target_ptr_size( &target, force_pointer_size );
 
     switch(exec_mode)
     {
@@ -730,6 +644,11 @@ int main(int argc, char **argv)
             output_fake_module( spec );
             break;
         }
+        if (data_only)
+        {
+            output_data_module( spec );
+            break;
+        }
         if (!is_pe())
         {
             files = load_import_libs( files );
