@@ -20,14 +20,11 @@
  */
 
 #include "config.h"
-#include "wine/port.h"
 
 #include <stdlib.h>
 #include <string.h>
 #include <assert.h>
 
-#include "windef.h"
-
 #include "winedump.h"
 
 #define MSFT_MAGIC 0x5446534d
@@ -260,7 +257,7 @@ static void print_guid(const char *name)
     print_offset();
 
     printf("%s = {%08x-%04x-%04x-%02x%02x-%02x%02x%02x%02x%02x%02x}\n", name,
-           guid.Data1, guid.Data2, guid.Data3, guid.Data4[0],
+           (unsigned int)guid.Data1, guid.Data2, guid.Data3, guid.Data4[0],
            guid.Data4[1], guid.Data4[2], guid.Data4[3], guid.Data4[4],
            guid.Data4[5], guid.Data4[6], guid.Data4[7]);
 }
@@ -1190,7 +1187,7 @@ static const char *decode_string(const BYTE *table, const char *stream, DWORD st
     table_size = *(const DWORD *)table;
     table += sizeof(DWORD);
 
-    buf = malloc(buf_size);
+    buf = xmalloc(buf_size);
     buf[0] = 0;
 
     while ((p = lookup_code(table, table_size, &bits)))
