@@ -171,6 +171,7 @@ struct options
     int nostartfiles;
     int nodefaultlibs;
     int noshortwchar;
+    int data_only;
     int unix_lib;
     int gui_app;
     int unicode_app;
@@ -657,8 +658,8 @@ static void init_argv0_dir( const char *argv0 )
 #elif defined (__FreeBSD__) || defined(__DragonFly__)
     static int pathname[] = { CTL_KERN, KERN_PROC, KERN_PROC_PATHNAME, -1 };
     size_t path_size = PATH_MAX;
-    char *path = malloc( path_size );
-    if (path && !sysctl( pathname, sizeof(pathname)/sizeof(pathname[0]), path, &path_size, NULL, 0 ))
+    char *path = xmalloc( path_size );
+    if (!sysctl( pathname, sizeof(pathname)/sizeof(pathname[0]), path, &path_size, NULL, 0 ))
         dir = realpath( path, NULL );
     free( path );
 #else
@@ -888,6 +889,8 @@ static struct strarray get_winebuild_args(struct options *opts)
         strarray_add( &spec_args, "--target" );
         strarray_add( &spec_args, opts->target_alias );
     }
+    if (opts->force_pointer_size)
+        strarray_add(&spec_args, strmake("-m%u", 8 * opts->force_pointer_size ));
     for (i = 0; i < opts->prefix.count; i++)
         strarray_add( &spec_args, strmake( "-B%s", opts->prefix.str[i] ));
     strarray_addall( &spec_args, opts->winebuild_args );
@@ -1016,8 +1019,6 @@ static const char *build_spec_obj( struct options *opts, const char *spec_file,
     }
 
     spec_o_name = get_temp_file(output_name, ".spec.o");
-    if (opts->force_pointer_size)
-        strarray_add(&spec_args, strmake("-m%u", 8 * opts->force_pointer_size ));
     if (opts->pic && !is_pe) strarray_add(&spec_args, "-fPIC");
     strarray_add(&spec_args, opts->shared ? "--dll" : "--exe");
     if (opts->fake_module)
@@ -1091,6 +1092,28 @@ static const char *build_spec_obj( struct options *opts, const char *spec_file,
     return spec_o_name;
 }
 
+/* run winebuild to generate a data-only library */
+static void build_data_lib( struct options *opts, const char *spec_file, const char *output_file, struct strarray files )
+{
+    unsigned int i;
+    struct strarray spec_args = get_winebuild_args( opts );
+
+    strarray_add(&spec_args, opts->shared ? "--dll" : "--exe");
+    strarray_add(&spec_args, "-o");
+    strarray_add(&spec_args, output_file);
+    if (spec_file)
+    {
+        strarray_add(&spec_args, "-E");
+        strarray_add(&spec_args, spec_file);
+    }
+
+    /* add resource files */
+    for (i = 0; i < files.count; i++)
+	if (files.str[i][1] == 'r') strarray_add(&spec_args, files.str[i]);
+
+    spawn(opts->prefix, spec_args, 0);
+}
+
 static void build(struct options* opts)
 {
     struct strarray lib_dirs = empty_strarray;
@@ -1114,7 +1137,7 @@ static void build(struct options* opts)
      *    -xlll:  lll is the language (c, c++, etc.)
      */
 
-    output_file = strdup( opts->output_name ? opts->output_name : "a.out" );
+    output_file = xstrdup( opts->output_name ? opts->output_name : "a.out" );
 
     /* 'winegcc -o app xxx.exe.so' only creates the load script */
     if (opts->files.count == 1 && strendswith(opts->files.str[0], ".exe.so"))
@@ -1246,6 +1269,11 @@ static void build(struct options* opts)
     else entry_point = opts->entry_point;
 
     /* run winebuild to generate the .spec.o file */
+    if (opts->data_only)
+    {
+        build_data_lib( opts, spec_file, output_file, files );
+        return;
+    }
     if (spec_file || !opts->unix_lib)
         spec_o_name = build_spec_obj( opts, spec_file, output_file, files, lib_dirs, entry_point );
 
@@ -1254,10 +1282,18 @@ static void build(struct options* opts)
     /* link everything together now */
     link_args = get_link_args( opts, output_name );
 
-    if ((opts->nodefaultlibs || opts->use_msvcrt) && opts->target.platform == PLATFORM_MINGW)
+    if (opts->nodefaultlibs || opts->use_msvcrt)
     {
-        libgcc = find_libgcc(opts->prefix, link_args);
-        if (!libgcc) libgcc = "-lgcc";
+        switch (opts->target.platform)
+        {
+        case PLATFORM_MINGW:
+        case PLATFORM_CYGWIN:
+            libgcc = find_libgcc( opts->prefix, link_args );
+            if (!libgcc) libgcc = "-lgcc";
+            break;
+        default:
+            break;
+        }
     }
 
     strarray_add(&link_args, "-o");
@@ -1640,7 +1676,7 @@ int main(int argc, char **argv)
             switch (opts.args.str[i][1])
 	    {
 		case 'B':
-		    str = strdup(option_arg);
+		    str = xstrdup(option_arg);
 		    if (strendswith(str, "/")) str[strlen(str) - 1] = 0;
                     strarray_add(&opts.prefix, str);
                     raw_linker_arg = 1;
@@ -1816,17 +1852,17 @@ int main(int argc, char **argv)
                         {
                             if (!strcmp(Wl.str[j], "--image-base") && j < Wl.count - 1)
                             {
-                                opts.image_base = strdup( Wl.str[++j] );
+                                opts.image_base = xstrdup( Wl.str[++j] );
                                 continue;
                             }
                             if (!strcmp(Wl.str[j], "--section-alignment") && j < Wl.count - 1)
                             {
-                                opts.section_align = strdup( Wl.str[++j] );
+                                opts.section_align = xstrdup( Wl.str[++j] );
                                 continue;
                             }
                             if (!strcmp(Wl.str[j], "--file-alignment") && j < Wl.count - 1)
                             {
-                                opts.file_align = strdup( Wl.str[++j] );
+                                opts.file_align = xstrdup( Wl.str[++j] );
                                 continue;
                             }
                             if (!strcmp(Wl.str[j], "--large-address-aware"))
@@ -1841,12 +1877,12 @@ int main(int argc, char **argv)
                             }
                             if (!strcmp(Wl.str[j], "--subsystem") && j < Wl.count - 1)
                             {
-                                opts.subsystem = strdup( Wl.str[++j] );
+                                opts.subsystem = xstrdup( Wl.str[++j] );
                                 continue;
                             }
                             if (!strcmp(Wl.str[j], "--entry") && j < Wl.count - 1)
                             {
-                                opts.entry_point = strdup( Wl.str[++j] );
+                                opts.entry_point = xstrdup( Wl.str[++j] );
                                 continue;
                             }
                             if (!strcmp(Wl.str[j], "-delayload") && j < Wl.count - 1)
@@ -1856,7 +1892,7 @@ int main(int argc, char **argv)
                             }
                             if (!strcmp(Wl.str[j], "--debug-file") && j < Wl.count - 1)
                             {
-                                opts.debug_file = strdup( Wl.str[++j] );
+                                opts.debug_file = xstrdup( Wl.str[++j] );
                                 continue;
                             }
                             if (!strcmp(Wl.str[j], "--whole-archive") ||
@@ -1869,7 +1905,7 @@ int main(int argc, char **argv)
                             }
                             if (!strcmp(Wl.str[j], "--out-implib"))
                             {
-                                opts.out_implib = strdup( Wl.str[++j] );
+                                opts.out_implib = xstrdup( Wl.str[++j] );
                                 continue;
                             }
                             if (!strcmp(Wl.str[j], "-static")) linking = -1;
@@ -1883,6 +1919,7 @@ int main(int argc, char **argv)
                         struct strarray Wb = strarray_fromstring(opts.args.str[i] + 4, ",");
                         for (j = 0; j < Wb.count; j++)
                         {
+                            if (!strcmp(Wb.str[j], "--data-only")) opts.data_only = 1;
                             if (!strcmp(Wb.str[j], "--fake-module")) opts.fake_module = 1;
                             else strarray_add( &opts.winebuild_args, Wb.str[j] );
                         }
